// Number of generated types: 338
// Number of generated members: 2889

// <Header>
using System;
using System.Reflection;
using System.Runtime.CompilerServices;
using System.Runtime.InteropServices;

namespace NativeGeneratedCode;


// </Header>
// <Shared Code>
internal class __BeyondNETNativeModuleInitializer
{
    [System.Runtime.CompilerServices.ModuleInitializer]
    internal static unsafe void BeyondNETNativeModuleInitializer()
    {
        // TODO: We could probably remove the native implementation if we port it to C# by using DllImport's for CoreFoundation stuff
         
        const string dnLibraryInitFuncName = "_DNLibraryInit";

        var selfHandle = System.Runtime.InteropServices.NativeLibrary.GetMainProgramHandle();

        if (selfHandle == IntPtr.Zero) {
            return;
        }

        bool getExportSuccess = System.Runtime.InteropServices.NativeLibrary.TryGetExport(
            selfHandle,
            dnLibraryInitFuncName,
            out IntPtr dnLibraryInitSymbol
        );

        if (!getExportSuccess ||
            dnLibraryInitSymbol == IntPtr.Zero) {
            return;
        }
    
        delegate* unmanaged<void> dnLibraryInitFunc = (delegate* unmanaged<void>)dnLibraryInitSymbol;

        dnLibraryInitFunc();
    }
}

internal unsafe class NativeDelegateBox<TDelegateType, TFunctionPointerType>
    where TDelegateType: Delegate
    where TFunctionPointerType: unmanaged
{
    internal TDelegateType Trampoline { get; }
    internal void* Context { get; }
    internal TFunctionPointerType FunctionPointer { get; }

    internal NativeDelegateBox(
        TDelegateType trampoline,
        void* context,
        TFunctionPointerType? functionPointer
    )
    {
        Trampoline = trampoline ?? throw new ArgumentNullException(nameof(trampoline));
        Context = context is not null ? context : throw new ArgumentNullException(nameof(context));
        FunctionPointer = functionPointer ?? throw new ArgumentNullException(nameof(functionPointer));
    }
}

internal static unsafe class InteropUtils
{
    #region Allocation
    internal static GCHandle AllocateGCHandle(this object instance, GCHandleType handleType)
    {
        GCHandle handle = GCHandle.Alloc(instance, handleType);

        return handle;
    }
    
    internal static void* AllocateGCHandleAndGetAddress(this object? instance)
    {
        if (instance is null) {
            return null;
        }
        
        GCHandle handle = instance.AllocateGCHandle(GCHandleType.Normal);
        void* handleAddress = handle.ToHandleAddress();

        return handleAddress;
    }
    #endregion Allocation

    #region Free
    internal static void FreeIfAllocated(void* handleAddress)
    {
        if (handleAddress is null) {
            return;
        }

        GCHandle? handle = GetGCHandle(handleAddress);
        
        handle?.FreeIfAllocated();
    }

    internal static void CheckedFreeIfAllocated<T>(void* handleAddress)
    {
        if (handleAddress is null) {
            return;
        }

        GCHandle? handle = GetGCHandle(handleAddress);

        if (handle is null) {
            return;
        }

        object? target = handle?.Target;

        if (target is not null &&
            !(target is T)) {
            throw new Exception("Type of handle is unexpected");
        }
        
        handle?.FreeIfAllocated();
    }
    
    internal static void FreeIfAllocated(this GCHandle handle)
    {
        if (!handle.IsAllocated) {
            return;
        }

        handle.Free();
    }
    #endregion Free

    #region Handle Address/GCHandle <-> Object Conversion
    internal static void* ToHandleAddress(this GCHandle handle)
    {
        void* handleAddress = (void*)GCHandle.ToIntPtr(handle);

        return handleAddress;
    }

    internal static GCHandle? GetGCHandle(void* handleAddress)
    {
        if (handleAddress is null) {
            return null;
        }
        
        GCHandle handle = GCHandle.FromIntPtr((nint)handleAddress);

        return handle;
    }

    internal static T? GetInstance<T>(void* handleAddress)
    {
        GCHandle? handle = GetGCHandle(handleAddress);

        object? target = handle?.Target;

        if (target is null) {
            return default;
        }

        T instance = (T)target;

        return instance;
    }

    internal static void ReplaceInstance(void* handleAddress, object? newInstance)
    {
        GCHandle? maybeHandle = GetGCHandle(handleAddress);

        if (!maybeHandle.HasValue) {
            return;
        }

        GCHandle handle = maybeHandle.Value;
        
        handle.Target = newInstance;
    }
    #endregion Handle Address/GCHandle <-> Object Conversion

    #region Type Conversion
    [UnmanagedCallersOnly(EntryPoint = "DNObjectCastTo")]
    internal static void* /* System.Object */ DNObjectCastTo(void* /* System.Object */ @object, void* /* System.Type */ type, void** /* out System.Exception */ outException)
    {
        System.Object objectConverted = InteropUtils.GetInstance<System.Object>(@object);
        System.Type typeConverted = InteropUtils.GetInstance<System.Type>(type);
    
        try {
	        System.Type currentType = objectConverted.GetType();
	        bool isValidCast = currentType.IsAssignableTo(typeConverted);

	        if (!isValidCast) {
		        throw new InvalidCastException();
	        }
    
            if (outException is not null) {
                *outException = null;
            }
    
            return objectConverted.AllocateGCHandleAndGetAddress();
        } catch (Exception exception) {
            if (outException is not null) {
                void* exceptionHandleAddress = exception.AllocateGCHandleAndGetAddress();
                    
                *outException = exceptionHandleAddress;
            }
    
            return null;
        }
    }

    [UnmanagedCallersOnly(EntryPoint = "DNObjectCastAs")]
    internal static void* /* System.Object */ DNObjectCastAs(void* /* System.Object */ @object, void* /* System.Type */ type)
    {
        System.Object objectConverted = InteropUtils.GetInstance<System.Object>(@object);
        System.Type typeConverted = InteropUtils.GetInstance<System.Type>(type);
    
        try {
	        System.Type currentType = objectConverted.GetType();
	        bool isValidCast = currentType.IsAssignableTo(typeConverted);

	        if (!isValidCast) {
		        return null;
	        }
    
            return objectConverted.AllocateGCHandleAndGetAddress();
        } catch {
            return null;
        }
    }

    [UnmanagedCallersOnly(EntryPoint = "DNObjectIs")]
    internal static byte DNObjectIs(void* /* System.Object */ @object, void* /* System.Type */ type)
    {
        System.Object objectConverted = InteropUtils.GetInstance<System.Object>(@object);
        System.Type typeConverted = InteropUtils.GetInstance<System.Type>(type);
    
        try {
	        System.Type currentType = objectConverted.GetType();
	        bool isValidCast = currentType.IsAssignableTo(typeConverted);

            return isValidCast.ToCBool();
        } catch {
            return false.ToCBool();
        }
    }
    #endregion Type Conversion

    #region Strings
    /// <summary>
    /// This allocates a native char* and copies the contents of the managed string into it.
    /// The allocated native string must be freed when not needed anymore!
    /// </summary>
    [UnmanagedCallersOnly(EntryPoint = "DNStringToC")]
    internal static byte* DNStringToC(void* /* System.String? */ systemString)
    {
        if (systemString is null) {
            return null;
        }

        System.String? systemStringConverted = InteropUtils.GetInstance<System.String>(systemString);

        if (systemStringConverted is null) {
            return null;
        }

        byte* cString = (byte*)Marshal.StringToHGlobalAuto(systemStringConverted);
        
        return cString;
    }

    /// <summary>
    /// This allocates a managed string and copies the contents of the native char* into it.
    /// </summary>
    [UnmanagedCallersOnly(EntryPoint = "DNStringFromC")]
    internal static void* /* System.String? */ DNStringFromC(byte* cString)
    {
        if (cString is null) {
            return null;
        }
        
        System.String? systemString = Marshal.PtrToStringAuto((nint)cString);

        if (systemString is null) {
            return null;
        }
        
        void* systemStringNative = systemString.AllocateGCHandleAndGetAddress();

        return systemStringNative;
    }
    #endregion Strings

    #region Bools
    internal static byte ToCBool(this bool @bool)
    {
        if (@bool) {
            return 1;
        } else {
            return 0;
        }
    }

    public static bool ToBool(this byte cBool)
    {
        return cBool == 1;
    }
    #endregion Bools

    #region Boxing/Unboxing of primitives
    #region Bool
    [UnmanagedCallersOnly(EntryPoint = "DNObjectCastToBool")]
    internal static byte DNObjectCastToBool(void* /* System.Object */ @object, void** /* out System.Exception */ outException)
    {
        System.Object objectConverted = InteropUtils.GetInstance<System.Object>(@object);
    
        try {
            bool returnValue = (bool)objectConverted;
    
            if (outException is not null) {
                *outException = null;
            }
    
            return returnValue.ToCBool();
        } catch (Exception exception) {
            if (outException is not null) {
                void* exceptionHandleAddress = exception.AllocateGCHandleAndGetAddress();
                    
                *outException = exceptionHandleAddress;
            }
    
            return default(bool).ToCBool();
        }
    }
    
    [UnmanagedCallersOnly(EntryPoint = "DNObjectFromBool")]
    internal static void* /* System.Object */ DNObjectFromBool(byte value)
    {
        return ((System.Object)value.ToBool()).AllocateGCHandleAndGetAddress();
    }
    #endregion Bool
    
    #region Float
    [UnmanagedCallersOnly(EntryPoint = "DNObjectCastToFloat")]
    internal static float DNObjectCastToFloat(void* /* System.Object */ @object, void** /* out System.Exception */ outException)
    {
        System.Object objectConverted = InteropUtils.GetInstance<System.Object>(@object);
    
        try {
            float returnValue = (float)objectConverted;
    
            if (outException is not null) {
                *outException = null;
            }
    
            return returnValue;
        } catch (Exception exception) {
            if (outException is not null) {
                void* exceptionHandleAddress = exception.AllocateGCHandleAndGetAddress();
                    
                *outException = exceptionHandleAddress;
            }
    
            return default(float);
        }
    }
    
    [UnmanagedCallersOnly(EntryPoint = "DNObjectFromFloat")]
    internal static void* /* System.Object */ DNObjectFromFloat(float number)
    {
        return ((System.Object)number).AllocateGCHandleAndGetAddress();
    }
    #endregion Float

    #region Double
    [UnmanagedCallersOnly(EntryPoint = "DNObjectCastToDouble")]
    internal static double DNObjectCastToDouble(void* /* System.Object */ @object, void** /* out System.Exception */ outException)
    {
        System.Object objectConverted = InteropUtils.GetInstance<System.Object>(@object);
    
        try {
            double returnValue = (double)objectConverted;
    
            if (outException is not null) {
                *outException = null;
            }
    
            return returnValue;
        } catch (Exception exception) {
            if (outException is not null) {
                void* exceptionHandleAddress = exception.AllocateGCHandleAndGetAddress();
                    
                *outException = exceptionHandleAddress;
            }
    
            return default(double);
        }
    }
    
    [UnmanagedCallersOnly(EntryPoint = "DNObjectFromDouble")]
    internal static void* /* System.Object */ DNObjectFromDouble(double number)
    {
        return ((System.Object)number).AllocateGCHandleAndGetAddress();
    }
    #endregion Double

    #region Int8
    [UnmanagedCallersOnly(EntryPoint = "DNObjectCastToInt8")]
    internal static sbyte DNObjectCastToInt8(void* /* System.Object */ @object, void** /* out System.Exception */ outException)
    {
        System.Object objectConverted = InteropUtils.GetInstance<System.Object>(@object);
    
        try {
            sbyte returnValue = (sbyte)objectConverted;
    
            if (outException is not null) {
                *outException = null;
            }
    
            return returnValue;
        } catch (Exception exception) {
            if (outException is not null) {
                void* exceptionHandleAddress = exception.AllocateGCHandleAndGetAddress();
                    
                *outException = exceptionHandleAddress;
            }
    
            return default(sbyte);
        }
    }
    
    [UnmanagedCallersOnly(EntryPoint = "DNObjectFromInt8")]
    internal static void* /* System.Object */ DNObjectFromInt8(sbyte number)
    {
        return ((System.Object)number).AllocateGCHandleAndGetAddress();
    }
    #endregion Int8
    
    #region UInt8
    [UnmanagedCallersOnly(EntryPoint = "DNObjectCastToUInt8")]
    internal static byte DNObjectCastToUInt8(void* /* System.Object */ @object, void** /* out System.Exception */ outException)
    {
        System.Object objectConverted = InteropUtils.GetInstance<System.Object>(@object);
    
        try {
            byte returnValue = (byte)objectConverted;
    
            if (outException is not null) {
                *outException = null;
            }
    
            return returnValue;
        } catch (Exception exception) {
            if (outException is not null) {
                void* exceptionHandleAddress = exception.AllocateGCHandleAndGetAddress();
                    
                *outException = exceptionHandleAddress;
            }
    
            return default(byte);
        }
    }
    
    [UnmanagedCallersOnly(EntryPoint = "DNObjectFromUInt8")]
    internal static void* /* System.Object */ DNObjectFromUInt8(byte number)
    {
        return ((System.Object)number).AllocateGCHandleAndGetAddress();
    }
    #endregion UInt8

    #region Int16
    [UnmanagedCallersOnly(EntryPoint = "DNObjectCastToInt16")]
    internal static Int16 DNObjectCastToInt16(void* /* System.Object */ @object, void** /* out System.Exception */ outException)
    {
        System.Object objectConverted = InteropUtils.GetInstance<System.Object>(@object);
    
        try {
            Int16 returnValue = (Int16)objectConverted;
    
            if (outException is not null) {
                *outException = null;
            }
    
            return returnValue;
        } catch (Exception exception) {
            if (outException is not null) {
                void* exceptionHandleAddress = exception.AllocateGCHandleAndGetAddress();
                    
                *outException = exceptionHandleAddress;
            }
    
            return default(Int16);
        }
    }
    
    [UnmanagedCallersOnly(EntryPoint = "DNObjectFromInt16")]
    internal static void* /* System.Object */ DNObjectFromInt16(Int16 number)
    {
        return ((System.Object)number).AllocateGCHandleAndGetAddress();
    }
    #endregion Int16
    
    #region UInt16
    [UnmanagedCallersOnly(EntryPoint = "DNObjectCastToUInt16")]
    internal static UInt16 DNObjectCastToUInt16(void* /* System.Object */ @object, void** /* out System.Exception */ outException)
    {
        System.Object objectConverted = InteropUtils.GetInstance<System.Object>(@object);
    
        try {
            UInt16 returnValue = (UInt16)objectConverted;
    
            if (outException is not null) {
                *outException = null;
            }
    
            return returnValue;
        } catch (Exception exception) {
            if (outException is not null) {
                void* exceptionHandleAddress = exception.AllocateGCHandleAndGetAddress();
                    
                *outException = exceptionHandleAddress;
            }
    
            return default(UInt16);
        }
    }
    
    [UnmanagedCallersOnly(EntryPoint = "DNObjectFromUInt16")]
    internal static void* /* System.Object */ DNObjectFromUInt16(UInt16 number)
    {
        return ((System.Object)number).AllocateGCHandleAndGetAddress();
    }
    #endregion UInt16

    #region Int32
    [UnmanagedCallersOnly(EntryPoint = "DNObjectCastToInt32")]
    internal static Int32 DNObjectCastToInt32(void* /* System.Object */ @object, void** /* out System.Exception */ outException)
    {
        System.Object objectConverted = InteropUtils.GetInstance<System.Object>(@object);
    
        try {
	        Int32 returnValue = (Int32)objectConverted;
    
            if (outException is not null) {
                *outException = null;
            }
    
            return returnValue;
        } catch (Exception exception) {
            if (outException is not null) {
                void* exceptionHandleAddress = exception.AllocateGCHandleAndGetAddress();
                    
                *outException = exceptionHandleAddress;
            }
    
            return default(Int32);
        }
    }

    [UnmanagedCallersOnly(EntryPoint = "DNObjectFromInt32")]
    internal static void* /* System.Object */ DNObjectFromInt32(Int32 number)
    {
        return ((System.Object)number).AllocateGCHandleAndGetAddress();
    }
    #endregion Int32
    
    #region UInt32
    [UnmanagedCallersOnly(EntryPoint = "DNObjectCastToUInt32")]
    internal static UInt32 DNObjectCastToUInt32(void* /* System.Object */ @object, void** /* out System.Exception */ outException)
    {
        System.Object objectConverted = InteropUtils.GetInstance<System.Object>(@object);
    
        try {
	        UInt32 returnValue = (UInt32)objectConverted;
    
            if (outException is not null) {
                *outException = null;
            }
    
            return returnValue;
        } catch (Exception exception) {
            if (outException is not null) {
                void* exceptionHandleAddress = exception.AllocateGCHandleAndGetAddress();
                    
                *outException = exceptionHandleAddress;
            }
    
            return default(UInt32);
        }
    }

    [UnmanagedCallersOnly(EntryPoint = "DNObjectFromUInt32")]
    internal static void* /* System.Object */ DNObjectFromUInt32(UInt32 number)
    {
        return ((System.Object)number).AllocateGCHandleAndGetAddress();
    }
    #endregion UInt32

    #region Int64
    [UnmanagedCallersOnly(EntryPoint = "DNObjectCastToInt64")]
    internal static Int64 DNObjectCastToInt64(void* /* System.Object */ @object, void** /* out System.Exception */ outException)
    {
        System.Object objectConverted = InteropUtils.GetInstance<System.Object>(@object);
    
        try {
            Int64 returnValue = (Int64)objectConverted;
    
            if (outException is not null) {
                *outException = null;
            }
    
            return returnValue;
        } catch (Exception exception) {
            if (outException is not null) {
                void* exceptionHandleAddress = exception.AllocateGCHandleAndGetAddress();
                    
                *outException = exceptionHandleAddress;
            }
    
            return default(Int64);
        }
    }

    [UnmanagedCallersOnly(EntryPoint = "DNObjectFromInt64")]
    internal static void* /* System.Object */ DNObjectFromInt64(Int64 number)
    {
        return ((System.Object)number).AllocateGCHandleAndGetAddress();
    }
    #endregion Int64
    
    #region UInt64
    [UnmanagedCallersOnly(EntryPoint = "DNObjectCastToUInt64")]
    internal static UInt64 DNObjectCastToUInt64(void* /* System.Object */ @object, void** /* out System.Exception */ outException)
    {
        System.Object objectConverted = InteropUtils.GetInstance<System.Object>(@object);
    
        try {
            UInt64 returnValue = (UInt64)objectConverted;
    
            if (outException is not null) {
                *outException = null;
            }
    
            return returnValue;
        } catch (Exception exception) {
            if (outException is not null) {
                void* exceptionHandleAddress = exception.AllocateGCHandleAndGetAddress();
                    
                *outException = exceptionHandleAddress;
            }
    
            return default(UInt64);
        }
    }

    [UnmanagedCallersOnly(EntryPoint = "DNObjectFromUInt64")]
    internal static void* /* System.Object */ DNObjectFromUInt64(UInt64 number)
    {
        return ((System.Object)number).AllocateGCHandleAndGetAddress();
    }
    #endregion UInt64
    #endregion Boxing/Unboxing of primitives
}

// </Shared Code>
// <Unsupported Types>
// Omitted due to settings

// </Unsupported Types>
// <APIs>
internal unsafe class System_Object
{
	[UnmanagedCallersOnly(EntryPoint = "System_Object_GetType")]
	internal static void* /* System.Type */ System_Object_GetType(void* /* System.Object */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Object __selfConverted = InteropUtils.GetInstance<System.Object>(__self);
	
	
	    try {
			System.Type __returnValue = __selfConverted.GetType();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Object_ToString")]
	internal static void* /* System.String */ System_Object_ToString(void* /* System.Object */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Object __selfConverted = InteropUtils.GetInstance<System.Object>(__self);
	
	
	    try {
			System.String __returnValue = __selfConverted.ToString();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Object_Equals")]
	internal static byte /* System.Boolean */ System_Object_Equals(void* /* System.Object */ __self, void* /* System.Object */ obj, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Object __selfConverted = InteropUtils.GetInstance<System.Object>(__self);
	
		System.Object objConverted = InteropUtils.GetInstance<System.Object>(obj);
	
	    try {
			System.Boolean __returnValue = __selfConverted.Equals(objConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Object_Equals_1")]
	internal static byte /* System.Boolean */ System_Object_Equals_1(void* /* System.Object */ objA, void* /* System.Object */ objB, void** /* System.Exception */ __outException)
	{
		System.Object objAConverted = InteropUtils.GetInstance<System.Object>(objA);
		System.Object objBConverted = InteropUtils.GetInstance<System.Object>(objB);
	
	    try {
			System.Boolean __returnValue = System.Object.Equals(objAConverted, objBConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Object_ReferenceEquals")]
	internal static byte /* System.Boolean */ System_Object_ReferenceEquals(void* /* System.Object */ objA, void* /* System.Object */ objB, void** /* System.Exception */ __outException)
	{
		System.Object objAConverted = InteropUtils.GetInstance<System.Object>(objA);
		System.Object objBConverted = InteropUtils.GetInstance<System.Object>(objB);
	
	    try {
			System.Boolean __returnValue = System.Object.ReferenceEquals(objAConverted, objBConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Object_GetHashCode")]
	internal static int /* System.Int32 */ System_Object_GetHashCode(void* /* System.Object */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Object __selfConverted = InteropUtils.GetInstance<System.Object>(__self);
	
	
	    try {
			System.Int32 __returnValue = __selfConverted.GetHashCode();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Object_Create")]
	internal static void* /* System.Object */ System_Object_Create(void** /* System.Exception */ __outException)
	{
	
	    try {
			System.Object __returnValue = new System.Object();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Object_TypeOf")]
	internal static void* /* System.Type */ System_Object_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.Object);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Object_Destroy")]
	internal static void /* System.Void */ System_Object_Destroy(void* /* System.Object */ __self)
	{
	
		InteropUtils.FreeIfAllocated(__self);
	}
	
}


internal unsafe class System_Type
{
	[UnmanagedCallersOnly(EntryPoint = "System_Type_GetType")]
	internal static void* /* System.Type */ System_Type_GetType(void* /* System.String */ typeName, byte /* System.Boolean */ throwOnError, byte /* System.Boolean */ ignoreCase, void** /* System.Exception */ __outException)
	{
		System.String typeNameConverted = InteropUtils.GetInstance<System.String>(typeName);
		System.Boolean throwOnErrorConverted = throwOnError.ToBool();
		System.Boolean ignoreCaseConverted = ignoreCase.ToBool();
	
	    try {
			System.Type __returnValue = System.Type.GetType(typeNameConverted, throwOnErrorConverted, ignoreCaseConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_GetType_1")]
	internal static void* /* System.Type */ System_Type_GetType_1(void* /* System.String */ typeName, byte /* System.Boolean */ throwOnError, void** /* System.Exception */ __outException)
	{
		System.String typeNameConverted = InteropUtils.GetInstance<System.String>(typeName);
		System.Boolean throwOnErrorConverted = throwOnError.ToBool();
	
	    try {
			System.Type __returnValue = System.Type.GetType(typeNameConverted, throwOnErrorConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_GetType_2")]
	internal static void* /* System.Type */ System_Type_GetType_2(void* /* System.String */ typeName, void** /* System.Exception */ __outException)
	{
		System.String typeNameConverted = InteropUtils.GetInstance<System.String>(typeName);
	
	    try {
			System.Type __returnValue = System.Type.GetType(typeNameConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_GetTypeFromHandle")]
	internal static void* /* System.Type */ System_Type_GetTypeFromHandle(void* /* System.RuntimeTypeHandle */ handle, void** /* System.Exception */ __outException)
	{
		System.RuntimeTypeHandle handleConverted = InteropUtils.GetInstance<System.RuntimeTypeHandle>(handle);
	
	    try {
			System.Type __returnValue = System.Type.GetTypeFromHandle(handleConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_GetType_3")]
	internal static void* /* System.Type */ System_Type_GetType_3(void* /* System.Type */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Type __selfConverted = InteropUtils.GetInstance<System.Type>(__self);
	
	
	    try {
			System.Type __returnValue = __selfConverted.GetType();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_GetElementType")]
	internal static void* /* System.Type */ System_Type_GetElementType(void* /* System.Type */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Type __selfConverted = InteropUtils.GetInstance<System.Type>(__self);
	
	
	    try {
			System.Type __returnValue = __selfConverted.GetElementType();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_GetArrayRank")]
	internal static int /* System.Int32 */ System_Type_GetArrayRank(void* /* System.Type */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Type __selfConverted = InteropUtils.GetInstance<System.Type>(__self);
	
	
	    try {
			System.Int32 __returnValue = __selfConverted.GetArrayRank();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_GetGenericTypeDefinition")]
	internal static void* /* System.Type */ System_Type_GetGenericTypeDefinition(void* /* System.Type */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Type __selfConverted = InteropUtils.GetInstance<System.Type>(__self);
	
	
	    try {
			System.Type __returnValue = __selfConverted.GetGenericTypeDefinition();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_GetGenericArguments")]
	internal static void* /* System.Type[] */ System_Type_GetGenericArguments(void* /* System.Type */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Type __selfConverted = InteropUtils.GetInstance<System.Type>(__self);
	
	
	    try {
			System.Type[] __returnValue = __selfConverted.GetGenericArguments();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_GetOptionalCustomModifiers")]
	internal static void* /* System.Type[] */ System_Type_GetOptionalCustomModifiers(void* /* System.Type */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Type __selfConverted = InteropUtils.GetInstance<System.Type>(__self);
	
	
	    try {
			System.Type[] __returnValue = __selfConverted.GetOptionalCustomModifiers();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_GetRequiredCustomModifiers")]
	internal static void* /* System.Type[] */ System_Type_GetRequiredCustomModifiers(void* /* System.Type */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Type __selfConverted = InteropUtils.GetInstance<System.Type>(__self);
	
	
	    try {
			System.Type[] __returnValue = __selfConverted.GetRequiredCustomModifiers();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_GetGenericParameterConstraints")]
	internal static void* /* System.Type[] */ System_Type_GetGenericParameterConstraints(void* /* System.Type */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Type __selfConverted = InteropUtils.GetInstance<System.Type>(__self);
	
	
	    try {
			System.Type[] __returnValue = __selfConverted.GetGenericParameterConstraints();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_IsAssignableTo")]
	internal static byte /* System.Boolean */ System_Type_IsAssignableTo(void* /* System.Type */ __self, void* /* System.Type */ targetType, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Type __selfConverted = InteropUtils.GetInstance<System.Type>(__self);
	
		System.Type targetTypeConverted = InteropUtils.GetInstance<System.Type>(targetType);
	
	    try {
			System.Boolean __returnValue = __selfConverted.IsAssignableTo(targetTypeConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_GetConstructor")]
	internal static void* /* System.Reflection.ConstructorInfo */ System_Type_GetConstructor(void* /* System.Type */ __self, void* /* System.Type[] */ types, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Type __selfConverted = InteropUtils.GetInstance<System.Type>(__self);
	
		System.Type[] typesConverted = InteropUtils.GetInstance<System.Type[]>(types);
	
	    try {
			System.Reflection.ConstructorInfo __returnValue = __selfConverted.GetConstructor(typesConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_GetConstructor_1")]
	internal static void* /* System.Reflection.ConstructorInfo */ System_Type_GetConstructor_1(void* /* System.Type */ __self, System.Reflection.BindingFlags /* System.Reflection.BindingFlags */ bindingAttr, void* /* System.Type[] */ types, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Type __selfConverted = InteropUtils.GetInstance<System.Type>(__self);
	
		System.Type[] typesConverted = InteropUtils.GetInstance<System.Type[]>(types);
	
	    try {
			System.Reflection.ConstructorInfo __returnValue = __selfConverted.GetConstructor(bindingAttr, typesConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_GetConstructor_2")]
	internal static void* /* System.Reflection.ConstructorInfo */ System_Type_GetConstructor_2(void* /* System.Type */ __self, System.Reflection.BindingFlags /* System.Reflection.BindingFlags */ bindingAttr, void* /* System.Reflection.Binder */ binder, void* /* System.Type[] */ types, void* /* System.Reflection.ParameterModifier[] */ modifiers, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Type __selfConverted = InteropUtils.GetInstance<System.Type>(__self);
	
		System.Reflection.Binder binderConverted = InteropUtils.GetInstance<System.Reflection.Binder>(binder);
		System.Type[] typesConverted = InteropUtils.GetInstance<System.Type[]>(types);
		System.Reflection.ParameterModifier[] modifiersConverted = InteropUtils.GetInstance<System.Reflection.ParameterModifier[]>(modifiers);
	
	    try {
			System.Reflection.ConstructorInfo __returnValue = __selfConverted.GetConstructor(bindingAttr, binderConverted, typesConverted, modifiersConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_GetConstructor_3")]
	internal static void* /* System.Reflection.ConstructorInfo */ System_Type_GetConstructor_3(void* /* System.Type */ __self, System.Reflection.BindingFlags /* System.Reflection.BindingFlags */ bindingAttr, void* /* System.Reflection.Binder */ binder, System.Reflection.CallingConventions /* System.Reflection.CallingConventions */ callConvention, void* /* System.Type[] */ types, void* /* System.Reflection.ParameterModifier[] */ modifiers, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Type __selfConverted = InteropUtils.GetInstance<System.Type>(__self);
	
		System.Reflection.Binder binderConverted = InteropUtils.GetInstance<System.Reflection.Binder>(binder);
		System.Type[] typesConverted = InteropUtils.GetInstance<System.Type[]>(types);
		System.Reflection.ParameterModifier[] modifiersConverted = InteropUtils.GetInstance<System.Reflection.ParameterModifier[]>(modifiers);
	
	    try {
			System.Reflection.ConstructorInfo __returnValue = __selfConverted.GetConstructor(bindingAttr, binderConverted, callConvention, typesConverted, modifiersConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_GetConstructors")]
	internal static void* /* System.Reflection.ConstructorInfo[] */ System_Type_GetConstructors(void* /* System.Type */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Type __selfConverted = InteropUtils.GetInstance<System.Type>(__self);
	
	
	    try {
			System.Reflection.ConstructorInfo[] __returnValue = __selfConverted.GetConstructors();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_GetConstructors_1")]
	internal static void* /* System.Reflection.ConstructorInfo[] */ System_Type_GetConstructors_1(void* /* System.Type */ __self, System.Reflection.BindingFlags /* System.Reflection.BindingFlags */ bindingAttr, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Type __selfConverted = InteropUtils.GetInstance<System.Type>(__self);
	
	
	    try {
			System.Reflection.ConstructorInfo[] __returnValue = __selfConverted.GetConstructors(bindingAttr);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_GetEvent")]
	internal static void* /* System.Reflection.EventInfo */ System_Type_GetEvent(void* /* System.Type */ __self, void* /* System.String */ name, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Type __selfConverted = InteropUtils.GetInstance<System.Type>(__self);
	
		System.String nameConverted = InteropUtils.GetInstance<System.String>(name);
	
	    try {
			System.Reflection.EventInfo __returnValue = __selfConverted.GetEvent(nameConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_GetEvent_1")]
	internal static void* /* System.Reflection.EventInfo */ System_Type_GetEvent_1(void* /* System.Type */ __self, void* /* System.String */ name, System.Reflection.BindingFlags /* System.Reflection.BindingFlags */ bindingAttr, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Type __selfConverted = InteropUtils.GetInstance<System.Type>(__self);
	
		System.String nameConverted = InteropUtils.GetInstance<System.String>(name);
	
	    try {
			System.Reflection.EventInfo __returnValue = __selfConverted.GetEvent(nameConverted, bindingAttr);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_GetEvents")]
	internal static void* /* System.Reflection.EventInfo[] */ System_Type_GetEvents(void* /* System.Type */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Type __selfConverted = InteropUtils.GetInstance<System.Type>(__self);
	
	
	    try {
			System.Reflection.EventInfo[] __returnValue = __selfConverted.GetEvents();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_GetEvents_1")]
	internal static void* /* System.Reflection.EventInfo[] */ System_Type_GetEvents_1(void* /* System.Type */ __self, System.Reflection.BindingFlags /* System.Reflection.BindingFlags */ bindingAttr, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Type __selfConverted = InteropUtils.GetInstance<System.Type>(__self);
	
	
	    try {
			System.Reflection.EventInfo[] __returnValue = __selfConverted.GetEvents(bindingAttr);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_GetField")]
	internal static void* /* System.Reflection.FieldInfo */ System_Type_GetField(void* /* System.Type */ __self, void* /* System.String */ name, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Type __selfConverted = InteropUtils.GetInstance<System.Type>(__self);
	
		System.String nameConverted = InteropUtils.GetInstance<System.String>(name);
	
	    try {
			System.Reflection.FieldInfo __returnValue = __selfConverted.GetField(nameConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_GetField_1")]
	internal static void* /* System.Reflection.FieldInfo */ System_Type_GetField_1(void* /* System.Type */ __self, void* /* System.String */ name, System.Reflection.BindingFlags /* System.Reflection.BindingFlags */ bindingAttr, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Type __selfConverted = InteropUtils.GetInstance<System.Type>(__self);
	
		System.String nameConverted = InteropUtils.GetInstance<System.String>(name);
	
	    try {
			System.Reflection.FieldInfo __returnValue = __selfConverted.GetField(nameConverted, bindingAttr);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_GetFields")]
	internal static void* /* System.Reflection.FieldInfo[] */ System_Type_GetFields(void* /* System.Type */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Type __selfConverted = InteropUtils.GetInstance<System.Type>(__self);
	
	
	    try {
			System.Reflection.FieldInfo[] __returnValue = __selfConverted.GetFields();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_GetFields_1")]
	internal static void* /* System.Reflection.FieldInfo[] */ System_Type_GetFields_1(void* /* System.Type */ __self, System.Reflection.BindingFlags /* System.Reflection.BindingFlags */ bindingAttr, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Type __selfConverted = InteropUtils.GetInstance<System.Type>(__self);
	
	
	    try {
			System.Reflection.FieldInfo[] __returnValue = __selfConverted.GetFields(bindingAttr);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_GetFunctionPointerCallingConventions")]
	internal static void* /* System.Type[] */ System_Type_GetFunctionPointerCallingConventions(void* /* System.Type */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Type __selfConverted = InteropUtils.GetInstance<System.Type>(__self);
	
	
	    try {
			System.Type[] __returnValue = __selfConverted.GetFunctionPointerCallingConventions();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_GetFunctionPointerReturnType")]
	internal static void* /* System.Type */ System_Type_GetFunctionPointerReturnType(void* /* System.Type */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Type __selfConverted = InteropUtils.GetInstance<System.Type>(__self);
	
	
	    try {
			System.Type __returnValue = __selfConverted.GetFunctionPointerReturnType();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_GetFunctionPointerParameterTypes")]
	internal static void* /* System.Type[] */ System_Type_GetFunctionPointerParameterTypes(void* /* System.Type */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Type __selfConverted = InteropUtils.GetInstance<System.Type>(__self);
	
	
	    try {
			System.Type[] __returnValue = __selfConverted.GetFunctionPointerParameterTypes();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_GetMember")]
	internal static void* /* System.Reflection.MemberInfo[] */ System_Type_GetMember(void* /* System.Type */ __self, void* /* System.String */ name, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Type __selfConverted = InteropUtils.GetInstance<System.Type>(__self);
	
		System.String nameConverted = InteropUtils.GetInstance<System.String>(name);
	
	    try {
			System.Reflection.MemberInfo[] __returnValue = __selfConverted.GetMember(nameConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_GetMember_1")]
	internal static void* /* System.Reflection.MemberInfo[] */ System_Type_GetMember_1(void* /* System.Type */ __self, void* /* System.String */ name, System.Reflection.BindingFlags /* System.Reflection.BindingFlags */ bindingAttr, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Type __selfConverted = InteropUtils.GetInstance<System.Type>(__self);
	
		System.String nameConverted = InteropUtils.GetInstance<System.String>(name);
	
	    try {
			System.Reflection.MemberInfo[] __returnValue = __selfConverted.GetMember(nameConverted, bindingAttr);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_GetMember_2")]
	internal static void* /* System.Reflection.MemberInfo[] */ System_Type_GetMember_2(void* /* System.Type */ __self, void* /* System.String */ name, System.Reflection.MemberTypes /* System.Reflection.MemberTypes */ type, System.Reflection.BindingFlags /* System.Reflection.BindingFlags */ bindingAttr, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Type __selfConverted = InteropUtils.GetInstance<System.Type>(__self);
	
		System.String nameConverted = InteropUtils.GetInstance<System.String>(name);
	
	    try {
			System.Reflection.MemberInfo[] __returnValue = __selfConverted.GetMember(nameConverted, type, bindingAttr);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_GetMembers")]
	internal static void* /* System.Reflection.MemberInfo[] */ System_Type_GetMembers(void* /* System.Type */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Type __selfConverted = InteropUtils.GetInstance<System.Type>(__self);
	
	
	    try {
			System.Reflection.MemberInfo[] __returnValue = __selfConverted.GetMembers();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_GetMemberWithSameMetadataDefinitionAs")]
	internal static void* /* System.Reflection.MemberInfo */ System_Type_GetMemberWithSameMetadataDefinitionAs(void* /* System.Type */ __self, void* /* System.Reflection.MemberInfo */ member, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Type __selfConverted = InteropUtils.GetInstance<System.Type>(__self);
	
		System.Reflection.MemberInfo memberConverted = InteropUtils.GetInstance<System.Reflection.MemberInfo>(member);
	
	    try {
			System.Reflection.MemberInfo __returnValue = __selfConverted.GetMemberWithSameMetadataDefinitionAs(memberConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_GetMembers_1")]
	internal static void* /* System.Reflection.MemberInfo[] */ System_Type_GetMembers_1(void* /* System.Type */ __self, System.Reflection.BindingFlags /* System.Reflection.BindingFlags */ bindingAttr, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Type __selfConverted = InteropUtils.GetInstance<System.Type>(__self);
	
	
	    try {
			System.Reflection.MemberInfo[] __returnValue = __selfConverted.GetMembers(bindingAttr);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_GetMethod")]
	internal static void* /* System.Reflection.MethodInfo */ System_Type_GetMethod(void* /* System.Type */ __self, void* /* System.String */ name, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Type __selfConverted = InteropUtils.GetInstance<System.Type>(__self);
	
		System.String nameConverted = InteropUtils.GetInstance<System.String>(name);
	
	    try {
			System.Reflection.MethodInfo __returnValue = __selfConverted.GetMethod(nameConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_GetMethod_1")]
	internal static void* /* System.Reflection.MethodInfo */ System_Type_GetMethod_1(void* /* System.Type */ __self, void* /* System.String */ name, System.Reflection.BindingFlags /* System.Reflection.BindingFlags */ bindingAttr, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Type __selfConverted = InteropUtils.GetInstance<System.Type>(__self);
	
		System.String nameConverted = InteropUtils.GetInstance<System.String>(name);
	
	    try {
			System.Reflection.MethodInfo __returnValue = __selfConverted.GetMethod(nameConverted, bindingAttr);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_GetMethod_2")]
	internal static void* /* System.Reflection.MethodInfo */ System_Type_GetMethod_2(void* /* System.Type */ __self, void* /* System.String */ name, System.Reflection.BindingFlags /* System.Reflection.BindingFlags */ bindingAttr, void* /* System.Type[] */ types, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Type __selfConverted = InteropUtils.GetInstance<System.Type>(__self);
	
		System.String nameConverted = InteropUtils.GetInstance<System.String>(name);
		System.Type[] typesConverted = InteropUtils.GetInstance<System.Type[]>(types);
	
	    try {
			System.Reflection.MethodInfo __returnValue = __selfConverted.GetMethod(nameConverted, bindingAttr, typesConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_GetMethod_3")]
	internal static void* /* System.Reflection.MethodInfo */ System_Type_GetMethod_3(void* /* System.Type */ __self, void* /* System.String */ name, void* /* System.Type[] */ types, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Type __selfConverted = InteropUtils.GetInstance<System.Type>(__self);
	
		System.String nameConverted = InteropUtils.GetInstance<System.String>(name);
		System.Type[] typesConverted = InteropUtils.GetInstance<System.Type[]>(types);
	
	    try {
			System.Reflection.MethodInfo __returnValue = __selfConverted.GetMethod(nameConverted, typesConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_GetMethod_4")]
	internal static void* /* System.Reflection.MethodInfo */ System_Type_GetMethod_4(void* /* System.Type */ __self, void* /* System.String */ name, void* /* System.Type[] */ types, void* /* System.Reflection.ParameterModifier[] */ modifiers, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Type __selfConverted = InteropUtils.GetInstance<System.Type>(__self);
	
		System.String nameConverted = InteropUtils.GetInstance<System.String>(name);
		System.Type[] typesConverted = InteropUtils.GetInstance<System.Type[]>(types);
		System.Reflection.ParameterModifier[] modifiersConverted = InteropUtils.GetInstance<System.Reflection.ParameterModifier[]>(modifiers);
	
	    try {
			System.Reflection.MethodInfo __returnValue = __selfConverted.GetMethod(nameConverted, typesConverted, modifiersConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_GetMethod_5")]
	internal static void* /* System.Reflection.MethodInfo */ System_Type_GetMethod_5(void* /* System.Type */ __self, void* /* System.String */ name, System.Reflection.BindingFlags /* System.Reflection.BindingFlags */ bindingAttr, void* /* System.Reflection.Binder */ binder, void* /* System.Type[] */ types, void* /* System.Reflection.ParameterModifier[] */ modifiers, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Type __selfConverted = InteropUtils.GetInstance<System.Type>(__self);
	
		System.String nameConverted = InteropUtils.GetInstance<System.String>(name);
		System.Reflection.Binder binderConverted = InteropUtils.GetInstance<System.Reflection.Binder>(binder);
		System.Type[] typesConverted = InteropUtils.GetInstance<System.Type[]>(types);
		System.Reflection.ParameterModifier[] modifiersConverted = InteropUtils.GetInstance<System.Reflection.ParameterModifier[]>(modifiers);
	
	    try {
			System.Reflection.MethodInfo __returnValue = __selfConverted.GetMethod(nameConverted, bindingAttr, binderConverted, typesConverted, modifiersConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_GetMethod_6")]
	internal static void* /* System.Reflection.MethodInfo */ System_Type_GetMethod_6(void* /* System.Type */ __self, void* /* System.String */ name, System.Reflection.BindingFlags /* System.Reflection.BindingFlags */ bindingAttr, void* /* System.Reflection.Binder */ binder, System.Reflection.CallingConventions /* System.Reflection.CallingConventions */ callConvention, void* /* System.Type[] */ types, void* /* System.Reflection.ParameterModifier[] */ modifiers, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Type __selfConverted = InteropUtils.GetInstance<System.Type>(__self);
	
		System.String nameConverted = InteropUtils.GetInstance<System.String>(name);
		System.Reflection.Binder binderConverted = InteropUtils.GetInstance<System.Reflection.Binder>(binder);
		System.Type[] typesConverted = InteropUtils.GetInstance<System.Type[]>(types);
		System.Reflection.ParameterModifier[] modifiersConverted = InteropUtils.GetInstance<System.Reflection.ParameterModifier[]>(modifiers);
	
	    try {
			System.Reflection.MethodInfo __returnValue = __selfConverted.GetMethod(nameConverted, bindingAttr, binderConverted, callConvention, typesConverted, modifiersConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_GetMethod_7")]
	internal static void* /* System.Reflection.MethodInfo */ System_Type_GetMethod_7(void* /* System.Type */ __self, void* /* System.String */ name, int /* System.Int32 */ genericParameterCount, void* /* System.Type[] */ types, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Type __selfConverted = InteropUtils.GetInstance<System.Type>(__self);
	
		System.String nameConverted = InteropUtils.GetInstance<System.String>(name);
		System.Type[] typesConverted = InteropUtils.GetInstance<System.Type[]>(types);
	
	    try {
			System.Reflection.MethodInfo __returnValue = __selfConverted.GetMethod(nameConverted, genericParameterCount, typesConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_GetMethod_8")]
	internal static void* /* System.Reflection.MethodInfo */ System_Type_GetMethod_8(void* /* System.Type */ __self, void* /* System.String */ name, int /* System.Int32 */ genericParameterCount, void* /* System.Type[] */ types, void* /* System.Reflection.ParameterModifier[] */ modifiers, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Type __selfConverted = InteropUtils.GetInstance<System.Type>(__self);
	
		System.String nameConverted = InteropUtils.GetInstance<System.String>(name);
		System.Type[] typesConverted = InteropUtils.GetInstance<System.Type[]>(types);
		System.Reflection.ParameterModifier[] modifiersConverted = InteropUtils.GetInstance<System.Reflection.ParameterModifier[]>(modifiers);
	
	    try {
			System.Reflection.MethodInfo __returnValue = __selfConverted.GetMethod(nameConverted, genericParameterCount, typesConverted, modifiersConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_GetMethod_9")]
	internal static void* /* System.Reflection.MethodInfo */ System_Type_GetMethod_9(void* /* System.Type */ __self, void* /* System.String */ name, int /* System.Int32 */ genericParameterCount, System.Reflection.BindingFlags /* System.Reflection.BindingFlags */ bindingAttr, void* /* System.Reflection.Binder */ binder, void* /* System.Type[] */ types, void* /* System.Reflection.ParameterModifier[] */ modifiers, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Type __selfConverted = InteropUtils.GetInstance<System.Type>(__self);
	
		System.String nameConverted = InteropUtils.GetInstance<System.String>(name);
		System.Reflection.Binder binderConverted = InteropUtils.GetInstance<System.Reflection.Binder>(binder);
		System.Type[] typesConverted = InteropUtils.GetInstance<System.Type[]>(types);
		System.Reflection.ParameterModifier[] modifiersConverted = InteropUtils.GetInstance<System.Reflection.ParameterModifier[]>(modifiers);
	
	    try {
			System.Reflection.MethodInfo __returnValue = __selfConverted.GetMethod(nameConverted, genericParameterCount, bindingAttr, binderConverted, typesConverted, modifiersConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_GetMethod_10")]
	internal static void* /* System.Reflection.MethodInfo */ System_Type_GetMethod_10(void* /* System.Type */ __self, void* /* System.String */ name, int /* System.Int32 */ genericParameterCount, System.Reflection.BindingFlags /* System.Reflection.BindingFlags */ bindingAttr, void* /* System.Reflection.Binder */ binder, System.Reflection.CallingConventions /* System.Reflection.CallingConventions */ callConvention, void* /* System.Type[] */ types, void* /* System.Reflection.ParameterModifier[] */ modifiers, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Type __selfConverted = InteropUtils.GetInstance<System.Type>(__self);
	
		System.String nameConverted = InteropUtils.GetInstance<System.String>(name);
		System.Reflection.Binder binderConverted = InteropUtils.GetInstance<System.Reflection.Binder>(binder);
		System.Type[] typesConverted = InteropUtils.GetInstance<System.Type[]>(types);
		System.Reflection.ParameterModifier[] modifiersConverted = InteropUtils.GetInstance<System.Reflection.ParameterModifier[]>(modifiers);
	
	    try {
			System.Reflection.MethodInfo __returnValue = __selfConverted.GetMethod(nameConverted, genericParameterCount, bindingAttr, binderConverted, callConvention, typesConverted, modifiersConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_GetMethods")]
	internal static void* /* System.Reflection.MethodInfo[] */ System_Type_GetMethods(void* /* System.Type */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Type __selfConverted = InteropUtils.GetInstance<System.Type>(__self);
	
	
	    try {
			System.Reflection.MethodInfo[] __returnValue = __selfConverted.GetMethods();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_GetMethods_1")]
	internal static void* /* System.Reflection.MethodInfo[] */ System_Type_GetMethods_1(void* /* System.Type */ __self, System.Reflection.BindingFlags /* System.Reflection.BindingFlags */ bindingAttr, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Type __selfConverted = InteropUtils.GetInstance<System.Type>(__self);
	
	
	    try {
			System.Reflection.MethodInfo[] __returnValue = __selfConverted.GetMethods(bindingAttr);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_GetNestedType")]
	internal static void* /* System.Type */ System_Type_GetNestedType(void* /* System.Type */ __self, void* /* System.String */ name, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Type __selfConverted = InteropUtils.GetInstance<System.Type>(__self);
	
		System.String nameConverted = InteropUtils.GetInstance<System.String>(name);
	
	    try {
			System.Type __returnValue = __selfConverted.GetNestedType(nameConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_GetNestedType_1")]
	internal static void* /* System.Type */ System_Type_GetNestedType_1(void* /* System.Type */ __self, void* /* System.String */ name, System.Reflection.BindingFlags /* System.Reflection.BindingFlags */ bindingAttr, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Type __selfConverted = InteropUtils.GetInstance<System.Type>(__self);
	
		System.String nameConverted = InteropUtils.GetInstance<System.String>(name);
	
	    try {
			System.Type __returnValue = __selfConverted.GetNestedType(nameConverted, bindingAttr);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_GetNestedTypes")]
	internal static void* /* System.Type[] */ System_Type_GetNestedTypes(void* /* System.Type */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Type __selfConverted = InteropUtils.GetInstance<System.Type>(__self);
	
	
	    try {
			System.Type[] __returnValue = __selfConverted.GetNestedTypes();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_GetNestedTypes_1")]
	internal static void* /* System.Type[] */ System_Type_GetNestedTypes_1(void* /* System.Type */ __self, System.Reflection.BindingFlags /* System.Reflection.BindingFlags */ bindingAttr, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Type __selfConverted = InteropUtils.GetInstance<System.Type>(__self);
	
	
	    try {
			System.Type[] __returnValue = __selfConverted.GetNestedTypes(bindingAttr);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_GetProperty")]
	internal static void* /* System.Reflection.PropertyInfo */ System_Type_GetProperty(void* /* System.Type */ __self, void* /* System.String */ name, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Type __selfConverted = InteropUtils.GetInstance<System.Type>(__self);
	
		System.String nameConverted = InteropUtils.GetInstance<System.String>(name);
	
	    try {
			System.Reflection.PropertyInfo __returnValue = __selfConverted.GetProperty(nameConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_GetProperty_1")]
	internal static void* /* System.Reflection.PropertyInfo */ System_Type_GetProperty_1(void* /* System.Type */ __self, void* /* System.String */ name, System.Reflection.BindingFlags /* System.Reflection.BindingFlags */ bindingAttr, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Type __selfConverted = InteropUtils.GetInstance<System.Type>(__self);
	
		System.String nameConverted = InteropUtils.GetInstance<System.String>(name);
	
	    try {
			System.Reflection.PropertyInfo __returnValue = __selfConverted.GetProperty(nameConverted, bindingAttr);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_GetProperty_2")]
	internal static void* /* System.Reflection.PropertyInfo */ System_Type_GetProperty_2(void* /* System.Type */ __self, void* /* System.String */ name, void* /* System.Type */ returnType, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Type __selfConverted = InteropUtils.GetInstance<System.Type>(__self);
	
		System.String nameConverted = InteropUtils.GetInstance<System.String>(name);
		System.Type returnTypeConverted = InteropUtils.GetInstance<System.Type>(returnType);
	
	    try {
			System.Reflection.PropertyInfo __returnValue = __selfConverted.GetProperty(nameConverted, returnTypeConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_GetProperty_3")]
	internal static void* /* System.Reflection.PropertyInfo */ System_Type_GetProperty_3(void* /* System.Type */ __self, void* /* System.String */ name, void* /* System.Type[] */ types, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Type __selfConverted = InteropUtils.GetInstance<System.Type>(__self);
	
		System.String nameConverted = InteropUtils.GetInstance<System.String>(name);
		System.Type[] typesConverted = InteropUtils.GetInstance<System.Type[]>(types);
	
	    try {
			System.Reflection.PropertyInfo __returnValue = __selfConverted.GetProperty(nameConverted, typesConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_GetProperty_4")]
	internal static void* /* System.Reflection.PropertyInfo */ System_Type_GetProperty_4(void* /* System.Type */ __self, void* /* System.String */ name, void* /* System.Type */ returnType, void* /* System.Type[] */ types, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Type __selfConverted = InteropUtils.GetInstance<System.Type>(__self);
	
		System.String nameConverted = InteropUtils.GetInstance<System.String>(name);
		System.Type returnTypeConverted = InteropUtils.GetInstance<System.Type>(returnType);
		System.Type[] typesConverted = InteropUtils.GetInstance<System.Type[]>(types);
	
	    try {
			System.Reflection.PropertyInfo __returnValue = __selfConverted.GetProperty(nameConverted, returnTypeConverted, typesConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_GetProperty_5")]
	internal static void* /* System.Reflection.PropertyInfo */ System_Type_GetProperty_5(void* /* System.Type */ __self, void* /* System.String */ name, void* /* System.Type */ returnType, void* /* System.Type[] */ types, void* /* System.Reflection.ParameterModifier[] */ modifiers, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Type __selfConverted = InteropUtils.GetInstance<System.Type>(__self);
	
		System.String nameConverted = InteropUtils.GetInstance<System.String>(name);
		System.Type returnTypeConverted = InteropUtils.GetInstance<System.Type>(returnType);
		System.Type[] typesConverted = InteropUtils.GetInstance<System.Type[]>(types);
		System.Reflection.ParameterModifier[] modifiersConverted = InteropUtils.GetInstance<System.Reflection.ParameterModifier[]>(modifiers);
	
	    try {
			System.Reflection.PropertyInfo __returnValue = __selfConverted.GetProperty(nameConverted, returnTypeConverted, typesConverted, modifiersConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_GetProperty_6")]
	internal static void* /* System.Reflection.PropertyInfo */ System_Type_GetProperty_6(void* /* System.Type */ __self, void* /* System.String */ name, System.Reflection.BindingFlags /* System.Reflection.BindingFlags */ bindingAttr, void* /* System.Reflection.Binder */ binder, void* /* System.Type */ returnType, void* /* System.Type[] */ types, void* /* System.Reflection.ParameterModifier[] */ modifiers, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Type __selfConverted = InteropUtils.GetInstance<System.Type>(__self);
	
		System.String nameConverted = InteropUtils.GetInstance<System.String>(name);
		System.Reflection.Binder binderConverted = InteropUtils.GetInstance<System.Reflection.Binder>(binder);
		System.Type returnTypeConverted = InteropUtils.GetInstance<System.Type>(returnType);
		System.Type[] typesConverted = InteropUtils.GetInstance<System.Type[]>(types);
		System.Reflection.ParameterModifier[] modifiersConverted = InteropUtils.GetInstance<System.Reflection.ParameterModifier[]>(modifiers);
	
	    try {
			System.Reflection.PropertyInfo __returnValue = __selfConverted.GetProperty(nameConverted, bindingAttr, binderConverted, returnTypeConverted, typesConverted, modifiersConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_GetProperties")]
	internal static void* /* System.Reflection.PropertyInfo[] */ System_Type_GetProperties(void* /* System.Type */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Type __selfConverted = InteropUtils.GetInstance<System.Type>(__self);
	
	
	    try {
			System.Reflection.PropertyInfo[] __returnValue = __selfConverted.GetProperties();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_GetProperties_1")]
	internal static void* /* System.Reflection.PropertyInfo[] */ System_Type_GetProperties_1(void* /* System.Type */ __self, System.Reflection.BindingFlags /* System.Reflection.BindingFlags */ bindingAttr, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Type __selfConverted = InteropUtils.GetInstance<System.Type>(__self);
	
	
	    try {
			System.Reflection.PropertyInfo[] __returnValue = __selfConverted.GetProperties(bindingAttr);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_GetDefaultMembers")]
	internal static void* /* System.Reflection.MemberInfo[] */ System_Type_GetDefaultMembers(void* /* System.Type */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Type __selfConverted = InteropUtils.GetInstance<System.Type>(__self);
	
	
	    try {
			System.Reflection.MemberInfo[] __returnValue = __selfConverted.GetDefaultMembers();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_GetTypeHandle")]
	internal static void* /* System.RuntimeTypeHandle */ System_Type_GetTypeHandle(void* /* System.Object */ o, void** /* System.Exception */ __outException)
	{
		System.Object oConverted = InteropUtils.GetInstance<System.Object>(o);
	
	    try {
			System.RuntimeTypeHandle __returnValue = System.Type.GetTypeHandle(oConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_GetTypeArray")]
	internal static void* /* System.Type[] */ System_Type_GetTypeArray(void* /* System.Object[] */ args, void** /* System.Exception */ __outException)
	{
		System.Object[] argsConverted = InteropUtils.GetInstance<System.Object[]>(args);
	
	    try {
			System.Type[] __returnValue = System.Type.GetTypeArray(argsConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_GetTypeCode")]
	internal static System.TypeCode /* System.TypeCode */ System_Type_GetTypeCode(void* /* System.Type */ type, void** /* System.Exception */ __outException)
	{
		System.Type typeConverted = InteropUtils.GetInstance<System.Type>(type);
	
	    try {
			System.TypeCode __returnValue = System.Type.GetTypeCode(typeConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return default(System.TypeCode);
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_GetTypeFromCLSID")]
	internal static void* /* System.Type */ System_Type_GetTypeFromCLSID(void* /* System.Guid */ clsid, void** /* System.Exception */ __outException)
	{
		System.Guid clsidConverted = InteropUtils.GetInstance<System.Guid>(clsid);
	
	    try {
			System.Type __returnValue = System.Type.GetTypeFromCLSID(clsidConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_GetTypeFromCLSID_1")]
	internal static void* /* System.Type */ System_Type_GetTypeFromCLSID_1(void* /* System.Guid */ clsid, byte /* System.Boolean */ throwOnError, void** /* System.Exception */ __outException)
	{
		System.Guid clsidConverted = InteropUtils.GetInstance<System.Guid>(clsid);
		System.Boolean throwOnErrorConverted = throwOnError.ToBool();
	
	    try {
			System.Type __returnValue = System.Type.GetTypeFromCLSID(clsidConverted, throwOnErrorConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_GetTypeFromCLSID_2")]
	internal static void* /* System.Type */ System_Type_GetTypeFromCLSID_2(void* /* System.Guid */ clsid, void* /* System.String */ server, void** /* System.Exception */ __outException)
	{
		System.Guid clsidConverted = InteropUtils.GetInstance<System.Guid>(clsid);
		System.String serverConverted = InteropUtils.GetInstance<System.String>(server);
	
	    try {
			System.Type __returnValue = System.Type.GetTypeFromCLSID(clsidConverted, serverConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_GetTypeFromCLSID_3")]
	internal static void* /* System.Type */ System_Type_GetTypeFromCLSID_3(void* /* System.Guid */ clsid, void* /* System.String */ server, byte /* System.Boolean */ throwOnError, void** /* System.Exception */ __outException)
	{
		System.Guid clsidConverted = InteropUtils.GetInstance<System.Guid>(clsid);
		System.String serverConverted = InteropUtils.GetInstance<System.String>(server);
		System.Boolean throwOnErrorConverted = throwOnError.ToBool();
	
	    try {
			System.Type __returnValue = System.Type.GetTypeFromCLSID(clsidConverted, serverConverted, throwOnErrorConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_GetTypeFromProgID")]
	internal static void* /* System.Type */ System_Type_GetTypeFromProgID(void* /* System.String */ progID, void** /* System.Exception */ __outException)
	{
		System.String progIDConverted = InteropUtils.GetInstance<System.String>(progID);
	
	    try {
			System.Type __returnValue = System.Type.GetTypeFromProgID(progIDConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_GetTypeFromProgID_1")]
	internal static void* /* System.Type */ System_Type_GetTypeFromProgID_1(void* /* System.String */ progID, byte /* System.Boolean */ throwOnError, void** /* System.Exception */ __outException)
	{
		System.String progIDConverted = InteropUtils.GetInstance<System.String>(progID);
		System.Boolean throwOnErrorConverted = throwOnError.ToBool();
	
	    try {
			System.Type __returnValue = System.Type.GetTypeFromProgID(progIDConverted, throwOnErrorConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_GetTypeFromProgID_2")]
	internal static void* /* System.Type */ System_Type_GetTypeFromProgID_2(void* /* System.String */ progID, void* /* System.String */ server, void** /* System.Exception */ __outException)
	{
		System.String progIDConverted = InteropUtils.GetInstance<System.String>(progID);
		System.String serverConverted = InteropUtils.GetInstance<System.String>(server);
	
	    try {
			System.Type __returnValue = System.Type.GetTypeFromProgID(progIDConverted, serverConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_GetTypeFromProgID_3")]
	internal static void* /* System.Type */ System_Type_GetTypeFromProgID_3(void* /* System.String */ progID, void* /* System.String */ server, byte /* System.Boolean */ throwOnError, void** /* System.Exception */ __outException)
	{
		System.String progIDConverted = InteropUtils.GetInstance<System.String>(progID);
		System.String serverConverted = InteropUtils.GetInstance<System.String>(server);
		System.Boolean throwOnErrorConverted = throwOnError.ToBool();
	
	    try {
			System.Type __returnValue = System.Type.GetTypeFromProgID(progIDConverted, serverConverted, throwOnErrorConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_InvokeMember")]
	internal static void* /* System.Object */ System_Type_InvokeMember(void* /* System.Type */ __self, void* /* System.String */ name, System.Reflection.BindingFlags /* System.Reflection.BindingFlags */ invokeAttr, void* /* System.Reflection.Binder */ binder, void* /* System.Object */ target, void* /* System.Object[] */ args, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Type __selfConverted = InteropUtils.GetInstance<System.Type>(__self);
	
		System.String nameConverted = InteropUtils.GetInstance<System.String>(name);
		System.Reflection.Binder binderConverted = InteropUtils.GetInstance<System.Reflection.Binder>(binder);
		System.Object targetConverted = InteropUtils.GetInstance<System.Object>(target);
		System.Object[] argsConverted = InteropUtils.GetInstance<System.Object[]>(args);
	
	    try {
			System.Object __returnValue = __selfConverted.InvokeMember(nameConverted, invokeAttr, binderConverted, targetConverted, argsConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_InvokeMember_1")]
	internal static void* /* System.Object */ System_Type_InvokeMember_1(void* /* System.Type */ __self, void* /* System.String */ name, System.Reflection.BindingFlags /* System.Reflection.BindingFlags */ invokeAttr, void* /* System.Reflection.Binder */ binder, void* /* System.Object */ target, void* /* System.Object[] */ args, void* /* System.Globalization.CultureInfo */ culture, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Type __selfConverted = InteropUtils.GetInstance<System.Type>(__self);
	
		System.String nameConverted = InteropUtils.GetInstance<System.String>(name);
		System.Reflection.Binder binderConverted = InteropUtils.GetInstance<System.Reflection.Binder>(binder);
		System.Object targetConverted = InteropUtils.GetInstance<System.Object>(target);
		System.Object[] argsConverted = InteropUtils.GetInstance<System.Object[]>(args);
		System.Globalization.CultureInfo cultureConverted = InteropUtils.GetInstance<System.Globalization.CultureInfo>(culture);
	
	    try {
			System.Object __returnValue = __selfConverted.InvokeMember(nameConverted, invokeAttr, binderConverted, targetConverted, argsConverted, cultureConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_InvokeMember_2")]
	internal static void* /* System.Object */ System_Type_InvokeMember_2(void* /* System.Type */ __self, void* /* System.String */ name, System.Reflection.BindingFlags /* System.Reflection.BindingFlags */ invokeAttr, void* /* System.Reflection.Binder */ binder, void* /* System.Object */ target, void* /* System.Object[] */ args, void* /* System.Reflection.ParameterModifier[] */ modifiers, void* /* System.Globalization.CultureInfo */ culture, void* /* System.String[] */ namedParameters, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Type __selfConverted = InteropUtils.GetInstance<System.Type>(__self);
	
		System.String nameConverted = InteropUtils.GetInstance<System.String>(name);
		System.Reflection.Binder binderConverted = InteropUtils.GetInstance<System.Reflection.Binder>(binder);
		System.Object targetConverted = InteropUtils.GetInstance<System.Object>(target);
		System.Object[] argsConverted = InteropUtils.GetInstance<System.Object[]>(args);
		System.Reflection.ParameterModifier[] modifiersConverted = InteropUtils.GetInstance<System.Reflection.ParameterModifier[]>(modifiers);
		System.Globalization.CultureInfo cultureConverted = InteropUtils.GetInstance<System.Globalization.CultureInfo>(culture);
		System.String[] namedParametersConverted = InteropUtils.GetInstance<System.String[]>(namedParameters);
	
	    try {
			System.Object __returnValue = __selfConverted.InvokeMember(nameConverted, invokeAttr, binderConverted, targetConverted, argsConverted, modifiersConverted, cultureConverted, namedParametersConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_GetInterface")]
	internal static void* /* System.Type */ System_Type_GetInterface(void* /* System.Type */ __self, void* /* System.String */ name, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Type __selfConverted = InteropUtils.GetInstance<System.Type>(__self);
	
		System.String nameConverted = InteropUtils.GetInstance<System.String>(name);
	
	    try {
			System.Type __returnValue = __selfConverted.GetInterface(nameConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_GetInterface_1")]
	internal static void* /* System.Type */ System_Type_GetInterface_1(void* /* System.Type */ __self, void* /* System.String */ name, byte /* System.Boolean */ ignoreCase, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Type __selfConverted = InteropUtils.GetInstance<System.Type>(__self);
	
		System.String nameConverted = InteropUtils.GetInstance<System.String>(name);
		System.Boolean ignoreCaseConverted = ignoreCase.ToBool();
	
	    try {
			System.Type __returnValue = __selfConverted.GetInterface(nameConverted, ignoreCaseConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_GetInterfaces")]
	internal static void* /* System.Type[] */ System_Type_GetInterfaces(void* /* System.Type */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Type __selfConverted = InteropUtils.GetInstance<System.Type>(__self);
	
	
	    try {
			System.Type[] __returnValue = __selfConverted.GetInterfaces();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_GetInterfaceMap")]
	internal static void* /* System.Reflection.InterfaceMapping */ System_Type_GetInterfaceMap(void* /* System.Type */ __self, void* /* System.Type */ interfaceType, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Type __selfConverted = InteropUtils.GetInstance<System.Type>(__self);
	
		System.Type interfaceTypeConverted = InteropUtils.GetInstance<System.Type>(interfaceType);
	
	    try {
			System.Reflection.InterfaceMapping __returnValue = __selfConverted.GetInterfaceMap(interfaceTypeConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_IsInstanceOfType")]
	internal static byte /* System.Boolean */ System_Type_IsInstanceOfType(void* /* System.Type */ __self, void* /* System.Object */ o, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Type __selfConverted = InteropUtils.GetInstance<System.Type>(__self);
	
		System.Object oConverted = InteropUtils.GetInstance<System.Object>(o);
	
	    try {
			System.Boolean __returnValue = __selfConverted.IsInstanceOfType(oConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_IsEquivalentTo")]
	internal static byte /* System.Boolean */ System_Type_IsEquivalentTo(void* /* System.Type */ __self, void* /* System.Type */ other, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Type __selfConverted = InteropUtils.GetInstance<System.Type>(__self);
	
		System.Type otherConverted = InteropUtils.GetInstance<System.Type>(other);
	
	    try {
			System.Boolean __returnValue = __selfConverted.IsEquivalentTo(otherConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_GetEnumUnderlyingType")]
	internal static void* /* System.Type */ System_Type_GetEnumUnderlyingType(void* /* System.Type */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Type __selfConverted = InteropUtils.GetInstance<System.Type>(__self);
	
	
	    try {
			System.Type __returnValue = __selfConverted.GetEnumUnderlyingType();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_GetEnumValues")]
	internal static void* /* System.Array */ System_Type_GetEnumValues(void* /* System.Type */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Type __selfConverted = InteropUtils.GetInstance<System.Type>(__self);
	
	
	    try {
			System.Array __returnValue = __selfConverted.GetEnumValues();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_GetEnumValuesAsUnderlyingType")]
	internal static void* /* System.Array */ System_Type_GetEnumValuesAsUnderlyingType(void* /* System.Type */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Type __selfConverted = InteropUtils.GetInstance<System.Type>(__self);
	
	
	    try {
			System.Array __returnValue = __selfConverted.GetEnumValuesAsUnderlyingType();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_MakeArrayType")]
	internal static void* /* System.Type */ System_Type_MakeArrayType(void* /* System.Type */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Type __selfConverted = InteropUtils.GetInstance<System.Type>(__self);
	
	
	    try {
			System.Type __returnValue = __selfConverted.MakeArrayType();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_MakeArrayType_1")]
	internal static void* /* System.Type */ System_Type_MakeArrayType_1(void* /* System.Type */ __self, int /* System.Int32 */ rank, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Type __selfConverted = InteropUtils.GetInstance<System.Type>(__self);
	
	
	    try {
			System.Type __returnValue = __selfConverted.MakeArrayType(rank);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_MakeByRefType")]
	internal static void* /* System.Type */ System_Type_MakeByRefType(void* /* System.Type */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Type __selfConverted = InteropUtils.GetInstance<System.Type>(__self);
	
	
	    try {
			System.Type __returnValue = __selfConverted.MakeByRefType();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_MakeGenericType")]
	internal static void* /* System.Type */ System_Type_MakeGenericType(void* /* System.Type */ __self, void* /* System.Type[] */ typeArguments, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Type __selfConverted = InteropUtils.GetInstance<System.Type>(__self);
	
		System.Type[] typeArgumentsConverted = InteropUtils.GetInstance<System.Type[]>(typeArguments);
	
	    try {
			System.Type __returnValue = __selfConverted.MakeGenericType(typeArgumentsConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_MakePointerType")]
	internal static void* /* System.Type */ System_Type_MakePointerType(void* /* System.Type */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Type __selfConverted = InteropUtils.GetInstance<System.Type>(__self);
	
	
	    try {
			System.Type __returnValue = __selfConverted.MakePointerType();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_MakeGenericSignatureType")]
	internal static void* /* System.Type */ System_Type_MakeGenericSignatureType(void* /* System.Type */ genericTypeDefinition, void* /* System.Type[] */ typeArguments, void** /* System.Exception */ __outException)
	{
		System.Type genericTypeDefinitionConverted = InteropUtils.GetInstance<System.Type>(genericTypeDefinition);
		System.Type[] typeArgumentsConverted = InteropUtils.GetInstance<System.Type[]>(typeArguments);
	
	    try {
			System.Type __returnValue = System.Type.MakeGenericSignatureType(genericTypeDefinitionConverted, typeArgumentsConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_MakeGenericMethodParameter")]
	internal static void* /* System.Type */ System_Type_MakeGenericMethodParameter(int /* System.Int32 */ position, void** /* System.Exception */ __outException)
	{
	
	    try {
			System.Type __returnValue = System.Type.MakeGenericMethodParameter(position);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_ToString")]
	internal static void* /* System.String */ System_Type_ToString(void* /* System.Type */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Type __selfConverted = InteropUtils.GetInstance<System.Type>(__self);
	
	
	    try {
			System.String __returnValue = __selfConverted.ToString();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_Equals")]
	internal static byte /* System.Boolean */ System_Type_Equals(void* /* System.Type */ __self, void* /* System.Object */ o, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Type __selfConverted = InteropUtils.GetInstance<System.Type>(__self);
	
		System.Object oConverted = InteropUtils.GetInstance<System.Object>(o);
	
	    try {
			System.Boolean __returnValue = __selfConverted.Equals(oConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_GetHashCode")]
	internal static int /* System.Int32 */ System_Type_GetHashCode(void* /* System.Type */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Type __selfConverted = InteropUtils.GetInstance<System.Type>(__self);
	
	
	    try {
			System.Int32 __returnValue = __selfConverted.GetHashCode();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_Equals_1")]
	internal static byte /* System.Boolean */ System_Type_Equals_1(void* /* System.Type */ __self, void* /* System.Type */ o, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Type __selfConverted = InteropUtils.GetInstance<System.Type>(__self);
	
		System.Type oConverted = InteropUtils.GetInstance<System.Type>(o);
	
	    try {
			System.Boolean __returnValue = __selfConverted.Equals(oConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_ReflectionOnlyGetType")]
	internal static void* /* System.Type */ System_Type_ReflectionOnlyGetType(void* /* System.String */ typeName, byte /* System.Boolean */ throwIfNotFound, byte /* System.Boolean */ ignoreCase, void** /* System.Exception */ __outException)
	{
		System.String typeNameConverted = InteropUtils.GetInstance<System.String>(typeName);
		System.Boolean throwIfNotFoundConverted = throwIfNotFound.ToBool();
		System.Boolean ignoreCaseConverted = ignoreCase.ToBool();
	
	    try {
			System.Type __returnValue = System.Type.ReflectionOnlyGetType(typeNameConverted, throwIfNotFoundConverted, ignoreCaseConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_IsEnumDefined")]
	internal static byte /* System.Boolean */ System_Type_IsEnumDefined(void* /* System.Type */ __self, void* /* System.Object */ value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Type __selfConverted = InteropUtils.GetInstance<System.Type>(__self);
	
		System.Object valueConverted = InteropUtils.GetInstance<System.Object>(value);
	
	    try {
			System.Boolean __returnValue = __selfConverted.IsEnumDefined(valueConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_GetEnumName")]
	internal static void* /* System.String */ System_Type_GetEnumName(void* /* System.Type */ __self, void* /* System.Object */ value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Type __selfConverted = InteropUtils.GetInstance<System.Type>(__self);
	
		System.Object valueConverted = InteropUtils.GetInstance<System.Object>(value);
	
	    try {
			System.String __returnValue = __selfConverted.GetEnumName(valueConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_GetEnumNames")]
	internal static void* /* System.String[] */ System_Type_GetEnumNames(void* /* System.Type */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Type __selfConverted = InteropUtils.GetInstance<System.Type>(__self);
	
	
	    try {
			System.String[] __returnValue = __selfConverted.GetEnumNames();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_FindInterfaces")]
	internal static void* /* System.Type[] */ System_Type_FindInterfaces(void* /* System.Type */ __self, void* /* System.Reflection.TypeFilter */ filter, void* /* System.Object */ filterCriteria, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Type __selfConverted = InteropUtils.GetInstance<System.Type>(__self);
	
		System.Reflection.TypeFilter filterConverted = InteropUtils.GetInstance<System_Reflection_TypeFilter>(filter)?.Trampoline;
		System.Object filterCriteriaConverted = InteropUtils.GetInstance<System.Object>(filterCriteria);
	
	    try {
			System.Type[] __returnValue = __selfConverted.FindInterfaces(filterConverted, filterCriteriaConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_FindMembers")]
	internal static void* /* System.Reflection.MemberInfo[] */ System_Type_FindMembers(void* /* System.Type */ __self, System.Reflection.MemberTypes /* System.Reflection.MemberTypes */ memberType, System.Reflection.BindingFlags /* System.Reflection.BindingFlags */ bindingAttr, void* /* System.Reflection.MemberFilter */ filter, void* /* System.Object */ filterCriteria, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Type __selfConverted = InteropUtils.GetInstance<System.Type>(__self);
	
		System.Reflection.MemberFilter filterConverted = InteropUtils.GetInstance<System_Reflection_MemberFilter>(filter)?.Trampoline;
		System.Object filterCriteriaConverted = InteropUtils.GetInstance<System.Object>(filterCriteria);
	
	    try {
			System.Reflection.MemberInfo[] __returnValue = __selfConverted.FindMembers(memberType, bindingAttr, filterConverted, filterCriteriaConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_IsSubclassOf")]
	internal static byte /* System.Boolean */ System_Type_IsSubclassOf(void* /* System.Type */ __self, void* /* System.Type */ c, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Type __selfConverted = InteropUtils.GetInstance<System.Type>(__self);
	
		System.Type cConverted = InteropUtils.GetInstance<System.Type>(c);
	
	    try {
			System.Boolean __returnValue = __selfConverted.IsSubclassOf(cConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_IsAssignableFrom")]
	internal static byte /* System.Boolean */ System_Type_IsAssignableFrom(void* /* System.Type */ __self, void* /* System.Type */ c, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Type __selfConverted = InteropUtils.GetInstance<System.Type>(__self);
	
		System.Type cConverted = InteropUtils.GetInstance<System.Type>(c);
	
	    try {
			System.Boolean __returnValue = __selfConverted.IsAssignableFrom(cConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_IsInterface_Get")]
	internal static byte /* System.Boolean */ System_Type_IsInterface_Get(void* /* System.Type */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Type __selfConverted = InteropUtils.GetInstance<System.Type>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.IsInterface;
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_MemberType_Get")]
	internal static System.Reflection.MemberTypes /* System.Reflection.MemberTypes */ System_Type_MemberType_Get(void* /* System.Type */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Type __selfConverted = InteropUtils.GetInstance<System.Type>(__self);
	
	
	    try {
			System.Reflection.MemberTypes __returnValue = __selfConverted.MemberType;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return default(System.Reflection.MemberTypes);
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_Namespace_Get")]
	internal static void* /* System.String */ System_Type_Namespace_Get(void* /* System.Type */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Type __selfConverted = InteropUtils.GetInstance<System.Type>(__self);
	
	
	    try {
			System.String __returnValue = __selfConverted.Namespace;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_AssemblyQualifiedName_Get")]
	internal static void* /* System.String */ System_Type_AssemblyQualifiedName_Get(void* /* System.Type */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Type __selfConverted = InteropUtils.GetInstance<System.Type>(__self);
	
	
	    try {
			System.String __returnValue = __selfConverted.AssemblyQualifiedName;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_FullName_Get")]
	internal static void* /* System.String */ System_Type_FullName_Get(void* /* System.Type */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Type __selfConverted = InteropUtils.GetInstance<System.Type>(__self);
	
	
	    try {
			System.String __returnValue = __selfConverted.FullName;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_Assembly_Get")]
	internal static void* /* System.Reflection.Assembly */ System_Type_Assembly_Get(void* /* System.Type */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Type __selfConverted = InteropUtils.GetInstance<System.Type>(__self);
	
	
	    try {
			System.Reflection.Assembly __returnValue = __selfConverted.Assembly;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_Module_Get")]
	internal static void* /* System.Reflection.Module */ System_Type_Module_Get(void* /* System.Type */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Type __selfConverted = InteropUtils.GetInstance<System.Type>(__self);
	
	
	    try {
			System.Reflection.Module __returnValue = __selfConverted.Module;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_IsNested_Get")]
	internal static byte /* System.Boolean */ System_Type_IsNested_Get(void* /* System.Type */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Type __selfConverted = InteropUtils.GetInstance<System.Type>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.IsNested;
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_DeclaringType_Get")]
	internal static void* /* System.Type */ System_Type_DeclaringType_Get(void* /* System.Type */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Type __selfConverted = InteropUtils.GetInstance<System.Type>(__self);
	
	
	    try {
			System.Type __returnValue = __selfConverted.DeclaringType;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_DeclaringMethod_Get")]
	internal static void* /* System.Reflection.MethodBase */ System_Type_DeclaringMethod_Get(void* /* System.Type */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Type __selfConverted = InteropUtils.GetInstance<System.Type>(__self);
	
	
	    try {
			System.Reflection.MethodBase __returnValue = __selfConverted.DeclaringMethod;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_ReflectedType_Get")]
	internal static void* /* System.Type */ System_Type_ReflectedType_Get(void* /* System.Type */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Type __selfConverted = InteropUtils.GetInstance<System.Type>(__self);
	
	
	    try {
			System.Type __returnValue = __selfConverted.ReflectedType;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_UnderlyingSystemType_Get")]
	internal static void* /* System.Type */ System_Type_UnderlyingSystemType_Get(void* /* System.Type */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Type __selfConverted = InteropUtils.GetInstance<System.Type>(__self);
	
	
	    try {
			System.Type __returnValue = __selfConverted.UnderlyingSystemType;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_IsTypeDefinition_Get")]
	internal static byte /* System.Boolean */ System_Type_IsTypeDefinition_Get(void* /* System.Type */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Type __selfConverted = InteropUtils.GetInstance<System.Type>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.IsTypeDefinition;
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_IsArray_Get")]
	internal static byte /* System.Boolean */ System_Type_IsArray_Get(void* /* System.Type */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Type __selfConverted = InteropUtils.GetInstance<System.Type>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.IsArray;
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_IsByRef_Get")]
	internal static byte /* System.Boolean */ System_Type_IsByRef_Get(void* /* System.Type */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Type __selfConverted = InteropUtils.GetInstance<System.Type>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.IsByRef;
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_IsPointer_Get")]
	internal static byte /* System.Boolean */ System_Type_IsPointer_Get(void* /* System.Type */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Type __selfConverted = InteropUtils.GetInstance<System.Type>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.IsPointer;
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_IsConstructedGenericType_Get")]
	internal static byte /* System.Boolean */ System_Type_IsConstructedGenericType_Get(void* /* System.Type */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Type __selfConverted = InteropUtils.GetInstance<System.Type>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.IsConstructedGenericType;
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_IsGenericParameter_Get")]
	internal static byte /* System.Boolean */ System_Type_IsGenericParameter_Get(void* /* System.Type */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Type __selfConverted = InteropUtils.GetInstance<System.Type>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.IsGenericParameter;
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_IsGenericTypeParameter_Get")]
	internal static byte /* System.Boolean */ System_Type_IsGenericTypeParameter_Get(void* /* System.Type */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Type __selfConverted = InteropUtils.GetInstance<System.Type>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.IsGenericTypeParameter;
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_IsGenericMethodParameter_Get")]
	internal static byte /* System.Boolean */ System_Type_IsGenericMethodParameter_Get(void* /* System.Type */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Type __selfConverted = InteropUtils.GetInstance<System.Type>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.IsGenericMethodParameter;
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_IsGenericType_Get")]
	internal static byte /* System.Boolean */ System_Type_IsGenericType_Get(void* /* System.Type */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Type __selfConverted = InteropUtils.GetInstance<System.Type>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.IsGenericType;
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_IsGenericTypeDefinition_Get")]
	internal static byte /* System.Boolean */ System_Type_IsGenericTypeDefinition_Get(void* /* System.Type */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Type __selfConverted = InteropUtils.GetInstance<System.Type>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.IsGenericTypeDefinition;
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_IsSZArray_Get")]
	internal static byte /* System.Boolean */ System_Type_IsSZArray_Get(void* /* System.Type */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Type __selfConverted = InteropUtils.GetInstance<System.Type>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.IsSZArray;
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_IsVariableBoundArray_Get")]
	internal static byte /* System.Boolean */ System_Type_IsVariableBoundArray_Get(void* /* System.Type */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Type __selfConverted = InteropUtils.GetInstance<System.Type>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.IsVariableBoundArray;
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_IsByRefLike_Get")]
	internal static byte /* System.Boolean */ System_Type_IsByRefLike_Get(void* /* System.Type */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Type __selfConverted = InteropUtils.GetInstance<System.Type>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.IsByRefLike;
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_IsFunctionPointer_Get")]
	internal static byte /* System.Boolean */ System_Type_IsFunctionPointer_Get(void* /* System.Type */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Type __selfConverted = InteropUtils.GetInstance<System.Type>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.IsFunctionPointer;
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_IsUnmanagedFunctionPointer_Get")]
	internal static byte /* System.Boolean */ System_Type_IsUnmanagedFunctionPointer_Get(void* /* System.Type */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Type __selfConverted = InteropUtils.GetInstance<System.Type>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.IsUnmanagedFunctionPointer;
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_HasElementType_Get")]
	internal static byte /* System.Boolean */ System_Type_HasElementType_Get(void* /* System.Type */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Type __selfConverted = InteropUtils.GetInstance<System.Type>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.HasElementType;
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_GenericTypeArguments_Get")]
	internal static void* /* System.Type[] */ System_Type_GenericTypeArguments_Get(void* /* System.Type */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Type __selfConverted = InteropUtils.GetInstance<System.Type>(__self);
	
	
	    try {
			System.Type[] __returnValue = __selfConverted.GenericTypeArguments;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_GenericParameterPosition_Get")]
	internal static int /* System.Int32 */ System_Type_GenericParameterPosition_Get(void* /* System.Type */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Type __selfConverted = InteropUtils.GetInstance<System.Type>(__self);
	
	
	    try {
			System.Int32 __returnValue = __selfConverted.GenericParameterPosition;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_GenericParameterAttributes_Get")]
	internal static System.Reflection.GenericParameterAttributes /* System.Reflection.GenericParameterAttributes */ System_Type_GenericParameterAttributes_Get(void* /* System.Type */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Type __selfConverted = InteropUtils.GetInstance<System.Type>(__self);
	
	
	    try {
			System.Reflection.GenericParameterAttributes __returnValue = __selfConverted.GenericParameterAttributes;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return default(System.Reflection.GenericParameterAttributes);
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_Attributes_Get")]
	internal static System.Reflection.TypeAttributes /* System.Reflection.TypeAttributes */ System_Type_Attributes_Get(void* /* System.Type */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Type __selfConverted = InteropUtils.GetInstance<System.Type>(__self);
	
	
	    try {
			System.Reflection.TypeAttributes __returnValue = __selfConverted.Attributes;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return default(System.Reflection.TypeAttributes);
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_IsAbstract_Get")]
	internal static byte /* System.Boolean */ System_Type_IsAbstract_Get(void* /* System.Type */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Type __selfConverted = InteropUtils.GetInstance<System.Type>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.IsAbstract;
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_IsImport_Get")]
	internal static byte /* System.Boolean */ System_Type_IsImport_Get(void* /* System.Type */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Type __selfConverted = InteropUtils.GetInstance<System.Type>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.IsImport;
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_IsSealed_Get")]
	internal static byte /* System.Boolean */ System_Type_IsSealed_Get(void* /* System.Type */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Type __selfConverted = InteropUtils.GetInstance<System.Type>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.IsSealed;
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_IsSpecialName_Get")]
	internal static byte /* System.Boolean */ System_Type_IsSpecialName_Get(void* /* System.Type */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Type __selfConverted = InteropUtils.GetInstance<System.Type>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.IsSpecialName;
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_IsClass_Get")]
	internal static byte /* System.Boolean */ System_Type_IsClass_Get(void* /* System.Type */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Type __selfConverted = InteropUtils.GetInstance<System.Type>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.IsClass;
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_IsNestedAssembly_Get")]
	internal static byte /* System.Boolean */ System_Type_IsNestedAssembly_Get(void* /* System.Type */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Type __selfConverted = InteropUtils.GetInstance<System.Type>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.IsNestedAssembly;
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_IsNestedFamANDAssem_Get")]
	internal static byte /* System.Boolean */ System_Type_IsNestedFamANDAssem_Get(void* /* System.Type */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Type __selfConverted = InteropUtils.GetInstance<System.Type>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.IsNestedFamANDAssem;
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_IsNestedFamily_Get")]
	internal static byte /* System.Boolean */ System_Type_IsNestedFamily_Get(void* /* System.Type */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Type __selfConverted = InteropUtils.GetInstance<System.Type>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.IsNestedFamily;
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_IsNestedFamORAssem_Get")]
	internal static byte /* System.Boolean */ System_Type_IsNestedFamORAssem_Get(void* /* System.Type */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Type __selfConverted = InteropUtils.GetInstance<System.Type>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.IsNestedFamORAssem;
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_IsNestedPrivate_Get")]
	internal static byte /* System.Boolean */ System_Type_IsNestedPrivate_Get(void* /* System.Type */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Type __selfConverted = InteropUtils.GetInstance<System.Type>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.IsNestedPrivate;
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_IsNestedPublic_Get")]
	internal static byte /* System.Boolean */ System_Type_IsNestedPublic_Get(void* /* System.Type */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Type __selfConverted = InteropUtils.GetInstance<System.Type>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.IsNestedPublic;
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_IsNotPublic_Get")]
	internal static byte /* System.Boolean */ System_Type_IsNotPublic_Get(void* /* System.Type */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Type __selfConverted = InteropUtils.GetInstance<System.Type>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.IsNotPublic;
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_IsPublic_Get")]
	internal static byte /* System.Boolean */ System_Type_IsPublic_Get(void* /* System.Type */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Type __selfConverted = InteropUtils.GetInstance<System.Type>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.IsPublic;
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_IsAutoLayout_Get")]
	internal static byte /* System.Boolean */ System_Type_IsAutoLayout_Get(void* /* System.Type */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Type __selfConverted = InteropUtils.GetInstance<System.Type>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.IsAutoLayout;
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_IsExplicitLayout_Get")]
	internal static byte /* System.Boolean */ System_Type_IsExplicitLayout_Get(void* /* System.Type */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Type __selfConverted = InteropUtils.GetInstance<System.Type>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.IsExplicitLayout;
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_IsLayoutSequential_Get")]
	internal static byte /* System.Boolean */ System_Type_IsLayoutSequential_Get(void* /* System.Type */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Type __selfConverted = InteropUtils.GetInstance<System.Type>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.IsLayoutSequential;
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_IsAnsiClass_Get")]
	internal static byte /* System.Boolean */ System_Type_IsAnsiClass_Get(void* /* System.Type */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Type __selfConverted = InteropUtils.GetInstance<System.Type>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.IsAnsiClass;
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_IsAutoClass_Get")]
	internal static byte /* System.Boolean */ System_Type_IsAutoClass_Get(void* /* System.Type */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Type __selfConverted = InteropUtils.GetInstance<System.Type>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.IsAutoClass;
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_IsUnicodeClass_Get")]
	internal static byte /* System.Boolean */ System_Type_IsUnicodeClass_Get(void* /* System.Type */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Type __selfConverted = InteropUtils.GetInstance<System.Type>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.IsUnicodeClass;
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_IsCOMObject_Get")]
	internal static byte /* System.Boolean */ System_Type_IsCOMObject_Get(void* /* System.Type */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Type __selfConverted = InteropUtils.GetInstance<System.Type>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.IsCOMObject;
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_IsContextful_Get")]
	internal static byte /* System.Boolean */ System_Type_IsContextful_Get(void* /* System.Type */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Type __selfConverted = InteropUtils.GetInstance<System.Type>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.IsContextful;
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_IsEnum_Get")]
	internal static byte /* System.Boolean */ System_Type_IsEnum_Get(void* /* System.Type */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Type __selfConverted = InteropUtils.GetInstance<System.Type>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.IsEnum;
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_IsMarshalByRef_Get")]
	internal static byte /* System.Boolean */ System_Type_IsMarshalByRef_Get(void* /* System.Type */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Type __selfConverted = InteropUtils.GetInstance<System.Type>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.IsMarshalByRef;
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_IsPrimitive_Get")]
	internal static byte /* System.Boolean */ System_Type_IsPrimitive_Get(void* /* System.Type */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Type __selfConverted = InteropUtils.GetInstance<System.Type>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.IsPrimitive;
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_IsValueType_Get")]
	internal static byte /* System.Boolean */ System_Type_IsValueType_Get(void* /* System.Type */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Type __selfConverted = InteropUtils.GetInstance<System.Type>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.IsValueType;
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_IsSignatureType_Get")]
	internal static byte /* System.Boolean */ System_Type_IsSignatureType_Get(void* /* System.Type */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Type __selfConverted = InteropUtils.GetInstance<System.Type>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.IsSignatureType;
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_IsSecurityCritical_Get")]
	internal static byte /* System.Boolean */ System_Type_IsSecurityCritical_Get(void* /* System.Type */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Type __selfConverted = InteropUtils.GetInstance<System.Type>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.IsSecurityCritical;
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_IsSecuritySafeCritical_Get")]
	internal static byte /* System.Boolean */ System_Type_IsSecuritySafeCritical_Get(void* /* System.Type */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Type __selfConverted = InteropUtils.GetInstance<System.Type>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.IsSecuritySafeCritical;
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_IsSecurityTransparent_Get")]
	internal static byte /* System.Boolean */ System_Type_IsSecurityTransparent_Get(void* /* System.Type */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Type __selfConverted = InteropUtils.GetInstance<System.Type>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.IsSecurityTransparent;
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_StructLayoutAttribute_Get")]
	internal static void* /* System.Runtime.InteropServices.StructLayoutAttribute */ System_Type_StructLayoutAttribute_Get(void* /* System.Type */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Type __selfConverted = InteropUtils.GetInstance<System.Type>(__self);
	
	
	    try {
			System.Runtime.InteropServices.StructLayoutAttribute __returnValue = __selfConverted.StructLayoutAttribute;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_TypeInitializer_Get")]
	internal static void* /* System.Reflection.ConstructorInfo */ System_Type_TypeInitializer_Get(void* /* System.Type */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Type __selfConverted = InteropUtils.GetInstance<System.Type>(__self);
	
	
	    try {
			System.Reflection.ConstructorInfo __returnValue = __selfConverted.TypeInitializer;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_TypeHandle_Get")]
	internal static void* /* System.RuntimeTypeHandle */ System_Type_TypeHandle_Get(void* /* System.Type */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Type __selfConverted = InteropUtils.GetInstance<System.Type>(__self);
	
	
	    try {
			System.RuntimeTypeHandle __returnValue = __selfConverted.TypeHandle;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_GUID_Get")]
	internal static void* /* System.Guid */ System_Type_GUID_Get(void* /* System.Type */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Type __selfConverted = InteropUtils.GetInstance<System.Type>(__self);
	
	
	    try {
			System.Guid __returnValue = __selfConverted.GUID;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_BaseType_Get")]
	internal static void* /* System.Type */ System_Type_BaseType_Get(void* /* System.Type */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Type __selfConverted = InteropUtils.GetInstance<System.Type>(__self);
	
	
	    try {
			System.Type __returnValue = __selfConverted.BaseType;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_DefaultBinder_Get")]
	internal static void* /* System.Reflection.Binder */ System_Type_DefaultBinder_Get(void** /* System.Exception */ __outException)
	{
	
	    try {
			System.Reflection.Binder __returnValue = System.Type.DefaultBinder;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_IsSerializable_Get")]
	internal static byte /* System.Boolean */ System_Type_IsSerializable_Get(void* /* System.Type */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Type __selfConverted = InteropUtils.GetInstance<System.Type>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.IsSerializable;
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_ContainsGenericParameters_Get")]
	internal static byte /* System.Boolean */ System_Type_ContainsGenericParameters_Get(void* /* System.Type */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Type __selfConverted = InteropUtils.GetInstance<System.Type>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.ContainsGenericParameters;
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_IsVisible_Get")]
	internal static byte /* System.Boolean */ System_Type_IsVisible_Get(void* /* System.Type */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Type __selfConverted = InteropUtils.GetInstance<System.Type>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.IsVisible;
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_Delimiter_Get")]
	internal static char /* System.Char */ System_Type_Delimiter_Get()
	{
	
		System.Char __returnValue = System.Type.Delimiter;
		return __returnValue;
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_EmptyTypes_Get")]
	internal static void* /* System.Type[] */ System_Type_EmptyTypes_Get()
	{
	
		System.Type[] __returnValue = System.Type.EmptyTypes;
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_Missing_Get")]
	internal static void* /* System.Object */ System_Type_Missing_Get()
	{
	
		System.Object __returnValue = System.Type.Missing;
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_FilterAttribute_Get")]
	internal static void* /* System.Reflection.MemberFilter */ System_Type_FilterAttribute_Get()
	{
	
		System.Reflection.MemberFilter __returnValue = System.Type.FilterAttribute;
		void* __returnValueNative = new System_Reflection_MemberFilter(__returnValue).AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_FilterName_Get")]
	internal static void* /* System.Reflection.MemberFilter */ System_Type_FilterName_Get()
	{
	
		System.Reflection.MemberFilter __returnValue = System.Type.FilterName;
		void* __returnValueNative = new System_Reflection_MemberFilter(__returnValue).AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_FilterNameIgnoreCase_Get")]
	internal static void* /* System.Reflection.MemberFilter */ System_Type_FilterNameIgnoreCase_Get()
	{
	
		System.Reflection.MemberFilter __returnValue = System.Type.FilterNameIgnoreCase;
		void* __returnValueNative = new System_Reflection_MemberFilter(__returnValue).AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_TypeOf")]
	internal static void* /* System.Type */ System_Type_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.Type);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Type_Destroy")]
	internal static void /* System.Void */ System_Type_Destroy(void* /* System.Type */ __self)
	{
	
		InteropUtils.FreeIfAllocated(__self);
	}
	
}


internal unsafe class System_Reflection_MemberInfo
{
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_MemberInfo_HasSameMetadataDefinitionAs")]
	internal static byte /* System.Boolean */ System_Reflection_MemberInfo_HasSameMetadataDefinitionAs(void* /* System.Reflection.MemberInfo */ __self, void* /* System.Reflection.MemberInfo */ other, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.MemberInfo __selfConverted = InteropUtils.GetInstance<System.Reflection.MemberInfo>(__self);
	
		System.Reflection.MemberInfo otherConverted = InteropUtils.GetInstance<System.Reflection.MemberInfo>(other);
	
	    try {
			System.Boolean __returnValue = __selfConverted.HasSameMetadataDefinitionAs(otherConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_MemberInfo_IsDefined")]
	internal static byte /* System.Boolean */ System_Reflection_MemberInfo_IsDefined(void* /* System.Reflection.MemberInfo */ __self, void* /* System.Type */ attributeType, byte /* System.Boolean */ inherit, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.MemberInfo __selfConverted = InteropUtils.GetInstance<System.Reflection.MemberInfo>(__self);
	
		System.Type attributeTypeConverted = InteropUtils.GetInstance<System.Type>(attributeType);
		System.Boolean inheritConverted = inherit.ToBool();
	
	    try {
			System.Boolean __returnValue = __selfConverted.IsDefined(attributeTypeConverted, inheritConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_MemberInfo_GetCustomAttributes")]
	internal static void* /* System.Object[] */ System_Reflection_MemberInfo_GetCustomAttributes(void* /* System.Reflection.MemberInfo */ __self, byte /* System.Boolean */ inherit, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.MemberInfo __selfConverted = InteropUtils.GetInstance<System.Reflection.MemberInfo>(__self);
	
		System.Boolean inheritConverted = inherit.ToBool();
	
	    try {
			System.Object[] __returnValue = __selfConverted.GetCustomAttributes(inheritConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_MemberInfo_GetCustomAttributes_1")]
	internal static void* /* System.Object[] */ System_Reflection_MemberInfo_GetCustomAttributes_1(void* /* System.Reflection.MemberInfo */ __self, void* /* System.Type */ attributeType, byte /* System.Boolean */ inherit, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.MemberInfo __selfConverted = InteropUtils.GetInstance<System.Reflection.MemberInfo>(__self);
	
		System.Type attributeTypeConverted = InteropUtils.GetInstance<System.Type>(attributeType);
		System.Boolean inheritConverted = inherit.ToBool();
	
	    try {
			System.Object[] __returnValue = __selfConverted.GetCustomAttributes(attributeTypeConverted, inheritConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_MemberInfo_Equals")]
	internal static byte /* System.Boolean */ System_Reflection_MemberInfo_Equals(void* /* System.Reflection.MemberInfo */ __self, void* /* System.Object */ obj, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.MemberInfo __selfConverted = InteropUtils.GetInstance<System.Reflection.MemberInfo>(__self);
	
		System.Object objConverted = InteropUtils.GetInstance<System.Object>(obj);
	
	    try {
			System.Boolean __returnValue = __selfConverted.Equals(objConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_MemberInfo_GetHashCode")]
	internal static int /* System.Int32 */ System_Reflection_MemberInfo_GetHashCode(void* /* System.Reflection.MemberInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.MemberInfo __selfConverted = InteropUtils.GetInstance<System.Reflection.MemberInfo>(__self);
	
	
	    try {
			System.Int32 __returnValue = __selfConverted.GetHashCode();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_MemberInfo_MemberType_Get")]
	internal static System.Reflection.MemberTypes /* System.Reflection.MemberTypes */ System_Reflection_MemberInfo_MemberType_Get(void* /* System.Reflection.MemberInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.MemberInfo __selfConverted = InteropUtils.GetInstance<System.Reflection.MemberInfo>(__self);
	
	
	    try {
			System.Reflection.MemberTypes __returnValue = __selfConverted.MemberType;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return default(System.Reflection.MemberTypes);
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_MemberInfo_Name_Get")]
	internal static void* /* System.String */ System_Reflection_MemberInfo_Name_Get(void* /* System.Reflection.MemberInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.MemberInfo __selfConverted = InteropUtils.GetInstance<System.Reflection.MemberInfo>(__self);
	
	
	    try {
			System.String __returnValue = __selfConverted.Name;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_MemberInfo_DeclaringType_Get")]
	internal static void* /* System.Type */ System_Reflection_MemberInfo_DeclaringType_Get(void* /* System.Reflection.MemberInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.MemberInfo __selfConverted = InteropUtils.GetInstance<System.Reflection.MemberInfo>(__self);
	
	
	    try {
			System.Type __returnValue = __selfConverted.DeclaringType;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_MemberInfo_ReflectedType_Get")]
	internal static void* /* System.Type */ System_Reflection_MemberInfo_ReflectedType_Get(void* /* System.Reflection.MemberInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.MemberInfo __selfConverted = InteropUtils.GetInstance<System.Reflection.MemberInfo>(__self);
	
	
	    try {
			System.Type __returnValue = __selfConverted.ReflectedType;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_MemberInfo_Module_Get")]
	internal static void* /* System.Reflection.Module */ System_Reflection_MemberInfo_Module_Get(void* /* System.Reflection.MemberInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.MemberInfo __selfConverted = InteropUtils.GetInstance<System.Reflection.MemberInfo>(__self);
	
	
	    try {
			System.Reflection.Module __returnValue = __selfConverted.Module;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_MemberInfo_IsCollectible_Get")]
	internal static byte /* System.Boolean */ System_Reflection_MemberInfo_IsCollectible_Get(void* /* System.Reflection.MemberInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.MemberInfo __selfConverted = InteropUtils.GetInstance<System.Reflection.MemberInfo>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.IsCollectible;
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_MemberInfo_MetadataToken_Get")]
	internal static int /* System.Int32 */ System_Reflection_MemberInfo_MetadataToken_Get(void* /* System.Reflection.MemberInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.MemberInfo __selfConverted = InteropUtils.GetInstance<System.Reflection.MemberInfo>(__self);
	
	
	    try {
			System.Int32 __returnValue = __selfConverted.MetadataToken;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_MemberInfo_TypeOf")]
	internal static void* /* System.Type */ System_Reflection_MemberInfo_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.Reflection.MemberInfo);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_MemberInfo_Destroy")]
	internal static void /* System.Void */ System_Reflection_MemberInfo_Destroy(void* /* System.Reflection.MemberInfo */ __self)
	{
	
		InteropUtils.FreeIfAllocated(__self);
	}
	
}


internal unsafe class System_Reflection_ICustomAttributeProvider
{
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_ICustomAttributeProvider_GetCustomAttributes")]
	internal static void* /* System.Object[] */ System_Reflection_ICustomAttributeProvider_GetCustomAttributes(void* /* System.Reflection.ICustomAttributeProvider */ __self, byte /* System.Boolean */ inherit, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.ICustomAttributeProvider __selfConverted = InteropUtils.GetInstance<System.Reflection.ICustomAttributeProvider>(__self);
	
		System.Boolean inheritConverted = inherit.ToBool();
	
	    try {
			System.Object[] __returnValue = __selfConverted.GetCustomAttributes(inheritConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_ICustomAttributeProvider_GetCustomAttributes_1")]
	internal static void* /* System.Object[] */ System_Reflection_ICustomAttributeProvider_GetCustomAttributes_1(void* /* System.Reflection.ICustomAttributeProvider */ __self, void* /* System.Type */ attributeType, byte /* System.Boolean */ inherit, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.ICustomAttributeProvider __selfConverted = InteropUtils.GetInstance<System.Reflection.ICustomAttributeProvider>(__self);
	
		System.Type attributeTypeConverted = InteropUtils.GetInstance<System.Type>(attributeType);
		System.Boolean inheritConverted = inherit.ToBool();
	
	    try {
			System.Object[] __returnValue = __selfConverted.GetCustomAttributes(attributeTypeConverted, inheritConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_ICustomAttributeProvider_IsDefined")]
	internal static byte /* System.Boolean */ System_Reflection_ICustomAttributeProvider_IsDefined(void* /* System.Reflection.ICustomAttributeProvider */ __self, void* /* System.Type */ attributeType, byte /* System.Boolean */ inherit, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.ICustomAttributeProvider __selfConverted = InteropUtils.GetInstance<System.Reflection.ICustomAttributeProvider>(__self);
	
		System.Type attributeTypeConverted = InteropUtils.GetInstance<System.Type>(attributeType);
		System.Boolean inheritConverted = inherit.ToBool();
	
	    try {
			System.Boolean __returnValue = __selfConverted.IsDefined(attributeTypeConverted, inheritConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_ICustomAttributeProvider_TypeOf")]
	internal static void* /* System.Type */ System_Reflection_ICustomAttributeProvider_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.Reflection.ICustomAttributeProvider);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_ICustomAttributeProvider_Destroy")]
	internal static void /* System.Void */ System_Reflection_ICustomAttributeProvider_Destroy(void* /* System.Reflection.ICustomAttributeProvider */ __self)
	{
	
		InteropUtils.FreeIfAllocated(__self);
	}
	
}



internal unsafe class System_Array
{
	[UnmanagedCallersOnly(EntryPoint = "System_Array_ConstrainedCopy")]
	internal static void /* System.Void */ System_Array_ConstrainedCopy(void* /* System.Array */ sourceArray, int /* System.Int32 */ sourceIndex, void* /* System.Array */ destinationArray, int /* System.Int32 */ destinationIndex, int /* System.Int32 */ length, void** /* System.Exception */ __outException)
	{
		System.Array sourceArrayConverted = InteropUtils.GetInstance<System.Array>(sourceArray);
		System.Array destinationArrayConverted = InteropUtils.GetInstance<System.Array>(destinationArray);
	
	    try {
			System.Array.ConstrainedCopy(sourceArrayConverted, sourceIndex, destinationArrayConverted, destinationIndex, length);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Array_Clear")]
	internal static void /* System.Void */ System_Array_Clear(void* /* System.Array */ array, void** /* System.Exception */ __outException)
	{
		System.Array arrayConverted = InteropUtils.GetInstance<System.Array>(array);
	
	    try {
			System.Array.Clear(arrayConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Array_Clear_1")]
	internal static void /* System.Void */ System_Array_Clear_1(void* /* System.Array */ array, int /* System.Int32 */ index, int /* System.Int32 */ length, void** /* System.Exception */ __outException)
	{
		System.Array arrayConverted = InteropUtils.GetInstance<System.Array>(array);
	
	    try {
			System.Array.Clear(arrayConverted, index, length);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Array_GetLength")]
	internal static int /* System.Int32 */ System_Array_GetLength(void* /* System.Array */ __self, int /* System.Int32 */ dimension, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Array __selfConverted = InteropUtils.GetInstance<System.Array>(__self);
	
	
	    try {
			System.Int32 __returnValue = __selfConverted.GetLength(dimension);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Array_GetUpperBound")]
	internal static int /* System.Int32 */ System_Array_GetUpperBound(void* /* System.Array */ __self, int /* System.Int32 */ dimension, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Array __selfConverted = InteropUtils.GetInstance<System.Array>(__self);
	
	
	    try {
			System.Int32 __returnValue = __selfConverted.GetUpperBound(dimension);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Array_GetLowerBound")]
	internal static int /* System.Int32 */ System_Array_GetLowerBound(void* /* System.Array */ __self, int /* System.Int32 */ dimension, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Array __selfConverted = InteropUtils.GetInstance<System.Array>(__self);
	
	
	    try {
			System.Int32 __returnValue = __selfConverted.GetLowerBound(dimension);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Array_Initialize")]
	internal static void /* System.Void */ System_Array_Initialize(void* /* System.Array */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Array __selfConverted = InteropUtils.GetInstance<System.Array>(__self);
	
	
	    try {
			__selfConverted.Initialize();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	// TODO: Generic Methods with out/ref parameters that are arrays are not supported
	[UnmanagedCallersOnly(EntryPoint = "System_Array_CreateInstance")]
	internal static void* /* System.Array */ System_Array_CreateInstance(void* /* System.Type */ elementType, int /* System.Int32 */ length, void** /* System.Exception */ __outException)
	{
		System.Type elementTypeConverted = InteropUtils.GetInstance<System.Type>(elementType);
	
	    try {
			System.Array __returnValue = System.Array.CreateInstance(elementTypeConverted, length);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Array_CreateInstance_1")]
	internal static void* /* System.Array */ System_Array_CreateInstance_1(void* /* System.Type */ elementType, int /* System.Int32 */ length1, int /* System.Int32 */ length2, void** /* System.Exception */ __outException)
	{
		System.Type elementTypeConverted = InteropUtils.GetInstance<System.Type>(elementType);
	
	    try {
			System.Array __returnValue = System.Array.CreateInstance(elementTypeConverted, length1, length2);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Array_CreateInstance_2")]
	internal static void* /* System.Array */ System_Array_CreateInstance_2(void* /* System.Type */ elementType, int /* System.Int32 */ length1, int /* System.Int32 */ length2, int /* System.Int32 */ length3, void** /* System.Exception */ __outException)
	{
		System.Type elementTypeConverted = InteropUtils.GetInstance<System.Type>(elementType);
	
	    try {
			System.Array __returnValue = System.Array.CreateInstance(elementTypeConverted, length1, length2, length3);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Array_CreateInstance_3")]
	internal static void* /* System.Array */ System_Array_CreateInstance_3(void* /* System.Type */ elementType, void* /* System.Int32[] */ lengths, void** /* System.Exception */ __outException)
	{
		System.Type elementTypeConverted = InteropUtils.GetInstance<System.Type>(elementType);
		System.Int32[] lengthsConverted = InteropUtils.GetInstance<System.Int32[]>(lengths);
	
	    try {
			System.Array __returnValue = System.Array.CreateInstance(elementTypeConverted, lengthsConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Array_CreateInstance_4")]
	internal static void* /* System.Array */ System_Array_CreateInstance_4(void* /* System.Type */ elementType, void* /* System.Int32[] */ lengths, void* /* System.Int32[] */ lowerBounds, void** /* System.Exception */ __outException)
	{
		System.Type elementTypeConverted = InteropUtils.GetInstance<System.Type>(elementType);
		System.Int32[] lengthsConverted = InteropUtils.GetInstance<System.Int32[]>(lengths);
		System.Int32[] lowerBoundsConverted = InteropUtils.GetInstance<System.Int32[]>(lowerBounds);
	
	    try {
			System.Array __returnValue = System.Array.CreateInstance(elementTypeConverted, lengthsConverted, lowerBoundsConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Array_CreateInstance_5")]
	internal static void* /* System.Array */ System_Array_CreateInstance_5(void* /* System.Type */ elementType, void* /* System.Int64[] */ lengths, void** /* System.Exception */ __outException)
	{
		System.Type elementTypeConverted = InteropUtils.GetInstance<System.Type>(elementType);
		System.Int64[] lengthsConverted = InteropUtils.GetInstance<System.Int64[]>(lengths);
	
	    try {
			System.Array __returnValue = System.Array.CreateInstance(elementTypeConverted, lengthsConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Array_Copy")]
	internal static void /* System.Void */ System_Array_Copy(void* /* System.Array */ sourceArray, void* /* System.Array */ destinationArray, long /* System.Int64 */ length, void** /* System.Exception */ __outException)
	{
		System.Array sourceArrayConverted = InteropUtils.GetInstance<System.Array>(sourceArray);
		System.Array destinationArrayConverted = InteropUtils.GetInstance<System.Array>(destinationArray);
	
	    try {
			System.Array.Copy(sourceArrayConverted, destinationArrayConverted, length);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Array_Copy_1")]
	internal static void /* System.Void */ System_Array_Copy_1(void* /* System.Array */ sourceArray, long /* System.Int64 */ sourceIndex, void* /* System.Array */ destinationArray, long /* System.Int64 */ destinationIndex, long /* System.Int64 */ length, void** /* System.Exception */ __outException)
	{
		System.Array sourceArrayConverted = InteropUtils.GetInstance<System.Array>(sourceArray);
		System.Array destinationArrayConverted = InteropUtils.GetInstance<System.Array>(destinationArray);
	
	    try {
			System.Array.Copy(sourceArrayConverted, sourceIndex, destinationArrayConverted, destinationIndex, length);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Array_Copy_2")]
	internal static void /* System.Void */ System_Array_Copy_2(void* /* System.Array */ sourceArray, void* /* System.Array */ destinationArray, int /* System.Int32 */ length, void** /* System.Exception */ __outException)
	{
		System.Array sourceArrayConverted = InteropUtils.GetInstance<System.Array>(sourceArray);
		System.Array destinationArrayConverted = InteropUtils.GetInstance<System.Array>(destinationArray);
	
	    try {
			System.Array.Copy(sourceArrayConverted, destinationArrayConverted, length);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Array_Copy_3")]
	internal static void /* System.Void */ System_Array_Copy_3(void* /* System.Array */ sourceArray, int /* System.Int32 */ sourceIndex, void* /* System.Array */ destinationArray, int /* System.Int32 */ destinationIndex, int /* System.Int32 */ length, void** /* System.Exception */ __outException)
	{
		System.Array sourceArrayConverted = InteropUtils.GetInstance<System.Array>(sourceArray);
		System.Array destinationArrayConverted = InteropUtils.GetInstance<System.Array>(destinationArray);
	
	    try {
			System.Array.Copy(sourceArrayConverted, sourceIndex, destinationArrayConverted, destinationIndex, length);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Array_GetValue")]
	internal static void* /* System.Object */ System_Array_GetValue(void* /* System.Array */ __self, void* /* System.Int32[] */ indices, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Array __selfConverted = InteropUtils.GetInstance<System.Array>(__self);
	
		System.Int32[] indicesConverted = InteropUtils.GetInstance<System.Int32[]>(indices);
	
	    try {
			System.Object __returnValue = __selfConverted.GetValue(indicesConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Array_GetValue_1")]
	internal static void* /* System.Object */ System_Array_GetValue_1(void* /* System.Array */ __self, int /* System.Int32 */ index, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Array __selfConverted = InteropUtils.GetInstance<System.Array>(__self);
	
	
	    try {
			System.Object __returnValue = __selfConverted.GetValue(index);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Array_GetValue_2")]
	internal static void* /* System.Object */ System_Array_GetValue_2(void* /* System.Array */ __self, int /* System.Int32 */ index1, int /* System.Int32 */ index2, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Array __selfConverted = InteropUtils.GetInstance<System.Array>(__self);
	
	
	    try {
			System.Object __returnValue = __selfConverted.GetValue(index1, index2);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Array_GetValue_3")]
	internal static void* /* System.Object */ System_Array_GetValue_3(void* /* System.Array */ __self, int /* System.Int32 */ index1, int /* System.Int32 */ index2, int /* System.Int32 */ index3, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Array __selfConverted = InteropUtils.GetInstance<System.Array>(__self);
	
	
	    try {
			System.Object __returnValue = __selfConverted.GetValue(index1, index2, index3);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Array_SetValue")]
	internal static void /* System.Void */ System_Array_SetValue(void* /* System.Array */ __self, void* /* System.Object */ value, int /* System.Int32 */ index, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Array __selfConverted = InteropUtils.GetInstance<System.Array>(__self);
	
		System.Object valueConverted = InteropUtils.GetInstance<System.Object>(value);
	
	    try {
			__selfConverted.SetValue(valueConverted, index);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Array_SetValue_1")]
	internal static void /* System.Void */ System_Array_SetValue_1(void* /* System.Array */ __self, void* /* System.Object */ value, int /* System.Int32 */ index1, int /* System.Int32 */ index2, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Array __selfConverted = InteropUtils.GetInstance<System.Array>(__self);
	
		System.Object valueConverted = InteropUtils.GetInstance<System.Object>(value);
	
	    try {
			__selfConverted.SetValue(valueConverted, index1, index2);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Array_SetValue_2")]
	internal static void /* System.Void */ System_Array_SetValue_2(void* /* System.Array */ __self, void* /* System.Object */ value, int /* System.Int32 */ index1, int /* System.Int32 */ index2, int /* System.Int32 */ index3, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Array __selfConverted = InteropUtils.GetInstance<System.Array>(__self);
	
		System.Object valueConverted = InteropUtils.GetInstance<System.Object>(value);
	
	    try {
			__selfConverted.SetValue(valueConverted, index1, index2, index3);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Array_SetValue_3")]
	internal static void /* System.Void */ System_Array_SetValue_3(void* /* System.Array */ __self, void* /* System.Object */ value, void* /* System.Int32[] */ indices, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Array __selfConverted = InteropUtils.GetInstance<System.Array>(__self);
	
		System.Object valueConverted = InteropUtils.GetInstance<System.Object>(value);
		System.Int32[] indicesConverted = InteropUtils.GetInstance<System.Int32[]>(indices);
	
	    try {
			__selfConverted.SetValue(valueConverted, indicesConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Array_GetValue_4")]
	internal static void* /* System.Object */ System_Array_GetValue_4(void* /* System.Array */ __self, long /* System.Int64 */ index, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Array __selfConverted = InteropUtils.GetInstance<System.Array>(__self);
	
	
	    try {
			System.Object __returnValue = __selfConverted.GetValue(index);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Array_GetValue_5")]
	internal static void* /* System.Object */ System_Array_GetValue_5(void* /* System.Array */ __self, long /* System.Int64 */ index1, long /* System.Int64 */ index2, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Array __selfConverted = InteropUtils.GetInstance<System.Array>(__self);
	
	
	    try {
			System.Object __returnValue = __selfConverted.GetValue(index1, index2);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Array_GetValue_6")]
	internal static void* /* System.Object */ System_Array_GetValue_6(void* /* System.Array */ __self, long /* System.Int64 */ index1, long /* System.Int64 */ index2, long /* System.Int64 */ index3, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Array __selfConverted = InteropUtils.GetInstance<System.Array>(__self);
	
	
	    try {
			System.Object __returnValue = __selfConverted.GetValue(index1, index2, index3);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Array_GetValue_7")]
	internal static void* /* System.Object */ System_Array_GetValue_7(void* /* System.Array */ __self, void* /* System.Int64[] */ indices, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Array __selfConverted = InteropUtils.GetInstance<System.Array>(__self);
	
		System.Int64[] indicesConverted = InteropUtils.GetInstance<System.Int64[]>(indices);
	
	    try {
			System.Object __returnValue = __selfConverted.GetValue(indicesConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Array_SetValue_4")]
	internal static void /* System.Void */ System_Array_SetValue_4(void* /* System.Array */ __self, void* /* System.Object */ value, long /* System.Int64 */ index, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Array __selfConverted = InteropUtils.GetInstance<System.Array>(__self);
	
		System.Object valueConverted = InteropUtils.GetInstance<System.Object>(value);
	
	    try {
			__selfConverted.SetValue(valueConverted, index);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Array_SetValue_5")]
	internal static void /* System.Void */ System_Array_SetValue_5(void* /* System.Array */ __self, void* /* System.Object */ value, long /* System.Int64 */ index1, long /* System.Int64 */ index2, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Array __selfConverted = InteropUtils.GetInstance<System.Array>(__self);
	
		System.Object valueConverted = InteropUtils.GetInstance<System.Object>(value);
	
	    try {
			__selfConverted.SetValue(valueConverted, index1, index2);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Array_SetValue_6")]
	internal static void /* System.Void */ System_Array_SetValue_6(void* /* System.Array */ __self, void* /* System.Object */ value, long /* System.Int64 */ index1, long /* System.Int64 */ index2, long /* System.Int64 */ index3, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Array __selfConverted = InteropUtils.GetInstance<System.Array>(__self);
	
		System.Object valueConverted = InteropUtils.GetInstance<System.Object>(value);
	
	    try {
			__selfConverted.SetValue(valueConverted, index1, index2, index3);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Array_SetValue_7")]
	internal static void /* System.Void */ System_Array_SetValue_7(void* /* System.Array */ __self, void* /* System.Object */ value, void* /* System.Int64[] */ indices, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Array __selfConverted = InteropUtils.GetInstance<System.Array>(__self);
	
		System.Object valueConverted = InteropUtils.GetInstance<System.Object>(value);
		System.Int64[] indicesConverted = InteropUtils.GetInstance<System.Int64[]>(indices);
	
	    try {
			__selfConverted.SetValue(valueConverted, indicesConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Array_GetLongLength")]
	internal static long /* System.Int64 */ System_Array_GetLongLength(void* /* System.Array */ __self, int /* System.Int32 */ dimension, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Array __selfConverted = InteropUtils.GetInstance<System.Array>(__self);
	
	
	    try {
			System.Int64 __returnValue = __selfConverted.GetLongLength(dimension);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Array_Clone")]
	internal static void* /* System.Object */ System_Array_Clone(void* /* System.Array */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Array __selfConverted = InteropUtils.GetInstance<System.Array>(__self);
	
	
	    try {
			System.Object __returnValue = __selfConverted.Clone();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Array_BinarySearch")]
	internal static int /* System.Int32 */ System_Array_BinarySearch(void* /* System.Array */ array, void* /* System.Object */ value, void** /* System.Exception */ __outException)
	{
		System.Array arrayConverted = InteropUtils.GetInstance<System.Array>(array);
		System.Object valueConverted = InteropUtils.GetInstance<System.Object>(value);
	
	    try {
			System.Int32 __returnValue = System.Array.BinarySearch(arrayConverted, valueConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Array_BinarySearch_1")]
	internal static int /* System.Int32 */ System_Array_BinarySearch_1(void* /* System.Array */ array, int /* System.Int32 */ index, int /* System.Int32 */ length, void* /* System.Object */ value, void** /* System.Exception */ __outException)
	{
		System.Array arrayConverted = InteropUtils.GetInstance<System.Array>(array);
		System.Object valueConverted = InteropUtils.GetInstance<System.Object>(value);
	
	    try {
			System.Int32 __returnValue = System.Array.BinarySearch(arrayConverted, index, length, valueConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Array_BinarySearch_2")]
	internal static int /* System.Int32 */ System_Array_BinarySearch_2(void* /* System.Array */ array, void* /* System.Object */ value, void* /* System.Collections.IComparer */ comparer, void** /* System.Exception */ __outException)
	{
		System.Array arrayConverted = InteropUtils.GetInstance<System.Array>(array);
		System.Object valueConverted = InteropUtils.GetInstance<System.Object>(value);
		System.Collections.IComparer comparerConverted = InteropUtils.GetInstance<System.Collections.IComparer>(comparer);
	
	    try {
			System.Int32 __returnValue = System.Array.BinarySearch(arrayConverted, valueConverted, comparerConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Array_BinarySearch_3")]
	internal static int /* System.Int32 */ System_Array_BinarySearch_3(void* /* System.Array */ array, int /* System.Int32 */ index, int /* System.Int32 */ length, void* /* System.Object */ value, void* /* System.Collections.IComparer */ comparer, void** /* System.Exception */ __outException)
	{
		System.Array arrayConverted = InteropUtils.GetInstance<System.Array>(array);
		System.Object valueConverted = InteropUtils.GetInstance<System.Object>(value);
		System.Collections.IComparer comparerConverted = InteropUtils.GetInstance<System.Collections.IComparer>(comparer);
	
	    try {
			System.Int32 __returnValue = System.Array.BinarySearch(arrayConverted, index, length, valueConverted, comparerConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Array_CopyTo")]
	internal static void /* System.Void */ System_Array_CopyTo(void* /* System.Array */ __self, void* /* System.Array */ array, int /* System.Int32 */ index, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Array __selfConverted = InteropUtils.GetInstance<System.Array>(__self);
	
		System.Array arrayConverted = InteropUtils.GetInstance<System.Array>(array);
	
	    try {
			__selfConverted.CopyTo(arrayConverted, index);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Array_CopyTo_1")]
	internal static void /* System.Void */ System_Array_CopyTo_1(void* /* System.Array */ __self, void* /* System.Array */ array, long /* System.Int64 */ index, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Array __selfConverted = InteropUtils.GetInstance<System.Array>(__self);
	
		System.Array arrayConverted = InteropUtils.GetInstance<System.Array>(array);
	
	    try {
			__selfConverted.CopyTo(arrayConverted, index);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Array_Empty_A1")]
	internal static void* /* System.Array */ System_Array_Empty_A1(void* /* System.Type */ T, void** /* System.Exception */ __outException)
	{
		System.Type TConverted = InteropUtils.GetInstance<System.Type>(T);
	
	    try {
			System.Type __targetTypeForGenericCall = typeof(System.Array);
			System.String __memberNameForGenericCall = nameof(System.Array.Empty);
			System.Object? __methodTargetForGenericCall = null;
	
			System.Object[]? __parametersForGenericCall = null;
			System.Type[] __parameterTypesForGenericCall = System.Type.EmptyTypes;
	
			System.Type[] __genericParameterTypesForGenericCall = new System.Type[] { TConverted };
	
			System.Reflection.MethodInfo __methodForGenericCall = __targetTypeForGenericCall.GetMethod(__memberNameForGenericCall, 1, __parameterTypesForGenericCall) ?? throw new Exception("Method Empty not found");
			System.Reflection.MethodInfo __genericMethodForGenericCall = __methodForGenericCall.MakeGenericMethod(__genericParameterTypesForGenericCall);
	
			System.Array __returnValue = (System.Array)__genericMethodForGenericCall.Invoke(__methodTargetForGenericCall, __parametersForGenericCall);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Array_IndexOf")]
	internal static int /* System.Int32 */ System_Array_IndexOf(void* /* System.Array */ array, void* /* System.Object */ value, void** /* System.Exception */ __outException)
	{
		System.Array arrayConverted = InteropUtils.GetInstance<System.Array>(array);
		System.Object valueConverted = InteropUtils.GetInstance<System.Object>(value);
	
	    try {
			System.Int32 __returnValue = System.Array.IndexOf(arrayConverted, valueConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Array_IndexOf_1")]
	internal static int /* System.Int32 */ System_Array_IndexOf_1(void* /* System.Array */ array, void* /* System.Object */ value, int /* System.Int32 */ startIndex, void** /* System.Exception */ __outException)
	{
		System.Array arrayConverted = InteropUtils.GetInstance<System.Array>(array);
		System.Object valueConverted = InteropUtils.GetInstance<System.Object>(value);
	
	    try {
			System.Int32 __returnValue = System.Array.IndexOf(arrayConverted, valueConverted, startIndex);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Array_IndexOf_2")]
	internal static int /* System.Int32 */ System_Array_IndexOf_2(void* /* System.Array */ array, void* /* System.Object */ value, int /* System.Int32 */ startIndex, int /* System.Int32 */ count, void** /* System.Exception */ __outException)
	{
		System.Array arrayConverted = InteropUtils.GetInstance<System.Array>(array);
		System.Object valueConverted = InteropUtils.GetInstance<System.Object>(value);
	
	    try {
			System.Int32 __returnValue = System.Array.IndexOf(arrayConverted, valueConverted, startIndex, count);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Array_LastIndexOf")]
	internal static int /* System.Int32 */ System_Array_LastIndexOf(void* /* System.Array */ array, void* /* System.Object */ value, void** /* System.Exception */ __outException)
	{
		System.Array arrayConverted = InteropUtils.GetInstance<System.Array>(array);
		System.Object valueConverted = InteropUtils.GetInstance<System.Object>(value);
	
	    try {
			System.Int32 __returnValue = System.Array.LastIndexOf(arrayConverted, valueConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Array_LastIndexOf_1")]
	internal static int /* System.Int32 */ System_Array_LastIndexOf_1(void* /* System.Array */ array, void* /* System.Object */ value, int /* System.Int32 */ startIndex, void** /* System.Exception */ __outException)
	{
		System.Array arrayConverted = InteropUtils.GetInstance<System.Array>(array);
		System.Object valueConverted = InteropUtils.GetInstance<System.Object>(value);
	
	    try {
			System.Int32 __returnValue = System.Array.LastIndexOf(arrayConverted, valueConverted, startIndex);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Array_LastIndexOf_2")]
	internal static int /* System.Int32 */ System_Array_LastIndexOf_2(void* /* System.Array */ array, void* /* System.Object */ value, int /* System.Int32 */ startIndex, int /* System.Int32 */ count, void** /* System.Exception */ __outException)
	{
		System.Array arrayConverted = InteropUtils.GetInstance<System.Array>(array);
		System.Object valueConverted = InteropUtils.GetInstance<System.Object>(value);
	
	    try {
			System.Int32 __returnValue = System.Array.LastIndexOf(arrayConverted, valueConverted, startIndex, count);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Array_Reverse")]
	internal static void /* System.Void */ System_Array_Reverse(void* /* System.Array */ array, void** /* System.Exception */ __outException)
	{
		System.Array arrayConverted = InteropUtils.GetInstance<System.Array>(array);
	
	    try {
			System.Array.Reverse(arrayConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Array_Reverse_1")]
	internal static void /* System.Void */ System_Array_Reverse_1(void* /* System.Array */ array, int /* System.Int32 */ index, int /* System.Int32 */ length, void** /* System.Exception */ __outException)
	{
		System.Array arrayConverted = InteropUtils.GetInstance<System.Array>(array);
	
	    try {
			System.Array.Reverse(arrayConverted, index, length);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Array_Reverse_A1")]
	internal static void /* System.Void */ System_Array_Reverse_A1(void* /* System.Type */ T, void* /* T[] */ array, void** /* System.Exception */ __outException)
	{
		System.Type TConverted = InteropUtils.GetInstance<System.Type>(T);
		System.Array arrayConverted = InteropUtils.GetInstance<System.Array>(array);
	
	    try {
			System.Type __targetTypeForGenericCall = typeof(System.Array);
			System.String __memberNameForGenericCall = nameof(System.Array.Reverse);
			System.Object? __methodTargetForGenericCall = null;
	
			System.Object[] __parametersForGenericCall = new System.Object[] { arrayConverted };
			System.Type[] __parameterTypesForGenericCall = new System.Type[] { System.Type.MakeGenericMethodParameter(0).MakeArrayType() };
	
			System.Type[] __genericParameterTypesForGenericCall = new System.Type[] { TConverted };
	
			System.Reflection.MethodInfo __methodForGenericCall = __targetTypeForGenericCall.GetMethod(__memberNameForGenericCall, 1, __parameterTypesForGenericCall) ?? throw new Exception("Method Reverse not found");
			System.Reflection.MethodInfo __genericMethodForGenericCall = __methodForGenericCall.MakeGenericMethod(__genericParameterTypesForGenericCall);
	
			__genericMethodForGenericCall.Invoke(__methodTargetForGenericCall, __parametersForGenericCall);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Array_Reverse_A1_1")]
	internal static void /* System.Void */ System_Array_Reverse_A1_1(void* /* System.Type */ T, void* /* T[] */ array, int /* System.Int32 */ index, int /* System.Int32 */ length, void** /* System.Exception */ __outException)
	{
		System.Type TConverted = InteropUtils.GetInstance<System.Type>(T);
		System.Array arrayConverted = InteropUtils.GetInstance<System.Array>(array);
	
	    try {
			System.Type __targetTypeForGenericCall = typeof(System.Array);
			System.String __memberNameForGenericCall = nameof(System.Array.Reverse);
			System.Object? __methodTargetForGenericCall = null;
	
			System.Object[] __parametersForGenericCall = new System.Object[] { arrayConverted, index, length };
			System.Type[] __parameterTypesForGenericCall = new System.Type[] { System.Type.MakeGenericMethodParameter(0).MakeArrayType(), typeof(System.Int32), typeof(System.Int32) };
	
			System.Type[] __genericParameterTypesForGenericCall = new System.Type[] { TConverted };
	
			System.Reflection.MethodInfo __methodForGenericCall = __targetTypeForGenericCall.GetMethod(__memberNameForGenericCall, 1, __parameterTypesForGenericCall) ?? throw new Exception("Method Reverse not found");
			System.Reflection.MethodInfo __genericMethodForGenericCall = __methodForGenericCall.MakeGenericMethod(__genericParameterTypesForGenericCall);
	
			__genericMethodForGenericCall.Invoke(__methodTargetForGenericCall, __parametersForGenericCall);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Array_Sort")]
	internal static void /* System.Void */ System_Array_Sort(void* /* System.Array */ array, void** /* System.Exception */ __outException)
	{
		System.Array arrayConverted = InteropUtils.GetInstance<System.Array>(array);
	
	    try {
			System.Array.Sort(arrayConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Array_Sort_1")]
	internal static void /* System.Void */ System_Array_Sort_1(void* /* System.Array */ keys, void* /* System.Array */ items, void** /* System.Exception */ __outException)
	{
		System.Array keysConverted = InteropUtils.GetInstance<System.Array>(keys);
		System.Array itemsConverted = InteropUtils.GetInstance<System.Array>(items);
	
	    try {
			System.Array.Sort(keysConverted, itemsConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Array_Sort_2")]
	internal static void /* System.Void */ System_Array_Sort_2(void* /* System.Array */ array, int /* System.Int32 */ index, int /* System.Int32 */ length, void** /* System.Exception */ __outException)
	{
		System.Array arrayConverted = InteropUtils.GetInstance<System.Array>(array);
	
	    try {
			System.Array.Sort(arrayConverted, index, length);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Array_Sort_3")]
	internal static void /* System.Void */ System_Array_Sort_3(void* /* System.Array */ keys, void* /* System.Array */ items, int /* System.Int32 */ index, int /* System.Int32 */ length, void** /* System.Exception */ __outException)
	{
		System.Array keysConverted = InteropUtils.GetInstance<System.Array>(keys);
		System.Array itemsConverted = InteropUtils.GetInstance<System.Array>(items);
	
	    try {
			System.Array.Sort(keysConverted, itemsConverted, index, length);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Array_Sort_4")]
	internal static void /* System.Void */ System_Array_Sort_4(void* /* System.Array */ array, void* /* System.Collections.IComparer */ comparer, void** /* System.Exception */ __outException)
	{
		System.Array arrayConverted = InteropUtils.GetInstance<System.Array>(array);
		System.Collections.IComparer comparerConverted = InteropUtils.GetInstance<System.Collections.IComparer>(comparer);
	
	    try {
			System.Array.Sort(arrayConverted, comparerConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Array_Sort_5")]
	internal static void /* System.Void */ System_Array_Sort_5(void* /* System.Array */ keys, void* /* System.Array */ items, void* /* System.Collections.IComparer */ comparer, void** /* System.Exception */ __outException)
	{
		System.Array keysConverted = InteropUtils.GetInstance<System.Array>(keys);
		System.Array itemsConverted = InteropUtils.GetInstance<System.Array>(items);
		System.Collections.IComparer comparerConverted = InteropUtils.GetInstance<System.Collections.IComparer>(comparer);
	
	    try {
			System.Array.Sort(keysConverted, itemsConverted, comparerConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Array_Sort_6")]
	internal static void /* System.Void */ System_Array_Sort_6(void* /* System.Array */ array, int /* System.Int32 */ index, int /* System.Int32 */ length, void* /* System.Collections.IComparer */ comparer, void** /* System.Exception */ __outException)
	{
		System.Array arrayConverted = InteropUtils.GetInstance<System.Array>(array);
		System.Collections.IComparer comparerConverted = InteropUtils.GetInstance<System.Collections.IComparer>(comparer);
	
	    try {
			System.Array.Sort(arrayConverted, index, length, comparerConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Array_Sort_7")]
	internal static void /* System.Void */ System_Array_Sort_7(void* /* System.Array */ keys, void* /* System.Array */ items, int /* System.Int32 */ index, int /* System.Int32 */ length, void* /* System.Collections.IComparer */ comparer, void** /* System.Exception */ __outException)
	{
		System.Array keysConverted = InteropUtils.GetInstance<System.Array>(keys);
		System.Array itemsConverted = InteropUtils.GetInstance<System.Array>(items);
		System.Collections.IComparer comparerConverted = InteropUtils.GetInstance<System.Collections.IComparer>(comparer);
	
	    try {
			System.Array.Sort(keysConverted, itemsConverted, index, length, comparerConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Array_Sort_A1")]
	internal static void /* System.Void */ System_Array_Sort_A1(void* /* System.Type */ T, void* /* T[] */ array, void** /* System.Exception */ __outException)
	{
		System.Type TConverted = InteropUtils.GetInstance<System.Type>(T);
		System.Array arrayConverted = InteropUtils.GetInstance<System.Array>(array);
	
	    try {
			System.Type __targetTypeForGenericCall = typeof(System.Array);
			System.String __memberNameForGenericCall = nameof(System.Array.Sort);
			System.Object? __methodTargetForGenericCall = null;
	
			System.Object[] __parametersForGenericCall = new System.Object[] { arrayConverted };
			System.Type[] __parameterTypesForGenericCall = new System.Type[] { System.Type.MakeGenericMethodParameter(0).MakeArrayType() };
	
			System.Type[] __genericParameterTypesForGenericCall = new System.Type[] { TConverted };
	
			System.Reflection.MethodInfo __methodForGenericCall = __targetTypeForGenericCall.GetMethod(__memberNameForGenericCall, 1, __parameterTypesForGenericCall) ?? throw new Exception("Method Sort not found");
			System.Reflection.MethodInfo __genericMethodForGenericCall = __methodForGenericCall.MakeGenericMethod(__genericParameterTypesForGenericCall);
	
			__genericMethodForGenericCall.Invoke(__methodTargetForGenericCall, __parametersForGenericCall);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Array_Sort_A2")]
	internal static void /* System.Void */ System_Array_Sort_A2(void* /* System.Type */ TKey, void* /* System.Type */ TValue, void* /* TKey[] */ keys, void* /* TValue[] */ items, void** /* System.Exception */ __outException)
	{
		System.Type TKeyConverted = InteropUtils.GetInstance<System.Type>(TKey);
		System.Type TValueConverted = InteropUtils.GetInstance<System.Type>(TValue);
		System.Array keysConverted = InteropUtils.GetInstance<System.Array>(keys);
		System.Array itemsConverted = InteropUtils.GetInstance<System.Array>(items);
	
	    try {
			System.Type __targetTypeForGenericCall = typeof(System.Array);
			System.String __memberNameForGenericCall = nameof(System.Array.Sort);
			System.Object? __methodTargetForGenericCall = null;
	
			System.Object[] __parametersForGenericCall = new System.Object[] { keysConverted, itemsConverted };
			System.Type[] __parameterTypesForGenericCall = new System.Type[] { System.Type.MakeGenericMethodParameter(0).MakeArrayType(), System.Type.MakeGenericMethodParameter(1).MakeArrayType() };
	
			System.Type[] __genericParameterTypesForGenericCall = new System.Type[] { TKeyConverted, TValueConverted };
	
			System.Reflection.MethodInfo __methodForGenericCall = __targetTypeForGenericCall.GetMethod(__memberNameForGenericCall, 2, __parameterTypesForGenericCall) ?? throw new Exception("Method Sort not found");
			System.Reflection.MethodInfo __genericMethodForGenericCall = __methodForGenericCall.MakeGenericMethod(__genericParameterTypesForGenericCall);
	
			__genericMethodForGenericCall.Invoke(__methodTargetForGenericCall, __parametersForGenericCall);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Array_Sort_A1_1")]
	internal static void /* System.Void */ System_Array_Sort_A1_1(void* /* System.Type */ T, void* /* T[] */ array, int /* System.Int32 */ index, int /* System.Int32 */ length, void** /* System.Exception */ __outException)
	{
		System.Type TConverted = InteropUtils.GetInstance<System.Type>(T);
		System.Array arrayConverted = InteropUtils.GetInstance<System.Array>(array);
	
	    try {
			System.Type __targetTypeForGenericCall = typeof(System.Array);
			System.String __memberNameForGenericCall = nameof(System.Array.Sort);
			System.Object? __methodTargetForGenericCall = null;
	
			System.Object[] __parametersForGenericCall = new System.Object[] { arrayConverted, index, length };
			System.Type[] __parameterTypesForGenericCall = new System.Type[] { System.Type.MakeGenericMethodParameter(0).MakeArrayType(), typeof(System.Int32), typeof(System.Int32) };
	
			System.Type[] __genericParameterTypesForGenericCall = new System.Type[] { TConverted };
	
			System.Reflection.MethodInfo __methodForGenericCall = __targetTypeForGenericCall.GetMethod(__memberNameForGenericCall, 1, __parameterTypesForGenericCall) ?? throw new Exception("Method Sort not found");
			System.Reflection.MethodInfo __genericMethodForGenericCall = __methodForGenericCall.MakeGenericMethod(__genericParameterTypesForGenericCall);
	
			__genericMethodForGenericCall.Invoke(__methodTargetForGenericCall, __parametersForGenericCall);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Array_Sort_A2_1")]
	internal static void /* System.Void */ System_Array_Sort_A2_1(void* /* System.Type */ TKey, void* /* System.Type */ TValue, void* /* TKey[] */ keys, void* /* TValue[] */ items, int /* System.Int32 */ index, int /* System.Int32 */ length, void** /* System.Exception */ __outException)
	{
		System.Type TKeyConverted = InteropUtils.GetInstance<System.Type>(TKey);
		System.Type TValueConverted = InteropUtils.GetInstance<System.Type>(TValue);
		System.Array keysConverted = InteropUtils.GetInstance<System.Array>(keys);
		System.Array itemsConverted = InteropUtils.GetInstance<System.Array>(items);
	
	    try {
			System.Type __targetTypeForGenericCall = typeof(System.Array);
			System.String __memberNameForGenericCall = nameof(System.Array.Sort);
			System.Object? __methodTargetForGenericCall = null;
	
			System.Object[] __parametersForGenericCall = new System.Object[] { keysConverted, itemsConverted, index, length };
			System.Type[] __parameterTypesForGenericCall = new System.Type[] { System.Type.MakeGenericMethodParameter(0).MakeArrayType(), System.Type.MakeGenericMethodParameter(1).MakeArrayType(), typeof(System.Int32), typeof(System.Int32) };
	
			System.Type[] __genericParameterTypesForGenericCall = new System.Type[] { TKeyConverted, TValueConverted };
	
			System.Reflection.MethodInfo __methodForGenericCall = __targetTypeForGenericCall.GetMethod(__memberNameForGenericCall, 2, __parameterTypesForGenericCall) ?? throw new Exception("Method Sort not found");
			System.Reflection.MethodInfo __genericMethodForGenericCall = __methodForGenericCall.MakeGenericMethod(__genericParameterTypesForGenericCall);
	
			__genericMethodForGenericCall.Invoke(__methodTargetForGenericCall, __parametersForGenericCall);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Array_GetEnumerator")]
	internal static void* /* System.Collections.IEnumerator */ System_Array_GetEnumerator(void* /* System.Array */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Array __selfConverted = InteropUtils.GetInstance<System.Array>(__self);
	
	
	    try {
			System.Collections.IEnumerator __returnValue = __selfConverted.GetEnumerator();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Array_Length_Get")]
	internal static int /* System.Int32 */ System_Array_Length_Get(void* /* System.Array */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Array __selfConverted = InteropUtils.GetInstance<System.Array>(__self);
	
	
	    try {
			System.Int32 __returnValue = __selfConverted.Length;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Array_LongLength_Get")]
	internal static long /* System.Int64 */ System_Array_LongLength_Get(void* /* System.Array */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Array __selfConverted = InteropUtils.GetInstance<System.Array>(__self);
	
	
	    try {
			System.Int64 __returnValue = __selfConverted.LongLength;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Array_Rank_Get")]
	internal static int /* System.Int32 */ System_Array_Rank_Get(void* /* System.Array */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Array __selfConverted = InteropUtils.GetInstance<System.Array>(__self);
	
	
	    try {
			System.Int32 __returnValue = __selfConverted.Rank;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Array_SyncRoot_Get")]
	internal static void* /* System.Object */ System_Array_SyncRoot_Get(void* /* System.Array */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Array __selfConverted = InteropUtils.GetInstance<System.Array>(__self);
	
	
	    try {
			System.Object __returnValue = __selfConverted.SyncRoot;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Array_IsReadOnly_Get")]
	internal static byte /* System.Boolean */ System_Array_IsReadOnly_Get(void* /* System.Array */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Array __selfConverted = InteropUtils.GetInstance<System.Array>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.IsReadOnly;
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Array_IsFixedSize_Get")]
	internal static byte /* System.Boolean */ System_Array_IsFixedSize_Get(void* /* System.Array */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Array __selfConverted = InteropUtils.GetInstance<System.Array>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.IsFixedSize;
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Array_IsSynchronized_Get")]
	internal static byte /* System.Boolean */ System_Array_IsSynchronized_Get(void* /* System.Array */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Array __selfConverted = InteropUtils.GetInstance<System.Array>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.IsSynchronized;
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Array_MaxLength_Get")]
	internal static int /* System.Int32 */ System_Array_MaxLength_Get(void** /* System.Exception */ __outException)
	{
	
	    try {
			System.Int32 __returnValue = System.Array.MaxLength;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Array_TypeOf")]
	internal static void* /* System.Type */ System_Array_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.Array);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Array_Destroy")]
	internal static void /* System.Void */ System_Array_Destroy(void* /* System.Array */ __self)
	{
	
		InteropUtils.FreeIfAllocated(__self);
	}
	
}


internal unsafe class System_ICloneable
{
	[UnmanagedCallersOnly(EntryPoint = "System_ICloneable_Clone")]
	internal static void* /* System.Object */ System_ICloneable_Clone(void* /* System.ICloneable */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.ICloneable __selfConverted = InteropUtils.GetInstance<System.ICloneable>(__self);
	
	
	    try {
			System.Object __returnValue = __selfConverted.Clone();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_ICloneable_TypeOf")]
	internal static void* /* System.Type */ System_ICloneable_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.ICloneable);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_ICloneable_Destroy")]
	internal static void /* System.Void */ System_ICloneable_Destroy(void* /* System.ICloneable */ __self)
	{
	
		InteropUtils.FreeIfAllocated(__self);
	}
	
}


internal unsafe class System_Collections_IList
{
	[UnmanagedCallersOnly(EntryPoint = "System_Collections_IList_Add")]
	internal static int /* System.Int32 */ System_Collections_IList_Add(void* /* System.Collections.IList */ __self, void* /* System.Object */ value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Collections.IList __selfConverted = InteropUtils.GetInstance<System.Collections.IList>(__self);
	
		System.Object valueConverted = InteropUtils.GetInstance<System.Object>(value);
	
	    try {
			System.Int32 __returnValue = __selfConverted.Add(valueConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Collections_IList_Contains")]
	internal static byte /* System.Boolean */ System_Collections_IList_Contains(void* /* System.Collections.IList */ __self, void* /* System.Object */ value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Collections.IList __selfConverted = InteropUtils.GetInstance<System.Collections.IList>(__self);
	
		System.Object valueConverted = InteropUtils.GetInstance<System.Object>(value);
	
	    try {
			System.Boolean __returnValue = __selfConverted.Contains(valueConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Collections_IList_Clear")]
	internal static void /* System.Void */ System_Collections_IList_Clear(void* /* System.Collections.IList */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Collections.IList __selfConverted = InteropUtils.GetInstance<System.Collections.IList>(__self);
	
	
	    try {
			__selfConverted.Clear();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Collections_IList_IndexOf")]
	internal static int /* System.Int32 */ System_Collections_IList_IndexOf(void* /* System.Collections.IList */ __self, void* /* System.Object */ value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Collections.IList __selfConverted = InteropUtils.GetInstance<System.Collections.IList>(__self);
	
		System.Object valueConverted = InteropUtils.GetInstance<System.Object>(value);
	
	    try {
			System.Int32 __returnValue = __selfConverted.IndexOf(valueConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Collections_IList_Insert")]
	internal static void /* System.Void */ System_Collections_IList_Insert(void* /* System.Collections.IList */ __self, int /* System.Int32 */ index, void* /* System.Object */ value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Collections.IList __selfConverted = InteropUtils.GetInstance<System.Collections.IList>(__self);
	
		System.Object valueConverted = InteropUtils.GetInstance<System.Object>(value);
	
	    try {
			__selfConverted.Insert(index, valueConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Collections_IList_Remove")]
	internal static void /* System.Void */ System_Collections_IList_Remove(void* /* System.Collections.IList */ __self, void* /* System.Object */ value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Collections.IList __selfConverted = InteropUtils.GetInstance<System.Collections.IList>(__self);
	
		System.Object valueConverted = InteropUtils.GetInstance<System.Object>(value);
	
	    try {
			__selfConverted.Remove(valueConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Collections_IList_RemoveAt")]
	internal static void /* System.Void */ System_Collections_IList_RemoveAt(void* /* System.Collections.IList */ __self, int /* System.Int32 */ index, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Collections.IList __selfConverted = InteropUtils.GetInstance<System.Collections.IList>(__self);
	
	
	    try {
			__selfConverted.RemoveAt(index);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Collections_IList_Item_Get")]
	internal static void* /* System.Object */ System_Collections_IList_Item_Get(void* /* System.Collections.IList */ __self, int /* System.Int32 */ index, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Collections.IList __selfConverted = InteropUtils.GetInstance<System.Collections.IList>(__self);
	
	
	    try {
			System.Object __returnValue = __selfConverted[index];
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Collections_IList_Item_Set")]
	internal static void /* System.Void */ System_Collections_IList_Item_Set(void* /* System.Collections.IList */ __self, int /* System.Int32 */ index, void* /* System.Object */ __value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Collections.IList __selfConverted = InteropUtils.GetInstance<System.Collections.IList>(__self);
	
	
	    try {
			__selfConverted[index]  = InteropUtils.GetInstance<System.Object>(__value);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Collections_IList_IsReadOnly_Get")]
	internal static byte /* System.Boolean */ System_Collections_IList_IsReadOnly_Get(void* /* System.Collections.IList */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Collections.IList __selfConverted = InteropUtils.GetInstance<System.Collections.IList>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.IsReadOnly;
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Collections_IList_IsFixedSize_Get")]
	internal static byte /* System.Boolean */ System_Collections_IList_IsFixedSize_Get(void* /* System.Collections.IList */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Collections.IList __selfConverted = InteropUtils.GetInstance<System.Collections.IList>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.IsFixedSize;
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Collections_IList_TypeOf")]
	internal static void* /* System.Type */ System_Collections_IList_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.Collections.IList);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Collections_IList_Destroy")]
	internal static void /* System.Void */ System_Collections_IList_Destroy(void* /* System.Collections.IList */ __self)
	{
	
		InteropUtils.FreeIfAllocated(__self);
	}
	
}


internal unsafe class System_Collections_ICollection
{
	[UnmanagedCallersOnly(EntryPoint = "System_Collections_ICollection_CopyTo")]
	internal static void /* System.Void */ System_Collections_ICollection_CopyTo(void* /* System.Collections.ICollection */ __self, void* /* System.Array */ array, int /* System.Int32 */ index, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Collections.ICollection __selfConverted = InteropUtils.GetInstance<System.Collections.ICollection>(__self);
	
		System.Array arrayConverted = InteropUtils.GetInstance<System.Array>(array);
	
	    try {
			__selfConverted.CopyTo(arrayConverted, index);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Collections_ICollection_Count_Get")]
	internal static int /* System.Int32 */ System_Collections_ICollection_Count_Get(void* /* System.Collections.ICollection */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Collections.ICollection __selfConverted = InteropUtils.GetInstance<System.Collections.ICollection>(__self);
	
	
	    try {
			System.Int32 __returnValue = __selfConverted.Count;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Collections_ICollection_SyncRoot_Get")]
	internal static void* /* System.Object */ System_Collections_ICollection_SyncRoot_Get(void* /* System.Collections.ICollection */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Collections.ICollection __selfConverted = InteropUtils.GetInstance<System.Collections.ICollection>(__self);
	
	
	    try {
			System.Object __returnValue = __selfConverted.SyncRoot;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Collections_ICollection_IsSynchronized_Get")]
	internal static byte /* System.Boolean */ System_Collections_ICollection_IsSynchronized_Get(void* /* System.Collections.ICollection */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Collections.ICollection __selfConverted = InteropUtils.GetInstance<System.Collections.ICollection>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.IsSynchronized;
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Collections_ICollection_TypeOf")]
	internal static void* /* System.Type */ System_Collections_ICollection_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.Collections.ICollection);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Collections_ICollection_Destroy")]
	internal static void /* System.Void */ System_Collections_ICollection_Destroy(void* /* System.Collections.ICollection */ __self)
	{
	
		InteropUtils.FreeIfAllocated(__self);
	}
	
}


internal unsafe class System_Collections_IEnumerable
{
	[UnmanagedCallersOnly(EntryPoint = "System_Collections_IEnumerable_GetEnumerator")]
	internal static void* /* System.Collections.IEnumerator */ System_Collections_IEnumerable_GetEnumerator(void* /* System.Collections.IEnumerable */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Collections.IEnumerable __selfConverted = InteropUtils.GetInstance<System.Collections.IEnumerable>(__self);
	
	
	    try {
			System.Collections.IEnumerator __returnValue = __selfConverted.GetEnumerator();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Collections_IEnumerable_TypeOf")]
	internal static void* /* System.Type */ System_Collections_IEnumerable_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.Collections.IEnumerable);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Collections_IEnumerable_Destroy")]
	internal static void /* System.Void */ System_Collections_IEnumerable_Destroy(void* /* System.Collections.IEnumerable */ __self)
	{
	
		InteropUtils.FreeIfAllocated(__self);
	}
	
}


internal unsafe class System_Collections_IEnumerator
{
	[UnmanagedCallersOnly(EntryPoint = "System_Collections_IEnumerator_MoveNext")]
	internal static byte /* System.Boolean */ System_Collections_IEnumerator_MoveNext(void* /* System.Collections.IEnumerator */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Collections.IEnumerator __selfConverted = InteropUtils.GetInstance<System.Collections.IEnumerator>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.MoveNext();
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Collections_IEnumerator_Reset")]
	internal static void /* System.Void */ System_Collections_IEnumerator_Reset(void* /* System.Collections.IEnumerator */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Collections.IEnumerator __selfConverted = InteropUtils.GetInstance<System.Collections.IEnumerator>(__self);
	
	
	    try {
			__selfConverted.Reset();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Collections_IEnumerator_Current_Get")]
	internal static void* /* System.Object */ System_Collections_IEnumerator_Current_Get(void* /* System.Collections.IEnumerator */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Collections.IEnumerator __selfConverted = InteropUtils.GetInstance<System.Collections.IEnumerator>(__self);
	
	
	    try {
			System.Object __returnValue = __selfConverted.Current;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Collections_IEnumerator_TypeOf")]
	internal static void* /* System.Type */ System_Collections_IEnumerator_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.Collections.IEnumerator);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Collections_IEnumerator_Destroy")]
	internal static void /* System.Void */ System_Collections_IEnumerator_Destroy(void* /* System.Collections.IEnumerator */ __self)
	{
	
		InteropUtils.FreeIfAllocated(__self);
	}
	
}


internal unsafe class System_Boolean
{
	[UnmanagedCallersOnly(EntryPoint = "System_Boolean_TypeOf")]
	internal static void* /* System.Type */ System_Boolean_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.Boolean);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
}


internal unsafe class System_ValueType
{
	[UnmanagedCallersOnly(EntryPoint = "System_ValueType_Equals")]
	internal static byte /* System.Boolean */ System_ValueType_Equals(void* /* System.ValueType */ __self, void* /* System.Object */ obj, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.ValueType __selfConverted = InteropUtils.GetInstance<System.ValueType>(__self);
	
		System.Object objConverted = InteropUtils.GetInstance<System.Object>(obj);
	
	    try {
			System.Boolean __returnValue = __selfConverted.Equals(objConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_ValueType_GetHashCode")]
	internal static int /* System.Int32 */ System_ValueType_GetHashCode(void* /* System.ValueType */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.ValueType __selfConverted = InteropUtils.GetInstance<System.ValueType>(__self);
	
	
	    try {
			System.Int32 __returnValue = __selfConverted.GetHashCode();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_ValueType_ToString")]
	internal static void* /* System.String */ System_ValueType_ToString(void* /* System.ValueType */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.ValueType __selfConverted = InteropUtils.GetInstance<System.ValueType>(__self);
	
	
	    try {
			System.String __returnValue = __selfConverted.ToString();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_ValueType_TypeOf")]
	internal static void* /* System.Type */ System_ValueType_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.ValueType);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_ValueType_Destroy")]
	internal static void /* System.Void */ System_ValueType_Destroy(void* /* System.ValueType */ __self)
	{
	
		InteropUtils.FreeIfAllocated(__self);
	}
	
}


internal unsafe class System_Int32
{
	[UnmanagedCallersOnly(EntryPoint = "System_Int32_TypeOf")]
	internal static void* /* System.Type */ System_Int32_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.Int32);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
}


internal unsafe class System_IComparable
{
	[UnmanagedCallersOnly(EntryPoint = "System_IComparable_CompareTo")]
	internal static int /* System.Int32 */ System_IComparable_CompareTo(void* /* System.IComparable */ __self, void* /* System.Object */ obj, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.IComparable __selfConverted = InteropUtils.GetInstance<System.IComparable>(__self);
	
		System.Object objConverted = InteropUtils.GetInstance<System.Object>(obj);
	
	    try {
			System.Int32 __returnValue = __selfConverted.CompareTo(objConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_IComparable_TypeOf")]
	internal static void* /* System.Type */ System_IComparable_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.IComparable);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_IComparable_Destroy")]
	internal static void /* System.Void */ System_IComparable_Destroy(void* /* System.IComparable */ __self)
	{
	
		InteropUtils.FreeIfAllocated(__self);
	}
	
}


internal unsafe class System_IConvertible
{
	[UnmanagedCallersOnly(EntryPoint = "System_IConvertible_GetTypeCode")]
	internal static System.TypeCode /* System.TypeCode */ System_IConvertible_GetTypeCode(void* /* System.IConvertible */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.IConvertible __selfConverted = InteropUtils.GetInstance<System.IConvertible>(__self);
	
	
	    try {
			System.TypeCode __returnValue = __selfConverted.GetTypeCode();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return default(System.TypeCode);
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_IConvertible_ToBoolean")]
	internal static byte /* System.Boolean */ System_IConvertible_ToBoolean(void* /* System.IConvertible */ __self, void* /* System.IFormatProvider */ provider, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.IConvertible __selfConverted = InteropUtils.GetInstance<System.IConvertible>(__self);
	
		System.IFormatProvider providerConverted = InteropUtils.GetInstance<System.IFormatProvider>(provider);
	
	    try {
			System.Boolean __returnValue = __selfConverted.ToBoolean(providerConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_IConvertible_ToChar")]
	internal static char /* System.Char */ System_IConvertible_ToChar(void* /* System.IConvertible */ __self, void* /* System.IFormatProvider */ provider, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.IConvertible __selfConverted = InteropUtils.GetInstance<System.IConvertible>(__self);
	
		System.IFormatProvider providerConverted = InteropUtils.GetInstance<System.IFormatProvider>(provider);
	
	    try {
			System.Char __returnValue = __selfConverted.ToChar(providerConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return (char)0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_IConvertible_ToSByte")]
	internal static sbyte /* System.SByte */ System_IConvertible_ToSByte(void* /* System.IConvertible */ __self, void* /* System.IFormatProvider */ provider, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.IConvertible __selfConverted = InteropUtils.GetInstance<System.IConvertible>(__self);
	
		System.IFormatProvider providerConverted = InteropUtils.GetInstance<System.IFormatProvider>(provider);
	
	    try {
			System.SByte __returnValue = __selfConverted.ToSByte(providerConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_IConvertible_ToByte")]
	internal static byte /* System.Byte */ System_IConvertible_ToByte(void* /* System.IConvertible */ __self, void* /* System.IFormatProvider */ provider, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.IConvertible __selfConverted = InteropUtils.GetInstance<System.IConvertible>(__self);
	
		System.IFormatProvider providerConverted = InteropUtils.GetInstance<System.IFormatProvider>(provider);
	
	    try {
			System.Byte __returnValue = __selfConverted.ToByte(providerConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_IConvertible_ToInt16")]
	internal static short /* System.Int16 */ System_IConvertible_ToInt16(void* /* System.IConvertible */ __self, void* /* System.IFormatProvider */ provider, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.IConvertible __selfConverted = InteropUtils.GetInstance<System.IConvertible>(__self);
	
		System.IFormatProvider providerConverted = InteropUtils.GetInstance<System.IFormatProvider>(provider);
	
	    try {
			System.Int16 __returnValue = __selfConverted.ToInt16(providerConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_IConvertible_ToUInt16")]
	internal static ushort /* System.UInt16 */ System_IConvertible_ToUInt16(void* /* System.IConvertible */ __self, void* /* System.IFormatProvider */ provider, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.IConvertible __selfConverted = InteropUtils.GetInstance<System.IConvertible>(__self);
	
		System.IFormatProvider providerConverted = InteropUtils.GetInstance<System.IFormatProvider>(provider);
	
	    try {
			System.UInt16 __returnValue = __selfConverted.ToUInt16(providerConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_IConvertible_ToInt32")]
	internal static int /* System.Int32 */ System_IConvertible_ToInt32(void* /* System.IConvertible */ __self, void* /* System.IFormatProvider */ provider, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.IConvertible __selfConverted = InteropUtils.GetInstance<System.IConvertible>(__self);
	
		System.IFormatProvider providerConverted = InteropUtils.GetInstance<System.IFormatProvider>(provider);
	
	    try {
			System.Int32 __returnValue = __selfConverted.ToInt32(providerConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_IConvertible_ToUInt32")]
	internal static uint /* System.UInt32 */ System_IConvertible_ToUInt32(void* /* System.IConvertible */ __self, void* /* System.IFormatProvider */ provider, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.IConvertible __selfConverted = InteropUtils.GetInstance<System.IConvertible>(__self);
	
		System.IFormatProvider providerConverted = InteropUtils.GetInstance<System.IFormatProvider>(provider);
	
	    try {
			System.UInt32 __returnValue = __selfConverted.ToUInt32(providerConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_IConvertible_ToInt64")]
	internal static long /* System.Int64 */ System_IConvertible_ToInt64(void* /* System.IConvertible */ __self, void* /* System.IFormatProvider */ provider, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.IConvertible __selfConverted = InteropUtils.GetInstance<System.IConvertible>(__self);
	
		System.IFormatProvider providerConverted = InteropUtils.GetInstance<System.IFormatProvider>(provider);
	
	    try {
			System.Int64 __returnValue = __selfConverted.ToInt64(providerConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_IConvertible_ToUInt64")]
	internal static ulong /* System.UInt64 */ System_IConvertible_ToUInt64(void* /* System.IConvertible */ __self, void* /* System.IFormatProvider */ provider, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.IConvertible __selfConverted = InteropUtils.GetInstance<System.IConvertible>(__self);
	
		System.IFormatProvider providerConverted = InteropUtils.GetInstance<System.IFormatProvider>(provider);
	
	    try {
			System.UInt64 __returnValue = __selfConverted.ToUInt64(providerConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_IConvertible_ToSingle")]
	internal static float /* System.Single */ System_IConvertible_ToSingle(void* /* System.IConvertible */ __self, void* /* System.IFormatProvider */ provider, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.IConvertible __selfConverted = InteropUtils.GetInstance<System.IConvertible>(__self);
	
		System.IFormatProvider providerConverted = InteropUtils.GetInstance<System.IFormatProvider>(provider);
	
	    try {
			System.Single __returnValue = __selfConverted.ToSingle(providerConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_IConvertible_ToDouble")]
	internal static double /* System.Double */ System_IConvertible_ToDouble(void* /* System.IConvertible */ __self, void* /* System.IFormatProvider */ provider, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.IConvertible __selfConverted = InteropUtils.GetInstance<System.IConvertible>(__self);
	
		System.IFormatProvider providerConverted = InteropUtils.GetInstance<System.IFormatProvider>(provider);
	
	    try {
			System.Double __returnValue = __selfConverted.ToDouble(providerConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_IConvertible_ToDecimal")]
	internal static void* /* System.Decimal */ System_IConvertible_ToDecimal(void* /* System.IConvertible */ __self, void* /* System.IFormatProvider */ provider, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.IConvertible __selfConverted = InteropUtils.GetInstance<System.IConvertible>(__self);
	
		System.IFormatProvider providerConverted = InteropUtils.GetInstance<System.IFormatProvider>(provider);
	
	    try {
			System.Decimal __returnValue = __selfConverted.ToDecimal(providerConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_IConvertible_ToDateTime")]
	internal static void* /* System.DateTime */ System_IConvertible_ToDateTime(void* /* System.IConvertible */ __self, void* /* System.IFormatProvider */ provider, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.IConvertible __selfConverted = InteropUtils.GetInstance<System.IConvertible>(__self);
	
		System.IFormatProvider providerConverted = InteropUtils.GetInstance<System.IFormatProvider>(provider);
	
	    try {
			System.DateTime __returnValue = __selfConverted.ToDateTime(providerConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_IConvertible_ToString")]
	internal static void* /* System.String */ System_IConvertible_ToString(void* /* System.IConvertible */ __self, void* /* System.IFormatProvider */ provider, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.IConvertible __selfConverted = InteropUtils.GetInstance<System.IConvertible>(__self);
	
		System.IFormatProvider providerConverted = InteropUtils.GetInstance<System.IFormatProvider>(provider);
	
	    try {
			System.String __returnValue = __selfConverted.ToString(providerConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_IConvertible_ToType")]
	internal static void* /* System.Object */ System_IConvertible_ToType(void* /* System.IConvertible */ __self, void* /* System.Type */ conversionType, void* /* System.IFormatProvider */ provider, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.IConvertible __selfConverted = InteropUtils.GetInstance<System.IConvertible>(__self);
	
		System.Type conversionTypeConverted = InteropUtils.GetInstance<System.Type>(conversionType);
		System.IFormatProvider providerConverted = InteropUtils.GetInstance<System.IFormatProvider>(provider);
	
	    try {
			System.Object __returnValue = __selfConverted.ToType(conversionTypeConverted, providerConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_IConvertible_TypeOf")]
	internal static void* /* System.Type */ System_IConvertible_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.IConvertible);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_IConvertible_Destroy")]
	internal static void /* System.Void */ System_IConvertible_Destroy(void* /* System.IConvertible */ __self)
	{
	
		InteropUtils.FreeIfAllocated(__self);
	}
	
}


internal unsafe class System_TypeCode
{
	[UnmanagedCallersOnly(EntryPoint = "System_TypeCode_TypeOf")]
	internal static void* /* System.Type */ System_TypeCode_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.TypeCode);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
}


internal unsafe class System_Enum
{
	[UnmanagedCallersOnly(EntryPoint = "System_Enum_GetName")]
	internal static void* /* System.String */ System_Enum_GetName(void* /* System.Type */ enumType, void* /* System.Object */ value, void** /* System.Exception */ __outException)
	{
		System.Type enumTypeConverted = InteropUtils.GetInstance<System.Type>(enumType);
		System.Object valueConverted = InteropUtils.GetInstance<System.Object>(value);
	
	    try {
			System.String __returnValue = System.Enum.GetName(enumTypeConverted, valueConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Enum_GetNames_A1")]
	internal static void* /* System.String[] */ System_Enum_GetNames_A1(void* /* System.Type */ TEnum, void** /* System.Exception */ __outException)
	{
		System.Type TEnumConverted = InteropUtils.GetInstance<System.Type>(TEnum);
	
	    try {
			System.Type __targetTypeForGenericCall = typeof(System.Enum);
			System.String __memberNameForGenericCall = nameof(System.Enum.GetNames);
			System.Object? __methodTargetForGenericCall = null;
	
			System.Object[]? __parametersForGenericCall = null;
			System.Type[] __parameterTypesForGenericCall = System.Type.EmptyTypes;
	
			System.Type[] __genericParameterTypesForGenericCall = new System.Type[] { TEnumConverted };
	
			System.Reflection.MethodInfo __methodForGenericCall = __targetTypeForGenericCall.GetMethod(__memberNameForGenericCall, 1, __parameterTypesForGenericCall) ?? throw new Exception("Method GetNames not found");
			System.Reflection.MethodInfo __genericMethodForGenericCall = __methodForGenericCall.MakeGenericMethod(__genericParameterTypesForGenericCall);
	
			System.String[] __returnValue = (System.String[])__genericMethodForGenericCall.Invoke(__methodTargetForGenericCall, __parametersForGenericCall);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Enum_GetNames_1")]
	internal static void* /* System.String[] */ System_Enum_GetNames_1(void* /* System.Type */ enumType, void** /* System.Exception */ __outException)
	{
		System.Type enumTypeConverted = InteropUtils.GetInstance<System.Type>(enumType);
	
	    try {
			System.String[] __returnValue = System.Enum.GetNames(enumTypeConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Enum_GetUnderlyingType")]
	internal static void* /* System.Type */ System_Enum_GetUnderlyingType(void* /* System.Type */ enumType, void** /* System.Exception */ __outException)
	{
		System.Type enumTypeConverted = InteropUtils.GetInstance<System.Type>(enumType);
	
	    try {
			System.Type __returnValue = System.Enum.GetUnderlyingType(enumTypeConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Enum_GetValues_A1")]
	internal static void* /* System.Array */ System_Enum_GetValues_A1(void* /* System.Type */ TEnum, void** /* System.Exception */ __outException)
	{
		System.Type TEnumConverted = InteropUtils.GetInstance<System.Type>(TEnum);
	
	    try {
			System.Type __targetTypeForGenericCall = typeof(System.Enum);
			System.String __memberNameForGenericCall = nameof(System.Enum.GetValues);
			System.Object? __methodTargetForGenericCall = null;
	
			System.Object[]? __parametersForGenericCall = null;
			System.Type[] __parameterTypesForGenericCall = System.Type.EmptyTypes;
	
			System.Type[] __genericParameterTypesForGenericCall = new System.Type[] { TEnumConverted };
	
			System.Reflection.MethodInfo __methodForGenericCall = __targetTypeForGenericCall.GetMethod(__memberNameForGenericCall, 1, __parameterTypesForGenericCall) ?? throw new Exception("Method GetValues not found");
			System.Reflection.MethodInfo __genericMethodForGenericCall = __methodForGenericCall.MakeGenericMethod(__genericParameterTypesForGenericCall);
	
			System.Array __returnValue = (System.Array)__genericMethodForGenericCall.Invoke(__methodTargetForGenericCall, __parametersForGenericCall);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Enum_GetValues_1")]
	internal static void* /* System.Array */ System_Enum_GetValues_1(void* /* System.Type */ enumType, void** /* System.Exception */ __outException)
	{
		System.Type enumTypeConverted = InteropUtils.GetInstance<System.Type>(enumType);
	
	    try {
			System.Array __returnValue = System.Enum.GetValues(enumTypeConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Enum_GetValuesAsUnderlyingType_A1")]
	internal static void* /* System.Array */ System_Enum_GetValuesAsUnderlyingType_A1(void* /* System.Type */ TEnum, void** /* System.Exception */ __outException)
	{
		System.Type TEnumConverted = InteropUtils.GetInstance<System.Type>(TEnum);
	
	    try {
			System.Type __targetTypeForGenericCall = typeof(System.Enum);
			System.String __memberNameForGenericCall = nameof(System.Enum.GetValuesAsUnderlyingType);
			System.Object? __methodTargetForGenericCall = null;
	
			System.Object[]? __parametersForGenericCall = null;
			System.Type[] __parameterTypesForGenericCall = System.Type.EmptyTypes;
	
			System.Type[] __genericParameterTypesForGenericCall = new System.Type[] { TEnumConverted };
	
			System.Reflection.MethodInfo __methodForGenericCall = __targetTypeForGenericCall.GetMethod(__memberNameForGenericCall, 1, __parameterTypesForGenericCall) ?? throw new Exception("Method GetValuesAsUnderlyingType not found");
			System.Reflection.MethodInfo __genericMethodForGenericCall = __methodForGenericCall.MakeGenericMethod(__genericParameterTypesForGenericCall);
	
			System.Array __returnValue = (System.Array)__genericMethodForGenericCall.Invoke(__methodTargetForGenericCall, __parametersForGenericCall);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Enum_GetValuesAsUnderlyingType_1")]
	internal static void* /* System.Array */ System_Enum_GetValuesAsUnderlyingType_1(void* /* System.Type */ enumType, void** /* System.Exception */ __outException)
	{
		System.Type enumTypeConverted = InteropUtils.GetInstance<System.Type>(enumType);
	
	    try {
			System.Array __returnValue = System.Enum.GetValuesAsUnderlyingType(enumTypeConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Enum_HasFlag")]
	internal static byte /* System.Boolean */ System_Enum_HasFlag(void* /* System.Enum */ __self, void* /* System.Enum */ flag, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Enum __selfConverted = InteropUtils.GetInstance<System.Enum>(__self);
	
		System.Enum flagConverted = InteropUtils.GetInstance<System.Enum>(flag);
	
	    try {
			System.Boolean __returnValue = __selfConverted.HasFlag(flagConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Enum_IsDefined")]
	internal static byte /* System.Boolean */ System_Enum_IsDefined(void* /* System.Type */ enumType, void* /* System.Object */ value, void** /* System.Exception */ __outException)
	{
		System.Type enumTypeConverted = InteropUtils.GetInstance<System.Type>(enumType);
		System.Object valueConverted = InteropUtils.GetInstance<System.Object>(value);
	
	    try {
			System.Boolean __returnValue = System.Enum.IsDefined(enumTypeConverted, valueConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Enum_Parse")]
	internal static void* /* System.Object */ System_Enum_Parse(void* /* System.Type */ enumType, void* /* System.String */ value, void** /* System.Exception */ __outException)
	{
		System.Type enumTypeConverted = InteropUtils.GetInstance<System.Type>(enumType);
		System.String valueConverted = InteropUtils.GetInstance<System.String>(value);
	
	    try {
			System.Object __returnValue = System.Enum.Parse(enumTypeConverted, valueConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Enum_Parse_1")]
	internal static void* /* System.Object */ System_Enum_Parse_1(void* /* System.Type */ enumType, void* /* System.String */ value, byte /* System.Boolean */ ignoreCase, void** /* System.Exception */ __outException)
	{
		System.Type enumTypeConverted = InteropUtils.GetInstance<System.Type>(enumType);
		System.String valueConverted = InteropUtils.GetInstance<System.String>(value);
		System.Boolean ignoreCaseConverted = ignoreCase.ToBool();
	
	    try {
			System.Object __returnValue = System.Enum.Parse(enumTypeConverted, valueConverted, ignoreCaseConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Enum_TryParse")]
	internal static byte /* System.Boolean */ System_Enum_TryParse(void* /* System.Type */ enumType, void* /* System.String */ value, void** /* System.Object */ result, void** /* System.Exception */ __outException)
	{
		System.Type enumTypeConverted = InteropUtils.GetInstance<System.Type>(enumType);
		System.String valueConverted = InteropUtils.GetInstance<System.String>(value);
		System.Object resultConverted;
	
	    try {
			System.Boolean __returnValue = System.Enum.TryParse(enumTypeConverted, valueConverted, out resultConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			if (result is not null) {
				*result = resultConverted.AllocateGCHandleAndGetAddress();
			}
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			if (result is not null) {
				*result = null;
			}
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Enum_TryParse_1")]
	internal static byte /* System.Boolean */ System_Enum_TryParse_1(void* /* System.Type */ enumType, void* /* System.String */ value, byte /* System.Boolean */ ignoreCase, void** /* System.Object */ result, void** /* System.Exception */ __outException)
	{
		System.Type enumTypeConverted = InteropUtils.GetInstance<System.Type>(enumType);
		System.String valueConverted = InteropUtils.GetInstance<System.String>(value);
		System.Boolean ignoreCaseConverted = ignoreCase.ToBool();
		System.Object resultConverted;
	
	    try {
			System.Boolean __returnValue = System.Enum.TryParse(enumTypeConverted, valueConverted, ignoreCaseConverted, out resultConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			if (result is not null) {
				*result = resultConverted.AllocateGCHandleAndGetAddress();
			}
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			if (result is not null) {
				*result = null;
			}
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Enum_Equals")]
	internal static byte /* System.Boolean */ System_Enum_Equals(void* /* System.Enum */ __self, void* /* System.Object */ obj, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Enum __selfConverted = InteropUtils.GetInstance<System.Enum>(__self);
	
		System.Object objConverted = InteropUtils.GetInstance<System.Object>(obj);
	
	    try {
			System.Boolean __returnValue = __selfConverted.Equals(objConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Enum_GetHashCode")]
	internal static int /* System.Int32 */ System_Enum_GetHashCode(void* /* System.Enum */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Enum __selfConverted = InteropUtils.GetInstance<System.Enum>(__self);
	
	
	    try {
			System.Int32 __returnValue = __selfConverted.GetHashCode();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Enum_CompareTo")]
	internal static int /* System.Int32 */ System_Enum_CompareTo(void* /* System.Enum */ __self, void* /* System.Object */ target, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Enum __selfConverted = InteropUtils.GetInstance<System.Enum>(__self);
	
		System.Object targetConverted = InteropUtils.GetInstance<System.Object>(target);
	
	    try {
			System.Int32 __returnValue = __selfConverted.CompareTo(targetConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Enum_ToString")]
	internal static void* /* System.String */ System_Enum_ToString(void* /* System.Enum */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Enum __selfConverted = InteropUtils.GetInstance<System.Enum>(__self);
	
	
	    try {
			System.String __returnValue = __selfConverted.ToString();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Enum_ToString_1")]
	internal static void* /* System.String */ System_Enum_ToString_1(void* /* System.Enum */ __self, void* /* System.String */ format, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Enum __selfConverted = InteropUtils.GetInstance<System.Enum>(__self);
	
		System.String formatConverted = InteropUtils.GetInstance<System.String>(format);
	
	    try {
			System.String __returnValue = __selfConverted.ToString(formatConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Enum_ToString_2")]
	internal static void* /* System.String */ System_Enum_ToString_2(void* /* System.Enum */ __self, void* /* System.IFormatProvider */ provider, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Enum __selfConverted = InteropUtils.GetInstance<System.Enum>(__self);
	
		System.IFormatProvider providerConverted = InteropUtils.GetInstance<System.IFormatProvider>(provider);
	
	    try {
			System.String __returnValue = __selfConverted.ToString(providerConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Enum_ToString_3")]
	internal static void* /* System.String */ System_Enum_ToString_3(void* /* System.Enum */ __self, void* /* System.String */ format, void* /* System.IFormatProvider */ provider, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Enum __selfConverted = InteropUtils.GetInstance<System.Enum>(__self);
	
		System.String formatConverted = InteropUtils.GetInstance<System.String>(format);
		System.IFormatProvider providerConverted = InteropUtils.GetInstance<System.IFormatProvider>(provider);
	
	    try {
			System.String __returnValue = __selfConverted.ToString(formatConverted, providerConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Enum_Format")]
	internal static void* /* System.String */ System_Enum_Format(void* /* System.Type */ enumType, void* /* System.Object */ value, void* /* System.String */ format, void** /* System.Exception */ __outException)
	{
		System.Type enumTypeConverted = InteropUtils.GetInstance<System.Type>(enumType);
		System.Object valueConverted = InteropUtils.GetInstance<System.Object>(value);
		System.String formatConverted = InteropUtils.GetInstance<System.String>(format);
	
	    try {
			System.String __returnValue = System.Enum.Format(enumTypeConverted, valueConverted, formatConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Enum_GetTypeCode")]
	internal static System.TypeCode /* System.TypeCode */ System_Enum_GetTypeCode(void* /* System.Enum */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Enum __selfConverted = InteropUtils.GetInstance<System.Enum>(__self);
	
	
	    try {
			System.TypeCode __returnValue = __selfConverted.GetTypeCode();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return default(System.TypeCode);
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Enum_ToObject")]
	internal static void* /* System.Object */ System_Enum_ToObject(void* /* System.Type */ enumType, void* /* System.Object */ value, void** /* System.Exception */ __outException)
	{
		System.Type enumTypeConverted = InteropUtils.GetInstance<System.Type>(enumType);
		System.Object valueConverted = InteropUtils.GetInstance<System.Object>(value);
	
	    try {
			System.Object __returnValue = System.Enum.ToObject(enumTypeConverted, valueConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Enum_ToObject_1")]
	internal static void* /* System.Object */ System_Enum_ToObject_1(void* /* System.Type */ enumType, sbyte /* System.SByte */ value, void** /* System.Exception */ __outException)
	{
		System.Type enumTypeConverted = InteropUtils.GetInstance<System.Type>(enumType);
	
	    try {
			System.Object __returnValue = System.Enum.ToObject(enumTypeConverted, value);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Enum_ToObject_2")]
	internal static void* /* System.Object */ System_Enum_ToObject_2(void* /* System.Type */ enumType, short /* System.Int16 */ value, void** /* System.Exception */ __outException)
	{
		System.Type enumTypeConverted = InteropUtils.GetInstance<System.Type>(enumType);
	
	    try {
			System.Object __returnValue = System.Enum.ToObject(enumTypeConverted, value);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Enum_ToObject_3")]
	internal static void* /* System.Object */ System_Enum_ToObject_3(void* /* System.Type */ enumType, int /* System.Int32 */ value, void** /* System.Exception */ __outException)
	{
		System.Type enumTypeConverted = InteropUtils.GetInstance<System.Type>(enumType);
	
	    try {
			System.Object __returnValue = System.Enum.ToObject(enumTypeConverted, value);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Enum_ToObject_4")]
	internal static void* /* System.Object */ System_Enum_ToObject_4(void* /* System.Type */ enumType, byte /* System.Byte */ value, void** /* System.Exception */ __outException)
	{
		System.Type enumTypeConverted = InteropUtils.GetInstance<System.Type>(enumType);
	
	    try {
			System.Object __returnValue = System.Enum.ToObject(enumTypeConverted, value);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Enum_ToObject_5")]
	internal static void* /* System.Object */ System_Enum_ToObject_5(void* /* System.Type */ enumType, ushort /* System.UInt16 */ value, void** /* System.Exception */ __outException)
	{
		System.Type enumTypeConverted = InteropUtils.GetInstance<System.Type>(enumType);
	
	    try {
			System.Object __returnValue = System.Enum.ToObject(enumTypeConverted, value);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Enum_ToObject_6")]
	internal static void* /* System.Object */ System_Enum_ToObject_6(void* /* System.Type */ enumType, uint /* System.UInt32 */ value, void** /* System.Exception */ __outException)
	{
		System.Type enumTypeConverted = InteropUtils.GetInstance<System.Type>(enumType);
	
	    try {
			System.Object __returnValue = System.Enum.ToObject(enumTypeConverted, value);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Enum_ToObject_7")]
	internal static void* /* System.Object */ System_Enum_ToObject_7(void* /* System.Type */ enumType, long /* System.Int64 */ value, void** /* System.Exception */ __outException)
	{
		System.Type enumTypeConverted = InteropUtils.GetInstance<System.Type>(enumType);
	
	    try {
			System.Object __returnValue = System.Enum.ToObject(enumTypeConverted, value);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Enum_ToObject_8")]
	internal static void* /* System.Object */ System_Enum_ToObject_8(void* /* System.Type */ enumType, ulong /* System.UInt64 */ value, void** /* System.Exception */ __outException)
	{
		System.Type enumTypeConverted = InteropUtils.GetInstance<System.Type>(enumType);
	
	    try {
			System.Object __returnValue = System.Enum.ToObject(enumTypeConverted, value);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Enum_TypeOf")]
	internal static void* /* System.Type */ System_Enum_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.Enum);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Enum_Destroy")]
	internal static void /* System.Void */ System_Enum_Destroy(void* /* System.Enum */ __self)
	{
	
		InteropUtils.FreeIfAllocated(__self);
	}
	
}


internal unsafe class System_ISpanFormattable
{
	[UnmanagedCallersOnly(EntryPoint = "System_ISpanFormattable_TypeOf")]
	internal static void* /* System.Type */ System_ISpanFormattable_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.ISpanFormattable);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_ISpanFormattable_Destroy")]
	internal static void /* System.Void */ System_ISpanFormattable_Destroy(void* /* System.ISpanFormattable */ __self)
	{
	
		InteropUtils.FreeIfAllocated(__self);
	}
	
}


internal unsafe class System_IFormattable
{
	[UnmanagedCallersOnly(EntryPoint = "System_IFormattable_ToString")]
	internal static void* /* System.String */ System_IFormattable_ToString(void* /* System.IFormattable */ __self, void* /* System.String */ format, void* /* System.IFormatProvider */ formatProvider, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.IFormattable __selfConverted = InteropUtils.GetInstance<System.IFormattable>(__self);
	
		System.String formatConverted = InteropUtils.GetInstance<System.String>(format);
		System.IFormatProvider formatProviderConverted = InteropUtils.GetInstance<System.IFormatProvider>(formatProvider);
	
	    try {
			System.String __returnValue = __selfConverted.ToString(formatConverted, formatProviderConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_IFormattable_TypeOf")]
	internal static void* /* System.Type */ System_IFormattable_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.IFormattable);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_IFormattable_Destroy")]
	internal static void /* System.Void */ System_IFormattable_Destroy(void* /* System.IFormattable */ __self)
	{
	
		InteropUtils.FreeIfAllocated(__self);
	}
	
}


internal unsafe class System_String
{
	[UnmanagedCallersOnly(EntryPoint = "System_String_Intern")]
	internal static void* /* System.String */ System_String_Intern(void* /* System.String */ str, void** /* System.Exception */ __outException)
	{
		System.String strConverted = InteropUtils.GetInstance<System.String>(str);
	
	    try {
			System.String __returnValue = System.String.Intern(strConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_String_IsInterned")]
	internal static void* /* System.String */ System_String_IsInterned(void* /* System.String */ str, void** /* System.Exception */ __outException)
	{
		System.String strConverted = InteropUtils.GetInstance<System.String>(str);
	
	    try {
			System.String __returnValue = System.String.IsInterned(strConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_String_Compare")]
	internal static int /* System.Int32 */ System_String_Compare(void* /* System.String */ strA, void* /* System.String */ strB, void** /* System.Exception */ __outException)
	{
		System.String strAConverted = InteropUtils.GetInstance<System.String>(strA);
		System.String strBConverted = InteropUtils.GetInstance<System.String>(strB);
	
	    try {
			System.Int32 __returnValue = System.String.Compare(strAConverted, strBConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_String_Compare_1")]
	internal static int /* System.Int32 */ System_String_Compare_1(void* /* System.String */ strA, void* /* System.String */ strB, byte /* System.Boolean */ ignoreCase, void** /* System.Exception */ __outException)
	{
		System.String strAConverted = InteropUtils.GetInstance<System.String>(strA);
		System.String strBConverted = InteropUtils.GetInstance<System.String>(strB);
		System.Boolean ignoreCaseConverted = ignoreCase.ToBool();
	
	    try {
			System.Int32 __returnValue = System.String.Compare(strAConverted, strBConverted, ignoreCaseConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_String_Compare_2")]
	internal static int /* System.Int32 */ System_String_Compare_2(void* /* System.String */ strA, void* /* System.String */ strB, System.StringComparison /* System.StringComparison */ comparisonType, void** /* System.Exception */ __outException)
	{
		System.String strAConverted = InteropUtils.GetInstance<System.String>(strA);
		System.String strBConverted = InteropUtils.GetInstance<System.String>(strB);
	
	    try {
			System.Int32 __returnValue = System.String.Compare(strAConverted, strBConverted, comparisonType);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_String_Compare_3")]
	internal static int /* System.Int32 */ System_String_Compare_3(void* /* System.String */ strA, void* /* System.String */ strB, void* /* System.Globalization.CultureInfo */ culture, System.Globalization.CompareOptions /* System.Globalization.CompareOptions */ options, void** /* System.Exception */ __outException)
	{
		System.String strAConverted = InteropUtils.GetInstance<System.String>(strA);
		System.String strBConverted = InteropUtils.GetInstance<System.String>(strB);
		System.Globalization.CultureInfo cultureConverted = InteropUtils.GetInstance<System.Globalization.CultureInfo>(culture);
	
	    try {
			System.Int32 __returnValue = System.String.Compare(strAConverted, strBConverted, cultureConverted, options);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_String_Compare_4")]
	internal static int /* System.Int32 */ System_String_Compare_4(void* /* System.String */ strA, void* /* System.String */ strB, byte /* System.Boolean */ ignoreCase, void* /* System.Globalization.CultureInfo */ culture, void** /* System.Exception */ __outException)
	{
		System.String strAConverted = InteropUtils.GetInstance<System.String>(strA);
		System.String strBConverted = InteropUtils.GetInstance<System.String>(strB);
		System.Boolean ignoreCaseConverted = ignoreCase.ToBool();
		System.Globalization.CultureInfo cultureConverted = InteropUtils.GetInstance<System.Globalization.CultureInfo>(culture);
	
	    try {
			System.Int32 __returnValue = System.String.Compare(strAConverted, strBConverted, ignoreCaseConverted, cultureConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_String_Compare_5")]
	internal static int /* System.Int32 */ System_String_Compare_5(void* /* System.String */ strA, int /* System.Int32 */ indexA, void* /* System.String */ strB, int /* System.Int32 */ indexB, int /* System.Int32 */ length, void** /* System.Exception */ __outException)
	{
		System.String strAConverted = InteropUtils.GetInstance<System.String>(strA);
		System.String strBConverted = InteropUtils.GetInstance<System.String>(strB);
	
	    try {
			System.Int32 __returnValue = System.String.Compare(strAConverted, indexA, strBConverted, indexB, length);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_String_Compare_6")]
	internal static int /* System.Int32 */ System_String_Compare_6(void* /* System.String */ strA, int /* System.Int32 */ indexA, void* /* System.String */ strB, int /* System.Int32 */ indexB, int /* System.Int32 */ length, byte /* System.Boolean */ ignoreCase, void** /* System.Exception */ __outException)
	{
		System.String strAConverted = InteropUtils.GetInstance<System.String>(strA);
		System.String strBConverted = InteropUtils.GetInstance<System.String>(strB);
		System.Boolean ignoreCaseConverted = ignoreCase.ToBool();
	
	    try {
			System.Int32 __returnValue = System.String.Compare(strAConverted, indexA, strBConverted, indexB, length, ignoreCaseConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_String_Compare_7")]
	internal static int /* System.Int32 */ System_String_Compare_7(void* /* System.String */ strA, int /* System.Int32 */ indexA, void* /* System.String */ strB, int /* System.Int32 */ indexB, int /* System.Int32 */ length, byte /* System.Boolean */ ignoreCase, void* /* System.Globalization.CultureInfo */ culture, void** /* System.Exception */ __outException)
	{
		System.String strAConverted = InteropUtils.GetInstance<System.String>(strA);
		System.String strBConverted = InteropUtils.GetInstance<System.String>(strB);
		System.Boolean ignoreCaseConverted = ignoreCase.ToBool();
		System.Globalization.CultureInfo cultureConverted = InteropUtils.GetInstance<System.Globalization.CultureInfo>(culture);
	
	    try {
			System.Int32 __returnValue = System.String.Compare(strAConverted, indexA, strBConverted, indexB, length, ignoreCaseConverted, cultureConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_String_Compare_8")]
	internal static int /* System.Int32 */ System_String_Compare_8(void* /* System.String */ strA, int /* System.Int32 */ indexA, void* /* System.String */ strB, int /* System.Int32 */ indexB, int /* System.Int32 */ length, void* /* System.Globalization.CultureInfo */ culture, System.Globalization.CompareOptions /* System.Globalization.CompareOptions */ options, void** /* System.Exception */ __outException)
	{
		System.String strAConverted = InteropUtils.GetInstance<System.String>(strA);
		System.String strBConverted = InteropUtils.GetInstance<System.String>(strB);
		System.Globalization.CultureInfo cultureConverted = InteropUtils.GetInstance<System.Globalization.CultureInfo>(culture);
	
	    try {
			System.Int32 __returnValue = System.String.Compare(strAConverted, indexA, strBConverted, indexB, length, cultureConverted, options);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_String_Compare_9")]
	internal static int /* System.Int32 */ System_String_Compare_9(void* /* System.String */ strA, int /* System.Int32 */ indexA, void* /* System.String */ strB, int /* System.Int32 */ indexB, int /* System.Int32 */ length, System.StringComparison /* System.StringComparison */ comparisonType, void** /* System.Exception */ __outException)
	{
		System.String strAConverted = InteropUtils.GetInstance<System.String>(strA);
		System.String strBConverted = InteropUtils.GetInstance<System.String>(strB);
	
	    try {
			System.Int32 __returnValue = System.String.Compare(strAConverted, indexA, strBConverted, indexB, length, comparisonType);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_String_CompareOrdinal")]
	internal static int /* System.Int32 */ System_String_CompareOrdinal(void* /* System.String */ strA, void* /* System.String */ strB, void** /* System.Exception */ __outException)
	{
		System.String strAConverted = InteropUtils.GetInstance<System.String>(strA);
		System.String strBConverted = InteropUtils.GetInstance<System.String>(strB);
	
	    try {
			System.Int32 __returnValue = System.String.CompareOrdinal(strAConverted, strBConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_String_CompareOrdinal_1")]
	internal static int /* System.Int32 */ System_String_CompareOrdinal_1(void* /* System.String */ strA, int /* System.Int32 */ indexA, void* /* System.String */ strB, int /* System.Int32 */ indexB, int /* System.Int32 */ length, void** /* System.Exception */ __outException)
	{
		System.String strAConverted = InteropUtils.GetInstance<System.String>(strA);
		System.String strBConverted = InteropUtils.GetInstance<System.String>(strB);
	
	    try {
			System.Int32 __returnValue = System.String.CompareOrdinal(strAConverted, indexA, strBConverted, indexB, length);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_String_CompareTo")]
	internal static int /* System.Int32 */ System_String_CompareTo(void* /* System.String */ __self, void* /* System.Object */ value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.String __selfConverted = InteropUtils.GetInstance<System.String>(__self);
	
		System.Object valueConverted = InteropUtils.GetInstance<System.Object>(value);
	
	    try {
			System.Int32 __returnValue = __selfConverted.CompareTo(valueConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_String_CompareTo_1")]
	internal static int /* System.Int32 */ System_String_CompareTo_1(void* /* System.String */ __self, void* /* System.String */ strB, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.String __selfConverted = InteropUtils.GetInstance<System.String>(__self);
	
		System.String strBConverted = InteropUtils.GetInstance<System.String>(strB);
	
	    try {
			System.Int32 __returnValue = __selfConverted.CompareTo(strBConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_String_EndsWith")]
	internal static byte /* System.Boolean */ System_String_EndsWith(void* /* System.String */ __self, void* /* System.String */ value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.String __selfConverted = InteropUtils.GetInstance<System.String>(__self);
	
		System.String valueConverted = InteropUtils.GetInstance<System.String>(value);
	
	    try {
			System.Boolean __returnValue = __selfConverted.EndsWith(valueConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_String_EndsWith_1")]
	internal static byte /* System.Boolean */ System_String_EndsWith_1(void* /* System.String */ __self, void* /* System.String */ value, System.StringComparison /* System.StringComparison */ comparisonType, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.String __selfConverted = InteropUtils.GetInstance<System.String>(__self);
	
		System.String valueConverted = InteropUtils.GetInstance<System.String>(value);
	
	    try {
			System.Boolean __returnValue = __selfConverted.EndsWith(valueConverted, comparisonType);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_String_EndsWith_2")]
	internal static byte /* System.Boolean */ System_String_EndsWith_2(void* /* System.String */ __self, void* /* System.String */ value, byte /* System.Boolean */ ignoreCase, void* /* System.Globalization.CultureInfo */ culture, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.String __selfConverted = InteropUtils.GetInstance<System.String>(__self);
	
		System.String valueConverted = InteropUtils.GetInstance<System.String>(value);
		System.Boolean ignoreCaseConverted = ignoreCase.ToBool();
		System.Globalization.CultureInfo cultureConverted = InteropUtils.GetInstance<System.Globalization.CultureInfo>(culture);
	
	    try {
			System.Boolean __returnValue = __selfConverted.EndsWith(valueConverted, ignoreCaseConverted, cultureConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_String_EndsWith_3")]
	internal static byte /* System.Boolean */ System_String_EndsWith_3(void* /* System.String */ __self, char /* System.Char */ value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.String __selfConverted = InteropUtils.GetInstance<System.String>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.EndsWith(value);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_String_Equals")]
	internal static byte /* System.Boolean */ System_String_Equals(void* /* System.String */ __self, void* /* System.Object */ obj, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.String __selfConverted = InteropUtils.GetInstance<System.String>(__self);
	
		System.Object objConverted = InteropUtils.GetInstance<System.Object>(obj);
	
	    try {
			System.Boolean __returnValue = __selfConverted.Equals(objConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_String_Equals_1")]
	internal static byte /* System.Boolean */ System_String_Equals_1(void* /* System.String */ __self, void* /* System.String */ value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.String __selfConverted = InteropUtils.GetInstance<System.String>(__self);
	
		System.String valueConverted = InteropUtils.GetInstance<System.String>(value);
	
	    try {
			System.Boolean __returnValue = __selfConverted.Equals(valueConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_String_Equals_2")]
	internal static byte /* System.Boolean */ System_String_Equals_2(void* /* System.String */ __self, void* /* System.String */ value, System.StringComparison /* System.StringComparison */ comparisonType, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.String __selfConverted = InteropUtils.GetInstance<System.String>(__self);
	
		System.String valueConverted = InteropUtils.GetInstance<System.String>(value);
	
	    try {
			System.Boolean __returnValue = __selfConverted.Equals(valueConverted, comparisonType);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_String_Equals_3")]
	internal static byte /* System.Boolean */ System_String_Equals_3(void* /* System.String */ a, void* /* System.String */ b, void** /* System.Exception */ __outException)
	{
		System.String aConverted = InteropUtils.GetInstance<System.String>(a);
		System.String bConverted = InteropUtils.GetInstance<System.String>(b);
	
	    try {
			System.Boolean __returnValue = System.String.Equals(aConverted, bConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_String_Equals_4")]
	internal static byte /* System.Boolean */ System_String_Equals_4(void* /* System.String */ a, void* /* System.String */ b, System.StringComparison /* System.StringComparison */ comparisonType, void** /* System.Exception */ __outException)
	{
		System.String aConverted = InteropUtils.GetInstance<System.String>(a);
		System.String bConverted = InteropUtils.GetInstance<System.String>(b);
	
	    try {
			System.Boolean __returnValue = System.String.Equals(aConverted, bConverted, comparisonType);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_String_GetHashCode")]
	internal static int /* System.Int32 */ System_String_GetHashCode(void* /* System.String */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.String __selfConverted = InteropUtils.GetInstance<System.String>(__self);
	
	
	    try {
			System.Int32 __returnValue = __selfConverted.GetHashCode();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_String_GetHashCode_1")]
	internal static int /* System.Int32 */ System_String_GetHashCode_1(void* /* System.String */ __self, System.StringComparison /* System.StringComparison */ comparisonType, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.String __selfConverted = InteropUtils.GetInstance<System.String>(__self);
	
	
	    try {
			System.Int32 __returnValue = __selfConverted.GetHashCode(comparisonType);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_String_StartsWith")]
	internal static byte /* System.Boolean */ System_String_StartsWith(void* /* System.String */ __self, void* /* System.String */ value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.String __selfConverted = InteropUtils.GetInstance<System.String>(__self);
	
		System.String valueConverted = InteropUtils.GetInstance<System.String>(value);
	
	    try {
			System.Boolean __returnValue = __selfConverted.StartsWith(valueConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_String_StartsWith_1")]
	internal static byte /* System.Boolean */ System_String_StartsWith_1(void* /* System.String */ __self, void* /* System.String */ value, System.StringComparison /* System.StringComparison */ comparisonType, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.String __selfConverted = InteropUtils.GetInstance<System.String>(__self);
	
		System.String valueConverted = InteropUtils.GetInstance<System.String>(value);
	
	    try {
			System.Boolean __returnValue = __selfConverted.StartsWith(valueConverted, comparisonType);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_String_StartsWith_2")]
	internal static byte /* System.Boolean */ System_String_StartsWith_2(void* /* System.String */ __self, void* /* System.String */ value, byte /* System.Boolean */ ignoreCase, void* /* System.Globalization.CultureInfo */ culture, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.String __selfConverted = InteropUtils.GetInstance<System.String>(__self);
	
		System.String valueConverted = InteropUtils.GetInstance<System.String>(value);
		System.Boolean ignoreCaseConverted = ignoreCase.ToBool();
		System.Globalization.CultureInfo cultureConverted = InteropUtils.GetInstance<System.Globalization.CultureInfo>(culture);
	
	    try {
			System.Boolean __returnValue = __selfConverted.StartsWith(valueConverted, ignoreCaseConverted, cultureConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_String_StartsWith_3")]
	internal static byte /* System.Boolean */ System_String_StartsWith_3(void* /* System.String */ __self, char /* System.Char */ value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.String __selfConverted = InteropUtils.GetInstance<System.String>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.StartsWith(value);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_String_Clone")]
	internal static void* /* System.Object */ System_String_Clone(void* /* System.String */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.String __selfConverted = InteropUtils.GetInstance<System.String>(__self);
	
	
	    try {
			System.Object __returnValue = __selfConverted.Clone();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_String_Copy")]
	internal static void* /* System.String */ System_String_Copy(void* /* System.String */ str, void** /* System.Exception */ __outException)
	{
		System.String strConverted = InteropUtils.GetInstance<System.String>(str);
	
	    try {
			System.String __returnValue = System.String.Copy(strConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_String_CopyTo")]
	internal static void /* System.Void */ System_String_CopyTo(void* /* System.String */ __self, int /* System.Int32 */ sourceIndex, void* /* System.Char[] */ destination, int /* System.Int32 */ destinationIndex, int /* System.Int32 */ count, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.String __selfConverted = InteropUtils.GetInstance<System.String>(__self);
	
		System.Char[] destinationConverted = InteropUtils.GetInstance<System.Char[]>(destination);
	
	    try {
			__selfConverted.CopyTo(sourceIndex, destinationConverted, destinationIndex, count);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_String_ToCharArray")]
	internal static void* /* System.Char[] */ System_String_ToCharArray(void* /* System.String */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.String __selfConverted = InteropUtils.GetInstance<System.String>(__self);
	
	
	    try {
			System.Char[] __returnValue = __selfConverted.ToCharArray();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_String_ToCharArray_1")]
	internal static void* /* System.Char[] */ System_String_ToCharArray_1(void* /* System.String */ __self, int /* System.Int32 */ startIndex, int /* System.Int32 */ length, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.String __selfConverted = InteropUtils.GetInstance<System.String>(__self);
	
	
	    try {
			System.Char[] __returnValue = __selfConverted.ToCharArray(startIndex, length);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_String_IsNullOrEmpty")]
	internal static byte /* System.Boolean */ System_String_IsNullOrEmpty(void* /* System.String */ value, void** /* System.Exception */ __outException)
	{
		System.String valueConverted = InteropUtils.GetInstance<System.String>(value);
	
	    try {
			System.Boolean __returnValue = System.String.IsNullOrEmpty(valueConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_String_IsNullOrWhiteSpace")]
	internal static byte /* System.Boolean */ System_String_IsNullOrWhiteSpace(void* /* System.String */ value, void** /* System.Exception */ __outException)
	{
		System.String valueConverted = InteropUtils.GetInstance<System.String>(value);
	
	    try {
			System.Boolean __returnValue = System.String.IsNullOrWhiteSpace(valueConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_String_ToString")]
	internal static void* /* System.String */ System_String_ToString(void* /* System.String */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.String __selfConverted = InteropUtils.GetInstance<System.String>(__self);
	
	
	    try {
			System.String __returnValue = __selfConverted.ToString();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_String_ToString_1")]
	internal static void* /* System.String */ System_String_ToString_1(void* /* System.String */ __self, void* /* System.IFormatProvider */ provider, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.String __selfConverted = InteropUtils.GetInstance<System.String>(__self);
	
		System.IFormatProvider providerConverted = InteropUtils.GetInstance<System.IFormatProvider>(provider);
	
	    try {
			System.String __returnValue = __selfConverted.ToString(providerConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_String_GetEnumerator")]
	internal static void* /* System.CharEnumerator */ System_String_GetEnumerator(void* /* System.String */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.String __selfConverted = InteropUtils.GetInstance<System.String>(__self);
	
	
	    try {
			System.CharEnumerator __returnValue = __selfConverted.GetEnumerator();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_String_EnumerateRunes")]
	internal static void* /* System.Text.StringRuneEnumerator */ System_String_EnumerateRunes(void* /* System.String */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.String __selfConverted = InteropUtils.GetInstance<System.String>(__self);
	
	
	    try {
			System.Text.StringRuneEnumerator __returnValue = __selfConverted.EnumerateRunes();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_String_GetTypeCode")]
	internal static System.TypeCode /* System.TypeCode */ System_String_GetTypeCode(void* /* System.String */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.String __selfConverted = InteropUtils.GetInstance<System.String>(__self);
	
	
	    try {
			System.TypeCode __returnValue = __selfConverted.GetTypeCode();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return default(System.TypeCode);
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_String_IsNormalized")]
	internal static byte /* System.Boolean */ System_String_IsNormalized(void* /* System.String */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.String __selfConverted = InteropUtils.GetInstance<System.String>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.IsNormalized();
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_String_IsNormalized_1")]
	internal static byte /* System.Boolean */ System_String_IsNormalized_1(void* /* System.String */ __self, System.Text.NormalizationForm /* System.Text.NormalizationForm */ normalizationForm, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.String __selfConverted = InteropUtils.GetInstance<System.String>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.IsNormalized(normalizationForm);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_String_Normalize")]
	internal static void* /* System.String */ System_String_Normalize(void* /* System.String */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.String __selfConverted = InteropUtils.GetInstance<System.String>(__self);
	
	
	    try {
			System.String __returnValue = __selfConverted.Normalize();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_String_Normalize_1")]
	internal static void* /* System.String */ System_String_Normalize_1(void* /* System.String */ __self, System.Text.NormalizationForm /* System.Text.NormalizationForm */ normalizationForm, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.String __selfConverted = InteropUtils.GetInstance<System.String>(__self);
	
	
	    try {
			System.String __returnValue = __selfConverted.Normalize(normalizationForm);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_String_Concat")]
	internal static void* /* System.String */ System_String_Concat(void* /* System.Object */ arg0, void** /* System.Exception */ __outException)
	{
		System.Object arg0Converted = InteropUtils.GetInstance<System.Object>(arg0);
	
	    try {
			System.String __returnValue = System.String.Concat(arg0Converted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_String_Concat_1")]
	internal static void* /* System.String */ System_String_Concat_1(void* /* System.Object */ arg0, void* /* System.Object */ arg1, void** /* System.Exception */ __outException)
	{
		System.Object arg0Converted = InteropUtils.GetInstance<System.Object>(arg0);
		System.Object arg1Converted = InteropUtils.GetInstance<System.Object>(arg1);
	
	    try {
			System.String __returnValue = System.String.Concat(arg0Converted, arg1Converted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_String_Concat_2")]
	internal static void* /* System.String */ System_String_Concat_2(void* /* System.Object */ arg0, void* /* System.Object */ arg1, void* /* System.Object */ arg2, void** /* System.Exception */ __outException)
	{
		System.Object arg0Converted = InteropUtils.GetInstance<System.Object>(arg0);
		System.Object arg1Converted = InteropUtils.GetInstance<System.Object>(arg1);
		System.Object arg2Converted = InteropUtils.GetInstance<System.Object>(arg2);
	
	    try {
			System.String __returnValue = System.String.Concat(arg0Converted, arg1Converted, arg2Converted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_String_Concat_3")]
	internal static void* /* System.String */ System_String_Concat_3(void* /* System.Object[] */ args, void** /* System.Exception */ __outException)
	{
		System.Object[] argsConverted = InteropUtils.GetInstance<System.Object[]>(args);
	
	    try {
			System.String __returnValue = System.String.Concat(argsConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_String_Concat_4")]
	internal static void* /* System.String */ System_String_Concat_4(void* /* System.String */ str0, void* /* System.String */ str1, void** /* System.Exception */ __outException)
	{
		System.String str0Converted = InteropUtils.GetInstance<System.String>(str0);
		System.String str1Converted = InteropUtils.GetInstance<System.String>(str1);
	
	    try {
			System.String __returnValue = System.String.Concat(str0Converted, str1Converted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_String_Concat_5")]
	internal static void* /* System.String */ System_String_Concat_5(void* /* System.String */ str0, void* /* System.String */ str1, void* /* System.String */ str2, void** /* System.Exception */ __outException)
	{
		System.String str0Converted = InteropUtils.GetInstance<System.String>(str0);
		System.String str1Converted = InteropUtils.GetInstance<System.String>(str1);
		System.String str2Converted = InteropUtils.GetInstance<System.String>(str2);
	
	    try {
			System.String __returnValue = System.String.Concat(str0Converted, str1Converted, str2Converted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_String_Concat_6")]
	internal static void* /* System.String */ System_String_Concat_6(void* /* System.String */ str0, void* /* System.String */ str1, void* /* System.String */ str2, void* /* System.String */ str3, void** /* System.Exception */ __outException)
	{
		System.String str0Converted = InteropUtils.GetInstance<System.String>(str0);
		System.String str1Converted = InteropUtils.GetInstance<System.String>(str1);
		System.String str2Converted = InteropUtils.GetInstance<System.String>(str2);
		System.String str3Converted = InteropUtils.GetInstance<System.String>(str3);
	
	    try {
			System.String __returnValue = System.String.Concat(str0Converted, str1Converted, str2Converted, str3Converted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_String_Concat_7")]
	internal static void* /* System.String */ System_String_Concat_7(void* /* System.String[] */ values, void** /* System.Exception */ __outException)
	{
		System.String[] valuesConverted = InteropUtils.GetInstance<System.String[]>(values);
	
	    try {
			System.String __returnValue = System.String.Concat(valuesConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_String_Format")]
	internal static void* /* System.String */ System_String_Format(void* /* System.String */ format, void* /* System.Object */ arg0, void** /* System.Exception */ __outException)
	{
		System.String formatConverted = InteropUtils.GetInstance<System.String>(format);
		System.Object arg0Converted = InteropUtils.GetInstance<System.Object>(arg0);
	
	    try {
			System.String __returnValue = System.String.Format(formatConverted, arg0Converted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_String_Format_1")]
	internal static void* /* System.String */ System_String_Format_1(void* /* System.String */ format, void* /* System.Object */ arg0, void* /* System.Object */ arg1, void** /* System.Exception */ __outException)
	{
		System.String formatConverted = InteropUtils.GetInstance<System.String>(format);
		System.Object arg0Converted = InteropUtils.GetInstance<System.Object>(arg0);
		System.Object arg1Converted = InteropUtils.GetInstance<System.Object>(arg1);
	
	    try {
			System.String __returnValue = System.String.Format(formatConverted, arg0Converted, arg1Converted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_String_Format_2")]
	internal static void* /* System.String */ System_String_Format_2(void* /* System.String */ format, void* /* System.Object */ arg0, void* /* System.Object */ arg1, void* /* System.Object */ arg2, void** /* System.Exception */ __outException)
	{
		System.String formatConverted = InteropUtils.GetInstance<System.String>(format);
		System.Object arg0Converted = InteropUtils.GetInstance<System.Object>(arg0);
		System.Object arg1Converted = InteropUtils.GetInstance<System.Object>(arg1);
		System.Object arg2Converted = InteropUtils.GetInstance<System.Object>(arg2);
	
	    try {
			System.String __returnValue = System.String.Format(formatConverted, arg0Converted, arg1Converted, arg2Converted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_String_Format_3")]
	internal static void* /* System.String */ System_String_Format_3(void* /* System.String */ format, void* /* System.Object[] */ args, void** /* System.Exception */ __outException)
	{
		System.String formatConverted = InteropUtils.GetInstance<System.String>(format);
		System.Object[] argsConverted = InteropUtils.GetInstance<System.Object[]>(args);
	
	    try {
			System.String __returnValue = System.String.Format(formatConverted, argsConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_String_Format_4")]
	internal static void* /* System.String */ System_String_Format_4(void* /* System.IFormatProvider */ provider, void* /* System.String */ format, void* /* System.Object */ arg0, void** /* System.Exception */ __outException)
	{
		System.IFormatProvider providerConverted = InteropUtils.GetInstance<System.IFormatProvider>(provider);
		System.String formatConverted = InteropUtils.GetInstance<System.String>(format);
		System.Object arg0Converted = InteropUtils.GetInstance<System.Object>(arg0);
	
	    try {
			System.String __returnValue = System.String.Format(providerConverted, formatConverted, arg0Converted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_String_Format_5")]
	internal static void* /* System.String */ System_String_Format_5(void* /* System.IFormatProvider */ provider, void* /* System.String */ format, void* /* System.Object */ arg0, void* /* System.Object */ arg1, void** /* System.Exception */ __outException)
	{
		System.IFormatProvider providerConverted = InteropUtils.GetInstance<System.IFormatProvider>(provider);
		System.String formatConverted = InteropUtils.GetInstance<System.String>(format);
		System.Object arg0Converted = InteropUtils.GetInstance<System.Object>(arg0);
		System.Object arg1Converted = InteropUtils.GetInstance<System.Object>(arg1);
	
	    try {
			System.String __returnValue = System.String.Format(providerConverted, formatConverted, arg0Converted, arg1Converted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_String_Format_6")]
	internal static void* /* System.String */ System_String_Format_6(void* /* System.IFormatProvider */ provider, void* /* System.String */ format, void* /* System.Object */ arg0, void* /* System.Object */ arg1, void* /* System.Object */ arg2, void** /* System.Exception */ __outException)
	{
		System.IFormatProvider providerConverted = InteropUtils.GetInstance<System.IFormatProvider>(provider);
		System.String formatConverted = InteropUtils.GetInstance<System.String>(format);
		System.Object arg0Converted = InteropUtils.GetInstance<System.Object>(arg0);
		System.Object arg1Converted = InteropUtils.GetInstance<System.Object>(arg1);
		System.Object arg2Converted = InteropUtils.GetInstance<System.Object>(arg2);
	
	    try {
			System.String __returnValue = System.String.Format(providerConverted, formatConverted, arg0Converted, arg1Converted, arg2Converted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_String_Format_7")]
	internal static void* /* System.String */ System_String_Format_7(void* /* System.IFormatProvider */ provider, void* /* System.String */ format, void* /* System.Object[] */ args, void** /* System.Exception */ __outException)
	{
		System.IFormatProvider providerConverted = InteropUtils.GetInstance<System.IFormatProvider>(provider);
		System.String formatConverted = InteropUtils.GetInstance<System.String>(format);
		System.Object[] argsConverted = InteropUtils.GetInstance<System.Object[]>(args);
	
	    try {
			System.String __returnValue = System.String.Format(providerConverted, formatConverted, argsConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_String_Format_8")]
	internal static void* /* System.String */ System_String_Format_8(void* /* System.IFormatProvider */ provider, void* /* System.Text.CompositeFormat */ format, void* /* System.Object[] */ args, void** /* System.Exception */ __outException)
	{
		System.IFormatProvider providerConverted = InteropUtils.GetInstance<System.IFormatProvider>(provider);
		System.Text.CompositeFormat formatConverted = InteropUtils.GetInstance<System.Text.CompositeFormat>(format);
		System.Object[] argsConverted = InteropUtils.GetInstance<System.Object[]>(args);
	
	    try {
			System.String __returnValue = System.String.Format(providerConverted, formatConverted, argsConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_String_Insert")]
	internal static void* /* System.String */ System_String_Insert(void* /* System.String */ __self, int /* System.Int32 */ startIndex, void* /* System.String */ value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.String __selfConverted = InteropUtils.GetInstance<System.String>(__self);
	
		System.String valueConverted = InteropUtils.GetInstance<System.String>(value);
	
	    try {
			System.String __returnValue = __selfConverted.Insert(startIndex, valueConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_String_Join")]
	internal static void* /* System.String */ System_String_Join(char /* System.Char */ separator, void* /* System.String[] */ value, void** /* System.Exception */ __outException)
	{
		System.String[] valueConverted = InteropUtils.GetInstance<System.String[]>(value);
	
	    try {
			System.String __returnValue = System.String.Join(separator, valueConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_String_Join_1")]
	internal static void* /* System.String */ System_String_Join_1(void* /* System.String */ separator, void* /* System.String[] */ value, void** /* System.Exception */ __outException)
	{
		System.String separatorConverted = InteropUtils.GetInstance<System.String>(separator);
		System.String[] valueConverted = InteropUtils.GetInstance<System.String[]>(value);
	
	    try {
			System.String __returnValue = System.String.Join(separatorConverted, valueConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_String_Join_2")]
	internal static void* /* System.String */ System_String_Join_2(char /* System.Char */ separator, void* /* System.String[] */ value, int /* System.Int32 */ startIndex, int /* System.Int32 */ count, void** /* System.Exception */ __outException)
	{
		System.String[] valueConverted = InteropUtils.GetInstance<System.String[]>(value);
	
	    try {
			System.String __returnValue = System.String.Join(separator, valueConverted, startIndex, count);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_String_Join_3")]
	internal static void* /* System.String */ System_String_Join_3(void* /* System.String */ separator, void* /* System.String[] */ value, int /* System.Int32 */ startIndex, int /* System.Int32 */ count, void** /* System.Exception */ __outException)
	{
		System.String separatorConverted = InteropUtils.GetInstance<System.String>(separator);
		System.String[] valueConverted = InteropUtils.GetInstance<System.String[]>(value);
	
	    try {
			System.String __returnValue = System.String.Join(separatorConverted, valueConverted, startIndex, count);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_String_Join_4")]
	internal static void* /* System.String */ System_String_Join_4(char /* System.Char */ separator, void* /* System.Object[] */ values, void** /* System.Exception */ __outException)
	{
		System.Object[] valuesConverted = InteropUtils.GetInstance<System.Object[]>(values);
	
	    try {
			System.String __returnValue = System.String.Join(separator, valuesConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_String_Join_5")]
	internal static void* /* System.String */ System_String_Join_5(void* /* System.String */ separator, void* /* System.Object[] */ values, void** /* System.Exception */ __outException)
	{
		System.String separatorConverted = InteropUtils.GetInstance<System.String>(separator);
		System.Object[] valuesConverted = InteropUtils.GetInstance<System.Object[]>(values);
	
	    try {
			System.String __returnValue = System.String.Join(separatorConverted, valuesConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_String_PadLeft")]
	internal static void* /* System.String */ System_String_PadLeft(void* /* System.String */ __self, int /* System.Int32 */ totalWidth, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.String __selfConverted = InteropUtils.GetInstance<System.String>(__self);
	
	
	    try {
			System.String __returnValue = __selfConverted.PadLeft(totalWidth);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_String_PadLeft_1")]
	internal static void* /* System.String */ System_String_PadLeft_1(void* /* System.String */ __self, int /* System.Int32 */ totalWidth, char /* System.Char */ paddingChar, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.String __selfConverted = InteropUtils.GetInstance<System.String>(__self);
	
	
	    try {
			System.String __returnValue = __selfConverted.PadLeft(totalWidth, paddingChar);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_String_PadRight")]
	internal static void* /* System.String */ System_String_PadRight(void* /* System.String */ __self, int /* System.Int32 */ totalWidth, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.String __selfConverted = InteropUtils.GetInstance<System.String>(__self);
	
	
	    try {
			System.String __returnValue = __selfConverted.PadRight(totalWidth);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_String_PadRight_1")]
	internal static void* /* System.String */ System_String_PadRight_1(void* /* System.String */ __self, int /* System.Int32 */ totalWidth, char /* System.Char */ paddingChar, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.String __selfConverted = InteropUtils.GetInstance<System.String>(__self);
	
	
	    try {
			System.String __returnValue = __selfConverted.PadRight(totalWidth, paddingChar);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_String_Remove")]
	internal static void* /* System.String */ System_String_Remove(void* /* System.String */ __self, int /* System.Int32 */ startIndex, int /* System.Int32 */ count, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.String __selfConverted = InteropUtils.GetInstance<System.String>(__self);
	
	
	    try {
			System.String __returnValue = __selfConverted.Remove(startIndex, count);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_String_Remove_1")]
	internal static void* /* System.String */ System_String_Remove_1(void* /* System.String */ __self, int /* System.Int32 */ startIndex, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.String __selfConverted = InteropUtils.GetInstance<System.String>(__self);
	
	
	    try {
			System.String __returnValue = __selfConverted.Remove(startIndex);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_String_Replace")]
	internal static void* /* System.String */ System_String_Replace(void* /* System.String */ __self, void* /* System.String */ oldValue, void* /* System.String */ newValue, byte /* System.Boolean */ ignoreCase, void* /* System.Globalization.CultureInfo */ culture, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.String __selfConverted = InteropUtils.GetInstance<System.String>(__self);
	
		System.String oldValueConverted = InteropUtils.GetInstance<System.String>(oldValue);
		System.String newValueConverted = InteropUtils.GetInstance<System.String>(newValue);
		System.Boolean ignoreCaseConverted = ignoreCase.ToBool();
		System.Globalization.CultureInfo cultureConverted = InteropUtils.GetInstance<System.Globalization.CultureInfo>(culture);
	
	    try {
			System.String __returnValue = __selfConverted.Replace(oldValueConverted, newValueConverted, ignoreCaseConverted, cultureConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_String_Replace_1")]
	internal static void* /* System.String */ System_String_Replace_1(void* /* System.String */ __self, void* /* System.String */ oldValue, void* /* System.String */ newValue, System.StringComparison /* System.StringComparison */ comparisonType, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.String __selfConverted = InteropUtils.GetInstance<System.String>(__self);
	
		System.String oldValueConverted = InteropUtils.GetInstance<System.String>(oldValue);
		System.String newValueConverted = InteropUtils.GetInstance<System.String>(newValue);
	
	    try {
			System.String __returnValue = __selfConverted.Replace(oldValueConverted, newValueConverted, comparisonType);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_String_Replace_2")]
	internal static void* /* System.String */ System_String_Replace_2(void* /* System.String */ __self, char /* System.Char */ oldChar, char /* System.Char */ newChar, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.String __selfConverted = InteropUtils.GetInstance<System.String>(__self);
	
	
	    try {
			System.String __returnValue = __selfConverted.Replace(oldChar, newChar);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_String_Replace_3")]
	internal static void* /* System.String */ System_String_Replace_3(void* /* System.String */ __self, void* /* System.String */ oldValue, void* /* System.String */ newValue, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.String __selfConverted = InteropUtils.GetInstance<System.String>(__self);
	
		System.String oldValueConverted = InteropUtils.GetInstance<System.String>(oldValue);
		System.String newValueConverted = InteropUtils.GetInstance<System.String>(newValue);
	
	    try {
			System.String __returnValue = __selfConverted.Replace(oldValueConverted, newValueConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_String_ReplaceLineEndings")]
	internal static void* /* System.String */ System_String_ReplaceLineEndings(void* /* System.String */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.String __selfConverted = InteropUtils.GetInstance<System.String>(__self);
	
	
	    try {
			System.String __returnValue = __selfConverted.ReplaceLineEndings();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_String_ReplaceLineEndings_1")]
	internal static void* /* System.String */ System_String_ReplaceLineEndings_1(void* /* System.String */ __self, void* /* System.String */ replacementText, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.String __selfConverted = InteropUtils.GetInstance<System.String>(__self);
	
		System.String replacementTextConverted = InteropUtils.GetInstance<System.String>(replacementText);
	
	    try {
			System.String __returnValue = __selfConverted.ReplaceLineEndings(replacementTextConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_String_Split")]
	internal static void* /* System.String[] */ System_String_Split(void* /* System.String */ __self, char /* System.Char */ separator, System.StringSplitOptions /* System.StringSplitOptions */ options, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.String __selfConverted = InteropUtils.GetInstance<System.String>(__self);
	
	
	    try {
			System.String[] __returnValue = __selfConverted.Split(separator, options);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_String_Split_1")]
	internal static void* /* System.String[] */ System_String_Split_1(void* /* System.String */ __self, char /* System.Char */ separator, int /* System.Int32 */ count, System.StringSplitOptions /* System.StringSplitOptions */ options, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.String __selfConverted = InteropUtils.GetInstance<System.String>(__self);
	
	
	    try {
			System.String[] __returnValue = __selfConverted.Split(separator, count, options);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_String_Split_2")]
	internal static void* /* System.String[] */ System_String_Split_2(void* /* System.String */ __self, void* /* System.Char[] */ separator, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.String __selfConverted = InteropUtils.GetInstance<System.String>(__self);
	
		System.Char[] separatorConverted = InteropUtils.GetInstance<System.Char[]>(separator);
	
	    try {
			System.String[] __returnValue = __selfConverted.Split(separatorConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_String_Split_3")]
	internal static void* /* System.String[] */ System_String_Split_3(void* /* System.String */ __self, void* /* System.Char[] */ separator, int /* System.Int32 */ count, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.String __selfConverted = InteropUtils.GetInstance<System.String>(__self);
	
		System.Char[] separatorConverted = InteropUtils.GetInstance<System.Char[]>(separator);
	
	    try {
			System.String[] __returnValue = __selfConverted.Split(separatorConverted, count);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_String_Split_4")]
	internal static void* /* System.String[] */ System_String_Split_4(void* /* System.String */ __self, void* /* System.Char[] */ separator, System.StringSplitOptions /* System.StringSplitOptions */ options, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.String __selfConverted = InteropUtils.GetInstance<System.String>(__self);
	
		System.Char[] separatorConverted = InteropUtils.GetInstance<System.Char[]>(separator);
	
	    try {
			System.String[] __returnValue = __selfConverted.Split(separatorConverted, options);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_String_Split_5")]
	internal static void* /* System.String[] */ System_String_Split_5(void* /* System.String */ __self, void* /* System.Char[] */ separator, int /* System.Int32 */ count, System.StringSplitOptions /* System.StringSplitOptions */ options, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.String __selfConverted = InteropUtils.GetInstance<System.String>(__self);
	
		System.Char[] separatorConverted = InteropUtils.GetInstance<System.Char[]>(separator);
	
	    try {
			System.String[] __returnValue = __selfConverted.Split(separatorConverted, count, options);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_String_Split_6")]
	internal static void* /* System.String[] */ System_String_Split_6(void* /* System.String */ __self, void* /* System.String */ separator, System.StringSplitOptions /* System.StringSplitOptions */ options, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.String __selfConverted = InteropUtils.GetInstance<System.String>(__self);
	
		System.String separatorConverted = InteropUtils.GetInstance<System.String>(separator);
	
	    try {
			System.String[] __returnValue = __selfConverted.Split(separatorConverted, options);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_String_Split_7")]
	internal static void* /* System.String[] */ System_String_Split_7(void* /* System.String */ __self, void* /* System.String */ separator, int /* System.Int32 */ count, System.StringSplitOptions /* System.StringSplitOptions */ options, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.String __selfConverted = InteropUtils.GetInstance<System.String>(__self);
	
		System.String separatorConverted = InteropUtils.GetInstance<System.String>(separator);
	
	    try {
			System.String[] __returnValue = __selfConverted.Split(separatorConverted, count, options);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_String_Split_8")]
	internal static void* /* System.String[] */ System_String_Split_8(void* /* System.String */ __self, void* /* System.String[] */ separator, System.StringSplitOptions /* System.StringSplitOptions */ options, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.String __selfConverted = InteropUtils.GetInstance<System.String>(__self);
	
		System.String[] separatorConverted = InteropUtils.GetInstance<System.String[]>(separator);
	
	    try {
			System.String[] __returnValue = __selfConverted.Split(separatorConverted, options);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_String_Split_9")]
	internal static void* /* System.String[] */ System_String_Split_9(void* /* System.String */ __self, void* /* System.String[] */ separator, int /* System.Int32 */ count, System.StringSplitOptions /* System.StringSplitOptions */ options, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.String __selfConverted = InteropUtils.GetInstance<System.String>(__self);
	
		System.String[] separatorConverted = InteropUtils.GetInstance<System.String[]>(separator);
	
	    try {
			System.String[] __returnValue = __selfConverted.Split(separatorConverted, count, options);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_String_Substring")]
	internal static void* /* System.String */ System_String_Substring(void* /* System.String */ __self, int /* System.Int32 */ startIndex, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.String __selfConverted = InteropUtils.GetInstance<System.String>(__self);
	
	
	    try {
			System.String __returnValue = __selfConverted.Substring(startIndex);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_String_Substring_1")]
	internal static void* /* System.String */ System_String_Substring_1(void* /* System.String */ __self, int /* System.Int32 */ startIndex, int /* System.Int32 */ length, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.String __selfConverted = InteropUtils.GetInstance<System.String>(__self);
	
	
	    try {
			System.String __returnValue = __selfConverted.Substring(startIndex, length);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_String_ToLower")]
	internal static void* /* System.String */ System_String_ToLower(void* /* System.String */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.String __selfConverted = InteropUtils.GetInstance<System.String>(__self);
	
	
	    try {
			System.String __returnValue = __selfConverted.ToLower();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_String_ToLower_1")]
	internal static void* /* System.String */ System_String_ToLower_1(void* /* System.String */ __self, void* /* System.Globalization.CultureInfo */ culture, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.String __selfConverted = InteropUtils.GetInstance<System.String>(__self);
	
		System.Globalization.CultureInfo cultureConverted = InteropUtils.GetInstance<System.Globalization.CultureInfo>(culture);
	
	    try {
			System.String __returnValue = __selfConverted.ToLower(cultureConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_String_ToLowerInvariant")]
	internal static void* /* System.String */ System_String_ToLowerInvariant(void* /* System.String */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.String __selfConverted = InteropUtils.GetInstance<System.String>(__self);
	
	
	    try {
			System.String __returnValue = __selfConverted.ToLowerInvariant();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_String_ToUpper")]
	internal static void* /* System.String */ System_String_ToUpper(void* /* System.String */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.String __selfConverted = InteropUtils.GetInstance<System.String>(__self);
	
	
	    try {
			System.String __returnValue = __selfConverted.ToUpper();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_String_ToUpper_1")]
	internal static void* /* System.String */ System_String_ToUpper_1(void* /* System.String */ __self, void* /* System.Globalization.CultureInfo */ culture, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.String __selfConverted = InteropUtils.GetInstance<System.String>(__self);
	
		System.Globalization.CultureInfo cultureConverted = InteropUtils.GetInstance<System.Globalization.CultureInfo>(culture);
	
	    try {
			System.String __returnValue = __selfConverted.ToUpper(cultureConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_String_ToUpperInvariant")]
	internal static void* /* System.String */ System_String_ToUpperInvariant(void* /* System.String */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.String __selfConverted = InteropUtils.GetInstance<System.String>(__self);
	
	
	    try {
			System.String __returnValue = __selfConverted.ToUpperInvariant();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_String_Trim")]
	internal static void* /* System.String */ System_String_Trim(void* /* System.String */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.String __selfConverted = InteropUtils.GetInstance<System.String>(__self);
	
	
	    try {
			System.String __returnValue = __selfConverted.Trim();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_String_Trim_1")]
	internal static void* /* System.String */ System_String_Trim_1(void* /* System.String */ __self, char /* System.Char */ trimChar, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.String __selfConverted = InteropUtils.GetInstance<System.String>(__self);
	
	
	    try {
			System.String __returnValue = __selfConverted.Trim(trimChar);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_String_Trim_2")]
	internal static void* /* System.String */ System_String_Trim_2(void* /* System.String */ __self, void* /* System.Char[] */ trimChars, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.String __selfConverted = InteropUtils.GetInstance<System.String>(__self);
	
		System.Char[] trimCharsConverted = InteropUtils.GetInstance<System.Char[]>(trimChars);
	
	    try {
			System.String __returnValue = __selfConverted.Trim(trimCharsConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_String_TrimStart")]
	internal static void* /* System.String */ System_String_TrimStart(void* /* System.String */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.String __selfConverted = InteropUtils.GetInstance<System.String>(__self);
	
	
	    try {
			System.String __returnValue = __selfConverted.TrimStart();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_String_TrimStart_1")]
	internal static void* /* System.String */ System_String_TrimStart_1(void* /* System.String */ __self, char /* System.Char */ trimChar, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.String __selfConverted = InteropUtils.GetInstance<System.String>(__self);
	
	
	    try {
			System.String __returnValue = __selfConverted.TrimStart(trimChar);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_String_TrimStart_2")]
	internal static void* /* System.String */ System_String_TrimStart_2(void* /* System.String */ __self, void* /* System.Char[] */ trimChars, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.String __selfConverted = InteropUtils.GetInstance<System.String>(__self);
	
		System.Char[] trimCharsConverted = InteropUtils.GetInstance<System.Char[]>(trimChars);
	
	    try {
			System.String __returnValue = __selfConverted.TrimStart(trimCharsConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_String_TrimEnd")]
	internal static void* /* System.String */ System_String_TrimEnd(void* /* System.String */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.String __selfConverted = InteropUtils.GetInstance<System.String>(__self);
	
	
	    try {
			System.String __returnValue = __selfConverted.TrimEnd();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_String_TrimEnd_1")]
	internal static void* /* System.String */ System_String_TrimEnd_1(void* /* System.String */ __self, char /* System.Char */ trimChar, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.String __selfConverted = InteropUtils.GetInstance<System.String>(__self);
	
	
	    try {
			System.String __returnValue = __selfConverted.TrimEnd(trimChar);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_String_TrimEnd_2")]
	internal static void* /* System.String */ System_String_TrimEnd_2(void* /* System.String */ __self, void* /* System.Char[] */ trimChars, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.String __selfConverted = InteropUtils.GetInstance<System.String>(__self);
	
		System.Char[] trimCharsConverted = InteropUtils.GetInstance<System.Char[]>(trimChars);
	
	    try {
			System.String __returnValue = __selfConverted.TrimEnd(trimCharsConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_String_Contains")]
	internal static byte /* System.Boolean */ System_String_Contains(void* /* System.String */ __self, void* /* System.String */ value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.String __selfConverted = InteropUtils.GetInstance<System.String>(__self);
	
		System.String valueConverted = InteropUtils.GetInstance<System.String>(value);
	
	    try {
			System.Boolean __returnValue = __selfConverted.Contains(valueConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_String_Contains_1")]
	internal static byte /* System.Boolean */ System_String_Contains_1(void* /* System.String */ __self, void* /* System.String */ value, System.StringComparison /* System.StringComparison */ comparisonType, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.String __selfConverted = InteropUtils.GetInstance<System.String>(__self);
	
		System.String valueConverted = InteropUtils.GetInstance<System.String>(value);
	
	    try {
			System.Boolean __returnValue = __selfConverted.Contains(valueConverted, comparisonType);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_String_Contains_2")]
	internal static byte /* System.Boolean */ System_String_Contains_2(void* /* System.String */ __self, char /* System.Char */ value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.String __selfConverted = InteropUtils.GetInstance<System.String>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.Contains(value);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_String_Contains_3")]
	internal static byte /* System.Boolean */ System_String_Contains_3(void* /* System.String */ __self, char /* System.Char */ value, System.StringComparison /* System.StringComparison */ comparisonType, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.String __selfConverted = InteropUtils.GetInstance<System.String>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.Contains(value, comparisonType);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_String_IndexOf")]
	internal static int /* System.Int32 */ System_String_IndexOf(void* /* System.String */ __self, char /* System.Char */ value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.String __selfConverted = InteropUtils.GetInstance<System.String>(__self);
	
	
	    try {
			System.Int32 __returnValue = __selfConverted.IndexOf(value);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_String_IndexOf_1")]
	internal static int /* System.Int32 */ System_String_IndexOf_1(void* /* System.String */ __self, char /* System.Char */ value, int /* System.Int32 */ startIndex, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.String __selfConverted = InteropUtils.GetInstance<System.String>(__self);
	
	
	    try {
			System.Int32 __returnValue = __selfConverted.IndexOf(value, startIndex);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_String_IndexOf_2")]
	internal static int /* System.Int32 */ System_String_IndexOf_2(void* /* System.String */ __self, char /* System.Char */ value, System.StringComparison /* System.StringComparison */ comparisonType, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.String __selfConverted = InteropUtils.GetInstance<System.String>(__self);
	
	
	    try {
			System.Int32 __returnValue = __selfConverted.IndexOf(value, comparisonType);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_String_IndexOf_3")]
	internal static int /* System.Int32 */ System_String_IndexOf_3(void* /* System.String */ __self, char /* System.Char */ value, int /* System.Int32 */ startIndex, int /* System.Int32 */ count, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.String __selfConverted = InteropUtils.GetInstance<System.String>(__self);
	
	
	    try {
			System.Int32 __returnValue = __selfConverted.IndexOf(value, startIndex, count);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_String_IndexOfAny")]
	internal static int /* System.Int32 */ System_String_IndexOfAny(void* /* System.String */ __self, void* /* System.Char[] */ anyOf, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.String __selfConverted = InteropUtils.GetInstance<System.String>(__self);
	
		System.Char[] anyOfConverted = InteropUtils.GetInstance<System.Char[]>(anyOf);
	
	    try {
			System.Int32 __returnValue = __selfConverted.IndexOfAny(anyOfConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_String_IndexOfAny_1")]
	internal static int /* System.Int32 */ System_String_IndexOfAny_1(void* /* System.String */ __self, void* /* System.Char[] */ anyOf, int /* System.Int32 */ startIndex, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.String __selfConverted = InteropUtils.GetInstance<System.String>(__self);
	
		System.Char[] anyOfConverted = InteropUtils.GetInstance<System.Char[]>(anyOf);
	
	    try {
			System.Int32 __returnValue = __selfConverted.IndexOfAny(anyOfConverted, startIndex);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_String_IndexOfAny_2")]
	internal static int /* System.Int32 */ System_String_IndexOfAny_2(void* /* System.String */ __self, void* /* System.Char[] */ anyOf, int /* System.Int32 */ startIndex, int /* System.Int32 */ count, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.String __selfConverted = InteropUtils.GetInstance<System.String>(__self);
	
		System.Char[] anyOfConverted = InteropUtils.GetInstance<System.Char[]>(anyOf);
	
	    try {
			System.Int32 __returnValue = __selfConverted.IndexOfAny(anyOfConverted, startIndex, count);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_String_IndexOf_4")]
	internal static int /* System.Int32 */ System_String_IndexOf_4(void* /* System.String */ __self, void* /* System.String */ value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.String __selfConverted = InteropUtils.GetInstance<System.String>(__self);
	
		System.String valueConverted = InteropUtils.GetInstance<System.String>(value);
	
	    try {
			System.Int32 __returnValue = __selfConverted.IndexOf(valueConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_String_IndexOf_5")]
	internal static int /* System.Int32 */ System_String_IndexOf_5(void* /* System.String */ __self, void* /* System.String */ value, int /* System.Int32 */ startIndex, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.String __selfConverted = InteropUtils.GetInstance<System.String>(__self);
	
		System.String valueConverted = InteropUtils.GetInstance<System.String>(value);
	
	    try {
			System.Int32 __returnValue = __selfConverted.IndexOf(valueConverted, startIndex);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_String_IndexOf_6")]
	internal static int /* System.Int32 */ System_String_IndexOf_6(void* /* System.String */ __self, void* /* System.String */ value, int /* System.Int32 */ startIndex, int /* System.Int32 */ count, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.String __selfConverted = InteropUtils.GetInstance<System.String>(__self);
	
		System.String valueConverted = InteropUtils.GetInstance<System.String>(value);
	
	    try {
			System.Int32 __returnValue = __selfConverted.IndexOf(valueConverted, startIndex, count);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_String_IndexOf_7")]
	internal static int /* System.Int32 */ System_String_IndexOf_7(void* /* System.String */ __self, void* /* System.String */ value, System.StringComparison /* System.StringComparison */ comparisonType, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.String __selfConverted = InteropUtils.GetInstance<System.String>(__self);
	
		System.String valueConverted = InteropUtils.GetInstance<System.String>(value);
	
	    try {
			System.Int32 __returnValue = __selfConverted.IndexOf(valueConverted, comparisonType);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_String_IndexOf_8")]
	internal static int /* System.Int32 */ System_String_IndexOf_8(void* /* System.String */ __self, void* /* System.String */ value, int /* System.Int32 */ startIndex, System.StringComparison /* System.StringComparison */ comparisonType, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.String __selfConverted = InteropUtils.GetInstance<System.String>(__self);
	
		System.String valueConverted = InteropUtils.GetInstance<System.String>(value);
	
	    try {
			System.Int32 __returnValue = __selfConverted.IndexOf(valueConverted, startIndex, comparisonType);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_String_IndexOf_9")]
	internal static int /* System.Int32 */ System_String_IndexOf_9(void* /* System.String */ __self, void* /* System.String */ value, int /* System.Int32 */ startIndex, int /* System.Int32 */ count, System.StringComparison /* System.StringComparison */ comparisonType, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.String __selfConverted = InteropUtils.GetInstance<System.String>(__self);
	
		System.String valueConverted = InteropUtils.GetInstance<System.String>(value);
	
	    try {
			System.Int32 __returnValue = __selfConverted.IndexOf(valueConverted, startIndex, count, comparisonType);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_String_LastIndexOf")]
	internal static int /* System.Int32 */ System_String_LastIndexOf(void* /* System.String */ __self, char /* System.Char */ value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.String __selfConverted = InteropUtils.GetInstance<System.String>(__self);
	
	
	    try {
			System.Int32 __returnValue = __selfConverted.LastIndexOf(value);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_String_LastIndexOf_1")]
	internal static int /* System.Int32 */ System_String_LastIndexOf_1(void* /* System.String */ __self, char /* System.Char */ value, int /* System.Int32 */ startIndex, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.String __selfConverted = InteropUtils.GetInstance<System.String>(__self);
	
	
	    try {
			System.Int32 __returnValue = __selfConverted.LastIndexOf(value, startIndex);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_String_LastIndexOf_2")]
	internal static int /* System.Int32 */ System_String_LastIndexOf_2(void* /* System.String */ __self, char /* System.Char */ value, int /* System.Int32 */ startIndex, int /* System.Int32 */ count, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.String __selfConverted = InteropUtils.GetInstance<System.String>(__self);
	
	
	    try {
			System.Int32 __returnValue = __selfConverted.LastIndexOf(value, startIndex, count);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_String_LastIndexOfAny")]
	internal static int /* System.Int32 */ System_String_LastIndexOfAny(void* /* System.String */ __self, void* /* System.Char[] */ anyOf, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.String __selfConverted = InteropUtils.GetInstance<System.String>(__self);
	
		System.Char[] anyOfConverted = InteropUtils.GetInstance<System.Char[]>(anyOf);
	
	    try {
			System.Int32 __returnValue = __selfConverted.LastIndexOfAny(anyOfConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_String_LastIndexOfAny_1")]
	internal static int /* System.Int32 */ System_String_LastIndexOfAny_1(void* /* System.String */ __self, void* /* System.Char[] */ anyOf, int /* System.Int32 */ startIndex, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.String __selfConverted = InteropUtils.GetInstance<System.String>(__self);
	
		System.Char[] anyOfConverted = InteropUtils.GetInstance<System.Char[]>(anyOf);
	
	    try {
			System.Int32 __returnValue = __selfConverted.LastIndexOfAny(anyOfConverted, startIndex);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_String_LastIndexOfAny_2")]
	internal static int /* System.Int32 */ System_String_LastIndexOfAny_2(void* /* System.String */ __self, void* /* System.Char[] */ anyOf, int /* System.Int32 */ startIndex, int /* System.Int32 */ count, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.String __selfConverted = InteropUtils.GetInstance<System.String>(__self);
	
		System.Char[] anyOfConverted = InteropUtils.GetInstance<System.Char[]>(anyOf);
	
	    try {
			System.Int32 __returnValue = __selfConverted.LastIndexOfAny(anyOfConverted, startIndex, count);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_String_LastIndexOf_3")]
	internal static int /* System.Int32 */ System_String_LastIndexOf_3(void* /* System.String */ __self, void* /* System.String */ value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.String __selfConverted = InteropUtils.GetInstance<System.String>(__self);
	
		System.String valueConverted = InteropUtils.GetInstance<System.String>(value);
	
	    try {
			System.Int32 __returnValue = __selfConverted.LastIndexOf(valueConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_String_LastIndexOf_4")]
	internal static int /* System.Int32 */ System_String_LastIndexOf_4(void* /* System.String */ __self, void* /* System.String */ value, int /* System.Int32 */ startIndex, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.String __selfConverted = InteropUtils.GetInstance<System.String>(__self);
	
		System.String valueConverted = InteropUtils.GetInstance<System.String>(value);
	
	    try {
			System.Int32 __returnValue = __selfConverted.LastIndexOf(valueConverted, startIndex);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_String_LastIndexOf_5")]
	internal static int /* System.Int32 */ System_String_LastIndexOf_5(void* /* System.String */ __self, void* /* System.String */ value, int /* System.Int32 */ startIndex, int /* System.Int32 */ count, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.String __selfConverted = InteropUtils.GetInstance<System.String>(__self);
	
		System.String valueConverted = InteropUtils.GetInstance<System.String>(value);
	
	    try {
			System.Int32 __returnValue = __selfConverted.LastIndexOf(valueConverted, startIndex, count);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_String_LastIndexOf_6")]
	internal static int /* System.Int32 */ System_String_LastIndexOf_6(void* /* System.String */ __self, void* /* System.String */ value, System.StringComparison /* System.StringComparison */ comparisonType, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.String __selfConverted = InteropUtils.GetInstance<System.String>(__self);
	
		System.String valueConverted = InteropUtils.GetInstance<System.String>(value);
	
	    try {
			System.Int32 __returnValue = __selfConverted.LastIndexOf(valueConverted, comparisonType);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_String_LastIndexOf_7")]
	internal static int /* System.Int32 */ System_String_LastIndexOf_7(void* /* System.String */ __self, void* /* System.String */ value, int /* System.Int32 */ startIndex, System.StringComparison /* System.StringComparison */ comparisonType, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.String __selfConverted = InteropUtils.GetInstance<System.String>(__self);
	
		System.String valueConverted = InteropUtils.GetInstance<System.String>(value);
	
	    try {
			System.Int32 __returnValue = __selfConverted.LastIndexOf(valueConverted, startIndex, comparisonType);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_String_LastIndexOf_8")]
	internal static int /* System.Int32 */ System_String_LastIndexOf_8(void* /* System.String */ __self, void* /* System.String */ value, int /* System.Int32 */ startIndex, int /* System.Int32 */ count, System.StringComparison /* System.StringComparison */ comparisonType, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.String __selfConverted = InteropUtils.GetInstance<System.String>(__self);
	
		System.String valueConverted = InteropUtils.GetInstance<System.String>(value);
	
	    try {
			System.Int32 __returnValue = __selfConverted.LastIndexOf(valueConverted, startIndex, count, comparisonType);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_String_Create")]
	internal static void* /* System.String */ System_String_Create(void* /* System.Char[] */ value, void** /* System.Exception */ __outException)
	{
		System.Char[] valueConverted = InteropUtils.GetInstance<System.Char[]>(value);
	
	    try {
			System.String __returnValue = new System.String(valueConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_String_Create_1")]
	internal static void* /* System.String */ System_String_Create_1(void* /* System.Char[] */ value, int /* System.Int32 */ startIndex, int /* System.Int32 */ length, void** /* System.Exception */ __outException)
	{
		System.Char[] valueConverted = InteropUtils.GetInstance<System.Char[]>(value);
	
	    try {
			System.String __returnValue = new System.String(valueConverted, startIndex, length);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_String_Create_2")]
	internal static void* /* System.String */ System_String_Create_2(char /* System.Char */ c, int /* System.Int32 */ count, void** /* System.Exception */ __outException)
	{
	
	    try {
			System.String __returnValue = new System.String(c, count);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_String_Chars_Get")]
	internal static char /* System.Char */ System_String_Chars_Get(void* /* System.String */ __self, int /* System.Int32 */ index, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.String __selfConverted = InteropUtils.GetInstance<System.String>(__self);
	
	
	    try {
			System.Char __returnValue = __selfConverted[index];
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return (char)0;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_String_Length_Get")]
	internal static int /* System.Int32 */ System_String_Length_Get(void* /* System.String */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.String __selfConverted = InteropUtils.GetInstance<System.String>(__self);
	
	
	    try {
			System.Int32 __returnValue = __selfConverted.Length;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_String_Empty_Get")]
	internal static void* /* System.String */ System_String_Empty_Get()
	{
	
		System.String __returnValue = System.String.Empty;
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_String_TypeOf")]
	internal static void* /* System.Type */ System_String_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.String);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_String_Destroy")]
	internal static void /* System.Void */ System_String_Destroy(void* /* System.String */ __self)
	{
	
		InteropUtils.FreeIfAllocated(__self);
	}
	
}


internal unsafe class System_StringComparison
{
	[UnmanagedCallersOnly(EntryPoint = "System_StringComparison_TypeOf")]
	internal static void* /* System.Type */ System_StringComparison_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.StringComparison);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
}


internal unsafe class System_Globalization_CultureInfo
{
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_CultureInfo_CreateSpecificCulture")]
	internal static void* /* System.Globalization.CultureInfo */ System_Globalization_CultureInfo_CreateSpecificCulture(void* /* System.String */ name, void** /* System.Exception */ __outException)
	{
		System.String nameConverted = InteropUtils.GetInstance<System.String>(name);
	
	    try {
			System.Globalization.CultureInfo __returnValue = System.Globalization.CultureInfo.CreateSpecificCulture(nameConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_CultureInfo_GetCultures")]
	internal static void* /* System.Globalization.CultureInfo[] */ System_Globalization_CultureInfo_GetCultures(System.Globalization.CultureTypes /* System.Globalization.CultureTypes */ types, void** /* System.Exception */ __outException)
	{
	
	    try {
			System.Globalization.CultureInfo[] __returnValue = System.Globalization.CultureInfo.GetCultures(types);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_CultureInfo_Equals")]
	internal static byte /* System.Boolean */ System_Globalization_CultureInfo_Equals(void* /* System.Globalization.CultureInfo */ __self, void* /* System.Object */ value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.CultureInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.CultureInfo>(__self);
	
		System.Object valueConverted = InteropUtils.GetInstance<System.Object>(value);
	
	    try {
			System.Boolean __returnValue = __selfConverted.Equals(valueConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_CultureInfo_GetHashCode")]
	internal static int /* System.Int32 */ System_Globalization_CultureInfo_GetHashCode(void* /* System.Globalization.CultureInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.CultureInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.CultureInfo>(__self);
	
	
	    try {
			System.Int32 __returnValue = __selfConverted.GetHashCode();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_CultureInfo_ToString")]
	internal static void* /* System.String */ System_Globalization_CultureInfo_ToString(void* /* System.Globalization.CultureInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.CultureInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.CultureInfo>(__self);
	
	
	    try {
			System.String __returnValue = __selfConverted.ToString();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_CultureInfo_GetFormat")]
	internal static void* /* System.Object */ System_Globalization_CultureInfo_GetFormat(void* /* System.Globalization.CultureInfo */ __self, void* /* System.Type */ formatType, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.CultureInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.CultureInfo>(__self);
	
		System.Type formatTypeConverted = InteropUtils.GetInstance<System.Type>(formatType);
	
	    try {
			System.Object __returnValue = __selfConverted.GetFormat(formatTypeConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_CultureInfo_ClearCachedData")]
	internal static void /* System.Void */ System_Globalization_CultureInfo_ClearCachedData(void* /* System.Globalization.CultureInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.CultureInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.CultureInfo>(__self);
	
	
	    try {
			__selfConverted.ClearCachedData();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_CultureInfo_GetConsoleFallbackUICulture")]
	internal static void* /* System.Globalization.CultureInfo */ System_Globalization_CultureInfo_GetConsoleFallbackUICulture(void* /* System.Globalization.CultureInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.CultureInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.CultureInfo>(__self);
	
	
	    try {
			System.Globalization.CultureInfo __returnValue = __selfConverted.GetConsoleFallbackUICulture();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_CultureInfo_Clone")]
	internal static void* /* System.Object */ System_Globalization_CultureInfo_Clone(void* /* System.Globalization.CultureInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.CultureInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.CultureInfo>(__self);
	
	
	    try {
			System.Object __returnValue = __selfConverted.Clone();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_CultureInfo_ReadOnly")]
	internal static void* /* System.Globalization.CultureInfo */ System_Globalization_CultureInfo_ReadOnly(void* /* System.Globalization.CultureInfo */ ci, void** /* System.Exception */ __outException)
	{
		System.Globalization.CultureInfo ciConverted = InteropUtils.GetInstance<System.Globalization.CultureInfo>(ci);
	
	    try {
			System.Globalization.CultureInfo __returnValue = System.Globalization.CultureInfo.ReadOnly(ciConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_CultureInfo_GetCultureInfo")]
	internal static void* /* System.Globalization.CultureInfo */ System_Globalization_CultureInfo_GetCultureInfo(int /* System.Int32 */ culture, void** /* System.Exception */ __outException)
	{
	
	    try {
			System.Globalization.CultureInfo __returnValue = System.Globalization.CultureInfo.GetCultureInfo(culture);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_CultureInfo_GetCultureInfo_1")]
	internal static void* /* System.Globalization.CultureInfo */ System_Globalization_CultureInfo_GetCultureInfo_1(void* /* System.String */ name, void** /* System.Exception */ __outException)
	{
		System.String nameConverted = InteropUtils.GetInstance<System.String>(name);
	
	    try {
			System.Globalization.CultureInfo __returnValue = System.Globalization.CultureInfo.GetCultureInfo(nameConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_CultureInfo_GetCultureInfo_2")]
	internal static void* /* System.Globalization.CultureInfo */ System_Globalization_CultureInfo_GetCultureInfo_2(void* /* System.String */ name, void* /* System.String */ altName, void** /* System.Exception */ __outException)
	{
		System.String nameConverted = InteropUtils.GetInstance<System.String>(name);
		System.String altNameConverted = InteropUtils.GetInstance<System.String>(altName);
	
	    try {
			System.Globalization.CultureInfo __returnValue = System.Globalization.CultureInfo.GetCultureInfo(nameConverted, altNameConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_CultureInfo_GetCultureInfo_3")]
	internal static void* /* System.Globalization.CultureInfo */ System_Globalization_CultureInfo_GetCultureInfo_3(void* /* System.String */ name, byte /* System.Boolean */ predefinedOnly, void** /* System.Exception */ __outException)
	{
		System.String nameConverted = InteropUtils.GetInstance<System.String>(name);
		System.Boolean predefinedOnlyConverted = predefinedOnly.ToBool();
	
	    try {
			System.Globalization.CultureInfo __returnValue = System.Globalization.CultureInfo.GetCultureInfo(nameConverted, predefinedOnlyConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_CultureInfo_GetCultureInfoByIetfLanguageTag")]
	internal static void* /* System.Globalization.CultureInfo */ System_Globalization_CultureInfo_GetCultureInfoByIetfLanguageTag(void* /* System.String */ name, void** /* System.Exception */ __outException)
	{
		System.String nameConverted = InteropUtils.GetInstance<System.String>(name);
	
	    try {
			System.Globalization.CultureInfo __returnValue = System.Globalization.CultureInfo.GetCultureInfoByIetfLanguageTag(nameConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_CultureInfo_Create_1")]
	internal static void* /* System.Globalization.CultureInfo */ System_Globalization_CultureInfo_Create_1(void* /* System.String */ name, void** /* System.Exception */ __outException)
	{
		System.String nameConverted = InteropUtils.GetInstance<System.String>(name);
	
	    try {
			System.Globalization.CultureInfo __returnValue = new System.Globalization.CultureInfo(nameConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_CultureInfo_Create_2")]
	internal static void* /* System.Globalization.CultureInfo */ System_Globalization_CultureInfo_Create_2(void* /* System.String */ name, byte /* System.Boolean */ useUserOverride, void** /* System.Exception */ __outException)
	{
		System.String nameConverted = InteropUtils.GetInstance<System.String>(name);
		System.Boolean useUserOverrideConverted = useUserOverride.ToBool();
	
	    try {
			System.Globalization.CultureInfo __returnValue = new System.Globalization.CultureInfo(nameConverted, useUserOverrideConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_CultureInfo_Create_3")]
	internal static void* /* System.Globalization.CultureInfo */ System_Globalization_CultureInfo_Create_3(int /* System.Int32 */ culture, void** /* System.Exception */ __outException)
	{
	
	    try {
			System.Globalization.CultureInfo __returnValue = new System.Globalization.CultureInfo(culture);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_CultureInfo_Create_4")]
	internal static void* /* System.Globalization.CultureInfo */ System_Globalization_CultureInfo_Create_4(int /* System.Int32 */ culture, byte /* System.Boolean */ useUserOverride, void** /* System.Exception */ __outException)
	{
		System.Boolean useUserOverrideConverted = useUserOverride.ToBool();
	
	    try {
			System.Globalization.CultureInfo __returnValue = new System.Globalization.CultureInfo(culture, useUserOverrideConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_CultureInfo_CurrentCulture_Get")]
	internal static void* /* System.Globalization.CultureInfo */ System_Globalization_CultureInfo_CurrentCulture_Get(void** /* System.Exception */ __outException)
	{
	
	    try {
			System.Globalization.CultureInfo __returnValue = System.Globalization.CultureInfo.CurrentCulture;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_CultureInfo_CurrentCulture_Set")]
	internal static void /* System.Void */ System_Globalization_CultureInfo_CurrentCulture_Set(void* /* System.Globalization.CultureInfo */ __value, void** /* System.Exception */ __outException)
	{
	
	    try {
			System.Globalization.CultureInfo.CurrentCulture = InteropUtils.GetInstance<System.Globalization.CultureInfo>(__value);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_CultureInfo_CurrentUICulture_Get")]
	internal static void* /* System.Globalization.CultureInfo */ System_Globalization_CultureInfo_CurrentUICulture_Get(void** /* System.Exception */ __outException)
	{
	
	    try {
			System.Globalization.CultureInfo __returnValue = System.Globalization.CultureInfo.CurrentUICulture;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_CultureInfo_CurrentUICulture_Set")]
	internal static void /* System.Void */ System_Globalization_CultureInfo_CurrentUICulture_Set(void* /* System.Globalization.CultureInfo */ __value, void** /* System.Exception */ __outException)
	{
	
	    try {
			System.Globalization.CultureInfo.CurrentUICulture = InteropUtils.GetInstance<System.Globalization.CultureInfo>(__value);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_CultureInfo_InstalledUICulture_Get")]
	internal static void* /* System.Globalization.CultureInfo */ System_Globalization_CultureInfo_InstalledUICulture_Get(void** /* System.Exception */ __outException)
	{
	
	    try {
			System.Globalization.CultureInfo __returnValue = System.Globalization.CultureInfo.InstalledUICulture;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_CultureInfo_DefaultThreadCurrentCulture_Get")]
	internal static void* /* System.Globalization.CultureInfo */ System_Globalization_CultureInfo_DefaultThreadCurrentCulture_Get(void** /* System.Exception */ __outException)
	{
	
	    try {
			System.Globalization.CultureInfo __returnValue = System.Globalization.CultureInfo.DefaultThreadCurrentCulture;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_CultureInfo_DefaultThreadCurrentCulture_Set")]
	internal static void /* System.Void */ System_Globalization_CultureInfo_DefaultThreadCurrentCulture_Set(void* /* System.Globalization.CultureInfo */ __value, void** /* System.Exception */ __outException)
	{
	
	    try {
			System.Globalization.CultureInfo.DefaultThreadCurrentCulture = InteropUtils.GetInstance<System.Globalization.CultureInfo>(__value);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_CultureInfo_DefaultThreadCurrentUICulture_Get")]
	internal static void* /* System.Globalization.CultureInfo */ System_Globalization_CultureInfo_DefaultThreadCurrentUICulture_Get(void** /* System.Exception */ __outException)
	{
	
	    try {
			System.Globalization.CultureInfo __returnValue = System.Globalization.CultureInfo.DefaultThreadCurrentUICulture;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_CultureInfo_DefaultThreadCurrentUICulture_Set")]
	internal static void /* System.Void */ System_Globalization_CultureInfo_DefaultThreadCurrentUICulture_Set(void* /* System.Globalization.CultureInfo */ __value, void** /* System.Exception */ __outException)
	{
	
	    try {
			System.Globalization.CultureInfo.DefaultThreadCurrentUICulture = InteropUtils.GetInstance<System.Globalization.CultureInfo>(__value);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_CultureInfo_InvariantCulture_Get")]
	internal static void* /* System.Globalization.CultureInfo */ System_Globalization_CultureInfo_InvariantCulture_Get(void** /* System.Exception */ __outException)
	{
	
	    try {
			System.Globalization.CultureInfo __returnValue = System.Globalization.CultureInfo.InvariantCulture;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_CultureInfo_Parent_Get")]
	internal static void* /* System.Globalization.CultureInfo */ System_Globalization_CultureInfo_Parent_Get(void* /* System.Globalization.CultureInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.CultureInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.CultureInfo>(__self);
	
	
	    try {
			System.Globalization.CultureInfo __returnValue = __selfConverted.Parent;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_CultureInfo_LCID_Get")]
	internal static int /* System.Int32 */ System_Globalization_CultureInfo_LCID_Get(void* /* System.Globalization.CultureInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.CultureInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.CultureInfo>(__self);
	
	
	    try {
			System.Int32 __returnValue = __selfConverted.LCID;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_CultureInfo_KeyboardLayoutId_Get")]
	internal static int /* System.Int32 */ System_Globalization_CultureInfo_KeyboardLayoutId_Get(void* /* System.Globalization.CultureInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.CultureInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.CultureInfo>(__self);
	
	
	    try {
			System.Int32 __returnValue = __selfConverted.KeyboardLayoutId;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_CultureInfo_Name_Get")]
	internal static void* /* System.String */ System_Globalization_CultureInfo_Name_Get(void* /* System.Globalization.CultureInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.CultureInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.CultureInfo>(__self);
	
	
	    try {
			System.String __returnValue = __selfConverted.Name;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_CultureInfo_IetfLanguageTag_Get")]
	internal static void* /* System.String */ System_Globalization_CultureInfo_IetfLanguageTag_Get(void* /* System.Globalization.CultureInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.CultureInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.CultureInfo>(__self);
	
	
	    try {
			System.String __returnValue = __selfConverted.IetfLanguageTag;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_CultureInfo_DisplayName_Get")]
	internal static void* /* System.String */ System_Globalization_CultureInfo_DisplayName_Get(void* /* System.Globalization.CultureInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.CultureInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.CultureInfo>(__self);
	
	
	    try {
			System.String __returnValue = __selfConverted.DisplayName;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_CultureInfo_NativeName_Get")]
	internal static void* /* System.String */ System_Globalization_CultureInfo_NativeName_Get(void* /* System.Globalization.CultureInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.CultureInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.CultureInfo>(__self);
	
	
	    try {
			System.String __returnValue = __selfConverted.NativeName;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_CultureInfo_EnglishName_Get")]
	internal static void* /* System.String */ System_Globalization_CultureInfo_EnglishName_Get(void* /* System.Globalization.CultureInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.CultureInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.CultureInfo>(__self);
	
	
	    try {
			System.String __returnValue = __selfConverted.EnglishName;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_CultureInfo_TwoLetterISOLanguageName_Get")]
	internal static void* /* System.String */ System_Globalization_CultureInfo_TwoLetterISOLanguageName_Get(void* /* System.Globalization.CultureInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.CultureInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.CultureInfo>(__self);
	
	
	    try {
			System.String __returnValue = __selfConverted.TwoLetterISOLanguageName;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_CultureInfo_ThreeLetterISOLanguageName_Get")]
	internal static void* /* System.String */ System_Globalization_CultureInfo_ThreeLetterISOLanguageName_Get(void* /* System.Globalization.CultureInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.CultureInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.CultureInfo>(__self);
	
	
	    try {
			System.String __returnValue = __selfConverted.ThreeLetterISOLanguageName;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_CultureInfo_ThreeLetterWindowsLanguageName_Get")]
	internal static void* /* System.String */ System_Globalization_CultureInfo_ThreeLetterWindowsLanguageName_Get(void* /* System.Globalization.CultureInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.CultureInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.CultureInfo>(__self);
	
	
	    try {
			System.String __returnValue = __selfConverted.ThreeLetterWindowsLanguageName;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_CultureInfo_CompareInfo_Get")]
	internal static void* /* System.Globalization.CompareInfo */ System_Globalization_CultureInfo_CompareInfo_Get(void* /* System.Globalization.CultureInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.CultureInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.CultureInfo>(__self);
	
	
	    try {
			System.Globalization.CompareInfo __returnValue = __selfConverted.CompareInfo;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_CultureInfo_TextInfo_Get")]
	internal static void* /* System.Globalization.TextInfo */ System_Globalization_CultureInfo_TextInfo_Get(void* /* System.Globalization.CultureInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.CultureInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.CultureInfo>(__self);
	
	
	    try {
			System.Globalization.TextInfo __returnValue = __selfConverted.TextInfo;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_CultureInfo_IsNeutralCulture_Get")]
	internal static byte /* System.Boolean */ System_Globalization_CultureInfo_IsNeutralCulture_Get(void* /* System.Globalization.CultureInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.CultureInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.CultureInfo>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.IsNeutralCulture;
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_CultureInfo_CultureTypes_Get")]
	internal static System.Globalization.CultureTypes /* System.Globalization.CultureTypes */ System_Globalization_CultureInfo_CultureTypes_Get(void* /* System.Globalization.CultureInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.CultureInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.CultureInfo>(__self);
	
	
	    try {
			System.Globalization.CultureTypes __returnValue = __selfConverted.CultureTypes;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return default(System.Globalization.CultureTypes);
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_CultureInfo_NumberFormat_Get")]
	internal static void* /* System.Globalization.NumberFormatInfo */ System_Globalization_CultureInfo_NumberFormat_Get(void* /* System.Globalization.CultureInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.CultureInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.CultureInfo>(__self);
	
	
	    try {
			System.Globalization.NumberFormatInfo __returnValue = __selfConverted.NumberFormat;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_CultureInfo_NumberFormat_Set")]
	internal static void /* System.Void */ System_Globalization_CultureInfo_NumberFormat_Set(void* /* System.Globalization.CultureInfo */ __self, void* /* System.Globalization.NumberFormatInfo */ __value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.CultureInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.CultureInfo>(__self);
	
	
	    try {
			__selfConverted.NumberFormat = InteropUtils.GetInstance<System.Globalization.NumberFormatInfo>(__value);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_CultureInfo_DateTimeFormat_Get")]
	internal static void* /* System.Globalization.DateTimeFormatInfo */ System_Globalization_CultureInfo_DateTimeFormat_Get(void* /* System.Globalization.CultureInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.CultureInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.CultureInfo>(__self);
	
	
	    try {
			System.Globalization.DateTimeFormatInfo __returnValue = __selfConverted.DateTimeFormat;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_CultureInfo_DateTimeFormat_Set")]
	internal static void /* System.Void */ System_Globalization_CultureInfo_DateTimeFormat_Set(void* /* System.Globalization.CultureInfo */ __self, void* /* System.Globalization.DateTimeFormatInfo */ __value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.CultureInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.CultureInfo>(__self);
	
	
	    try {
			__selfConverted.DateTimeFormat = InteropUtils.GetInstance<System.Globalization.DateTimeFormatInfo>(__value);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_CultureInfo_Calendar_Get")]
	internal static void* /* System.Globalization.Calendar */ System_Globalization_CultureInfo_Calendar_Get(void* /* System.Globalization.CultureInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.CultureInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.CultureInfo>(__self);
	
	
	    try {
			System.Globalization.Calendar __returnValue = __selfConverted.Calendar;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_CultureInfo_OptionalCalendars_Get")]
	internal static void* /* System.Globalization.Calendar[] */ System_Globalization_CultureInfo_OptionalCalendars_Get(void* /* System.Globalization.CultureInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.CultureInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.CultureInfo>(__self);
	
	
	    try {
			System.Globalization.Calendar[] __returnValue = __selfConverted.OptionalCalendars;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_CultureInfo_UseUserOverride_Get")]
	internal static byte /* System.Boolean */ System_Globalization_CultureInfo_UseUserOverride_Get(void* /* System.Globalization.CultureInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.CultureInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.CultureInfo>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.UseUserOverride;
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_CultureInfo_IsReadOnly_Get")]
	internal static byte /* System.Boolean */ System_Globalization_CultureInfo_IsReadOnly_Get(void* /* System.Globalization.CultureInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.CultureInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.CultureInfo>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.IsReadOnly;
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_CultureInfo_TypeOf")]
	internal static void* /* System.Type */ System_Globalization_CultureInfo_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.Globalization.CultureInfo);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_CultureInfo_Destroy")]
	internal static void /* System.Void */ System_Globalization_CultureInfo_Destroy(void* /* System.Globalization.CultureInfo */ __self)
	{
	
		InteropUtils.FreeIfAllocated(__self);
	}
	
}


internal unsafe class System_IFormatProvider
{
	[UnmanagedCallersOnly(EntryPoint = "System_IFormatProvider_GetFormat")]
	internal static void* /* System.Object */ System_IFormatProvider_GetFormat(void* /* System.IFormatProvider */ __self, void* /* System.Type */ formatType, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.IFormatProvider __selfConverted = InteropUtils.GetInstance<System.IFormatProvider>(__self);
	
		System.Type formatTypeConverted = InteropUtils.GetInstance<System.Type>(formatType);
	
	    try {
			System.Object __returnValue = __selfConverted.GetFormat(formatTypeConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_IFormatProvider_TypeOf")]
	internal static void* /* System.Type */ System_IFormatProvider_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.IFormatProvider);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_IFormatProvider_Destroy")]
	internal static void /* System.Void */ System_IFormatProvider_Destroy(void* /* System.IFormatProvider */ __self)
	{
	
		InteropUtils.FreeIfAllocated(__self);
	}
	
}



internal unsafe class System_Collections_IStructuralComparable
{
	[UnmanagedCallersOnly(EntryPoint = "System_Collections_IStructuralComparable_CompareTo")]
	internal static int /* System.Int32 */ System_Collections_IStructuralComparable_CompareTo(void* /* System.Collections.IStructuralComparable */ __self, void* /* System.Object */ other, void* /* System.Collections.IComparer */ comparer, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Collections.IStructuralComparable __selfConverted = InteropUtils.GetInstance<System.Collections.IStructuralComparable>(__self);
	
		System.Object otherConverted = InteropUtils.GetInstance<System.Object>(other);
		System.Collections.IComparer comparerConverted = InteropUtils.GetInstance<System.Collections.IComparer>(comparer);
	
	    try {
			System.Int32 __returnValue = __selfConverted.CompareTo(otherConverted, comparerConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Collections_IStructuralComparable_TypeOf")]
	internal static void* /* System.Type */ System_Collections_IStructuralComparable_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.Collections.IStructuralComparable);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Collections_IStructuralComparable_Destroy")]
	internal static void /* System.Void */ System_Collections_IStructuralComparable_Destroy(void* /* System.Collections.IStructuralComparable */ __self)
	{
	
		InteropUtils.FreeIfAllocated(__self);
	}
	
}


internal unsafe class System_Collections_IComparer
{
	[UnmanagedCallersOnly(EntryPoint = "System_Collections_IComparer_Compare")]
	internal static int /* System.Int32 */ System_Collections_IComparer_Compare(void* /* System.Collections.IComparer */ __self, void* /* System.Object */ x, void* /* System.Object */ y, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Collections.IComparer __selfConverted = InteropUtils.GetInstance<System.Collections.IComparer>(__self);
	
		System.Object xConverted = InteropUtils.GetInstance<System.Object>(x);
		System.Object yConverted = InteropUtils.GetInstance<System.Object>(y);
	
	    try {
			System.Int32 __returnValue = __selfConverted.Compare(xConverted, yConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Collections_IComparer_TypeOf")]
	internal static void* /* System.Type */ System_Collections_IComparer_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.Collections.IComparer);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Collections_IComparer_Destroy")]
	internal static void /* System.Void */ System_Collections_IComparer_Destroy(void* /* System.Collections.IComparer */ __self)
	{
	
		InteropUtils.FreeIfAllocated(__self);
	}
	
}


internal unsafe class System_Collections_IStructuralEquatable
{
	[UnmanagedCallersOnly(EntryPoint = "System_Collections_IStructuralEquatable_Equals")]
	internal static byte /* System.Boolean */ System_Collections_IStructuralEquatable_Equals(void* /* System.Collections.IStructuralEquatable */ __self, void* /* System.Object */ other, void* /* System.Collections.IEqualityComparer */ comparer, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Collections.IStructuralEquatable __selfConverted = InteropUtils.GetInstance<System.Collections.IStructuralEquatable>(__self);
	
		System.Object otherConverted = InteropUtils.GetInstance<System.Object>(other);
		System.Collections.IEqualityComparer comparerConverted = InteropUtils.GetInstance<System.Collections.IEqualityComparer>(comparer);
	
	    try {
			System.Boolean __returnValue = __selfConverted.Equals(otherConverted, comparerConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Collections_IStructuralEquatable_GetHashCode")]
	internal static int /* System.Int32 */ System_Collections_IStructuralEquatable_GetHashCode(void* /* System.Collections.IStructuralEquatable */ __self, void* /* System.Collections.IEqualityComparer */ comparer, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Collections.IStructuralEquatable __selfConverted = InteropUtils.GetInstance<System.Collections.IStructuralEquatable>(__self);
	
		System.Collections.IEqualityComparer comparerConverted = InteropUtils.GetInstance<System.Collections.IEqualityComparer>(comparer);
	
	    try {
			System.Int32 __returnValue = __selfConverted.GetHashCode(comparerConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Collections_IStructuralEquatable_TypeOf")]
	internal static void* /* System.Type */ System_Collections_IStructuralEquatable_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.Collections.IStructuralEquatable);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Collections_IStructuralEquatable_Destroy")]
	internal static void /* System.Void */ System_Collections_IStructuralEquatable_Destroy(void* /* System.Collections.IStructuralEquatable */ __self)
	{
	
		InteropUtils.FreeIfAllocated(__self);
	}
	
}


internal unsafe class System_Collections_IEqualityComparer
{
	[UnmanagedCallersOnly(EntryPoint = "System_Collections_IEqualityComparer_Equals")]
	internal static byte /* System.Boolean */ System_Collections_IEqualityComparer_Equals(void* /* System.Collections.IEqualityComparer */ __self, void* /* System.Object */ x, void* /* System.Object */ y, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Collections.IEqualityComparer __selfConverted = InteropUtils.GetInstance<System.Collections.IEqualityComparer>(__self);
	
		System.Object xConverted = InteropUtils.GetInstance<System.Object>(x);
		System.Object yConverted = InteropUtils.GetInstance<System.Object>(y);
	
	    try {
			System.Boolean __returnValue = __selfConverted.Equals(xConverted, yConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Collections_IEqualityComparer_GetHashCode")]
	internal static int /* System.Int32 */ System_Collections_IEqualityComparer_GetHashCode(void* /* System.Collections.IEqualityComparer */ __self, void* /* System.Object */ obj, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Collections.IEqualityComparer __selfConverted = InteropUtils.GetInstance<System.Collections.IEqualityComparer>(__self);
	
		System.Object objConverted = InteropUtils.GetInstance<System.Object>(obj);
	
	    try {
			System.Int32 __returnValue = __selfConverted.GetHashCode(objConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Collections_IEqualityComparer_TypeOf")]
	internal static void* /* System.Type */ System_Collections_IEqualityComparer_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.Collections.IEqualityComparer);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Collections_IEqualityComparer_Destroy")]
	internal static void /* System.Void */ System_Collections_IEqualityComparer_Destroy(void* /* System.Collections.IEqualityComparer */ __self)
	{
	
		InteropUtils.FreeIfAllocated(__self);
	}
	
}



internal unsafe class System_Globalization_CultureTypes
{
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_CultureTypes_TypeOf")]
	internal static void* /* System.Type */ System_Globalization_CultureTypes_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.Globalization.CultureTypes);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
}


internal unsafe class System_Globalization_CompareInfo
{
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_CompareInfo_GetCompareInfo")]
	internal static void* /* System.Globalization.CompareInfo */ System_Globalization_CompareInfo_GetCompareInfo(int /* System.Int32 */ culture, void* /* System.Reflection.Assembly */ assembly, void** /* System.Exception */ __outException)
	{
		System.Reflection.Assembly assemblyConverted = InteropUtils.GetInstance<System.Reflection.Assembly>(assembly);
	
	    try {
			System.Globalization.CompareInfo __returnValue = System.Globalization.CompareInfo.GetCompareInfo(culture, assemblyConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_CompareInfo_GetCompareInfo_1")]
	internal static void* /* System.Globalization.CompareInfo */ System_Globalization_CompareInfo_GetCompareInfo_1(void* /* System.String */ name, void* /* System.Reflection.Assembly */ assembly, void** /* System.Exception */ __outException)
	{
		System.String nameConverted = InteropUtils.GetInstance<System.String>(name);
		System.Reflection.Assembly assemblyConverted = InteropUtils.GetInstance<System.Reflection.Assembly>(assembly);
	
	    try {
			System.Globalization.CompareInfo __returnValue = System.Globalization.CompareInfo.GetCompareInfo(nameConverted, assemblyConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_CompareInfo_GetCompareInfo_2")]
	internal static void* /* System.Globalization.CompareInfo */ System_Globalization_CompareInfo_GetCompareInfo_2(int /* System.Int32 */ culture, void** /* System.Exception */ __outException)
	{
	
	    try {
			System.Globalization.CompareInfo __returnValue = System.Globalization.CompareInfo.GetCompareInfo(culture);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_CompareInfo_GetCompareInfo_3")]
	internal static void* /* System.Globalization.CompareInfo */ System_Globalization_CompareInfo_GetCompareInfo_3(void* /* System.String */ name, void** /* System.Exception */ __outException)
	{
		System.String nameConverted = InteropUtils.GetInstance<System.String>(name);
	
	    try {
			System.Globalization.CompareInfo __returnValue = System.Globalization.CompareInfo.GetCompareInfo(nameConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_CompareInfo_IsSortable")]
	internal static byte /* System.Boolean */ System_Globalization_CompareInfo_IsSortable(char /* System.Char */ ch, void** /* System.Exception */ __outException)
	{
	
	    try {
			System.Boolean __returnValue = System.Globalization.CompareInfo.IsSortable(ch);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_CompareInfo_IsSortable_1")]
	internal static byte /* System.Boolean */ System_Globalization_CompareInfo_IsSortable_1(void* /* System.String */ text, void** /* System.Exception */ __outException)
	{
		System.String textConverted = InteropUtils.GetInstance<System.String>(text);
	
	    try {
			System.Boolean __returnValue = System.Globalization.CompareInfo.IsSortable(textConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_CompareInfo_IsSortable_2")]
	internal static byte /* System.Boolean */ System_Globalization_CompareInfo_IsSortable_2(void* /* System.Text.Rune */ value, void** /* System.Exception */ __outException)
	{
		System.Text.Rune valueConverted = InteropUtils.GetInstance<System.Text.Rune>(value);
	
	    try {
			System.Boolean __returnValue = System.Globalization.CompareInfo.IsSortable(valueConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_CompareInfo_Compare")]
	internal static int /* System.Int32 */ System_Globalization_CompareInfo_Compare(void* /* System.Globalization.CompareInfo */ __self, void* /* System.String */ string1, void* /* System.String */ string2, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.CompareInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.CompareInfo>(__self);
	
		System.String string1Converted = InteropUtils.GetInstance<System.String>(string1);
		System.String string2Converted = InteropUtils.GetInstance<System.String>(string2);
	
	    try {
			System.Int32 __returnValue = __selfConverted.Compare(string1Converted, string2Converted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_CompareInfo_Compare_1")]
	internal static int /* System.Int32 */ System_Globalization_CompareInfo_Compare_1(void* /* System.Globalization.CompareInfo */ __self, void* /* System.String */ string1, void* /* System.String */ string2, System.Globalization.CompareOptions /* System.Globalization.CompareOptions */ options, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.CompareInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.CompareInfo>(__self);
	
		System.String string1Converted = InteropUtils.GetInstance<System.String>(string1);
		System.String string2Converted = InteropUtils.GetInstance<System.String>(string2);
	
	    try {
			System.Int32 __returnValue = __selfConverted.Compare(string1Converted, string2Converted, options);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_CompareInfo_Compare_2")]
	internal static int /* System.Int32 */ System_Globalization_CompareInfo_Compare_2(void* /* System.Globalization.CompareInfo */ __self, void* /* System.String */ string1, int /* System.Int32 */ offset1, int /* System.Int32 */ length1, void* /* System.String */ string2, int /* System.Int32 */ offset2, int /* System.Int32 */ length2, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.CompareInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.CompareInfo>(__self);
	
		System.String string1Converted = InteropUtils.GetInstance<System.String>(string1);
		System.String string2Converted = InteropUtils.GetInstance<System.String>(string2);
	
	    try {
			System.Int32 __returnValue = __selfConverted.Compare(string1Converted, offset1, length1, string2Converted, offset2, length2);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_CompareInfo_Compare_3")]
	internal static int /* System.Int32 */ System_Globalization_CompareInfo_Compare_3(void* /* System.Globalization.CompareInfo */ __self, void* /* System.String */ string1, int /* System.Int32 */ offset1, void* /* System.String */ string2, int /* System.Int32 */ offset2, System.Globalization.CompareOptions /* System.Globalization.CompareOptions */ options, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.CompareInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.CompareInfo>(__self);
	
		System.String string1Converted = InteropUtils.GetInstance<System.String>(string1);
		System.String string2Converted = InteropUtils.GetInstance<System.String>(string2);
	
	    try {
			System.Int32 __returnValue = __selfConverted.Compare(string1Converted, offset1, string2Converted, offset2, options);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_CompareInfo_Compare_4")]
	internal static int /* System.Int32 */ System_Globalization_CompareInfo_Compare_4(void* /* System.Globalization.CompareInfo */ __self, void* /* System.String */ string1, int /* System.Int32 */ offset1, void* /* System.String */ string2, int /* System.Int32 */ offset2, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.CompareInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.CompareInfo>(__self);
	
		System.String string1Converted = InteropUtils.GetInstance<System.String>(string1);
		System.String string2Converted = InteropUtils.GetInstance<System.String>(string2);
	
	    try {
			System.Int32 __returnValue = __selfConverted.Compare(string1Converted, offset1, string2Converted, offset2);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_CompareInfo_Compare_5")]
	internal static int /* System.Int32 */ System_Globalization_CompareInfo_Compare_5(void* /* System.Globalization.CompareInfo */ __self, void* /* System.String */ string1, int /* System.Int32 */ offset1, int /* System.Int32 */ length1, void* /* System.String */ string2, int /* System.Int32 */ offset2, int /* System.Int32 */ length2, System.Globalization.CompareOptions /* System.Globalization.CompareOptions */ options, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.CompareInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.CompareInfo>(__self);
	
		System.String string1Converted = InteropUtils.GetInstance<System.String>(string1);
		System.String string2Converted = InteropUtils.GetInstance<System.String>(string2);
	
	    try {
			System.Int32 __returnValue = __selfConverted.Compare(string1Converted, offset1, length1, string2Converted, offset2, length2, options);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_CompareInfo_IsPrefix")]
	internal static byte /* System.Boolean */ System_Globalization_CompareInfo_IsPrefix(void* /* System.Globalization.CompareInfo */ __self, void* /* System.String */ source, void* /* System.String */ prefix, System.Globalization.CompareOptions /* System.Globalization.CompareOptions */ options, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.CompareInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.CompareInfo>(__self);
	
		System.String sourceConverted = InteropUtils.GetInstance<System.String>(source);
		System.String prefixConverted = InteropUtils.GetInstance<System.String>(prefix);
	
	    try {
			System.Boolean __returnValue = __selfConverted.IsPrefix(sourceConverted, prefixConverted, options);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_CompareInfo_IsPrefix_1")]
	internal static byte /* System.Boolean */ System_Globalization_CompareInfo_IsPrefix_1(void* /* System.Globalization.CompareInfo */ __self, void* /* System.String */ source, void* /* System.String */ prefix, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.CompareInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.CompareInfo>(__self);
	
		System.String sourceConverted = InteropUtils.GetInstance<System.String>(source);
		System.String prefixConverted = InteropUtils.GetInstance<System.String>(prefix);
	
	    try {
			System.Boolean __returnValue = __selfConverted.IsPrefix(sourceConverted, prefixConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_CompareInfo_IsSuffix")]
	internal static byte /* System.Boolean */ System_Globalization_CompareInfo_IsSuffix(void* /* System.Globalization.CompareInfo */ __self, void* /* System.String */ source, void* /* System.String */ suffix, System.Globalization.CompareOptions /* System.Globalization.CompareOptions */ options, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.CompareInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.CompareInfo>(__self);
	
		System.String sourceConverted = InteropUtils.GetInstance<System.String>(source);
		System.String suffixConverted = InteropUtils.GetInstance<System.String>(suffix);
	
	    try {
			System.Boolean __returnValue = __selfConverted.IsSuffix(sourceConverted, suffixConverted, options);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_CompareInfo_IsSuffix_1")]
	internal static byte /* System.Boolean */ System_Globalization_CompareInfo_IsSuffix_1(void* /* System.Globalization.CompareInfo */ __self, void* /* System.String */ source, void* /* System.String */ suffix, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.CompareInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.CompareInfo>(__self);
	
		System.String sourceConverted = InteropUtils.GetInstance<System.String>(source);
		System.String suffixConverted = InteropUtils.GetInstance<System.String>(suffix);
	
	    try {
			System.Boolean __returnValue = __selfConverted.IsSuffix(sourceConverted, suffixConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_CompareInfo_IndexOf")]
	internal static int /* System.Int32 */ System_Globalization_CompareInfo_IndexOf(void* /* System.Globalization.CompareInfo */ __self, void* /* System.String */ source, char /* System.Char */ value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.CompareInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.CompareInfo>(__self);
	
		System.String sourceConverted = InteropUtils.GetInstance<System.String>(source);
	
	    try {
			System.Int32 __returnValue = __selfConverted.IndexOf(sourceConverted, value);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_CompareInfo_IndexOf_1")]
	internal static int /* System.Int32 */ System_Globalization_CompareInfo_IndexOf_1(void* /* System.Globalization.CompareInfo */ __self, void* /* System.String */ source, void* /* System.String */ value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.CompareInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.CompareInfo>(__self);
	
		System.String sourceConverted = InteropUtils.GetInstance<System.String>(source);
		System.String valueConverted = InteropUtils.GetInstance<System.String>(value);
	
	    try {
			System.Int32 __returnValue = __selfConverted.IndexOf(sourceConverted, valueConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_CompareInfo_IndexOf_2")]
	internal static int /* System.Int32 */ System_Globalization_CompareInfo_IndexOf_2(void* /* System.Globalization.CompareInfo */ __self, void* /* System.String */ source, char /* System.Char */ value, System.Globalization.CompareOptions /* System.Globalization.CompareOptions */ options, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.CompareInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.CompareInfo>(__self);
	
		System.String sourceConverted = InteropUtils.GetInstance<System.String>(source);
	
	    try {
			System.Int32 __returnValue = __selfConverted.IndexOf(sourceConverted, value, options);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_CompareInfo_IndexOf_3")]
	internal static int /* System.Int32 */ System_Globalization_CompareInfo_IndexOf_3(void* /* System.Globalization.CompareInfo */ __self, void* /* System.String */ source, void* /* System.String */ value, System.Globalization.CompareOptions /* System.Globalization.CompareOptions */ options, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.CompareInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.CompareInfo>(__self);
	
		System.String sourceConverted = InteropUtils.GetInstance<System.String>(source);
		System.String valueConverted = InteropUtils.GetInstance<System.String>(value);
	
	    try {
			System.Int32 __returnValue = __selfConverted.IndexOf(sourceConverted, valueConverted, options);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_CompareInfo_IndexOf_4")]
	internal static int /* System.Int32 */ System_Globalization_CompareInfo_IndexOf_4(void* /* System.Globalization.CompareInfo */ __self, void* /* System.String */ source, char /* System.Char */ value, int /* System.Int32 */ startIndex, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.CompareInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.CompareInfo>(__self);
	
		System.String sourceConverted = InteropUtils.GetInstance<System.String>(source);
	
	    try {
			System.Int32 __returnValue = __selfConverted.IndexOf(sourceConverted, value, startIndex);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_CompareInfo_IndexOf_5")]
	internal static int /* System.Int32 */ System_Globalization_CompareInfo_IndexOf_5(void* /* System.Globalization.CompareInfo */ __self, void* /* System.String */ source, void* /* System.String */ value, int /* System.Int32 */ startIndex, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.CompareInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.CompareInfo>(__self);
	
		System.String sourceConverted = InteropUtils.GetInstance<System.String>(source);
		System.String valueConverted = InteropUtils.GetInstance<System.String>(value);
	
	    try {
			System.Int32 __returnValue = __selfConverted.IndexOf(sourceConverted, valueConverted, startIndex);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_CompareInfo_IndexOf_6")]
	internal static int /* System.Int32 */ System_Globalization_CompareInfo_IndexOf_6(void* /* System.Globalization.CompareInfo */ __self, void* /* System.String */ source, char /* System.Char */ value, int /* System.Int32 */ startIndex, System.Globalization.CompareOptions /* System.Globalization.CompareOptions */ options, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.CompareInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.CompareInfo>(__self);
	
		System.String sourceConverted = InteropUtils.GetInstance<System.String>(source);
	
	    try {
			System.Int32 __returnValue = __selfConverted.IndexOf(sourceConverted, value, startIndex, options);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_CompareInfo_IndexOf_7")]
	internal static int /* System.Int32 */ System_Globalization_CompareInfo_IndexOf_7(void* /* System.Globalization.CompareInfo */ __self, void* /* System.String */ source, void* /* System.String */ value, int /* System.Int32 */ startIndex, System.Globalization.CompareOptions /* System.Globalization.CompareOptions */ options, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.CompareInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.CompareInfo>(__self);
	
		System.String sourceConverted = InteropUtils.GetInstance<System.String>(source);
		System.String valueConverted = InteropUtils.GetInstance<System.String>(value);
	
	    try {
			System.Int32 __returnValue = __selfConverted.IndexOf(sourceConverted, valueConverted, startIndex, options);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_CompareInfo_IndexOf_8")]
	internal static int /* System.Int32 */ System_Globalization_CompareInfo_IndexOf_8(void* /* System.Globalization.CompareInfo */ __self, void* /* System.String */ source, char /* System.Char */ value, int /* System.Int32 */ startIndex, int /* System.Int32 */ count, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.CompareInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.CompareInfo>(__self);
	
		System.String sourceConverted = InteropUtils.GetInstance<System.String>(source);
	
	    try {
			System.Int32 __returnValue = __selfConverted.IndexOf(sourceConverted, value, startIndex, count);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_CompareInfo_IndexOf_9")]
	internal static int /* System.Int32 */ System_Globalization_CompareInfo_IndexOf_9(void* /* System.Globalization.CompareInfo */ __self, void* /* System.String */ source, void* /* System.String */ value, int /* System.Int32 */ startIndex, int /* System.Int32 */ count, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.CompareInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.CompareInfo>(__self);
	
		System.String sourceConverted = InteropUtils.GetInstance<System.String>(source);
		System.String valueConverted = InteropUtils.GetInstance<System.String>(value);
	
	    try {
			System.Int32 __returnValue = __selfConverted.IndexOf(sourceConverted, valueConverted, startIndex, count);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_CompareInfo_IndexOf_10")]
	internal static int /* System.Int32 */ System_Globalization_CompareInfo_IndexOf_10(void* /* System.Globalization.CompareInfo */ __self, void* /* System.String */ source, char /* System.Char */ value, int /* System.Int32 */ startIndex, int /* System.Int32 */ count, System.Globalization.CompareOptions /* System.Globalization.CompareOptions */ options, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.CompareInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.CompareInfo>(__self);
	
		System.String sourceConverted = InteropUtils.GetInstance<System.String>(source);
	
	    try {
			System.Int32 __returnValue = __selfConverted.IndexOf(sourceConverted, value, startIndex, count, options);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_CompareInfo_IndexOf_11")]
	internal static int /* System.Int32 */ System_Globalization_CompareInfo_IndexOf_11(void* /* System.Globalization.CompareInfo */ __self, void* /* System.String */ source, void* /* System.String */ value, int /* System.Int32 */ startIndex, int /* System.Int32 */ count, System.Globalization.CompareOptions /* System.Globalization.CompareOptions */ options, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.CompareInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.CompareInfo>(__self);
	
		System.String sourceConverted = InteropUtils.GetInstance<System.String>(source);
		System.String valueConverted = InteropUtils.GetInstance<System.String>(value);
	
	    try {
			System.Int32 __returnValue = __selfConverted.IndexOf(sourceConverted, valueConverted, startIndex, count, options);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_CompareInfo_LastIndexOf")]
	internal static int /* System.Int32 */ System_Globalization_CompareInfo_LastIndexOf(void* /* System.Globalization.CompareInfo */ __self, void* /* System.String */ source, char /* System.Char */ value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.CompareInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.CompareInfo>(__self);
	
		System.String sourceConverted = InteropUtils.GetInstance<System.String>(source);
	
	    try {
			System.Int32 __returnValue = __selfConverted.LastIndexOf(sourceConverted, value);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_CompareInfo_LastIndexOf_1")]
	internal static int /* System.Int32 */ System_Globalization_CompareInfo_LastIndexOf_1(void* /* System.Globalization.CompareInfo */ __self, void* /* System.String */ source, void* /* System.String */ value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.CompareInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.CompareInfo>(__self);
	
		System.String sourceConverted = InteropUtils.GetInstance<System.String>(source);
		System.String valueConverted = InteropUtils.GetInstance<System.String>(value);
	
	    try {
			System.Int32 __returnValue = __selfConverted.LastIndexOf(sourceConverted, valueConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_CompareInfo_LastIndexOf_2")]
	internal static int /* System.Int32 */ System_Globalization_CompareInfo_LastIndexOf_2(void* /* System.Globalization.CompareInfo */ __self, void* /* System.String */ source, char /* System.Char */ value, System.Globalization.CompareOptions /* System.Globalization.CompareOptions */ options, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.CompareInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.CompareInfo>(__self);
	
		System.String sourceConverted = InteropUtils.GetInstance<System.String>(source);
	
	    try {
			System.Int32 __returnValue = __selfConverted.LastIndexOf(sourceConverted, value, options);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_CompareInfo_LastIndexOf_3")]
	internal static int /* System.Int32 */ System_Globalization_CompareInfo_LastIndexOf_3(void* /* System.Globalization.CompareInfo */ __self, void* /* System.String */ source, void* /* System.String */ value, System.Globalization.CompareOptions /* System.Globalization.CompareOptions */ options, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.CompareInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.CompareInfo>(__self);
	
		System.String sourceConverted = InteropUtils.GetInstance<System.String>(source);
		System.String valueConverted = InteropUtils.GetInstance<System.String>(value);
	
	    try {
			System.Int32 __returnValue = __selfConverted.LastIndexOf(sourceConverted, valueConverted, options);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_CompareInfo_LastIndexOf_4")]
	internal static int /* System.Int32 */ System_Globalization_CompareInfo_LastIndexOf_4(void* /* System.Globalization.CompareInfo */ __self, void* /* System.String */ source, char /* System.Char */ value, int /* System.Int32 */ startIndex, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.CompareInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.CompareInfo>(__self);
	
		System.String sourceConverted = InteropUtils.GetInstance<System.String>(source);
	
	    try {
			System.Int32 __returnValue = __selfConverted.LastIndexOf(sourceConverted, value, startIndex);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_CompareInfo_LastIndexOf_5")]
	internal static int /* System.Int32 */ System_Globalization_CompareInfo_LastIndexOf_5(void* /* System.Globalization.CompareInfo */ __self, void* /* System.String */ source, void* /* System.String */ value, int /* System.Int32 */ startIndex, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.CompareInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.CompareInfo>(__self);
	
		System.String sourceConverted = InteropUtils.GetInstance<System.String>(source);
		System.String valueConverted = InteropUtils.GetInstance<System.String>(value);
	
	    try {
			System.Int32 __returnValue = __selfConverted.LastIndexOf(sourceConverted, valueConverted, startIndex);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_CompareInfo_LastIndexOf_6")]
	internal static int /* System.Int32 */ System_Globalization_CompareInfo_LastIndexOf_6(void* /* System.Globalization.CompareInfo */ __self, void* /* System.String */ source, char /* System.Char */ value, int /* System.Int32 */ startIndex, System.Globalization.CompareOptions /* System.Globalization.CompareOptions */ options, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.CompareInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.CompareInfo>(__self);
	
		System.String sourceConverted = InteropUtils.GetInstance<System.String>(source);
	
	    try {
			System.Int32 __returnValue = __selfConverted.LastIndexOf(sourceConverted, value, startIndex, options);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_CompareInfo_LastIndexOf_7")]
	internal static int /* System.Int32 */ System_Globalization_CompareInfo_LastIndexOf_7(void* /* System.Globalization.CompareInfo */ __self, void* /* System.String */ source, void* /* System.String */ value, int /* System.Int32 */ startIndex, System.Globalization.CompareOptions /* System.Globalization.CompareOptions */ options, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.CompareInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.CompareInfo>(__self);
	
		System.String sourceConverted = InteropUtils.GetInstance<System.String>(source);
		System.String valueConverted = InteropUtils.GetInstance<System.String>(value);
	
	    try {
			System.Int32 __returnValue = __selfConverted.LastIndexOf(sourceConverted, valueConverted, startIndex, options);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_CompareInfo_LastIndexOf_8")]
	internal static int /* System.Int32 */ System_Globalization_CompareInfo_LastIndexOf_8(void* /* System.Globalization.CompareInfo */ __self, void* /* System.String */ source, char /* System.Char */ value, int /* System.Int32 */ startIndex, int /* System.Int32 */ count, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.CompareInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.CompareInfo>(__self);
	
		System.String sourceConverted = InteropUtils.GetInstance<System.String>(source);
	
	    try {
			System.Int32 __returnValue = __selfConverted.LastIndexOf(sourceConverted, value, startIndex, count);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_CompareInfo_LastIndexOf_9")]
	internal static int /* System.Int32 */ System_Globalization_CompareInfo_LastIndexOf_9(void* /* System.Globalization.CompareInfo */ __self, void* /* System.String */ source, void* /* System.String */ value, int /* System.Int32 */ startIndex, int /* System.Int32 */ count, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.CompareInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.CompareInfo>(__self);
	
		System.String sourceConverted = InteropUtils.GetInstance<System.String>(source);
		System.String valueConverted = InteropUtils.GetInstance<System.String>(value);
	
	    try {
			System.Int32 __returnValue = __selfConverted.LastIndexOf(sourceConverted, valueConverted, startIndex, count);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_CompareInfo_LastIndexOf_10")]
	internal static int /* System.Int32 */ System_Globalization_CompareInfo_LastIndexOf_10(void* /* System.Globalization.CompareInfo */ __self, void* /* System.String */ source, char /* System.Char */ value, int /* System.Int32 */ startIndex, int /* System.Int32 */ count, System.Globalization.CompareOptions /* System.Globalization.CompareOptions */ options, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.CompareInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.CompareInfo>(__self);
	
		System.String sourceConverted = InteropUtils.GetInstance<System.String>(source);
	
	    try {
			System.Int32 __returnValue = __selfConverted.LastIndexOf(sourceConverted, value, startIndex, count, options);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_CompareInfo_LastIndexOf_11")]
	internal static int /* System.Int32 */ System_Globalization_CompareInfo_LastIndexOf_11(void* /* System.Globalization.CompareInfo */ __self, void* /* System.String */ source, void* /* System.String */ value, int /* System.Int32 */ startIndex, int /* System.Int32 */ count, System.Globalization.CompareOptions /* System.Globalization.CompareOptions */ options, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.CompareInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.CompareInfo>(__self);
	
		System.String sourceConverted = InteropUtils.GetInstance<System.String>(source);
		System.String valueConverted = InteropUtils.GetInstance<System.String>(value);
	
	    try {
			System.Int32 __returnValue = __selfConverted.LastIndexOf(sourceConverted, valueConverted, startIndex, count, options);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_CompareInfo_GetSortKey")]
	internal static void* /* System.Globalization.SortKey */ System_Globalization_CompareInfo_GetSortKey(void* /* System.Globalization.CompareInfo */ __self, void* /* System.String */ source, System.Globalization.CompareOptions /* System.Globalization.CompareOptions */ options, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.CompareInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.CompareInfo>(__self);
	
		System.String sourceConverted = InteropUtils.GetInstance<System.String>(source);
	
	    try {
			System.Globalization.SortKey __returnValue = __selfConverted.GetSortKey(sourceConverted, options);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_CompareInfo_GetSortKey_1")]
	internal static void* /* System.Globalization.SortKey */ System_Globalization_CompareInfo_GetSortKey_1(void* /* System.Globalization.CompareInfo */ __self, void* /* System.String */ source, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.CompareInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.CompareInfo>(__self);
	
		System.String sourceConverted = InteropUtils.GetInstance<System.String>(source);
	
	    try {
			System.Globalization.SortKey __returnValue = __selfConverted.GetSortKey(sourceConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_CompareInfo_Equals")]
	internal static byte /* System.Boolean */ System_Globalization_CompareInfo_Equals(void* /* System.Globalization.CompareInfo */ __self, void* /* System.Object */ value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.CompareInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.CompareInfo>(__self);
	
		System.Object valueConverted = InteropUtils.GetInstance<System.Object>(value);
	
	    try {
			System.Boolean __returnValue = __selfConverted.Equals(valueConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_CompareInfo_GetHashCode")]
	internal static int /* System.Int32 */ System_Globalization_CompareInfo_GetHashCode(void* /* System.Globalization.CompareInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.CompareInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.CompareInfo>(__self);
	
	
	    try {
			System.Int32 __returnValue = __selfConverted.GetHashCode();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_CompareInfo_GetHashCode_1")]
	internal static int /* System.Int32 */ System_Globalization_CompareInfo_GetHashCode_1(void* /* System.Globalization.CompareInfo */ __self, void* /* System.String */ source, System.Globalization.CompareOptions /* System.Globalization.CompareOptions */ options, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.CompareInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.CompareInfo>(__self);
	
		System.String sourceConverted = InteropUtils.GetInstance<System.String>(source);
	
	    try {
			System.Int32 __returnValue = __selfConverted.GetHashCode(sourceConverted, options);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_CompareInfo_ToString")]
	internal static void* /* System.String */ System_Globalization_CompareInfo_ToString(void* /* System.Globalization.CompareInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.CompareInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.CompareInfo>(__self);
	
	
	    try {
			System.String __returnValue = __selfConverted.ToString();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_CompareInfo_Name_Get")]
	internal static void* /* System.String */ System_Globalization_CompareInfo_Name_Get(void* /* System.Globalization.CompareInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.CompareInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.CompareInfo>(__self);
	
	
	    try {
			System.String __returnValue = __selfConverted.Name;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_CompareInfo_Version_Get")]
	internal static void* /* System.Globalization.SortVersion */ System_Globalization_CompareInfo_Version_Get(void* /* System.Globalization.CompareInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.CompareInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.CompareInfo>(__self);
	
	
	    try {
			System.Globalization.SortVersion __returnValue = __selfConverted.Version;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_CompareInfo_LCID_Get")]
	internal static int /* System.Int32 */ System_Globalization_CompareInfo_LCID_Get(void* /* System.Globalization.CompareInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.CompareInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.CompareInfo>(__self);
	
	
	    try {
			System.Int32 __returnValue = __selfConverted.LCID;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_CompareInfo_TypeOf")]
	internal static void* /* System.Type */ System_Globalization_CompareInfo_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.Globalization.CompareInfo);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_CompareInfo_Destroy")]
	internal static void /* System.Void */ System_Globalization_CompareInfo_Destroy(void* /* System.Globalization.CompareInfo */ __self)
	{
	
		InteropUtils.FreeIfAllocated(__self);
	}
	
}


internal unsafe class System_Runtime_Serialization_IDeserializationCallback
{
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_Serialization_IDeserializationCallback_OnDeserialization")]
	internal static void /* System.Void */ System_Runtime_Serialization_IDeserializationCallback_OnDeserialization(void* /* System.Runtime.Serialization.IDeserializationCallback */ __self, void* /* System.Object */ sender, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Runtime.Serialization.IDeserializationCallback __selfConverted = InteropUtils.GetInstance<System.Runtime.Serialization.IDeserializationCallback>(__self);
	
		System.Object senderConverted = InteropUtils.GetInstance<System.Object>(sender);
	
	    try {
			__selfConverted.OnDeserialization(senderConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_Serialization_IDeserializationCallback_TypeOf")]
	internal static void* /* System.Type */ System_Runtime_Serialization_IDeserializationCallback_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.Runtime.Serialization.IDeserializationCallback);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_Serialization_IDeserializationCallback_Destroy")]
	internal static void /* System.Void */ System_Runtime_Serialization_IDeserializationCallback_Destroy(void* /* System.Runtime.Serialization.IDeserializationCallback */ __self)
	{
	
		InteropUtils.FreeIfAllocated(__self);
	}
	
}


internal unsafe class System_Reflection_Assembly
{
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_Assembly_Load")]
	internal static void* /* System.Reflection.Assembly */ System_Reflection_Assembly_Load(void* /* System.String */ assemblyString, void** /* System.Exception */ __outException)
	{
		System.String assemblyStringConverted = InteropUtils.GetInstance<System.String>(assemblyString);
	
	    try {
			System.Reflection.Assembly __returnValue = System.Reflection.Assembly.Load(assemblyStringConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_Assembly_LoadWithPartialName")]
	internal static void* /* System.Reflection.Assembly */ System_Reflection_Assembly_LoadWithPartialName(void* /* System.String */ partialName, void** /* System.Exception */ __outException)
	{
		System.String partialNameConverted = InteropUtils.GetInstance<System.String>(partialName);
	
	    try {
			System.Reflection.Assembly __returnValue = System.Reflection.Assembly.LoadWithPartialName(partialNameConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_Assembly_Load_1")]
	internal static void* /* System.Reflection.Assembly */ System_Reflection_Assembly_Load_1(void* /* System.Reflection.AssemblyName */ assemblyRef, void** /* System.Exception */ __outException)
	{
		System.Reflection.AssemblyName assemblyRefConverted = InteropUtils.GetInstance<System.Reflection.AssemblyName>(assemblyRef);
	
	    try {
			System.Reflection.Assembly __returnValue = System.Reflection.Assembly.Load(assemblyRefConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_Assembly_GetExecutingAssembly")]
	internal static void* /* System.Reflection.Assembly */ System_Reflection_Assembly_GetExecutingAssembly(void** /* System.Exception */ __outException)
	{
	
	    try {
			System.Reflection.Assembly __returnValue = System.Reflection.Assembly.GetExecutingAssembly();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_Assembly_GetCallingAssembly")]
	internal static void* /* System.Reflection.Assembly */ System_Reflection_Assembly_GetCallingAssembly(void** /* System.Exception */ __outException)
	{
	
	    try {
			System.Reflection.Assembly __returnValue = System.Reflection.Assembly.GetCallingAssembly();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_Assembly_GetTypes")]
	internal static void* /* System.Type[] */ System_Reflection_Assembly_GetTypes(void* /* System.Reflection.Assembly */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.Assembly __selfConverted = InteropUtils.GetInstance<System.Reflection.Assembly>(__self);
	
	
	    try {
			System.Type[] __returnValue = __selfConverted.GetTypes();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_Assembly_GetExportedTypes")]
	internal static void* /* System.Type[] */ System_Reflection_Assembly_GetExportedTypes(void* /* System.Reflection.Assembly */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.Assembly __selfConverted = InteropUtils.GetInstance<System.Reflection.Assembly>(__self);
	
	
	    try {
			System.Type[] __returnValue = __selfConverted.GetExportedTypes();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_Assembly_GetForwardedTypes")]
	internal static void* /* System.Type[] */ System_Reflection_Assembly_GetForwardedTypes(void* /* System.Reflection.Assembly */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.Assembly __selfConverted = InteropUtils.GetInstance<System.Reflection.Assembly>(__self);
	
	
	    try {
			System.Type[] __returnValue = __selfConverted.GetForwardedTypes();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_Assembly_GetManifestResourceInfo")]
	internal static void* /* System.Reflection.ManifestResourceInfo */ System_Reflection_Assembly_GetManifestResourceInfo(void* /* System.Reflection.Assembly */ __self, void* /* System.String */ resourceName, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.Assembly __selfConverted = InteropUtils.GetInstance<System.Reflection.Assembly>(__self);
	
		System.String resourceNameConverted = InteropUtils.GetInstance<System.String>(resourceName);
	
	    try {
			System.Reflection.ManifestResourceInfo __returnValue = __selfConverted.GetManifestResourceInfo(resourceNameConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_Assembly_GetManifestResourceNames")]
	internal static void* /* System.String[] */ System_Reflection_Assembly_GetManifestResourceNames(void* /* System.Reflection.Assembly */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.Assembly __selfConverted = InteropUtils.GetInstance<System.Reflection.Assembly>(__self);
	
	
	    try {
			System.String[] __returnValue = __selfConverted.GetManifestResourceNames();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_Assembly_GetManifestResourceStream")]
	internal static void* /* System.IO.Stream */ System_Reflection_Assembly_GetManifestResourceStream(void* /* System.Reflection.Assembly */ __self, void* /* System.String */ name, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.Assembly __selfConverted = InteropUtils.GetInstance<System.Reflection.Assembly>(__self);
	
		System.String nameConverted = InteropUtils.GetInstance<System.String>(name);
	
	    try {
			System.IO.Stream __returnValue = __selfConverted.GetManifestResourceStream(nameConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_Assembly_GetManifestResourceStream_1")]
	internal static void* /* System.IO.Stream */ System_Reflection_Assembly_GetManifestResourceStream_1(void* /* System.Reflection.Assembly */ __self, void* /* System.Type */ type, void* /* System.String */ name, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.Assembly __selfConverted = InteropUtils.GetInstance<System.Reflection.Assembly>(__self);
	
		System.Type typeConverted = InteropUtils.GetInstance<System.Type>(type);
		System.String nameConverted = InteropUtils.GetInstance<System.String>(name);
	
	    try {
			System.IO.Stream __returnValue = __selfConverted.GetManifestResourceStream(typeConverted, nameConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_Assembly_GetName")]
	internal static void* /* System.Reflection.AssemblyName */ System_Reflection_Assembly_GetName(void* /* System.Reflection.Assembly */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.Assembly __selfConverted = InteropUtils.GetInstance<System.Reflection.Assembly>(__self);
	
	
	    try {
			System.Reflection.AssemblyName __returnValue = __selfConverted.GetName();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_Assembly_GetName_1")]
	internal static void* /* System.Reflection.AssemblyName */ System_Reflection_Assembly_GetName_1(void* /* System.Reflection.Assembly */ __self, byte /* System.Boolean */ copiedName, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.Assembly __selfConverted = InteropUtils.GetInstance<System.Reflection.Assembly>(__self);
	
		System.Boolean copiedNameConverted = copiedName.ToBool();
	
	    try {
			System.Reflection.AssemblyName __returnValue = __selfConverted.GetName(copiedNameConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_Assembly_GetType_1")]
	internal static void* /* System.Type */ System_Reflection_Assembly_GetType_1(void* /* System.Reflection.Assembly */ __self, void* /* System.String */ name, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.Assembly __selfConverted = InteropUtils.GetInstance<System.Reflection.Assembly>(__self);
	
		System.String nameConverted = InteropUtils.GetInstance<System.String>(name);
	
	    try {
			System.Type __returnValue = __selfConverted.GetType(nameConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_Assembly_GetType_2")]
	internal static void* /* System.Type */ System_Reflection_Assembly_GetType_2(void* /* System.Reflection.Assembly */ __self, void* /* System.String */ name, byte /* System.Boolean */ throwOnError, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.Assembly __selfConverted = InteropUtils.GetInstance<System.Reflection.Assembly>(__self);
	
		System.String nameConverted = InteropUtils.GetInstance<System.String>(name);
		System.Boolean throwOnErrorConverted = throwOnError.ToBool();
	
	    try {
			System.Type __returnValue = __selfConverted.GetType(nameConverted, throwOnErrorConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_Assembly_GetType_3")]
	internal static void* /* System.Type */ System_Reflection_Assembly_GetType_3(void* /* System.Reflection.Assembly */ __self, void* /* System.String */ name, byte /* System.Boolean */ throwOnError, byte /* System.Boolean */ ignoreCase, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.Assembly __selfConverted = InteropUtils.GetInstance<System.Reflection.Assembly>(__self);
	
		System.String nameConverted = InteropUtils.GetInstance<System.String>(name);
		System.Boolean throwOnErrorConverted = throwOnError.ToBool();
		System.Boolean ignoreCaseConverted = ignoreCase.ToBool();
	
	    try {
			System.Type __returnValue = __selfConverted.GetType(nameConverted, throwOnErrorConverted, ignoreCaseConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_Assembly_IsDefined")]
	internal static byte /* System.Boolean */ System_Reflection_Assembly_IsDefined(void* /* System.Reflection.Assembly */ __self, void* /* System.Type */ attributeType, byte /* System.Boolean */ inherit, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.Assembly __selfConverted = InteropUtils.GetInstance<System.Reflection.Assembly>(__self);
	
		System.Type attributeTypeConverted = InteropUtils.GetInstance<System.Type>(attributeType);
		System.Boolean inheritConverted = inherit.ToBool();
	
	    try {
			System.Boolean __returnValue = __selfConverted.IsDefined(attributeTypeConverted, inheritConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_Assembly_GetCustomAttributes")]
	internal static void* /* System.Object[] */ System_Reflection_Assembly_GetCustomAttributes(void* /* System.Reflection.Assembly */ __self, byte /* System.Boolean */ inherit, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.Assembly __selfConverted = InteropUtils.GetInstance<System.Reflection.Assembly>(__self);
	
		System.Boolean inheritConverted = inherit.ToBool();
	
	    try {
			System.Object[] __returnValue = __selfConverted.GetCustomAttributes(inheritConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_Assembly_GetCustomAttributes_1")]
	internal static void* /* System.Object[] */ System_Reflection_Assembly_GetCustomAttributes_1(void* /* System.Reflection.Assembly */ __self, void* /* System.Type */ attributeType, byte /* System.Boolean */ inherit, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.Assembly __selfConverted = InteropUtils.GetInstance<System.Reflection.Assembly>(__self);
	
		System.Type attributeTypeConverted = InteropUtils.GetInstance<System.Type>(attributeType);
		System.Boolean inheritConverted = inherit.ToBool();
	
	    try {
			System.Object[] __returnValue = __selfConverted.GetCustomAttributes(attributeTypeConverted, inheritConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_Assembly_CreateInstance")]
	internal static void* /* System.Object */ System_Reflection_Assembly_CreateInstance(void* /* System.Reflection.Assembly */ __self, void* /* System.String */ typeName, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.Assembly __selfConverted = InteropUtils.GetInstance<System.Reflection.Assembly>(__self);
	
		System.String typeNameConverted = InteropUtils.GetInstance<System.String>(typeName);
	
	    try {
			System.Object __returnValue = __selfConverted.CreateInstance(typeNameConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_Assembly_CreateInstance_1")]
	internal static void* /* System.Object */ System_Reflection_Assembly_CreateInstance_1(void* /* System.Reflection.Assembly */ __self, void* /* System.String */ typeName, byte /* System.Boolean */ ignoreCase, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.Assembly __selfConverted = InteropUtils.GetInstance<System.Reflection.Assembly>(__self);
	
		System.String typeNameConverted = InteropUtils.GetInstance<System.String>(typeName);
		System.Boolean ignoreCaseConverted = ignoreCase.ToBool();
	
	    try {
			System.Object __returnValue = __selfConverted.CreateInstance(typeNameConverted, ignoreCaseConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_Assembly_CreateInstance_2")]
	internal static void* /* System.Object */ System_Reflection_Assembly_CreateInstance_2(void* /* System.Reflection.Assembly */ __self, void* /* System.String */ typeName, byte /* System.Boolean */ ignoreCase, System.Reflection.BindingFlags /* System.Reflection.BindingFlags */ bindingAttr, void* /* System.Reflection.Binder */ binder, void* /* System.Object[] */ args, void* /* System.Globalization.CultureInfo */ culture, void* /* System.Object[] */ activationAttributes, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.Assembly __selfConverted = InteropUtils.GetInstance<System.Reflection.Assembly>(__self);
	
		System.String typeNameConverted = InteropUtils.GetInstance<System.String>(typeName);
		System.Boolean ignoreCaseConverted = ignoreCase.ToBool();
		System.Reflection.Binder binderConverted = InteropUtils.GetInstance<System.Reflection.Binder>(binder);
		System.Object[] argsConverted = InteropUtils.GetInstance<System.Object[]>(args);
		System.Globalization.CultureInfo cultureConverted = InteropUtils.GetInstance<System.Globalization.CultureInfo>(culture);
		System.Object[] activationAttributesConverted = InteropUtils.GetInstance<System.Object[]>(activationAttributes);
	
	    try {
			System.Object __returnValue = __selfConverted.CreateInstance(typeNameConverted, ignoreCaseConverted, bindingAttr, binderConverted, argsConverted, cultureConverted, activationAttributesConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_Assembly_GetModule")]
	internal static void* /* System.Reflection.Module */ System_Reflection_Assembly_GetModule(void* /* System.Reflection.Assembly */ __self, void* /* System.String */ name, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.Assembly __selfConverted = InteropUtils.GetInstance<System.Reflection.Assembly>(__self);
	
		System.String nameConverted = InteropUtils.GetInstance<System.String>(name);
	
	    try {
			System.Reflection.Module __returnValue = __selfConverted.GetModule(nameConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_Assembly_GetModules")]
	internal static void* /* System.Reflection.Module[] */ System_Reflection_Assembly_GetModules(void* /* System.Reflection.Assembly */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.Assembly __selfConverted = InteropUtils.GetInstance<System.Reflection.Assembly>(__self);
	
	
	    try {
			System.Reflection.Module[] __returnValue = __selfConverted.GetModules();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_Assembly_GetModules_1")]
	internal static void* /* System.Reflection.Module[] */ System_Reflection_Assembly_GetModules_1(void* /* System.Reflection.Assembly */ __self, byte /* System.Boolean */ getResourceModules, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.Assembly __selfConverted = InteropUtils.GetInstance<System.Reflection.Assembly>(__self);
	
		System.Boolean getResourceModulesConverted = getResourceModules.ToBool();
	
	    try {
			System.Reflection.Module[] __returnValue = __selfConverted.GetModules(getResourceModulesConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_Assembly_GetLoadedModules")]
	internal static void* /* System.Reflection.Module[] */ System_Reflection_Assembly_GetLoadedModules(void* /* System.Reflection.Assembly */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.Assembly __selfConverted = InteropUtils.GetInstance<System.Reflection.Assembly>(__self);
	
	
	    try {
			System.Reflection.Module[] __returnValue = __selfConverted.GetLoadedModules();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_Assembly_GetLoadedModules_1")]
	internal static void* /* System.Reflection.Module[] */ System_Reflection_Assembly_GetLoadedModules_1(void* /* System.Reflection.Assembly */ __self, byte /* System.Boolean */ getResourceModules, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.Assembly __selfConverted = InteropUtils.GetInstance<System.Reflection.Assembly>(__self);
	
		System.Boolean getResourceModulesConverted = getResourceModules.ToBool();
	
	    try {
			System.Reflection.Module[] __returnValue = __selfConverted.GetLoadedModules(getResourceModulesConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_Assembly_GetReferencedAssemblies")]
	internal static void* /* System.Reflection.AssemblyName[] */ System_Reflection_Assembly_GetReferencedAssemblies(void* /* System.Reflection.Assembly */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.Assembly __selfConverted = InteropUtils.GetInstance<System.Reflection.Assembly>(__self);
	
	
	    try {
			System.Reflection.AssemblyName[] __returnValue = __selfConverted.GetReferencedAssemblies();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_Assembly_GetSatelliteAssembly")]
	internal static void* /* System.Reflection.Assembly */ System_Reflection_Assembly_GetSatelliteAssembly(void* /* System.Reflection.Assembly */ __self, void* /* System.Globalization.CultureInfo */ culture, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.Assembly __selfConverted = InteropUtils.GetInstance<System.Reflection.Assembly>(__self);
	
		System.Globalization.CultureInfo cultureConverted = InteropUtils.GetInstance<System.Globalization.CultureInfo>(culture);
	
	    try {
			System.Reflection.Assembly __returnValue = __selfConverted.GetSatelliteAssembly(cultureConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_Assembly_GetSatelliteAssembly_1")]
	internal static void* /* System.Reflection.Assembly */ System_Reflection_Assembly_GetSatelliteAssembly_1(void* /* System.Reflection.Assembly */ __self, void* /* System.Globalization.CultureInfo */ culture, void* /* System.Version */ version, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.Assembly __selfConverted = InteropUtils.GetInstance<System.Reflection.Assembly>(__self);
	
		System.Globalization.CultureInfo cultureConverted = InteropUtils.GetInstance<System.Globalization.CultureInfo>(culture);
		System.Version versionConverted = InteropUtils.GetInstance<System.Version>(version);
	
	    try {
			System.Reflection.Assembly __returnValue = __selfConverted.GetSatelliteAssembly(cultureConverted, versionConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_Assembly_GetFile")]
	internal static void* /* System.IO.FileStream */ System_Reflection_Assembly_GetFile(void* /* System.Reflection.Assembly */ __self, void* /* System.String */ name, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.Assembly __selfConverted = InteropUtils.GetInstance<System.Reflection.Assembly>(__self);
	
		System.String nameConverted = InteropUtils.GetInstance<System.String>(name);
	
	    try {
			System.IO.FileStream __returnValue = __selfConverted.GetFile(nameConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_Assembly_GetFiles")]
	internal static void* /* System.IO.FileStream[] */ System_Reflection_Assembly_GetFiles(void* /* System.Reflection.Assembly */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.Assembly __selfConverted = InteropUtils.GetInstance<System.Reflection.Assembly>(__self);
	
	
	    try {
			System.IO.FileStream[] __returnValue = __selfConverted.GetFiles();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_Assembly_GetFiles_1")]
	internal static void* /* System.IO.FileStream[] */ System_Reflection_Assembly_GetFiles_1(void* /* System.Reflection.Assembly */ __self, byte /* System.Boolean */ getResourceModules, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.Assembly __selfConverted = InteropUtils.GetInstance<System.Reflection.Assembly>(__self);
	
		System.Boolean getResourceModulesConverted = getResourceModules.ToBool();
	
	    try {
			System.IO.FileStream[] __returnValue = __selfConverted.GetFiles(getResourceModulesConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_Assembly_GetObjectData")]
	internal static void /* System.Void */ System_Reflection_Assembly_GetObjectData(void* /* System.Reflection.Assembly */ __self, void* /* System.Runtime.Serialization.SerializationInfo */ info, void* /* System.Runtime.Serialization.StreamingContext */ context, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.Assembly __selfConverted = InteropUtils.GetInstance<System.Reflection.Assembly>(__self);
	
		System.Runtime.Serialization.SerializationInfo infoConverted = InteropUtils.GetInstance<System.Runtime.Serialization.SerializationInfo>(info);
		System.Runtime.Serialization.StreamingContext contextConverted = InteropUtils.GetInstance<System.Runtime.Serialization.StreamingContext>(context);
	
	    try {
			__selfConverted.GetObjectData(infoConverted, contextConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_Assembly_ToString")]
	internal static void* /* System.String */ System_Reflection_Assembly_ToString(void* /* System.Reflection.Assembly */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.Assembly __selfConverted = InteropUtils.GetInstance<System.Reflection.Assembly>(__self);
	
	
	    try {
			System.String __returnValue = __selfConverted.ToString();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_Assembly_Equals")]
	internal static byte /* System.Boolean */ System_Reflection_Assembly_Equals(void* /* System.Reflection.Assembly */ __self, void* /* System.Object */ o, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.Assembly __selfConverted = InteropUtils.GetInstance<System.Reflection.Assembly>(__self);
	
		System.Object oConverted = InteropUtils.GetInstance<System.Object>(o);
	
	    try {
			System.Boolean __returnValue = __selfConverted.Equals(oConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_Assembly_GetHashCode")]
	internal static int /* System.Int32 */ System_Reflection_Assembly_GetHashCode(void* /* System.Reflection.Assembly */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.Assembly __selfConverted = InteropUtils.GetInstance<System.Reflection.Assembly>(__self);
	
	
	    try {
			System.Int32 __returnValue = __selfConverted.GetHashCode();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_Assembly_CreateQualifiedName")]
	internal static void* /* System.String */ System_Reflection_Assembly_CreateQualifiedName(void* /* System.String */ assemblyName, void* /* System.String */ typeName, void** /* System.Exception */ __outException)
	{
		System.String assemblyNameConverted = InteropUtils.GetInstance<System.String>(assemblyName);
		System.String typeNameConverted = InteropUtils.GetInstance<System.String>(typeName);
	
	    try {
			System.String __returnValue = System.Reflection.Assembly.CreateQualifiedName(assemblyNameConverted, typeNameConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_Assembly_GetAssembly")]
	internal static void* /* System.Reflection.Assembly */ System_Reflection_Assembly_GetAssembly(void* /* System.Type */ type, void** /* System.Exception */ __outException)
	{
		System.Type typeConverted = InteropUtils.GetInstance<System.Type>(type);
	
	    try {
			System.Reflection.Assembly __returnValue = System.Reflection.Assembly.GetAssembly(typeConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_Assembly_GetEntryAssembly")]
	internal static void* /* System.Reflection.Assembly */ System_Reflection_Assembly_GetEntryAssembly(void** /* System.Exception */ __outException)
	{
	
	    try {
			System.Reflection.Assembly __returnValue = System.Reflection.Assembly.GetEntryAssembly();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_Assembly_Load_2")]
	internal static void* /* System.Reflection.Assembly */ System_Reflection_Assembly_Load_2(void* /* System.Byte[] */ rawAssembly, void** /* System.Exception */ __outException)
	{
		System.Byte[] rawAssemblyConverted = InteropUtils.GetInstance<System.Byte[]>(rawAssembly);
	
	    try {
			System.Reflection.Assembly __returnValue = System.Reflection.Assembly.Load(rawAssemblyConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_Assembly_Load_3")]
	internal static void* /* System.Reflection.Assembly */ System_Reflection_Assembly_Load_3(void* /* System.Byte[] */ rawAssembly, void* /* System.Byte[] */ rawSymbolStore, void** /* System.Exception */ __outException)
	{
		System.Byte[] rawAssemblyConverted = InteropUtils.GetInstance<System.Byte[]>(rawAssembly);
		System.Byte[] rawSymbolStoreConverted = InteropUtils.GetInstance<System.Byte[]>(rawSymbolStore);
	
	    try {
			System.Reflection.Assembly __returnValue = System.Reflection.Assembly.Load(rawAssemblyConverted, rawSymbolStoreConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_Assembly_LoadFile")]
	internal static void* /* System.Reflection.Assembly */ System_Reflection_Assembly_LoadFile(void* /* System.String */ path, void** /* System.Exception */ __outException)
	{
		System.String pathConverted = InteropUtils.GetInstance<System.String>(path);
	
	    try {
			System.Reflection.Assembly __returnValue = System.Reflection.Assembly.LoadFile(pathConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_Assembly_LoadFrom")]
	internal static void* /* System.Reflection.Assembly */ System_Reflection_Assembly_LoadFrom(void* /* System.String */ assemblyFile, void** /* System.Exception */ __outException)
	{
		System.String assemblyFileConverted = InteropUtils.GetInstance<System.String>(assemblyFile);
	
	    try {
			System.Reflection.Assembly __returnValue = System.Reflection.Assembly.LoadFrom(assemblyFileConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_Assembly_LoadFrom_1")]
	internal static void* /* System.Reflection.Assembly */ System_Reflection_Assembly_LoadFrom_1(void* /* System.String */ assemblyFile, void* /* System.Byte[] */ hashValue, System.Configuration.Assemblies.AssemblyHashAlgorithm /* System.Configuration.Assemblies.AssemblyHashAlgorithm */ hashAlgorithm, void** /* System.Exception */ __outException)
	{
		System.String assemblyFileConverted = InteropUtils.GetInstance<System.String>(assemblyFile);
		System.Byte[] hashValueConverted = InteropUtils.GetInstance<System.Byte[]>(hashValue);
	
	    try {
			System.Reflection.Assembly __returnValue = System.Reflection.Assembly.LoadFrom(assemblyFileConverted, hashValueConverted, hashAlgorithm);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_Assembly_UnsafeLoadFrom")]
	internal static void* /* System.Reflection.Assembly */ System_Reflection_Assembly_UnsafeLoadFrom(void* /* System.String */ assemblyFile, void** /* System.Exception */ __outException)
	{
		System.String assemblyFileConverted = InteropUtils.GetInstance<System.String>(assemblyFile);
	
	    try {
			System.Reflection.Assembly __returnValue = System.Reflection.Assembly.UnsafeLoadFrom(assemblyFileConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_Assembly_LoadModule")]
	internal static void* /* System.Reflection.Module */ System_Reflection_Assembly_LoadModule(void* /* System.Reflection.Assembly */ __self, void* /* System.String */ moduleName, void* /* System.Byte[] */ rawModule, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.Assembly __selfConverted = InteropUtils.GetInstance<System.Reflection.Assembly>(__self);
	
		System.String moduleNameConverted = InteropUtils.GetInstance<System.String>(moduleName);
		System.Byte[] rawModuleConverted = InteropUtils.GetInstance<System.Byte[]>(rawModule);
	
	    try {
			System.Reflection.Module __returnValue = __selfConverted.LoadModule(moduleNameConverted, rawModuleConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_Assembly_LoadModule_1")]
	internal static void* /* System.Reflection.Module */ System_Reflection_Assembly_LoadModule_1(void* /* System.Reflection.Assembly */ __self, void* /* System.String */ moduleName, void* /* System.Byte[] */ rawModule, void* /* System.Byte[] */ rawSymbolStore, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.Assembly __selfConverted = InteropUtils.GetInstance<System.Reflection.Assembly>(__self);
	
		System.String moduleNameConverted = InteropUtils.GetInstance<System.String>(moduleName);
		System.Byte[] rawModuleConverted = InteropUtils.GetInstance<System.Byte[]>(rawModule);
		System.Byte[] rawSymbolStoreConverted = InteropUtils.GetInstance<System.Byte[]>(rawSymbolStore);
	
	    try {
			System.Reflection.Module __returnValue = __selfConverted.LoadModule(moduleNameConverted, rawModuleConverted, rawSymbolStoreConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_Assembly_ReflectionOnlyLoad")]
	internal static void* /* System.Reflection.Assembly */ System_Reflection_Assembly_ReflectionOnlyLoad(void* /* System.Byte[] */ rawAssembly, void** /* System.Exception */ __outException)
	{
		System.Byte[] rawAssemblyConverted = InteropUtils.GetInstance<System.Byte[]>(rawAssembly);
	
	    try {
			System.Reflection.Assembly __returnValue = System.Reflection.Assembly.ReflectionOnlyLoad(rawAssemblyConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_Assembly_ReflectionOnlyLoad_1")]
	internal static void* /* System.Reflection.Assembly */ System_Reflection_Assembly_ReflectionOnlyLoad_1(void* /* System.String */ assemblyString, void** /* System.Exception */ __outException)
	{
		System.String assemblyStringConverted = InteropUtils.GetInstance<System.String>(assemblyString);
	
	    try {
			System.Reflection.Assembly __returnValue = System.Reflection.Assembly.ReflectionOnlyLoad(assemblyStringConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_Assembly_ReflectionOnlyLoadFrom")]
	internal static void* /* System.Reflection.Assembly */ System_Reflection_Assembly_ReflectionOnlyLoadFrom(void* /* System.String */ assemblyFile, void** /* System.Exception */ __outException)
	{
		System.String assemblyFileConverted = InteropUtils.GetInstance<System.String>(assemblyFile);
	
	    try {
			System.Reflection.Assembly __returnValue = System.Reflection.Assembly.ReflectionOnlyLoadFrom(assemblyFileConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_Assembly_CodeBase_Get")]
	internal static void* /* System.String */ System_Reflection_Assembly_CodeBase_Get(void* /* System.Reflection.Assembly */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.Assembly __selfConverted = InteropUtils.GetInstance<System.Reflection.Assembly>(__self);
	
	
	    try {
			System.String __returnValue = __selfConverted.CodeBase;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_Assembly_EntryPoint_Get")]
	internal static void* /* System.Reflection.MethodInfo */ System_Reflection_Assembly_EntryPoint_Get(void* /* System.Reflection.Assembly */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.Assembly __selfConverted = InteropUtils.GetInstance<System.Reflection.Assembly>(__self);
	
	
	    try {
			System.Reflection.MethodInfo __returnValue = __selfConverted.EntryPoint;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_Assembly_FullName_Get")]
	internal static void* /* System.String */ System_Reflection_Assembly_FullName_Get(void* /* System.Reflection.Assembly */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.Assembly __selfConverted = InteropUtils.GetInstance<System.Reflection.Assembly>(__self);
	
	
	    try {
			System.String __returnValue = __selfConverted.FullName;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_Assembly_ImageRuntimeVersion_Get")]
	internal static void* /* System.String */ System_Reflection_Assembly_ImageRuntimeVersion_Get(void* /* System.Reflection.Assembly */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.Assembly __selfConverted = InteropUtils.GetInstance<System.Reflection.Assembly>(__self);
	
	
	    try {
			System.String __returnValue = __selfConverted.ImageRuntimeVersion;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_Assembly_IsDynamic_Get")]
	internal static byte /* System.Boolean */ System_Reflection_Assembly_IsDynamic_Get(void* /* System.Reflection.Assembly */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.Assembly __selfConverted = InteropUtils.GetInstance<System.Reflection.Assembly>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.IsDynamic;
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_Assembly_Location_Get")]
	internal static void* /* System.String */ System_Reflection_Assembly_Location_Get(void* /* System.Reflection.Assembly */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.Assembly __selfConverted = InteropUtils.GetInstance<System.Reflection.Assembly>(__self);
	
	
	    try {
			System.String __returnValue = __selfConverted.Location;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_Assembly_ReflectionOnly_Get")]
	internal static byte /* System.Boolean */ System_Reflection_Assembly_ReflectionOnly_Get(void* /* System.Reflection.Assembly */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.Assembly __selfConverted = InteropUtils.GetInstance<System.Reflection.Assembly>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.ReflectionOnly;
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_Assembly_IsCollectible_Get")]
	internal static byte /* System.Boolean */ System_Reflection_Assembly_IsCollectible_Get(void* /* System.Reflection.Assembly */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.Assembly __selfConverted = InteropUtils.GetInstance<System.Reflection.Assembly>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.IsCollectible;
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_Assembly_IsFullyTrusted_Get")]
	internal static byte /* System.Boolean */ System_Reflection_Assembly_IsFullyTrusted_Get(void* /* System.Reflection.Assembly */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.Assembly __selfConverted = InteropUtils.GetInstance<System.Reflection.Assembly>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.IsFullyTrusted;
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_Assembly_EscapedCodeBase_Get")]
	internal static void* /* System.String */ System_Reflection_Assembly_EscapedCodeBase_Get(void* /* System.Reflection.Assembly */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.Assembly __selfConverted = InteropUtils.GetInstance<System.Reflection.Assembly>(__self);
	
	
	    try {
			System.String __returnValue = __selfConverted.EscapedCodeBase;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_Assembly_ManifestModule_Get")]
	internal static void* /* System.Reflection.Module */ System_Reflection_Assembly_ManifestModule_Get(void* /* System.Reflection.Assembly */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.Assembly __selfConverted = InteropUtils.GetInstance<System.Reflection.Assembly>(__self);
	
	
	    try {
			System.Reflection.Module __returnValue = __selfConverted.ManifestModule;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_Assembly_GlobalAssemblyCache_Get")]
	internal static byte /* System.Boolean */ System_Reflection_Assembly_GlobalAssemblyCache_Get(void* /* System.Reflection.Assembly */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.Assembly __selfConverted = InteropUtils.GetInstance<System.Reflection.Assembly>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.GlobalAssemblyCache;
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_Assembly_HostContext_Get")]
	internal static long /* System.Int64 */ System_Reflection_Assembly_HostContext_Get(void* /* System.Reflection.Assembly */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.Assembly __selfConverted = InteropUtils.GetInstance<System.Reflection.Assembly>(__self);
	
	
	    try {
			System.Int64 __returnValue = __selfConverted.HostContext;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_Assembly_SecurityRuleSet_Get")]
	internal static System.Security.SecurityRuleSet /* System.Security.SecurityRuleSet */ System_Reflection_Assembly_SecurityRuleSet_Get(void* /* System.Reflection.Assembly */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.Assembly __selfConverted = InteropUtils.GetInstance<System.Reflection.Assembly>(__self);
	
	
	    try {
			System.Security.SecurityRuleSet __returnValue = __selfConverted.SecurityRuleSet;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return default(System.Security.SecurityRuleSet);
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_Assembly_ModuleResolve_Add")]
	internal static void /* System.Void */ System_Reflection_Assembly_ModuleResolve_Add(void* /* System.Reflection.Assembly */ __self, void* /* System.Reflection.ModuleResolveEventHandler */ __value)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.Assembly __selfConverted = InteropUtils.GetInstance<System.Reflection.Assembly>(__self);
	
	
		__selfConverted.ModuleResolve += InteropUtils.GetInstance<System_Reflection_ModuleResolveEventHandler>(__value)?.Trampoline;
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_Assembly_ModuleResolve_Remove")]
	internal static void /* System.Void */ System_Reflection_Assembly_ModuleResolve_Remove(void* /* System.Reflection.Assembly */ __self, void* /* System.Reflection.ModuleResolveEventHandler */ __value)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.Assembly __selfConverted = InteropUtils.GetInstance<System.Reflection.Assembly>(__self);
	
	
		__selfConverted.ModuleResolve -= InteropUtils.GetInstance<System_Reflection_ModuleResolveEventHandler>(__value)?.Trampoline;
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_Assembly_TypeOf")]
	internal static void* /* System.Type */ System_Reflection_Assembly_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.Reflection.Assembly);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_Assembly_Destroy")]
	internal static void /* System.Void */ System_Reflection_Assembly_Destroy(void* /* System.Reflection.Assembly */ __self)
	{
	
		InteropUtils.FreeIfAllocated(__self);
	}
	
}


internal unsafe class System_Runtime_Serialization_ISerializable
{
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_Serialization_ISerializable_GetObjectData")]
	internal static void /* System.Void */ System_Runtime_Serialization_ISerializable_GetObjectData(void* /* System.Runtime.Serialization.ISerializable */ __self, void* /* System.Runtime.Serialization.SerializationInfo */ info, void* /* System.Runtime.Serialization.StreamingContext */ context, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Runtime.Serialization.ISerializable __selfConverted = InteropUtils.GetInstance<System.Runtime.Serialization.ISerializable>(__self);
	
		System.Runtime.Serialization.SerializationInfo infoConverted = InteropUtils.GetInstance<System.Runtime.Serialization.SerializationInfo>(info);
		System.Runtime.Serialization.StreamingContext contextConverted = InteropUtils.GetInstance<System.Runtime.Serialization.StreamingContext>(context);
	
	    try {
			__selfConverted.GetObjectData(infoConverted, contextConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_Serialization_ISerializable_TypeOf")]
	internal static void* /* System.Type */ System_Runtime_Serialization_ISerializable_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.Runtime.Serialization.ISerializable);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_Serialization_ISerializable_Destroy")]
	internal static void /* System.Void */ System_Runtime_Serialization_ISerializable_Destroy(void* /* System.Runtime.Serialization.ISerializable */ __self)
	{
	
		InteropUtils.FreeIfAllocated(__self);
	}
	
}


internal unsafe class System_Runtime_Serialization_SerializationInfo
{
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_Serialization_SerializationInfo_SetType")]
	internal static void /* System.Void */ System_Runtime_Serialization_SerializationInfo_SetType(void* /* System.Runtime.Serialization.SerializationInfo */ __self, void* /* System.Type */ type, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Runtime.Serialization.SerializationInfo __selfConverted = InteropUtils.GetInstance<System.Runtime.Serialization.SerializationInfo>(__self);
	
		System.Type typeConverted = InteropUtils.GetInstance<System.Type>(type);
	
	    try {
			__selfConverted.SetType(typeConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_Serialization_SerializationInfo_GetEnumerator")]
	internal static void* /* System.Runtime.Serialization.SerializationInfoEnumerator */ System_Runtime_Serialization_SerializationInfo_GetEnumerator(void* /* System.Runtime.Serialization.SerializationInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Runtime.Serialization.SerializationInfo __selfConverted = InteropUtils.GetInstance<System.Runtime.Serialization.SerializationInfo>(__self);
	
	
	    try {
			System.Runtime.Serialization.SerializationInfoEnumerator __returnValue = __selfConverted.GetEnumerator();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_Serialization_SerializationInfo_AddValue")]
	internal static void /* System.Void */ System_Runtime_Serialization_SerializationInfo_AddValue(void* /* System.Runtime.Serialization.SerializationInfo */ __self, void* /* System.String */ name, void* /* System.Object */ value, void* /* System.Type */ type, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Runtime.Serialization.SerializationInfo __selfConverted = InteropUtils.GetInstance<System.Runtime.Serialization.SerializationInfo>(__self);
	
		System.String nameConverted = InteropUtils.GetInstance<System.String>(name);
		System.Object valueConverted = InteropUtils.GetInstance<System.Object>(value);
		System.Type typeConverted = InteropUtils.GetInstance<System.Type>(type);
	
	    try {
			__selfConverted.AddValue(nameConverted, valueConverted, typeConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_Serialization_SerializationInfo_AddValue_1")]
	internal static void /* System.Void */ System_Runtime_Serialization_SerializationInfo_AddValue_1(void* /* System.Runtime.Serialization.SerializationInfo */ __self, void* /* System.String */ name, void* /* System.Object */ value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Runtime.Serialization.SerializationInfo __selfConverted = InteropUtils.GetInstance<System.Runtime.Serialization.SerializationInfo>(__self);
	
		System.String nameConverted = InteropUtils.GetInstance<System.String>(name);
		System.Object valueConverted = InteropUtils.GetInstance<System.Object>(value);
	
	    try {
			__selfConverted.AddValue(nameConverted, valueConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_Serialization_SerializationInfo_AddValue_2")]
	internal static void /* System.Void */ System_Runtime_Serialization_SerializationInfo_AddValue_2(void* /* System.Runtime.Serialization.SerializationInfo */ __self, void* /* System.String */ name, byte /* System.Boolean */ value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Runtime.Serialization.SerializationInfo __selfConverted = InteropUtils.GetInstance<System.Runtime.Serialization.SerializationInfo>(__self);
	
		System.String nameConverted = InteropUtils.GetInstance<System.String>(name);
		System.Boolean valueConverted = value.ToBool();
	
	    try {
			__selfConverted.AddValue(nameConverted, valueConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_Serialization_SerializationInfo_AddValue_3")]
	internal static void /* System.Void */ System_Runtime_Serialization_SerializationInfo_AddValue_3(void* /* System.Runtime.Serialization.SerializationInfo */ __self, void* /* System.String */ name, char /* System.Char */ value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Runtime.Serialization.SerializationInfo __selfConverted = InteropUtils.GetInstance<System.Runtime.Serialization.SerializationInfo>(__self);
	
		System.String nameConverted = InteropUtils.GetInstance<System.String>(name);
	
	    try {
			__selfConverted.AddValue(nameConverted, value);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_Serialization_SerializationInfo_AddValue_4")]
	internal static void /* System.Void */ System_Runtime_Serialization_SerializationInfo_AddValue_4(void* /* System.Runtime.Serialization.SerializationInfo */ __self, void* /* System.String */ name, sbyte /* System.SByte */ value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Runtime.Serialization.SerializationInfo __selfConverted = InteropUtils.GetInstance<System.Runtime.Serialization.SerializationInfo>(__self);
	
		System.String nameConverted = InteropUtils.GetInstance<System.String>(name);
	
	    try {
			__selfConverted.AddValue(nameConverted, value);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_Serialization_SerializationInfo_AddValue_5")]
	internal static void /* System.Void */ System_Runtime_Serialization_SerializationInfo_AddValue_5(void* /* System.Runtime.Serialization.SerializationInfo */ __self, void* /* System.String */ name, byte /* System.Byte */ value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Runtime.Serialization.SerializationInfo __selfConverted = InteropUtils.GetInstance<System.Runtime.Serialization.SerializationInfo>(__self);
	
		System.String nameConverted = InteropUtils.GetInstance<System.String>(name);
	
	    try {
			__selfConverted.AddValue(nameConverted, value);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_Serialization_SerializationInfo_AddValue_6")]
	internal static void /* System.Void */ System_Runtime_Serialization_SerializationInfo_AddValue_6(void* /* System.Runtime.Serialization.SerializationInfo */ __self, void* /* System.String */ name, short /* System.Int16 */ value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Runtime.Serialization.SerializationInfo __selfConverted = InteropUtils.GetInstance<System.Runtime.Serialization.SerializationInfo>(__self);
	
		System.String nameConverted = InteropUtils.GetInstance<System.String>(name);
	
	    try {
			__selfConverted.AddValue(nameConverted, value);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_Serialization_SerializationInfo_AddValue_7")]
	internal static void /* System.Void */ System_Runtime_Serialization_SerializationInfo_AddValue_7(void* /* System.Runtime.Serialization.SerializationInfo */ __self, void* /* System.String */ name, ushort /* System.UInt16 */ value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Runtime.Serialization.SerializationInfo __selfConverted = InteropUtils.GetInstance<System.Runtime.Serialization.SerializationInfo>(__self);
	
		System.String nameConverted = InteropUtils.GetInstance<System.String>(name);
	
	    try {
			__selfConverted.AddValue(nameConverted, value);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_Serialization_SerializationInfo_AddValue_8")]
	internal static void /* System.Void */ System_Runtime_Serialization_SerializationInfo_AddValue_8(void* /* System.Runtime.Serialization.SerializationInfo */ __self, void* /* System.String */ name, int /* System.Int32 */ value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Runtime.Serialization.SerializationInfo __selfConverted = InteropUtils.GetInstance<System.Runtime.Serialization.SerializationInfo>(__self);
	
		System.String nameConverted = InteropUtils.GetInstance<System.String>(name);
	
	    try {
			__selfConverted.AddValue(nameConverted, value);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_Serialization_SerializationInfo_AddValue_9")]
	internal static void /* System.Void */ System_Runtime_Serialization_SerializationInfo_AddValue_9(void* /* System.Runtime.Serialization.SerializationInfo */ __self, void* /* System.String */ name, uint /* System.UInt32 */ value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Runtime.Serialization.SerializationInfo __selfConverted = InteropUtils.GetInstance<System.Runtime.Serialization.SerializationInfo>(__self);
	
		System.String nameConverted = InteropUtils.GetInstance<System.String>(name);
	
	    try {
			__selfConverted.AddValue(nameConverted, value);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_Serialization_SerializationInfo_AddValue_10")]
	internal static void /* System.Void */ System_Runtime_Serialization_SerializationInfo_AddValue_10(void* /* System.Runtime.Serialization.SerializationInfo */ __self, void* /* System.String */ name, long /* System.Int64 */ value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Runtime.Serialization.SerializationInfo __selfConverted = InteropUtils.GetInstance<System.Runtime.Serialization.SerializationInfo>(__self);
	
		System.String nameConverted = InteropUtils.GetInstance<System.String>(name);
	
	    try {
			__selfConverted.AddValue(nameConverted, value);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_Serialization_SerializationInfo_AddValue_11")]
	internal static void /* System.Void */ System_Runtime_Serialization_SerializationInfo_AddValue_11(void* /* System.Runtime.Serialization.SerializationInfo */ __self, void* /* System.String */ name, ulong /* System.UInt64 */ value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Runtime.Serialization.SerializationInfo __selfConverted = InteropUtils.GetInstance<System.Runtime.Serialization.SerializationInfo>(__self);
	
		System.String nameConverted = InteropUtils.GetInstance<System.String>(name);
	
	    try {
			__selfConverted.AddValue(nameConverted, value);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_Serialization_SerializationInfo_AddValue_12")]
	internal static void /* System.Void */ System_Runtime_Serialization_SerializationInfo_AddValue_12(void* /* System.Runtime.Serialization.SerializationInfo */ __self, void* /* System.String */ name, float /* System.Single */ value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Runtime.Serialization.SerializationInfo __selfConverted = InteropUtils.GetInstance<System.Runtime.Serialization.SerializationInfo>(__self);
	
		System.String nameConverted = InteropUtils.GetInstance<System.String>(name);
	
	    try {
			__selfConverted.AddValue(nameConverted, value);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_Serialization_SerializationInfo_AddValue_13")]
	internal static void /* System.Void */ System_Runtime_Serialization_SerializationInfo_AddValue_13(void* /* System.Runtime.Serialization.SerializationInfo */ __self, void* /* System.String */ name, double /* System.Double */ value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Runtime.Serialization.SerializationInfo __selfConverted = InteropUtils.GetInstance<System.Runtime.Serialization.SerializationInfo>(__self);
	
		System.String nameConverted = InteropUtils.GetInstance<System.String>(name);
	
	    try {
			__selfConverted.AddValue(nameConverted, value);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_Serialization_SerializationInfo_AddValue_14")]
	internal static void /* System.Void */ System_Runtime_Serialization_SerializationInfo_AddValue_14(void* /* System.Runtime.Serialization.SerializationInfo */ __self, void* /* System.String */ name, void* /* System.Decimal */ value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Runtime.Serialization.SerializationInfo __selfConverted = InteropUtils.GetInstance<System.Runtime.Serialization.SerializationInfo>(__self);
	
		System.String nameConverted = InteropUtils.GetInstance<System.String>(name);
		System.Decimal valueConverted = InteropUtils.GetInstance<System.Decimal>(value);
	
	    try {
			__selfConverted.AddValue(nameConverted, valueConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_Serialization_SerializationInfo_AddValue_15")]
	internal static void /* System.Void */ System_Runtime_Serialization_SerializationInfo_AddValue_15(void* /* System.Runtime.Serialization.SerializationInfo */ __self, void* /* System.String */ name, void* /* System.DateTime */ value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Runtime.Serialization.SerializationInfo __selfConverted = InteropUtils.GetInstance<System.Runtime.Serialization.SerializationInfo>(__self);
	
		System.String nameConverted = InteropUtils.GetInstance<System.String>(name);
		System.DateTime valueConverted = InteropUtils.GetInstance<System.DateTime>(value);
	
	    try {
			__selfConverted.AddValue(nameConverted, valueConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_Serialization_SerializationInfo_GetValue")]
	internal static void* /* System.Object */ System_Runtime_Serialization_SerializationInfo_GetValue(void* /* System.Runtime.Serialization.SerializationInfo */ __self, void* /* System.String */ name, void* /* System.Type */ type, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Runtime.Serialization.SerializationInfo __selfConverted = InteropUtils.GetInstance<System.Runtime.Serialization.SerializationInfo>(__self);
	
		System.String nameConverted = InteropUtils.GetInstance<System.String>(name);
		System.Type typeConverted = InteropUtils.GetInstance<System.Type>(type);
	
	    try {
			System.Object __returnValue = __selfConverted.GetValue(nameConverted, typeConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_Serialization_SerializationInfo_GetBoolean")]
	internal static byte /* System.Boolean */ System_Runtime_Serialization_SerializationInfo_GetBoolean(void* /* System.Runtime.Serialization.SerializationInfo */ __self, void* /* System.String */ name, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Runtime.Serialization.SerializationInfo __selfConverted = InteropUtils.GetInstance<System.Runtime.Serialization.SerializationInfo>(__self);
	
		System.String nameConverted = InteropUtils.GetInstance<System.String>(name);
	
	    try {
			System.Boolean __returnValue = __selfConverted.GetBoolean(nameConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_Serialization_SerializationInfo_GetChar")]
	internal static char /* System.Char */ System_Runtime_Serialization_SerializationInfo_GetChar(void* /* System.Runtime.Serialization.SerializationInfo */ __self, void* /* System.String */ name, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Runtime.Serialization.SerializationInfo __selfConverted = InteropUtils.GetInstance<System.Runtime.Serialization.SerializationInfo>(__self);
	
		System.String nameConverted = InteropUtils.GetInstance<System.String>(name);
	
	    try {
			System.Char __returnValue = __selfConverted.GetChar(nameConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return (char)0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_Serialization_SerializationInfo_GetSByte")]
	internal static sbyte /* System.SByte */ System_Runtime_Serialization_SerializationInfo_GetSByte(void* /* System.Runtime.Serialization.SerializationInfo */ __self, void* /* System.String */ name, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Runtime.Serialization.SerializationInfo __selfConverted = InteropUtils.GetInstance<System.Runtime.Serialization.SerializationInfo>(__self);
	
		System.String nameConverted = InteropUtils.GetInstance<System.String>(name);
	
	    try {
			System.SByte __returnValue = __selfConverted.GetSByte(nameConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_Serialization_SerializationInfo_GetByte")]
	internal static byte /* System.Byte */ System_Runtime_Serialization_SerializationInfo_GetByte(void* /* System.Runtime.Serialization.SerializationInfo */ __self, void* /* System.String */ name, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Runtime.Serialization.SerializationInfo __selfConverted = InteropUtils.GetInstance<System.Runtime.Serialization.SerializationInfo>(__self);
	
		System.String nameConverted = InteropUtils.GetInstance<System.String>(name);
	
	    try {
			System.Byte __returnValue = __selfConverted.GetByte(nameConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_Serialization_SerializationInfo_GetInt16")]
	internal static short /* System.Int16 */ System_Runtime_Serialization_SerializationInfo_GetInt16(void* /* System.Runtime.Serialization.SerializationInfo */ __self, void* /* System.String */ name, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Runtime.Serialization.SerializationInfo __selfConverted = InteropUtils.GetInstance<System.Runtime.Serialization.SerializationInfo>(__self);
	
		System.String nameConverted = InteropUtils.GetInstance<System.String>(name);
	
	    try {
			System.Int16 __returnValue = __selfConverted.GetInt16(nameConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_Serialization_SerializationInfo_GetUInt16")]
	internal static ushort /* System.UInt16 */ System_Runtime_Serialization_SerializationInfo_GetUInt16(void* /* System.Runtime.Serialization.SerializationInfo */ __self, void* /* System.String */ name, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Runtime.Serialization.SerializationInfo __selfConverted = InteropUtils.GetInstance<System.Runtime.Serialization.SerializationInfo>(__self);
	
		System.String nameConverted = InteropUtils.GetInstance<System.String>(name);
	
	    try {
			System.UInt16 __returnValue = __selfConverted.GetUInt16(nameConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_Serialization_SerializationInfo_GetInt32")]
	internal static int /* System.Int32 */ System_Runtime_Serialization_SerializationInfo_GetInt32(void* /* System.Runtime.Serialization.SerializationInfo */ __self, void* /* System.String */ name, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Runtime.Serialization.SerializationInfo __selfConverted = InteropUtils.GetInstance<System.Runtime.Serialization.SerializationInfo>(__self);
	
		System.String nameConverted = InteropUtils.GetInstance<System.String>(name);
	
	    try {
			System.Int32 __returnValue = __selfConverted.GetInt32(nameConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_Serialization_SerializationInfo_GetUInt32")]
	internal static uint /* System.UInt32 */ System_Runtime_Serialization_SerializationInfo_GetUInt32(void* /* System.Runtime.Serialization.SerializationInfo */ __self, void* /* System.String */ name, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Runtime.Serialization.SerializationInfo __selfConverted = InteropUtils.GetInstance<System.Runtime.Serialization.SerializationInfo>(__self);
	
		System.String nameConverted = InteropUtils.GetInstance<System.String>(name);
	
	    try {
			System.UInt32 __returnValue = __selfConverted.GetUInt32(nameConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_Serialization_SerializationInfo_GetInt64")]
	internal static long /* System.Int64 */ System_Runtime_Serialization_SerializationInfo_GetInt64(void* /* System.Runtime.Serialization.SerializationInfo */ __self, void* /* System.String */ name, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Runtime.Serialization.SerializationInfo __selfConverted = InteropUtils.GetInstance<System.Runtime.Serialization.SerializationInfo>(__self);
	
		System.String nameConverted = InteropUtils.GetInstance<System.String>(name);
	
	    try {
			System.Int64 __returnValue = __selfConverted.GetInt64(nameConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_Serialization_SerializationInfo_GetUInt64")]
	internal static ulong /* System.UInt64 */ System_Runtime_Serialization_SerializationInfo_GetUInt64(void* /* System.Runtime.Serialization.SerializationInfo */ __self, void* /* System.String */ name, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Runtime.Serialization.SerializationInfo __selfConverted = InteropUtils.GetInstance<System.Runtime.Serialization.SerializationInfo>(__self);
	
		System.String nameConverted = InteropUtils.GetInstance<System.String>(name);
	
	    try {
			System.UInt64 __returnValue = __selfConverted.GetUInt64(nameConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_Serialization_SerializationInfo_GetSingle")]
	internal static float /* System.Single */ System_Runtime_Serialization_SerializationInfo_GetSingle(void* /* System.Runtime.Serialization.SerializationInfo */ __self, void* /* System.String */ name, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Runtime.Serialization.SerializationInfo __selfConverted = InteropUtils.GetInstance<System.Runtime.Serialization.SerializationInfo>(__self);
	
		System.String nameConverted = InteropUtils.GetInstance<System.String>(name);
	
	    try {
			System.Single __returnValue = __selfConverted.GetSingle(nameConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_Serialization_SerializationInfo_GetDouble")]
	internal static double /* System.Double */ System_Runtime_Serialization_SerializationInfo_GetDouble(void* /* System.Runtime.Serialization.SerializationInfo */ __self, void* /* System.String */ name, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Runtime.Serialization.SerializationInfo __selfConverted = InteropUtils.GetInstance<System.Runtime.Serialization.SerializationInfo>(__self);
	
		System.String nameConverted = InteropUtils.GetInstance<System.String>(name);
	
	    try {
			System.Double __returnValue = __selfConverted.GetDouble(nameConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_Serialization_SerializationInfo_GetDecimal")]
	internal static void* /* System.Decimal */ System_Runtime_Serialization_SerializationInfo_GetDecimal(void* /* System.Runtime.Serialization.SerializationInfo */ __self, void* /* System.String */ name, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Runtime.Serialization.SerializationInfo __selfConverted = InteropUtils.GetInstance<System.Runtime.Serialization.SerializationInfo>(__self);
	
		System.String nameConverted = InteropUtils.GetInstance<System.String>(name);
	
	    try {
			System.Decimal __returnValue = __selfConverted.GetDecimal(nameConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_Serialization_SerializationInfo_GetDateTime")]
	internal static void* /* System.DateTime */ System_Runtime_Serialization_SerializationInfo_GetDateTime(void* /* System.Runtime.Serialization.SerializationInfo */ __self, void* /* System.String */ name, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Runtime.Serialization.SerializationInfo __selfConverted = InteropUtils.GetInstance<System.Runtime.Serialization.SerializationInfo>(__self);
	
		System.String nameConverted = InteropUtils.GetInstance<System.String>(name);
	
	    try {
			System.DateTime __returnValue = __selfConverted.GetDateTime(nameConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_Serialization_SerializationInfo_GetString")]
	internal static void* /* System.String */ System_Runtime_Serialization_SerializationInfo_GetString(void* /* System.Runtime.Serialization.SerializationInfo */ __self, void* /* System.String */ name, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Runtime.Serialization.SerializationInfo __selfConverted = InteropUtils.GetInstance<System.Runtime.Serialization.SerializationInfo>(__self);
	
		System.String nameConverted = InteropUtils.GetInstance<System.String>(name);
	
	    try {
			System.String __returnValue = __selfConverted.GetString(nameConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_Serialization_SerializationInfo_Create")]
	internal static void* /* System.Runtime.Serialization.SerializationInfo */ System_Runtime_Serialization_SerializationInfo_Create(void* /* System.Type */ type, void* /* System.Runtime.Serialization.IFormatterConverter */ converter, void** /* System.Exception */ __outException)
	{
		System.Type typeConverted = InteropUtils.GetInstance<System.Type>(type);
		System.Runtime.Serialization.IFormatterConverter converterConverted = InteropUtils.GetInstance<System.Runtime.Serialization.IFormatterConverter>(converter);
	
	    try {
			System.Runtime.Serialization.SerializationInfo __returnValue = new System.Runtime.Serialization.SerializationInfo(typeConverted, converterConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_Serialization_SerializationInfo_Create_1")]
	internal static void* /* System.Runtime.Serialization.SerializationInfo */ System_Runtime_Serialization_SerializationInfo_Create_1(void* /* System.Type */ type, void* /* System.Runtime.Serialization.IFormatterConverter */ converter, byte /* System.Boolean */ requireSameTokenInPartialTrust, void** /* System.Exception */ __outException)
	{
		System.Type typeConverted = InteropUtils.GetInstance<System.Type>(type);
		System.Runtime.Serialization.IFormatterConverter converterConverted = InteropUtils.GetInstance<System.Runtime.Serialization.IFormatterConverter>(converter);
		System.Boolean requireSameTokenInPartialTrustConverted = requireSameTokenInPartialTrust.ToBool();
	
	    try {
			System.Runtime.Serialization.SerializationInfo __returnValue = new System.Runtime.Serialization.SerializationInfo(typeConverted, converterConverted, requireSameTokenInPartialTrustConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_Serialization_SerializationInfo_FullTypeName_Get")]
	internal static void* /* System.String */ System_Runtime_Serialization_SerializationInfo_FullTypeName_Get(void* /* System.Runtime.Serialization.SerializationInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Runtime.Serialization.SerializationInfo __selfConverted = InteropUtils.GetInstance<System.Runtime.Serialization.SerializationInfo>(__self);
	
	
	    try {
			System.String __returnValue = __selfConverted.FullTypeName;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_Serialization_SerializationInfo_FullTypeName_Set")]
	internal static void /* System.Void */ System_Runtime_Serialization_SerializationInfo_FullTypeName_Set(void* /* System.Runtime.Serialization.SerializationInfo */ __self, void* /* System.String */ __value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Runtime.Serialization.SerializationInfo __selfConverted = InteropUtils.GetInstance<System.Runtime.Serialization.SerializationInfo>(__self);
	
	
	    try {
			__selfConverted.FullTypeName = InteropUtils.GetInstance<System.String>(__value);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_Serialization_SerializationInfo_AssemblyName_Get")]
	internal static void* /* System.String */ System_Runtime_Serialization_SerializationInfo_AssemblyName_Get(void* /* System.Runtime.Serialization.SerializationInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Runtime.Serialization.SerializationInfo __selfConverted = InteropUtils.GetInstance<System.Runtime.Serialization.SerializationInfo>(__self);
	
	
	    try {
			System.String __returnValue = __selfConverted.AssemblyName;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_Serialization_SerializationInfo_AssemblyName_Set")]
	internal static void /* System.Void */ System_Runtime_Serialization_SerializationInfo_AssemblyName_Set(void* /* System.Runtime.Serialization.SerializationInfo */ __self, void* /* System.String */ __value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Runtime.Serialization.SerializationInfo __selfConverted = InteropUtils.GetInstance<System.Runtime.Serialization.SerializationInfo>(__self);
	
	
	    try {
			__selfConverted.AssemblyName = InteropUtils.GetInstance<System.String>(__value);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_Serialization_SerializationInfo_IsFullTypeNameSetExplicit_Get")]
	internal static byte /* System.Boolean */ System_Runtime_Serialization_SerializationInfo_IsFullTypeNameSetExplicit_Get(void* /* System.Runtime.Serialization.SerializationInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Runtime.Serialization.SerializationInfo __selfConverted = InteropUtils.GetInstance<System.Runtime.Serialization.SerializationInfo>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.IsFullTypeNameSetExplicit;
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_Serialization_SerializationInfo_IsAssemblyNameSetExplicit_Get")]
	internal static byte /* System.Boolean */ System_Runtime_Serialization_SerializationInfo_IsAssemblyNameSetExplicit_Get(void* /* System.Runtime.Serialization.SerializationInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Runtime.Serialization.SerializationInfo __selfConverted = InteropUtils.GetInstance<System.Runtime.Serialization.SerializationInfo>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.IsAssemblyNameSetExplicit;
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_Serialization_SerializationInfo_MemberCount_Get")]
	internal static int /* System.Int32 */ System_Runtime_Serialization_SerializationInfo_MemberCount_Get(void* /* System.Runtime.Serialization.SerializationInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Runtime.Serialization.SerializationInfo __selfConverted = InteropUtils.GetInstance<System.Runtime.Serialization.SerializationInfo>(__self);
	
	
	    try {
			System.Int32 __returnValue = __selfConverted.MemberCount;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_Serialization_SerializationInfo_ObjectType_Get")]
	internal static void* /* System.Type */ System_Runtime_Serialization_SerializationInfo_ObjectType_Get(void* /* System.Runtime.Serialization.SerializationInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Runtime.Serialization.SerializationInfo __selfConverted = InteropUtils.GetInstance<System.Runtime.Serialization.SerializationInfo>(__self);
	
	
	    try {
			System.Type __returnValue = __selfConverted.ObjectType;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_Serialization_SerializationInfo_TypeOf")]
	internal static void* /* System.Type */ System_Runtime_Serialization_SerializationInfo_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.Runtime.Serialization.SerializationInfo);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_Serialization_SerializationInfo_Destroy")]
	internal static void /* System.Void */ System_Runtime_Serialization_SerializationInfo_Destroy(void* /* System.Runtime.Serialization.SerializationInfo */ __self)
	{
	
		InteropUtils.FreeIfAllocated(__self);
	}
	
}


internal unsafe class System_Runtime_Serialization_SerializationInfoEnumerator
{
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_Serialization_SerializationInfoEnumerator_MoveNext")]
	internal static byte /* System.Boolean */ System_Runtime_Serialization_SerializationInfoEnumerator_MoveNext(void* /* System.Runtime.Serialization.SerializationInfoEnumerator */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Runtime.Serialization.SerializationInfoEnumerator __selfConverted = InteropUtils.GetInstance<System.Runtime.Serialization.SerializationInfoEnumerator>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.MoveNext();
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_Serialization_SerializationInfoEnumerator_Reset")]
	internal static void /* System.Void */ System_Runtime_Serialization_SerializationInfoEnumerator_Reset(void* /* System.Runtime.Serialization.SerializationInfoEnumerator */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Runtime.Serialization.SerializationInfoEnumerator __selfConverted = InteropUtils.GetInstance<System.Runtime.Serialization.SerializationInfoEnumerator>(__self);
	
	
	    try {
			__selfConverted.Reset();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_Serialization_SerializationInfoEnumerator_Current_Get")]
	internal static void* /* System.Runtime.Serialization.SerializationEntry */ System_Runtime_Serialization_SerializationInfoEnumerator_Current_Get(void* /* System.Runtime.Serialization.SerializationInfoEnumerator */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Runtime.Serialization.SerializationInfoEnumerator __selfConverted = InteropUtils.GetInstance<System.Runtime.Serialization.SerializationInfoEnumerator>(__self);
	
	
	    try {
			System.Runtime.Serialization.SerializationEntry __returnValue = __selfConverted.Current;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_Serialization_SerializationInfoEnumerator_Name_Get")]
	internal static void* /* System.String */ System_Runtime_Serialization_SerializationInfoEnumerator_Name_Get(void* /* System.Runtime.Serialization.SerializationInfoEnumerator */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Runtime.Serialization.SerializationInfoEnumerator __selfConverted = InteropUtils.GetInstance<System.Runtime.Serialization.SerializationInfoEnumerator>(__self);
	
	
	    try {
			System.String __returnValue = __selfConverted.Name;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_Serialization_SerializationInfoEnumerator_Value_Get")]
	internal static void* /* System.Object */ System_Runtime_Serialization_SerializationInfoEnumerator_Value_Get(void* /* System.Runtime.Serialization.SerializationInfoEnumerator */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Runtime.Serialization.SerializationInfoEnumerator __selfConverted = InteropUtils.GetInstance<System.Runtime.Serialization.SerializationInfoEnumerator>(__self);
	
	
	    try {
			System.Object __returnValue = __selfConverted.Value;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_Serialization_SerializationInfoEnumerator_ObjectType_Get")]
	internal static void* /* System.Type */ System_Runtime_Serialization_SerializationInfoEnumerator_ObjectType_Get(void* /* System.Runtime.Serialization.SerializationInfoEnumerator */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Runtime.Serialization.SerializationInfoEnumerator __selfConverted = InteropUtils.GetInstance<System.Runtime.Serialization.SerializationInfoEnumerator>(__self);
	
	
	    try {
			System.Type __returnValue = __selfConverted.ObjectType;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_Serialization_SerializationInfoEnumerator_TypeOf")]
	internal static void* /* System.Type */ System_Runtime_Serialization_SerializationInfoEnumerator_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.Runtime.Serialization.SerializationInfoEnumerator);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_Serialization_SerializationInfoEnumerator_Destroy")]
	internal static void /* System.Void */ System_Runtime_Serialization_SerializationInfoEnumerator_Destroy(void* /* System.Runtime.Serialization.SerializationInfoEnumerator */ __self)
	{
	
		InteropUtils.FreeIfAllocated(__self);
	}
	
}


internal unsafe class System_Runtime_Serialization_SerializationEntry
{
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_Serialization_SerializationEntry_Value_Get")]
	internal static void* /* System.Object */ System_Runtime_Serialization_SerializationEntry_Value_Get(void* /* System.Runtime.Serialization.SerializationEntry */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Runtime.Serialization.SerializationEntry __selfConverted = InteropUtils.GetInstance<System.Runtime.Serialization.SerializationEntry>(__self);
	
	
	    try {
			System.Object __returnValue = __selfConverted.Value;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_Serialization_SerializationEntry_Name_Get")]
	internal static void* /* System.String */ System_Runtime_Serialization_SerializationEntry_Name_Get(void* /* System.Runtime.Serialization.SerializationEntry */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Runtime.Serialization.SerializationEntry __selfConverted = InteropUtils.GetInstance<System.Runtime.Serialization.SerializationEntry>(__self);
	
	
	    try {
			System.String __returnValue = __selfConverted.Name;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_Serialization_SerializationEntry_ObjectType_Get")]
	internal static void* /* System.Type */ System_Runtime_Serialization_SerializationEntry_ObjectType_Get(void* /* System.Runtime.Serialization.SerializationEntry */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Runtime.Serialization.SerializationEntry __selfConverted = InteropUtils.GetInstance<System.Runtime.Serialization.SerializationEntry>(__self);
	
	
	    try {
			System.Type __returnValue = __selfConverted.ObjectType;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_Serialization_SerializationEntry_Create")]
	internal static void* /* System.Runtime.Serialization.SerializationEntry */ System_Runtime_Serialization_SerializationEntry_Create(void** /* System.Exception */ __outException)
	{
	
	    try {
			System.Runtime.Serialization.SerializationEntry __returnValue = new System.Runtime.Serialization.SerializationEntry();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_Serialization_SerializationEntry_TypeOf")]
	internal static void* /* System.Type */ System_Runtime_Serialization_SerializationEntry_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.Runtime.Serialization.SerializationEntry);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_Serialization_SerializationEntry_Destroy")]
	internal static void /* System.Void */ System_Runtime_Serialization_SerializationEntry_Destroy(void* /* System.Runtime.Serialization.SerializationEntry */ __self)
	{
	
		InteropUtils.FreeIfAllocated(__self);
	}
	
}


internal unsafe class System_Char
{
	[UnmanagedCallersOnly(EntryPoint = "System_Char_TypeOf")]
	internal static void* /* System.Type */ System_Char_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.Char);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
}


internal unsafe class System_IUtf8SpanFormattable
{
	[UnmanagedCallersOnly(EntryPoint = "System_IUtf8SpanFormattable_TypeOf")]
	internal static void* /* System.Type */ System_IUtf8SpanFormattable_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.IUtf8SpanFormattable);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_IUtf8SpanFormattable_Destroy")]
	internal static void /* System.Void */ System_IUtf8SpanFormattable_Destroy(void* /* System.IUtf8SpanFormattable */ __self)
	{
	
		InteropUtils.FreeIfAllocated(__self);
	}
	
}



internal unsafe class System_Globalization_UnicodeCategory
{
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_UnicodeCategory_TypeOf")]
	internal static void* /* System.Type */ System_Globalization_UnicodeCategory_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.Globalization.UnicodeCategory);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
}


internal unsafe class System_Double
{
	[UnmanagedCallersOnly(EntryPoint = "System_Double_TypeOf")]
	internal static void* /* System.Type */ System_Double_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.Double);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
}


internal unsafe class System_Globalization_NumberStyles
{
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_NumberStyles_TypeOf")]
	internal static void* /* System.Type */ System_Globalization_NumberStyles_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.Globalization.NumberStyles);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
}



internal unsafe class System_MidpointRounding
{
	[UnmanagedCallersOnly(EntryPoint = "System_MidpointRounding_TypeOf")]
	internal static void* /* System.Type */ System_MidpointRounding_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.MidpointRounding);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
}


internal unsafe class System_SByte
{
	[UnmanagedCallersOnly(EntryPoint = "System_SByte_TypeOf")]
	internal static void* /* System.Type */ System_SByte_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.SByte);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
}



internal unsafe class System_Byte
{
	[UnmanagedCallersOnly(EntryPoint = "System_Byte_TypeOf")]
	internal static void* /* System.Type */ System_Byte_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.Byte);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
}



internal unsafe class System_Int16
{
	[UnmanagedCallersOnly(EntryPoint = "System_Int16_TypeOf")]
	internal static void* /* System.Type */ System_Int16_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.Int16);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
}



internal unsafe class System_UInt16
{
	[UnmanagedCallersOnly(EntryPoint = "System_UInt16_TypeOf")]
	internal static void* /* System.Type */ System_UInt16_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.UInt16);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
}



internal unsafe class System_UInt32
{
	[UnmanagedCallersOnly(EntryPoint = "System_UInt32_TypeOf")]
	internal static void* /* System.Type */ System_UInt32_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.UInt32);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
}



internal unsafe class System_Int64
{
	[UnmanagedCallersOnly(EntryPoint = "System_Int64_TypeOf")]
	internal static void* /* System.Type */ System_Int64_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.Int64);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
}



internal unsafe class System_UInt64
{
	[UnmanagedCallersOnly(EntryPoint = "System_UInt64_TypeOf")]
	internal static void* /* System.Type */ System_UInt64_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.UInt64);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
}



internal unsafe class System_Single
{
	[UnmanagedCallersOnly(EntryPoint = "System_Single_TypeOf")]
	internal static void* /* System.Type */ System_Single_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.Single);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
}



internal unsafe class System_Decimal
{
	[UnmanagedCallersOnly(EntryPoint = "System_Decimal_FromOACurrency")]
	internal static void* /* System.Decimal */ System_Decimal_FromOACurrency(long /* System.Int64 */ cy, void** /* System.Exception */ __outException)
	{
	
	    try {
			System.Decimal __returnValue = System.Decimal.FromOACurrency(cy);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Decimal_ToOACurrency")]
	internal static long /* System.Int64 */ System_Decimal_ToOACurrency(void* /* System.Decimal */ value, void** /* System.Exception */ __outException)
	{
		System.Decimal valueConverted = InteropUtils.GetInstance<System.Decimal>(value);
	
	    try {
			System.Int64 __returnValue = System.Decimal.ToOACurrency(valueConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Decimal_Add")]
	internal static void* /* System.Decimal */ System_Decimal_Add(void* /* System.Decimal */ d1, void* /* System.Decimal */ d2, void** /* System.Exception */ __outException)
	{
		System.Decimal d1Converted = InteropUtils.GetInstance<System.Decimal>(d1);
		System.Decimal d2Converted = InteropUtils.GetInstance<System.Decimal>(d2);
	
	    try {
			System.Decimal __returnValue = System.Decimal.Add(d1Converted, d2Converted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Decimal_Ceiling")]
	internal static void* /* System.Decimal */ System_Decimal_Ceiling(void* /* System.Decimal */ d, void** /* System.Exception */ __outException)
	{
		System.Decimal dConverted = InteropUtils.GetInstance<System.Decimal>(d);
	
	    try {
			System.Decimal __returnValue = System.Decimal.Ceiling(dConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Decimal_Compare")]
	internal static int /* System.Int32 */ System_Decimal_Compare(void* /* System.Decimal */ d1, void* /* System.Decimal */ d2, void** /* System.Exception */ __outException)
	{
		System.Decimal d1Converted = InteropUtils.GetInstance<System.Decimal>(d1);
		System.Decimal d2Converted = InteropUtils.GetInstance<System.Decimal>(d2);
	
	    try {
			System.Int32 __returnValue = System.Decimal.Compare(d1Converted, d2Converted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Decimal_CompareTo")]
	internal static int /* System.Int32 */ System_Decimal_CompareTo(void* /* System.Decimal */ __self, void* /* System.Object */ value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Decimal __selfConverted = InteropUtils.GetInstance<System.Decimal>(__self);
	
		System.Object valueConverted = InteropUtils.GetInstance<System.Object>(value);
	
	    try {
			System.Int32 __returnValue = __selfConverted.CompareTo(valueConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Decimal_CompareTo_1")]
	internal static int /* System.Int32 */ System_Decimal_CompareTo_1(void* /* System.Decimal */ __self, void* /* System.Decimal */ value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Decimal __selfConverted = InteropUtils.GetInstance<System.Decimal>(__self);
	
		System.Decimal valueConverted = InteropUtils.GetInstance<System.Decimal>(value);
	
	    try {
			System.Int32 __returnValue = __selfConverted.CompareTo(valueConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Decimal_Divide")]
	internal static void* /* System.Decimal */ System_Decimal_Divide(void* /* System.Decimal */ d1, void* /* System.Decimal */ d2, void** /* System.Exception */ __outException)
	{
		System.Decimal d1Converted = InteropUtils.GetInstance<System.Decimal>(d1);
		System.Decimal d2Converted = InteropUtils.GetInstance<System.Decimal>(d2);
	
	    try {
			System.Decimal __returnValue = System.Decimal.Divide(d1Converted, d2Converted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Decimal_Equals")]
	internal static byte /* System.Boolean */ System_Decimal_Equals(void* /* System.Decimal */ __self, void* /* System.Object */ value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Decimal __selfConverted = InteropUtils.GetInstance<System.Decimal>(__self);
	
		System.Object valueConverted = InteropUtils.GetInstance<System.Object>(value);
	
	    try {
			System.Boolean __returnValue = __selfConverted.Equals(valueConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Decimal_Equals_1")]
	internal static byte /* System.Boolean */ System_Decimal_Equals_1(void* /* System.Decimal */ __self, void* /* System.Decimal */ value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Decimal __selfConverted = InteropUtils.GetInstance<System.Decimal>(__self);
	
		System.Decimal valueConverted = InteropUtils.GetInstance<System.Decimal>(value);
	
	    try {
			System.Boolean __returnValue = __selfConverted.Equals(valueConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Decimal_GetHashCode")]
	internal static int /* System.Int32 */ System_Decimal_GetHashCode(void* /* System.Decimal */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Decimal __selfConverted = InteropUtils.GetInstance<System.Decimal>(__self);
	
	
	    try {
			System.Int32 __returnValue = __selfConverted.GetHashCode();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Decimal_Equals_2")]
	internal static byte /* System.Boolean */ System_Decimal_Equals_2(void* /* System.Decimal */ d1, void* /* System.Decimal */ d2, void** /* System.Exception */ __outException)
	{
		System.Decimal d1Converted = InteropUtils.GetInstance<System.Decimal>(d1);
		System.Decimal d2Converted = InteropUtils.GetInstance<System.Decimal>(d2);
	
	    try {
			System.Boolean __returnValue = System.Decimal.Equals(d1Converted, d2Converted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Decimal_Floor")]
	internal static void* /* System.Decimal */ System_Decimal_Floor(void* /* System.Decimal */ d, void** /* System.Exception */ __outException)
	{
		System.Decimal dConverted = InteropUtils.GetInstance<System.Decimal>(d);
	
	    try {
			System.Decimal __returnValue = System.Decimal.Floor(dConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Decimal_ToString")]
	internal static void* /* System.String */ System_Decimal_ToString(void* /* System.Decimal */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Decimal __selfConverted = InteropUtils.GetInstance<System.Decimal>(__self);
	
	
	    try {
			System.String __returnValue = __selfConverted.ToString();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Decimal_ToString_1")]
	internal static void* /* System.String */ System_Decimal_ToString_1(void* /* System.Decimal */ __self, void* /* System.String */ format, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Decimal __selfConverted = InteropUtils.GetInstance<System.Decimal>(__self);
	
		System.String formatConverted = InteropUtils.GetInstance<System.String>(format);
	
	    try {
			System.String __returnValue = __selfConverted.ToString(formatConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Decimal_ToString_2")]
	internal static void* /* System.String */ System_Decimal_ToString_2(void* /* System.Decimal */ __self, void* /* System.IFormatProvider */ provider, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Decimal __selfConverted = InteropUtils.GetInstance<System.Decimal>(__self);
	
		System.IFormatProvider providerConverted = InteropUtils.GetInstance<System.IFormatProvider>(provider);
	
	    try {
			System.String __returnValue = __selfConverted.ToString(providerConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Decimal_ToString_3")]
	internal static void* /* System.String */ System_Decimal_ToString_3(void* /* System.Decimal */ __self, void* /* System.String */ format, void* /* System.IFormatProvider */ provider, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Decimal __selfConverted = InteropUtils.GetInstance<System.Decimal>(__self);
	
		System.String formatConverted = InteropUtils.GetInstance<System.String>(format);
		System.IFormatProvider providerConverted = InteropUtils.GetInstance<System.IFormatProvider>(provider);
	
	    try {
			System.String __returnValue = __selfConverted.ToString(formatConverted, providerConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Decimal_Parse")]
	internal static void* /* System.Decimal */ System_Decimal_Parse(void* /* System.String */ s, void** /* System.Exception */ __outException)
	{
		System.String sConverted = InteropUtils.GetInstance<System.String>(s);
	
	    try {
			System.Decimal __returnValue = System.Decimal.Parse(sConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Decimal_Parse_1")]
	internal static void* /* System.Decimal */ System_Decimal_Parse_1(void* /* System.String */ s, System.Globalization.NumberStyles /* System.Globalization.NumberStyles */ style, void** /* System.Exception */ __outException)
	{
		System.String sConverted = InteropUtils.GetInstance<System.String>(s);
	
	    try {
			System.Decimal __returnValue = System.Decimal.Parse(sConverted, style);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Decimal_Parse_2")]
	internal static void* /* System.Decimal */ System_Decimal_Parse_2(void* /* System.String */ s, void* /* System.IFormatProvider */ provider, void** /* System.Exception */ __outException)
	{
		System.String sConverted = InteropUtils.GetInstance<System.String>(s);
		System.IFormatProvider providerConverted = InteropUtils.GetInstance<System.IFormatProvider>(provider);
	
	    try {
			System.Decimal __returnValue = System.Decimal.Parse(sConverted, providerConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Decimal_Parse_3")]
	internal static void* /* System.Decimal */ System_Decimal_Parse_3(void* /* System.String */ s, System.Globalization.NumberStyles /* System.Globalization.NumberStyles */ style, void* /* System.IFormatProvider */ provider, void** /* System.Exception */ __outException)
	{
		System.String sConverted = InteropUtils.GetInstance<System.String>(s);
		System.IFormatProvider providerConverted = InteropUtils.GetInstance<System.IFormatProvider>(provider);
	
	    try {
			System.Decimal __returnValue = System.Decimal.Parse(sConverted, style, providerConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Decimal_TryParse")]
	internal static byte /* System.Boolean */ System_Decimal_TryParse(void* /* System.String */ s, void** /* System.Decimal */ result, void** /* System.Exception */ __outException)
	{
		System.String sConverted = InteropUtils.GetInstance<System.String>(s);
		System.Decimal resultConverted;
	
	    try {
			System.Boolean __returnValue = System.Decimal.TryParse(sConverted, out resultConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			if (result is not null) {
				*result = resultConverted.AllocateGCHandleAndGetAddress();
			}
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			if (result is not null) {
				*result = null;
			}
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Decimal_TryParse_1")]
	internal static byte /* System.Boolean */ System_Decimal_TryParse_1(void* /* System.String */ s, System.Globalization.NumberStyles /* System.Globalization.NumberStyles */ style, void* /* System.IFormatProvider */ provider, void** /* System.Decimal */ result, void** /* System.Exception */ __outException)
	{
		System.String sConverted = InteropUtils.GetInstance<System.String>(s);
		System.IFormatProvider providerConverted = InteropUtils.GetInstance<System.IFormatProvider>(provider);
		System.Decimal resultConverted;
	
	    try {
			System.Boolean __returnValue = System.Decimal.TryParse(sConverted, style, providerConverted, out resultConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			if (result is not null) {
				*result = resultConverted.AllocateGCHandleAndGetAddress();
			}
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			if (result is not null) {
				*result = null;
			}
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Decimal_GetBits")]
	internal static void* /* System.Int32[] */ System_Decimal_GetBits(void* /* System.Decimal */ d, void** /* System.Exception */ __outException)
	{
		System.Decimal dConverted = InteropUtils.GetInstance<System.Decimal>(d);
	
	    try {
			System.Int32[] __returnValue = System.Decimal.GetBits(dConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Decimal_Remainder")]
	internal static void* /* System.Decimal */ System_Decimal_Remainder(void* /* System.Decimal */ d1, void* /* System.Decimal */ d2, void** /* System.Exception */ __outException)
	{
		System.Decimal d1Converted = InteropUtils.GetInstance<System.Decimal>(d1);
		System.Decimal d2Converted = InteropUtils.GetInstance<System.Decimal>(d2);
	
	    try {
			System.Decimal __returnValue = System.Decimal.Remainder(d1Converted, d2Converted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Decimal_Multiply")]
	internal static void* /* System.Decimal */ System_Decimal_Multiply(void* /* System.Decimal */ d1, void* /* System.Decimal */ d2, void** /* System.Exception */ __outException)
	{
		System.Decimal d1Converted = InteropUtils.GetInstance<System.Decimal>(d1);
		System.Decimal d2Converted = InteropUtils.GetInstance<System.Decimal>(d2);
	
	    try {
			System.Decimal __returnValue = System.Decimal.Multiply(d1Converted, d2Converted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Decimal_Negate")]
	internal static void* /* System.Decimal */ System_Decimal_Negate(void* /* System.Decimal */ d, void** /* System.Exception */ __outException)
	{
		System.Decimal dConverted = InteropUtils.GetInstance<System.Decimal>(d);
	
	    try {
			System.Decimal __returnValue = System.Decimal.Negate(dConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Decimal_Round")]
	internal static void* /* System.Decimal */ System_Decimal_Round(void* /* System.Decimal */ d, void** /* System.Exception */ __outException)
	{
		System.Decimal dConverted = InteropUtils.GetInstance<System.Decimal>(d);
	
	    try {
			System.Decimal __returnValue = System.Decimal.Round(dConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Decimal_Round_1")]
	internal static void* /* System.Decimal */ System_Decimal_Round_1(void* /* System.Decimal */ d, int /* System.Int32 */ decimals, void** /* System.Exception */ __outException)
	{
		System.Decimal dConverted = InteropUtils.GetInstance<System.Decimal>(d);
	
	    try {
			System.Decimal __returnValue = System.Decimal.Round(dConverted, decimals);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Decimal_Round_2")]
	internal static void* /* System.Decimal */ System_Decimal_Round_2(void* /* System.Decimal */ d, System.MidpointRounding /* System.MidpointRounding */ mode, void** /* System.Exception */ __outException)
	{
		System.Decimal dConverted = InteropUtils.GetInstance<System.Decimal>(d);
	
	    try {
			System.Decimal __returnValue = System.Decimal.Round(dConverted, mode);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Decimal_Round_3")]
	internal static void* /* System.Decimal */ System_Decimal_Round_3(void* /* System.Decimal */ d, int /* System.Int32 */ decimals, System.MidpointRounding /* System.MidpointRounding */ mode, void** /* System.Exception */ __outException)
	{
		System.Decimal dConverted = InteropUtils.GetInstance<System.Decimal>(d);
	
	    try {
			System.Decimal __returnValue = System.Decimal.Round(dConverted, decimals, mode);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Decimal_Subtract")]
	internal static void* /* System.Decimal */ System_Decimal_Subtract(void* /* System.Decimal */ d1, void* /* System.Decimal */ d2, void** /* System.Exception */ __outException)
	{
		System.Decimal d1Converted = InteropUtils.GetInstance<System.Decimal>(d1);
		System.Decimal d2Converted = InteropUtils.GetInstance<System.Decimal>(d2);
	
	    try {
			System.Decimal __returnValue = System.Decimal.Subtract(d1Converted, d2Converted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Decimal_ToByte")]
	internal static byte /* System.Byte */ System_Decimal_ToByte(void* /* System.Decimal */ value, void** /* System.Exception */ __outException)
	{
		System.Decimal valueConverted = InteropUtils.GetInstance<System.Decimal>(value);
	
	    try {
			System.Byte __returnValue = System.Decimal.ToByte(valueConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Decimal_ToSByte")]
	internal static sbyte /* System.SByte */ System_Decimal_ToSByte(void* /* System.Decimal */ value, void** /* System.Exception */ __outException)
	{
		System.Decimal valueConverted = InteropUtils.GetInstance<System.Decimal>(value);
	
	    try {
			System.SByte __returnValue = System.Decimal.ToSByte(valueConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Decimal_ToInt16")]
	internal static short /* System.Int16 */ System_Decimal_ToInt16(void* /* System.Decimal */ value, void** /* System.Exception */ __outException)
	{
		System.Decimal valueConverted = InteropUtils.GetInstance<System.Decimal>(value);
	
	    try {
			System.Int16 __returnValue = System.Decimal.ToInt16(valueConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Decimal_ToDouble")]
	internal static double /* System.Double */ System_Decimal_ToDouble(void* /* System.Decimal */ d, void** /* System.Exception */ __outException)
	{
		System.Decimal dConverted = InteropUtils.GetInstance<System.Decimal>(d);
	
	    try {
			System.Double __returnValue = System.Decimal.ToDouble(dConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Decimal_ToInt32")]
	internal static int /* System.Int32 */ System_Decimal_ToInt32(void* /* System.Decimal */ d, void** /* System.Exception */ __outException)
	{
		System.Decimal dConverted = InteropUtils.GetInstance<System.Decimal>(d);
	
	    try {
			System.Int32 __returnValue = System.Decimal.ToInt32(dConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Decimal_ToInt64")]
	internal static long /* System.Int64 */ System_Decimal_ToInt64(void* /* System.Decimal */ d, void** /* System.Exception */ __outException)
	{
		System.Decimal dConverted = InteropUtils.GetInstance<System.Decimal>(d);
	
	    try {
			System.Int64 __returnValue = System.Decimal.ToInt64(dConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Decimal_ToUInt16")]
	internal static ushort /* System.UInt16 */ System_Decimal_ToUInt16(void* /* System.Decimal */ value, void** /* System.Exception */ __outException)
	{
		System.Decimal valueConverted = InteropUtils.GetInstance<System.Decimal>(value);
	
	    try {
			System.UInt16 __returnValue = System.Decimal.ToUInt16(valueConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Decimal_ToUInt32")]
	internal static uint /* System.UInt32 */ System_Decimal_ToUInt32(void* /* System.Decimal */ d, void** /* System.Exception */ __outException)
	{
		System.Decimal dConverted = InteropUtils.GetInstance<System.Decimal>(d);
	
	    try {
			System.UInt32 __returnValue = System.Decimal.ToUInt32(dConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Decimal_ToUInt64")]
	internal static ulong /* System.UInt64 */ System_Decimal_ToUInt64(void* /* System.Decimal */ d, void** /* System.Exception */ __outException)
	{
		System.Decimal dConverted = InteropUtils.GetInstance<System.Decimal>(d);
	
	    try {
			System.UInt64 __returnValue = System.Decimal.ToUInt64(dConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Decimal_ToSingle")]
	internal static float /* System.Single */ System_Decimal_ToSingle(void* /* System.Decimal */ d, void** /* System.Exception */ __outException)
	{
		System.Decimal dConverted = InteropUtils.GetInstance<System.Decimal>(d);
	
	    try {
			System.Single __returnValue = System.Decimal.ToSingle(dConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Decimal_Truncate")]
	internal static void* /* System.Decimal */ System_Decimal_Truncate(void* /* System.Decimal */ d, void** /* System.Exception */ __outException)
	{
		System.Decimal dConverted = InteropUtils.GetInstance<System.Decimal>(d);
	
	    try {
			System.Decimal __returnValue = System.Decimal.Truncate(dConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Decimal_GetTypeCode")]
	internal static System.TypeCode /* System.TypeCode */ System_Decimal_GetTypeCode(void* /* System.Decimal */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Decimal __selfConverted = InteropUtils.GetInstance<System.Decimal>(__self);
	
	
	    try {
			System.TypeCode __returnValue = __selfConverted.GetTypeCode();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return default(System.TypeCode);
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Decimal_Clamp")]
	internal static void* /* System.Decimal */ System_Decimal_Clamp(void* /* System.Decimal */ value, void* /* System.Decimal */ min, void* /* System.Decimal */ max, void** /* System.Exception */ __outException)
	{
		System.Decimal valueConverted = InteropUtils.GetInstance<System.Decimal>(value);
		System.Decimal minConverted = InteropUtils.GetInstance<System.Decimal>(min);
		System.Decimal maxConverted = InteropUtils.GetInstance<System.Decimal>(max);
	
	    try {
			System.Decimal __returnValue = System.Decimal.Clamp(valueConverted, minConverted, maxConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Decimal_CopySign")]
	internal static void* /* System.Decimal */ System_Decimal_CopySign(void* /* System.Decimal */ value, void* /* System.Decimal */ sign, void** /* System.Exception */ __outException)
	{
		System.Decimal valueConverted = InteropUtils.GetInstance<System.Decimal>(value);
		System.Decimal signConverted = InteropUtils.GetInstance<System.Decimal>(sign);
	
	    try {
			System.Decimal __returnValue = System.Decimal.CopySign(valueConverted, signConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Decimal_Max")]
	internal static void* /* System.Decimal */ System_Decimal_Max(void* /* System.Decimal */ x, void* /* System.Decimal */ y, void** /* System.Exception */ __outException)
	{
		System.Decimal xConverted = InteropUtils.GetInstance<System.Decimal>(x);
		System.Decimal yConverted = InteropUtils.GetInstance<System.Decimal>(y);
	
	    try {
			System.Decimal __returnValue = System.Decimal.Max(xConverted, yConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Decimal_Min")]
	internal static void* /* System.Decimal */ System_Decimal_Min(void* /* System.Decimal */ x, void* /* System.Decimal */ y, void** /* System.Exception */ __outException)
	{
		System.Decimal xConverted = InteropUtils.GetInstance<System.Decimal>(x);
		System.Decimal yConverted = InteropUtils.GetInstance<System.Decimal>(y);
	
	    try {
			System.Decimal __returnValue = System.Decimal.Min(xConverted, yConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Decimal_Sign")]
	internal static int /* System.Int32 */ System_Decimal_Sign(void* /* System.Decimal */ d, void** /* System.Exception */ __outException)
	{
		System.Decimal dConverted = InteropUtils.GetInstance<System.Decimal>(d);
	
	    try {
			System.Int32 __returnValue = System.Decimal.Sign(dConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Decimal_Abs")]
	internal static void* /* System.Decimal */ System_Decimal_Abs(void* /* System.Decimal */ value, void** /* System.Exception */ __outException)
	{
		System.Decimal valueConverted = InteropUtils.GetInstance<System.Decimal>(value);
	
	    try {
			System.Decimal __returnValue = System.Decimal.Abs(valueConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Decimal_IsCanonical")]
	internal static byte /* System.Boolean */ System_Decimal_IsCanonical(void* /* System.Decimal */ value, void** /* System.Exception */ __outException)
	{
		System.Decimal valueConverted = InteropUtils.GetInstance<System.Decimal>(value);
	
	    try {
			System.Boolean __returnValue = System.Decimal.IsCanonical(valueConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Decimal_IsEvenInteger")]
	internal static byte /* System.Boolean */ System_Decimal_IsEvenInteger(void* /* System.Decimal */ value, void** /* System.Exception */ __outException)
	{
		System.Decimal valueConverted = InteropUtils.GetInstance<System.Decimal>(value);
	
	    try {
			System.Boolean __returnValue = System.Decimal.IsEvenInteger(valueConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Decimal_IsInteger")]
	internal static byte /* System.Boolean */ System_Decimal_IsInteger(void* /* System.Decimal */ value, void** /* System.Exception */ __outException)
	{
		System.Decimal valueConverted = InteropUtils.GetInstance<System.Decimal>(value);
	
	    try {
			System.Boolean __returnValue = System.Decimal.IsInteger(valueConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Decimal_IsNegative")]
	internal static byte /* System.Boolean */ System_Decimal_IsNegative(void* /* System.Decimal */ value, void** /* System.Exception */ __outException)
	{
		System.Decimal valueConverted = InteropUtils.GetInstance<System.Decimal>(value);
	
	    try {
			System.Boolean __returnValue = System.Decimal.IsNegative(valueConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Decimal_IsOddInteger")]
	internal static byte /* System.Boolean */ System_Decimal_IsOddInteger(void* /* System.Decimal */ value, void** /* System.Exception */ __outException)
	{
		System.Decimal valueConverted = InteropUtils.GetInstance<System.Decimal>(value);
	
	    try {
			System.Boolean __returnValue = System.Decimal.IsOddInteger(valueConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Decimal_IsPositive")]
	internal static byte /* System.Boolean */ System_Decimal_IsPositive(void* /* System.Decimal */ value, void** /* System.Exception */ __outException)
	{
		System.Decimal valueConverted = InteropUtils.GetInstance<System.Decimal>(value);
	
	    try {
			System.Boolean __returnValue = System.Decimal.IsPositive(valueConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Decimal_MaxMagnitude")]
	internal static void* /* System.Decimal */ System_Decimal_MaxMagnitude(void* /* System.Decimal */ x, void* /* System.Decimal */ y, void** /* System.Exception */ __outException)
	{
		System.Decimal xConverted = InteropUtils.GetInstance<System.Decimal>(x);
		System.Decimal yConverted = InteropUtils.GetInstance<System.Decimal>(y);
	
	    try {
			System.Decimal __returnValue = System.Decimal.MaxMagnitude(xConverted, yConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Decimal_MinMagnitude")]
	internal static void* /* System.Decimal */ System_Decimal_MinMagnitude(void* /* System.Decimal */ x, void* /* System.Decimal */ y, void** /* System.Exception */ __outException)
	{
		System.Decimal xConverted = InteropUtils.GetInstance<System.Decimal>(x);
		System.Decimal yConverted = InteropUtils.GetInstance<System.Decimal>(y);
	
	    try {
			System.Decimal __returnValue = System.Decimal.MinMagnitude(xConverted, yConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Decimal_TryParse_2")]
	internal static byte /* System.Boolean */ System_Decimal_TryParse_2(void* /* System.String */ s, void* /* System.IFormatProvider */ provider, void** /* System.Decimal */ result, void** /* System.Exception */ __outException)
	{
		System.String sConverted = InteropUtils.GetInstance<System.String>(s);
		System.IFormatProvider providerConverted = InteropUtils.GetInstance<System.IFormatProvider>(provider);
		System.Decimal resultConverted;
	
	    try {
			System.Boolean __returnValue = System.Decimal.TryParse(sConverted, providerConverted, out resultConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			if (result is not null) {
				*result = resultConverted.AllocateGCHandleAndGetAddress();
			}
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			if (result is not null) {
				*result = null;
			}
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Decimal_Create")]
	internal static void* /* System.Decimal */ System_Decimal_Create(int /* System.Int32 */ value, void** /* System.Exception */ __outException)
	{
	
	    try {
			System.Decimal __returnValue = new System.Decimal(value);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Decimal_Create_1")]
	internal static void* /* System.Decimal */ System_Decimal_Create_1(uint /* System.UInt32 */ value, void** /* System.Exception */ __outException)
	{
	
	    try {
			System.Decimal __returnValue = new System.Decimal(value);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Decimal_Create_2")]
	internal static void* /* System.Decimal */ System_Decimal_Create_2(long /* System.Int64 */ value, void** /* System.Exception */ __outException)
	{
	
	    try {
			System.Decimal __returnValue = new System.Decimal(value);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Decimal_Create_3")]
	internal static void* /* System.Decimal */ System_Decimal_Create_3(ulong /* System.UInt64 */ value, void** /* System.Exception */ __outException)
	{
	
	    try {
			System.Decimal __returnValue = new System.Decimal(value);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Decimal_Create_4")]
	internal static void* /* System.Decimal */ System_Decimal_Create_4(float /* System.Single */ value, void** /* System.Exception */ __outException)
	{
	
	    try {
			System.Decimal __returnValue = new System.Decimal(value);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Decimal_Create_5")]
	internal static void* /* System.Decimal */ System_Decimal_Create_5(double /* System.Double */ value, void** /* System.Exception */ __outException)
	{
	
	    try {
			System.Decimal __returnValue = new System.Decimal(value);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Decimal_Create_6")]
	internal static void* /* System.Decimal */ System_Decimal_Create_6(void* /* System.Int32[] */ bits, void** /* System.Exception */ __outException)
	{
		System.Int32[] bitsConverted = InteropUtils.GetInstance<System.Int32[]>(bits);
	
	    try {
			System.Decimal __returnValue = new System.Decimal(bitsConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Decimal_Create_7")]
	internal static void* /* System.Decimal */ System_Decimal_Create_7(int /* System.Int32 */ lo, int /* System.Int32 */ mid, int /* System.Int32 */ hi, byte /* System.Boolean */ isNegative, byte /* System.Byte */ scale, void** /* System.Exception */ __outException)
	{
		System.Boolean isNegativeConverted = isNegative.ToBool();
	
	    try {
			System.Decimal __returnValue = new System.Decimal(lo, mid, hi, isNegativeConverted, scale);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Decimal_Scale_Get")]
	internal static byte /* System.Byte */ System_Decimal_Scale_Get(void* /* System.Decimal */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Decimal __selfConverted = InteropUtils.GetInstance<System.Decimal>(__self);
	
	
	    try {
			System.Byte __returnValue = __selfConverted.Scale;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Decimal_Zero_Get")]
	internal static void* /* System.Decimal */ System_Decimal_Zero_Get()
	{
	
		System.Decimal __returnValue = System.Decimal.Zero;
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Decimal_One_Get")]
	internal static void* /* System.Decimal */ System_Decimal_One_Get()
	{
	
		System.Decimal __returnValue = System.Decimal.One;
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Decimal_MinusOne_Get")]
	internal static void* /* System.Decimal */ System_Decimal_MinusOne_Get()
	{
	
		System.Decimal __returnValue = System.Decimal.MinusOne;
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Decimal_MaxValue_Get")]
	internal static void* /* System.Decimal */ System_Decimal_MaxValue_Get()
	{
	
		System.Decimal __returnValue = System.Decimal.MaxValue;
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Decimal_MinValue_Get")]
	internal static void* /* System.Decimal */ System_Decimal_MinValue_Get()
	{
	
		System.Decimal __returnValue = System.Decimal.MinValue;
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Decimal_Create_8")]
	internal static void* /* System.Decimal */ System_Decimal_Create_8(void** /* System.Exception */ __outException)
	{
	
	    try {
			System.Decimal __returnValue = new System.Decimal();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Decimal_TypeOf")]
	internal static void* /* System.Type */ System_Decimal_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.Decimal);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Decimal_Destroy")]
	internal static void /* System.Void */ System_Decimal_Destroy(void* /* System.Decimal */ __self)
	{
	
		InteropUtils.FreeIfAllocated(__self);
	}
	
}




internal unsafe class System_DateTime
{
	[UnmanagedCallersOnly(EntryPoint = "System_DateTime_Add")]
	internal static void* /* System.DateTime */ System_DateTime_Add(void* /* System.DateTime */ __self, void* /* System.TimeSpan */ value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.DateTime __selfConverted = InteropUtils.GetInstance<System.DateTime>(__self);
	
		System.TimeSpan valueConverted = InteropUtils.GetInstance<System.TimeSpan>(value);
	
	    try {
			System.DateTime __returnValue = __selfConverted.Add(valueConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateTime_AddDays")]
	internal static void* /* System.DateTime */ System_DateTime_AddDays(void* /* System.DateTime */ __self, double /* System.Double */ value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.DateTime __selfConverted = InteropUtils.GetInstance<System.DateTime>(__self);
	
	
	    try {
			System.DateTime __returnValue = __selfConverted.AddDays(value);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateTime_AddHours")]
	internal static void* /* System.DateTime */ System_DateTime_AddHours(void* /* System.DateTime */ __self, double /* System.Double */ value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.DateTime __selfConverted = InteropUtils.GetInstance<System.DateTime>(__self);
	
	
	    try {
			System.DateTime __returnValue = __selfConverted.AddHours(value);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateTime_AddMilliseconds")]
	internal static void* /* System.DateTime */ System_DateTime_AddMilliseconds(void* /* System.DateTime */ __self, double /* System.Double */ value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.DateTime __selfConverted = InteropUtils.GetInstance<System.DateTime>(__self);
	
	
	    try {
			System.DateTime __returnValue = __selfConverted.AddMilliseconds(value);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateTime_AddMicroseconds")]
	internal static void* /* System.DateTime */ System_DateTime_AddMicroseconds(void* /* System.DateTime */ __self, double /* System.Double */ value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.DateTime __selfConverted = InteropUtils.GetInstance<System.DateTime>(__self);
	
	
	    try {
			System.DateTime __returnValue = __selfConverted.AddMicroseconds(value);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateTime_AddMinutes")]
	internal static void* /* System.DateTime */ System_DateTime_AddMinutes(void* /* System.DateTime */ __self, double /* System.Double */ value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.DateTime __selfConverted = InteropUtils.GetInstance<System.DateTime>(__self);
	
	
	    try {
			System.DateTime __returnValue = __selfConverted.AddMinutes(value);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateTime_AddMonths")]
	internal static void* /* System.DateTime */ System_DateTime_AddMonths(void* /* System.DateTime */ __self, int /* System.Int32 */ months, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.DateTime __selfConverted = InteropUtils.GetInstance<System.DateTime>(__self);
	
	
	    try {
			System.DateTime __returnValue = __selfConverted.AddMonths(months);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateTime_AddSeconds")]
	internal static void* /* System.DateTime */ System_DateTime_AddSeconds(void* /* System.DateTime */ __self, double /* System.Double */ value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.DateTime __selfConverted = InteropUtils.GetInstance<System.DateTime>(__self);
	
	
	    try {
			System.DateTime __returnValue = __selfConverted.AddSeconds(value);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateTime_AddTicks")]
	internal static void* /* System.DateTime */ System_DateTime_AddTicks(void* /* System.DateTime */ __self, long /* System.Int64 */ value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.DateTime __selfConverted = InteropUtils.GetInstance<System.DateTime>(__self);
	
	
	    try {
			System.DateTime __returnValue = __selfConverted.AddTicks(value);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateTime_AddYears")]
	internal static void* /* System.DateTime */ System_DateTime_AddYears(void* /* System.DateTime */ __self, int /* System.Int32 */ value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.DateTime __selfConverted = InteropUtils.GetInstance<System.DateTime>(__self);
	
	
	    try {
			System.DateTime __returnValue = __selfConverted.AddYears(value);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateTime_Compare")]
	internal static int /* System.Int32 */ System_DateTime_Compare(void* /* System.DateTime */ t1, void* /* System.DateTime */ t2, void** /* System.Exception */ __outException)
	{
		System.DateTime t1Converted = InteropUtils.GetInstance<System.DateTime>(t1);
		System.DateTime t2Converted = InteropUtils.GetInstance<System.DateTime>(t2);
	
	    try {
			System.Int32 __returnValue = System.DateTime.Compare(t1Converted, t2Converted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateTime_CompareTo")]
	internal static int /* System.Int32 */ System_DateTime_CompareTo(void* /* System.DateTime */ __self, void* /* System.Object */ value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.DateTime __selfConverted = InteropUtils.GetInstance<System.DateTime>(__self);
	
		System.Object valueConverted = InteropUtils.GetInstance<System.Object>(value);
	
	    try {
			System.Int32 __returnValue = __selfConverted.CompareTo(valueConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateTime_CompareTo_1")]
	internal static int /* System.Int32 */ System_DateTime_CompareTo_1(void* /* System.DateTime */ __self, void* /* System.DateTime */ value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.DateTime __selfConverted = InteropUtils.GetInstance<System.DateTime>(__self);
	
		System.DateTime valueConverted = InteropUtils.GetInstance<System.DateTime>(value);
	
	    try {
			System.Int32 __returnValue = __selfConverted.CompareTo(valueConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateTime_DaysInMonth")]
	internal static int /* System.Int32 */ System_DateTime_DaysInMonth(int /* System.Int32 */ year, int /* System.Int32 */ month, void** /* System.Exception */ __outException)
	{
	
	    try {
			System.Int32 __returnValue = System.DateTime.DaysInMonth(year, month);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateTime_Equals")]
	internal static byte /* System.Boolean */ System_DateTime_Equals(void* /* System.DateTime */ __self, void* /* System.Object */ value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.DateTime __selfConverted = InteropUtils.GetInstance<System.DateTime>(__self);
	
		System.Object valueConverted = InteropUtils.GetInstance<System.Object>(value);
	
	    try {
			System.Boolean __returnValue = __selfConverted.Equals(valueConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateTime_Equals_1")]
	internal static byte /* System.Boolean */ System_DateTime_Equals_1(void* /* System.DateTime */ __self, void* /* System.DateTime */ value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.DateTime __selfConverted = InteropUtils.GetInstance<System.DateTime>(__self);
	
		System.DateTime valueConverted = InteropUtils.GetInstance<System.DateTime>(value);
	
	    try {
			System.Boolean __returnValue = __selfConverted.Equals(valueConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateTime_Equals_2")]
	internal static byte /* System.Boolean */ System_DateTime_Equals_2(void* /* System.DateTime */ t1, void* /* System.DateTime */ t2, void** /* System.Exception */ __outException)
	{
		System.DateTime t1Converted = InteropUtils.GetInstance<System.DateTime>(t1);
		System.DateTime t2Converted = InteropUtils.GetInstance<System.DateTime>(t2);
	
	    try {
			System.Boolean __returnValue = System.DateTime.Equals(t1Converted, t2Converted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateTime_FromBinary")]
	internal static void* /* System.DateTime */ System_DateTime_FromBinary(long /* System.Int64 */ dateData, void** /* System.Exception */ __outException)
	{
	
	    try {
			System.DateTime __returnValue = System.DateTime.FromBinary(dateData);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateTime_FromFileTime")]
	internal static void* /* System.DateTime */ System_DateTime_FromFileTime(long /* System.Int64 */ fileTime, void** /* System.Exception */ __outException)
	{
	
	    try {
			System.DateTime __returnValue = System.DateTime.FromFileTime(fileTime);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateTime_FromFileTimeUtc")]
	internal static void* /* System.DateTime */ System_DateTime_FromFileTimeUtc(long /* System.Int64 */ fileTime, void** /* System.Exception */ __outException)
	{
	
	    try {
			System.DateTime __returnValue = System.DateTime.FromFileTimeUtc(fileTime);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateTime_FromOADate")]
	internal static void* /* System.DateTime */ System_DateTime_FromOADate(double /* System.Double */ d, void** /* System.Exception */ __outException)
	{
	
	    try {
			System.DateTime __returnValue = System.DateTime.FromOADate(d);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateTime_IsDaylightSavingTime")]
	internal static byte /* System.Boolean */ System_DateTime_IsDaylightSavingTime(void* /* System.DateTime */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.DateTime __selfConverted = InteropUtils.GetInstance<System.DateTime>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.IsDaylightSavingTime();
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateTime_SpecifyKind")]
	internal static void* /* System.DateTime */ System_DateTime_SpecifyKind(void* /* System.DateTime */ value, System.DateTimeKind /* System.DateTimeKind */ kind, void** /* System.Exception */ __outException)
	{
		System.DateTime valueConverted = InteropUtils.GetInstance<System.DateTime>(value);
	
	    try {
			System.DateTime __returnValue = System.DateTime.SpecifyKind(valueConverted, kind);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateTime_ToBinary")]
	internal static long /* System.Int64 */ System_DateTime_ToBinary(void* /* System.DateTime */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.DateTime __selfConverted = InteropUtils.GetInstance<System.DateTime>(__self);
	
	
	    try {
			System.Int64 __returnValue = __selfConverted.ToBinary();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateTime_GetHashCode")]
	internal static int /* System.Int32 */ System_DateTime_GetHashCode(void* /* System.DateTime */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.DateTime __selfConverted = InteropUtils.GetInstance<System.DateTime>(__self);
	
	
	    try {
			System.Int32 __returnValue = __selfConverted.GetHashCode();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateTime_IsLeapYear")]
	internal static byte /* System.Boolean */ System_DateTime_IsLeapYear(int /* System.Int32 */ year, void** /* System.Exception */ __outException)
	{
	
	    try {
			System.Boolean __returnValue = System.DateTime.IsLeapYear(year);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateTime_Parse")]
	internal static void* /* System.DateTime */ System_DateTime_Parse(void* /* System.String */ s, void** /* System.Exception */ __outException)
	{
		System.String sConverted = InteropUtils.GetInstance<System.String>(s);
	
	    try {
			System.DateTime __returnValue = System.DateTime.Parse(sConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateTime_Parse_1")]
	internal static void* /* System.DateTime */ System_DateTime_Parse_1(void* /* System.String */ s, void* /* System.IFormatProvider */ provider, void** /* System.Exception */ __outException)
	{
		System.String sConverted = InteropUtils.GetInstance<System.String>(s);
		System.IFormatProvider providerConverted = InteropUtils.GetInstance<System.IFormatProvider>(provider);
	
	    try {
			System.DateTime __returnValue = System.DateTime.Parse(sConverted, providerConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateTime_Parse_2")]
	internal static void* /* System.DateTime */ System_DateTime_Parse_2(void* /* System.String */ s, void* /* System.IFormatProvider */ provider, System.Globalization.DateTimeStyles /* System.Globalization.DateTimeStyles */ styles, void** /* System.Exception */ __outException)
	{
		System.String sConverted = InteropUtils.GetInstance<System.String>(s);
		System.IFormatProvider providerConverted = InteropUtils.GetInstance<System.IFormatProvider>(provider);
	
	    try {
			System.DateTime __returnValue = System.DateTime.Parse(sConverted, providerConverted, styles);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateTime_ParseExact")]
	internal static void* /* System.DateTime */ System_DateTime_ParseExact(void* /* System.String */ s, void* /* System.String */ format, void* /* System.IFormatProvider */ provider, void** /* System.Exception */ __outException)
	{
		System.String sConverted = InteropUtils.GetInstance<System.String>(s);
		System.String formatConverted = InteropUtils.GetInstance<System.String>(format);
		System.IFormatProvider providerConverted = InteropUtils.GetInstance<System.IFormatProvider>(provider);
	
	    try {
			System.DateTime __returnValue = System.DateTime.ParseExact(sConverted, formatConverted, providerConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateTime_ParseExact_1")]
	internal static void* /* System.DateTime */ System_DateTime_ParseExact_1(void* /* System.String */ s, void* /* System.String */ format, void* /* System.IFormatProvider */ provider, System.Globalization.DateTimeStyles /* System.Globalization.DateTimeStyles */ style, void** /* System.Exception */ __outException)
	{
		System.String sConverted = InteropUtils.GetInstance<System.String>(s);
		System.String formatConverted = InteropUtils.GetInstance<System.String>(format);
		System.IFormatProvider providerConverted = InteropUtils.GetInstance<System.IFormatProvider>(provider);
	
	    try {
			System.DateTime __returnValue = System.DateTime.ParseExact(sConverted, formatConverted, providerConverted, style);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateTime_ParseExact_2")]
	internal static void* /* System.DateTime */ System_DateTime_ParseExact_2(void* /* System.String */ s, void* /* System.String[] */ formats, void* /* System.IFormatProvider */ provider, System.Globalization.DateTimeStyles /* System.Globalization.DateTimeStyles */ style, void** /* System.Exception */ __outException)
	{
		System.String sConverted = InteropUtils.GetInstance<System.String>(s);
		System.String[] formatsConverted = InteropUtils.GetInstance<System.String[]>(formats);
		System.IFormatProvider providerConverted = InteropUtils.GetInstance<System.IFormatProvider>(provider);
	
	    try {
			System.DateTime __returnValue = System.DateTime.ParseExact(sConverted, formatsConverted, providerConverted, style);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateTime_Subtract")]
	internal static void* /* System.TimeSpan */ System_DateTime_Subtract(void* /* System.DateTime */ __self, void* /* System.DateTime */ value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.DateTime __selfConverted = InteropUtils.GetInstance<System.DateTime>(__self);
	
		System.DateTime valueConverted = InteropUtils.GetInstance<System.DateTime>(value);
	
	    try {
			System.TimeSpan __returnValue = __selfConverted.Subtract(valueConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateTime_Subtract_1")]
	internal static void* /* System.DateTime */ System_DateTime_Subtract_1(void* /* System.DateTime */ __self, void* /* System.TimeSpan */ value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.DateTime __selfConverted = InteropUtils.GetInstance<System.DateTime>(__self);
	
		System.TimeSpan valueConverted = InteropUtils.GetInstance<System.TimeSpan>(value);
	
	    try {
			System.DateTime __returnValue = __selfConverted.Subtract(valueConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateTime_ToOADate")]
	internal static double /* System.Double */ System_DateTime_ToOADate(void* /* System.DateTime */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.DateTime __selfConverted = InteropUtils.GetInstance<System.DateTime>(__self);
	
	
	    try {
			System.Double __returnValue = __selfConverted.ToOADate();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateTime_ToFileTime")]
	internal static long /* System.Int64 */ System_DateTime_ToFileTime(void* /* System.DateTime */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.DateTime __selfConverted = InteropUtils.GetInstance<System.DateTime>(__self);
	
	
	    try {
			System.Int64 __returnValue = __selfConverted.ToFileTime();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateTime_ToFileTimeUtc")]
	internal static long /* System.Int64 */ System_DateTime_ToFileTimeUtc(void* /* System.DateTime */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.DateTime __selfConverted = InteropUtils.GetInstance<System.DateTime>(__self);
	
	
	    try {
			System.Int64 __returnValue = __selfConverted.ToFileTimeUtc();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateTime_ToLocalTime")]
	internal static void* /* System.DateTime */ System_DateTime_ToLocalTime(void* /* System.DateTime */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.DateTime __selfConverted = InteropUtils.GetInstance<System.DateTime>(__self);
	
	
	    try {
			System.DateTime __returnValue = __selfConverted.ToLocalTime();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateTime_ToLongDateString")]
	internal static void* /* System.String */ System_DateTime_ToLongDateString(void* /* System.DateTime */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.DateTime __selfConverted = InteropUtils.GetInstance<System.DateTime>(__self);
	
	
	    try {
			System.String __returnValue = __selfConverted.ToLongDateString();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateTime_ToLongTimeString")]
	internal static void* /* System.String */ System_DateTime_ToLongTimeString(void* /* System.DateTime */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.DateTime __selfConverted = InteropUtils.GetInstance<System.DateTime>(__self);
	
	
	    try {
			System.String __returnValue = __selfConverted.ToLongTimeString();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateTime_ToShortDateString")]
	internal static void* /* System.String */ System_DateTime_ToShortDateString(void* /* System.DateTime */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.DateTime __selfConverted = InteropUtils.GetInstance<System.DateTime>(__self);
	
	
	    try {
			System.String __returnValue = __selfConverted.ToShortDateString();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateTime_ToShortTimeString")]
	internal static void* /* System.String */ System_DateTime_ToShortTimeString(void* /* System.DateTime */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.DateTime __selfConverted = InteropUtils.GetInstance<System.DateTime>(__self);
	
	
	    try {
			System.String __returnValue = __selfConverted.ToShortTimeString();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateTime_ToString")]
	internal static void* /* System.String */ System_DateTime_ToString(void* /* System.DateTime */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.DateTime __selfConverted = InteropUtils.GetInstance<System.DateTime>(__self);
	
	
	    try {
			System.String __returnValue = __selfConverted.ToString();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateTime_ToString_1")]
	internal static void* /* System.String */ System_DateTime_ToString_1(void* /* System.DateTime */ __self, void* /* System.String */ format, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.DateTime __selfConverted = InteropUtils.GetInstance<System.DateTime>(__self);
	
		System.String formatConverted = InteropUtils.GetInstance<System.String>(format);
	
	    try {
			System.String __returnValue = __selfConverted.ToString(formatConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateTime_ToString_2")]
	internal static void* /* System.String */ System_DateTime_ToString_2(void* /* System.DateTime */ __self, void* /* System.IFormatProvider */ provider, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.DateTime __selfConverted = InteropUtils.GetInstance<System.DateTime>(__self);
	
		System.IFormatProvider providerConverted = InteropUtils.GetInstance<System.IFormatProvider>(provider);
	
	    try {
			System.String __returnValue = __selfConverted.ToString(providerConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateTime_ToString_3")]
	internal static void* /* System.String */ System_DateTime_ToString_3(void* /* System.DateTime */ __self, void* /* System.String */ format, void* /* System.IFormatProvider */ provider, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.DateTime __selfConverted = InteropUtils.GetInstance<System.DateTime>(__self);
	
		System.String formatConverted = InteropUtils.GetInstance<System.String>(format);
		System.IFormatProvider providerConverted = InteropUtils.GetInstance<System.IFormatProvider>(provider);
	
	    try {
			System.String __returnValue = __selfConverted.ToString(formatConverted, providerConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateTime_ToUniversalTime")]
	internal static void* /* System.DateTime */ System_DateTime_ToUniversalTime(void* /* System.DateTime */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.DateTime __selfConverted = InteropUtils.GetInstance<System.DateTime>(__self);
	
	
	    try {
			System.DateTime __returnValue = __selfConverted.ToUniversalTime();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateTime_TryParse")]
	internal static byte /* System.Boolean */ System_DateTime_TryParse(void* /* System.String */ s, void** /* System.DateTime */ result, void** /* System.Exception */ __outException)
	{
		System.String sConverted = InteropUtils.GetInstance<System.String>(s);
		System.DateTime resultConverted;
	
	    try {
			System.Boolean __returnValue = System.DateTime.TryParse(sConverted, out resultConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			if (result is not null) {
				*result = resultConverted.AllocateGCHandleAndGetAddress();
			}
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			if (result is not null) {
				*result = null;
			}
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateTime_TryParse_1")]
	internal static byte /* System.Boolean */ System_DateTime_TryParse_1(void* /* System.String */ s, void* /* System.IFormatProvider */ provider, System.Globalization.DateTimeStyles /* System.Globalization.DateTimeStyles */ styles, void** /* System.DateTime */ result, void** /* System.Exception */ __outException)
	{
		System.String sConverted = InteropUtils.GetInstance<System.String>(s);
		System.IFormatProvider providerConverted = InteropUtils.GetInstance<System.IFormatProvider>(provider);
		System.DateTime resultConverted;
	
	    try {
			System.Boolean __returnValue = System.DateTime.TryParse(sConverted, providerConverted, styles, out resultConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			if (result is not null) {
				*result = resultConverted.AllocateGCHandleAndGetAddress();
			}
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			if (result is not null) {
				*result = null;
			}
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateTime_TryParseExact")]
	internal static byte /* System.Boolean */ System_DateTime_TryParseExact(void* /* System.String */ s, void* /* System.String */ format, void* /* System.IFormatProvider */ provider, System.Globalization.DateTimeStyles /* System.Globalization.DateTimeStyles */ style, void** /* System.DateTime */ result, void** /* System.Exception */ __outException)
	{
		System.String sConverted = InteropUtils.GetInstance<System.String>(s);
		System.String formatConverted = InteropUtils.GetInstance<System.String>(format);
		System.IFormatProvider providerConverted = InteropUtils.GetInstance<System.IFormatProvider>(provider);
		System.DateTime resultConverted;
	
	    try {
			System.Boolean __returnValue = System.DateTime.TryParseExact(sConverted, formatConverted, providerConverted, style, out resultConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			if (result is not null) {
				*result = resultConverted.AllocateGCHandleAndGetAddress();
			}
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			if (result is not null) {
				*result = null;
			}
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateTime_TryParseExact_1")]
	internal static byte /* System.Boolean */ System_DateTime_TryParseExact_1(void* /* System.String */ s, void* /* System.String[] */ formats, void* /* System.IFormatProvider */ provider, System.Globalization.DateTimeStyles /* System.Globalization.DateTimeStyles */ style, void** /* System.DateTime */ result, void** /* System.Exception */ __outException)
	{
		System.String sConverted = InteropUtils.GetInstance<System.String>(s);
		System.String[] formatsConverted = InteropUtils.GetInstance<System.String[]>(formats);
		System.IFormatProvider providerConverted = InteropUtils.GetInstance<System.IFormatProvider>(provider);
		System.DateTime resultConverted;
	
	    try {
			System.Boolean __returnValue = System.DateTime.TryParseExact(sConverted, formatsConverted, providerConverted, style, out resultConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			if (result is not null) {
				*result = resultConverted.AllocateGCHandleAndGetAddress();
			}
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			if (result is not null) {
				*result = null;
			}
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateTime_Deconstruct")]
	internal static void /* System.Void */ System_DateTime_Deconstruct(void* /* System.DateTime */ __self, void** /* System.DateOnly */ date, void** /* System.TimeOnly */ time, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.DateTime __selfConverted = InteropUtils.GetInstance<System.DateTime>(__self);
	
		System.DateOnly dateConverted;
		System.TimeOnly timeConverted;
	
	    try {
			__selfConverted.Deconstruct(out dateConverted, out timeConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			if (date is not null) {
				*date = dateConverted.AllocateGCHandleAndGetAddress();
			}
	
			if (time is not null) {
				*time = timeConverted.AllocateGCHandleAndGetAddress();
			}
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			if (date is not null) {
				*date = null;
			}
	
			if (time is not null) {
				*time = null;
			}
	
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateTime_Deconstruct_1")]
	internal static void /* System.Void */ System_DateTime_Deconstruct_1(void* /* System.DateTime */ __self, int* /* System.Int32 */ year, int* /* System.Int32 */ month, int* /* System.Int32 */ day, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.DateTime __selfConverted = InteropUtils.GetInstance<System.DateTime>(__self);
	
		System.Int32 yearConverted;
		System.Int32 monthConverted;
		System.Int32 dayConverted;
	
	    try {
			__selfConverted.Deconstruct(out yearConverted, out monthConverted, out dayConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			if (year is not null) {
				*year = yearConverted;
			}
	
			if (month is not null) {
				*month = monthConverted;
			}
	
			if (day is not null) {
				*day = dayConverted;
			}
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			if (year is not null) {
				*year = -1;
			}
	
			if (month is not null) {
				*month = -1;
			}
	
			if (day is not null) {
				*day = -1;
			}
	
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateTime_GetDateTimeFormats")]
	internal static void* /* System.String[] */ System_DateTime_GetDateTimeFormats(void* /* System.DateTime */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.DateTime __selfConverted = InteropUtils.GetInstance<System.DateTime>(__self);
	
	
	    try {
			System.String[] __returnValue = __selfConverted.GetDateTimeFormats();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateTime_GetDateTimeFormats_1")]
	internal static void* /* System.String[] */ System_DateTime_GetDateTimeFormats_1(void* /* System.DateTime */ __self, void* /* System.IFormatProvider */ provider, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.DateTime __selfConverted = InteropUtils.GetInstance<System.DateTime>(__self);
	
		System.IFormatProvider providerConverted = InteropUtils.GetInstance<System.IFormatProvider>(provider);
	
	    try {
			System.String[] __returnValue = __selfConverted.GetDateTimeFormats(providerConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateTime_GetDateTimeFormats_2")]
	internal static void* /* System.String[] */ System_DateTime_GetDateTimeFormats_2(void* /* System.DateTime */ __self, char /* System.Char */ format, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.DateTime __selfConverted = InteropUtils.GetInstance<System.DateTime>(__self);
	
	
	    try {
			System.String[] __returnValue = __selfConverted.GetDateTimeFormats(format);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateTime_GetDateTimeFormats_3")]
	internal static void* /* System.String[] */ System_DateTime_GetDateTimeFormats_3(void* /* System.DateTime */ __self, char /* System.Char */ format, void* /* System.IFormatProvider */ provider, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.DateTime __selfConverted = InteropUtils.GetInstance<System.DateTime>(__self);
	
		System.IFormatProvider providerConverted = InteropUtils.GetInstance<System.IFormatProvider>(provider);
	
	    try {
			System.String[] __returnValue = __selfConverted.GetDateTimeFormats(format, providerConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateTime_GetTypeCode")]
	internal static System.TypeCode /* System.TypeCode */ System_DateTime_GetTypeCode(void* /* System.DateTime */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.DateTime __selfConverted = InteropUtils.GetInstance<System.DateTime>(__self);
	
	
	    try {
			System.TypeCode __returnValue = __selfConverted.GetTypeCode();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return default(System.TypeCode);
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateTime_TryParse_2")]
	internal static byte /* System.Boolean */ System_DateTime_TryParse_2(void* /* System.String */ s, void* /* System.IFormatProvider */ provider, void** /* System.DateTime */ result, void** /* System.Exception */ __outException)
	{
		System.String sConverted = InteropUtils.GetInstance<System.String>(s);
		System.IFormatProvider providerConverted = InteropUtils.GetInstance<System.IFormatProvider>(provider);
		System.DateTime resultConverted;
	
	    try {
			System.Boolean __returnValue = System.DateTime.TryParse(sConverted, providerConverted, out resultConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			if (result is not null) {
				*result = resultConverted.AllocateGCHandleAndGetAddress();
			}
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			if (result is not null) {
				*result = null;
			}
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateTime_Create")]
	internal static void* /* System.DateTime */ System_DateTime_Create(long /* System.Int64 */ ticks, void** /* System.Exception */ __outException)
	{
	
	    try {
			System.DateTime __returnValue = new System.DateTime(ticks);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateTime_Create_1")]
	internal static void* /* System.DateTime */ System_DateTime_Create_1(long /* System.Int64 */ ticks, System.DateTimeKind /* System.DateTimeKind */ kind, void** /* System.Exception */ __outException)
	{
	
	    try {
			System.DateTime __returnValue = new System.DateTime(ticks, kind);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateTime_Create_2")]
	internal static void* /* System.DateTime */ System_DateTime_Create_2(void* /* System.DateOnly */ date, void* /* System.TimeOnly */ time, void** /* System.Exception */ __outException)
	{
		System.DateOnly dateConverted = InteropUtils.GetInstance<System.DateOnly>(date);
		System.TimeOnly timeConverted = InteropUtils.GetInstance<System.TimeOnly>(time);
	
	    try {
			System.DateTime __returnValue = new System.DateTime(dateConverted, timeConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateTime_Create_3")]
	internal static void* /* System.DateTime */ System_DateTime_Create_3(void* /* System.DateOnly */ date, void* /* System.TimeOnly */ time, System.DateTimeKind /* System.DateTimeKind */ kind, void** /* System.Exception */ __outException)
	{
		System.DateOnly dateConverted = InteropUtils.GetInstance<System.DateOnly>(date);
		System.TimeOnly timeConverted = InteropUtils.GetInstance<System.TimeOnly>(time);
	
	    try {
			System.DateTime __returnValue = new System.DateTime(dateConverted, timeConverted, kind);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateTime_Create_4")]
	internal static void* /* System.DateTime */ System_DateTime_Create_4(int /* System.Int32 */ year, int /* System.Int32 */ month, int /* System.Int32 */ day, void** /* System.Exception */ __outException)
	{
	
	    try {
			System.DateTime __returnValue = new System.DateTime(year, month, day);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateTime_Create_5")]
	internal static void* /* System.DateTime */ System_DateTime_Create_5(int /* System.Int32 */ year, int /* System.Int32 */ month, int /* System.Int32 */ day, void* /* System.Globalization.Calendar */ calendar, void** /* System.Exception */ __outException)
	{
		System.Globalization.Calendar calendarConverted = InteropUtils.GetInstance<System.Globalization.Calendar>(calendar);
	
	    try {
			System.DateTime __returnValue = new System.DateTime(year, month, day, calendarConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateTime_Create_6")]
	internal static void* /* System.DateTime */ System_DateTime_Create_6(int /* System.Int32 */ year, int /* System.Int32 */ month, int /* System.Int32 */ day, int /* System.Int32 */ hour, int /* System.Int32 */ minute, int /* System.Int32 */ second, int /* System.Int32 */ millisecond, void* /* System.Globalization.Calendar */ calendar, System.DateTimeKind /* System.DateTimeKind */ kind, void** /* System.Exception */ __outException)
	{
		System.Globalization.Calendar calendarConverted = InteropUtils.GetInstance<System.Globalization.Calendar>(calendar);
	
	    try {
			System.DateTime __returnValue = new System.DateTime(year, month, day, hour, minute, second, millisecond, calendarConverted, kind);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateTime_Create_7")]
	internal static void* /* System.DateTime */ System_DateTime_Create_7(int /* System.Int32 */ year, int /* System.Int32 */ month, int /* System.Int32 */ day, int /* System.Int32 */ hour, int /* System.Int32 */ minute, int /* System.Int32 */ second, void** /* System.Exception */ __outException)
	{
	
	    try {
			System.DateTime __returnValue = new System.DateTime(year, month, day, hour, minute, second);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateTime_Create_8")]
	internal static void* /* System.DateTime */ System_DateTime_Create_8(int /* System.Int32 */ year, int /* System.Int32 */ month, int /* System.Int32 */ day, int /* System.Int32 */ hour, int /* System.Int32 */ minute, int /* System.Int32 */ second, System.DateTimeKind /* System.DateTimeKind */ kind, void** /* System.Exception */ __outException)
	{
	
	    try {
			System.DateTime __returnValue = new System.DateTime(year, month, day, hour, minute, second, kind);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateTime_Create_9")]
	internal static void* /* System.DateTime */ System_DateTime_Create_9(int /* System.Int32 */ year, int /* System.Int32 */ month, int /* System.Int32 */ day, int /* System.Int32 */ hour, int /* System.Int32 */ minute, int /* System.Int32 */ second, void* /* System.Globalization.Calendar */ calendar, void** /* System.Exception */ __outException)
	{
		System.Globalization.Calendar calendarConverted = InteropUtils.GetInstance<System.Globalization.Calendar>(calendar);
	
	    try {
			System.DateTime __returnValue = new System.DateTime(year, month, day, hour, minute, second, calendarConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateTime_Create_10")]
	internal static void* /* System.DateTime */ System_DateTime_Create_10(int /* System.Int32 */ year, int /* System.Int32 */ month, int /* System.Int32 */ day, int /* System.Int32 */ hour, int /* System.Int32 */ minute, int /* System.Int32 */ second, int /* System.Int32 */ millisecond, void** /* System.Exception */ __outException)
	{
	
	    try {
			System.DateTime __returnValue = new System.DateTime(year, month, day, hour, minute, second, millisecond);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateTime_Create_11")]
	internal static void* /* System.DateTime */ System_DateTime_Create_11(int /* System.Int32 */ year, int /* System.Int32 */ month, int /* System.Int32 */ day, int /* System.Int32 */ hour, int /* System.Int32 */ minute, int /* System.Int32 */ second, int /* System.Int32 */ millisecond, System.DateTimeKind /* System.DateTimeKind */ kind, void** /* System.Exception */ __outException)
	{
	
	    try {
			System.DateTime __returnValue = new System.DateTime(year, month, day, hour, minute, second, millisecond, kind);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateTime_Create_12")]
	internal static void* /* System.DateTime */ System_DateTime_Create_12(int /* System.Int32 */ year, int /* System.Int32 */ month, int /* System.Int32 */ day, int /* System.Int32 */ hour, int /* System.Int32 */ minute, int /* System.Int32 */ second, int /* System.Int32 */ millisecond, void* /* System.Globalization.Calendar */ calendar, void** /* System.Exception */ __outException)
	{
		System.Globalization.Calendar calendarConverted = InteropUtils.GetInstance<System.Globalization.Calendar>(calendar);
	
	    try {
			System.DateTime __returnValue = new System.DateTime(year, month, day, hour, minute, second, millisecond, calendarConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateTime_Create_13")]
	internal static void* /* System.DateTime */ System_DateTime_Create_13(int /* System.Int32 */ year, int /* System.Int32 */ month, int /* System.Int32 */ day, int /* System.Int32 */ hour, int /* System.Int32 */ minute, int /* System.Int32 */ second, int /* System.Int32 */ millisecond, int /* System.Int32 */ microsecond, void** /* System.Exception */ __outException)
	{
	
	    try {
			System.DateTime __returnValue = new System.DateTime(year, month, day, hour, minute, second, millisecond, microsecond);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateTime_Create_14")]
	internal static void* /* System.DateTime */ System_DateTime_Create_14(int /* System.Int32 */ year, int /* System.Int32 */ month, int /* System.Int32 */ day, int /* System.Int32 */ hour, int /* System.Int32 */ minute, int /* System.Int32 */ second, int /* System.Int32 */ millisecond, int /* System.Int32 */ microsecond, System.DateTimeKind /* System.DateTimeKind */ kind, void** /* System.Exception */ __outException)
	{
	
	    try {
			System.DateTime __returnValue = new System.DateTime(year, month, day, hour, minute, second, millisecond, microsecond, kind);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateTime_Create_15")]
	internal static void* /* System.DateTime */ System_DateTime_Create_15(int /* System.Int32 */ year, int /* System.Int32 */ month, int /* System.Int32 */ day, int /* System.Int32 */ hour, int /* System.Int32 */ minute, int /* System.Int32 */ second, int /* System.Int32 */ millisecond, int /* System.Int32 */ microsecond, void* /* System.Globalization.Calendar */ calendar, void** /* System.Exception */ __outException)
	{
		System.Globalization.Calendar calendarConverted = InteropUtils.GetInstance<System.Globalization.Calendar>(calendar);
	
	    try {
			System.DateTime __returnValue = new System.DateTime(year, month, day, hour, minute, second, millisecond, microsecond, calendarConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateTime_Create_16")]
	internal static void* /* System.DateTime */ System_DateTime_Create_16(int /* System.Int32 */ year, int /* System.Int32 */ month, int /* System.Int32 */ day, int /* System.Int32 */ hour, int /* System.Int32 */ minute, int /* System.Int32 */ second, int /* System.Int32 */ millisecond, int /* System.Int32 */ microsecond, void* /* System.Globalization.Calendar */ calendar, System.DateTimeKind /* System.DateTimeKind */ kind, void** /* System.Exception */ __outException)
	{
		System.Globalization.Calendar calendarConverted = InteropUtils.GetInstance<System.Globalization.Calendar>(calendar);
	
	    try {
			System.DateTime __returnValue = new System.DateTime(year, month, day, hour, minute, second, millisecond, microsecond, calendarConverted, kind);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateTime_Date_Get")]
	internal static void* /* System.DateTime */ System_DateTime_Date_Get(void* /* System.DateTime */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.DateTime __selfConverted = InteropUtils.GetInstance<System.DateTime>(__self);
	
	
	    try {
			System.DateTime __returnValue = __selfConverted.Date;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateTime_Day_Get")]
	internal static int /* System.Int32 */ System_DateTime_Day_Get(void* /* System.DateTime */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.DateTime __selfConverted = InteropUtils.GetInstance<System.DateTime>(__self);
	
	
	    try {
			System.Int32 __returnValue = __selfConverted.Day;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateTime_DayOfWeek_Get")]
	internal static System.DayOfWeek /* System.DayOfWeek */ System_DateTime_DayOfWeek_Get(void* /* System.DateTime */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.DateTime __selfConverted = InteropUtils.GetInstance<System.DateTime>(__self);
	
	
	    try {
			System.DayOfWeek __returnValue = __selfConverted.DayOfWeek;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return default(System.DayOfWeek);
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateTime_DayOfYear_Get")]
	internal static int /* System.Int32 */ System_DateTime_DayOfYear_Get(void* /* System.DateTime */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.DateTime __selfConverted = InteropUtils.GetInstance<System.DateTime>(__self);
	
	
	    try {
			System.Int32 __returnValue = __selfConverted.DayOfYear;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateTime_Hour_Get")]
	internal static int /* System.Int32 */ System_DateTime_Hour_Get(void* /* System.DateTime */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.DateTime __selfConverted = InteropUtils.GetInstance<System.DateTime>(__self);
	
	
	    try {
			System.Int32 __returnValue = __selfConverted.Hour;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateTime_Kind_Get")]
	internal static System.DateTimeKind /* System.DateTimeKind */ System_DateTime_Kind_Get(void* /* System.DateTime */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.DateTime __selfConverted = InteropUtils.GetInstance<System.DateTime>(__self);
	
	
	    try {
			System.DateTimeKind __returnValue = __selfConverted.Kind;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return default(System.DateTimeKind);
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateTime_Millisecond_Get")]
	internal static int /* System.Int32 */ System_DateTime_Millisecond_Get(void* /* System.DateTime */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.DateTime __selfConverted = InteropUtils.GetInstance<System.DateTime>(__self);
	
	
	    try {
			System.Int32 __returnValue = __selfConverted.Millisecond;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateTime_Microsecond_Get")]
	internal static int /* System.Int32 */ System_DateTime_Microsecond_Get(void* /* System.DateTime */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.DateTime __selfConverted = InteropUtils.GetInstance<System.DateTime>(__self);
	
	
	    try {
			System.Int32 __returnValue = __selfConverted.Microsecond;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateTime_Nanosecond_Get")]
	internal static int /* System.Int32 */ System_DateTime_Nanosecond_Get(void* /* System.DateTime */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.DateTime __selfConverted = InteropUtils.GetInstance<System.DateTime>(__self);
	
	
	    try {
			System.Int32 __returnValue = __selfConverted.Nanosecond;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateTime_Minute_Get")]
	internal static int /* System.Int32 */ System_DateTime_Minute_Get(void* /* System.DateTime */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.DateTime __selfConverted = InteropUtils.GetInstance<System.DateTime>(__self);
	
	
	    try {
			System.Int32 __returnValue = __selfConverted.Minute;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateTime_Month_Get")]
	internal static int /* System.Int32 */ System_DateTime_Month_Get(void* /* System.DateTime */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.DateTime __selfConverted = InteropUtils.GetInstance<System.DateTime>(__self);
	
	
	    try {
			System.Int32 __returnValue = __selfConverted.Month;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateTime_Now_Get")]
	internal static void* /* System.DateTime */ System_DateTime_Now_Get(void** /* System.Exception */ __outException)
	{
	
	    try {
			System.DateTime __returnValue = System.DateTime.Now;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateTime_Second_Get")]
	internal static int /* System.Int32 */ System_DateTime_Second_Get(void* /* System.DateTime */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.DateTime __selfConverted = InteropUtils.GetInstance<System.DateTime>(__self);
	
	
	    try {
			System.Int32 __returnValue = __selfConverted.Second;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateTime_Ticks_Get")]
	internal static long /* System.Int64 */ System_DateTime_Ticks_Get(void* /* System.DateTime */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.DateTime __selfConverted = InteropUtils.GetInstance<System.DateTime>(__self);
	
	
	    try {
			System.Int64 __returnValue = __selfConverted.Ticks;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateTime_TimeOfDay_Get")]
	internal static void* /* System.TimeSpan */ System_DateTime_TimeOfDay_Get(void* /* System.DateTime */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.DateTime __selfConverted = InteropUtils.GetInstance<System.DateTime>(__self);
	
	
	    try {
			System.TimeSpan __returnValue = __selfConverted.TimeOfDay;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateTime_Today_Get")]
	internal static void* /* System.DateTime */ System_DateTime_Today_Get(void** /* System.Exception */ __outException)
	{
	
	    try {
			System.DateTime __returnValue = System.DateTime.Today;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateTime_Year_Get")]
	internal static int /* System.Int32 */ System_DateTime_Year_Get(void* /* System.DateTime */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.DateTime __selfConverted = InteropUtils.GetInstance<System.DateTime>(__self);
	
	
	    try {
			System.Int32 __returnValue = __selfConverted.Year;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateTime_UtcNow_Get")]
	internal static void* /* System.DateTime */ System_DateTime_UtcNow_Get(void** /* System.Exception */ __outException)
	{
	
	    try {
			System.DateTime __returnValue = System.DateTime.UtcNow;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateTime_MinValue_Get")]
	internal static void* /* System.DateTime */ System_DateTime_MinValue_Get()
	{
	
		System.DateTime __returnValue = System.DateTime.MinValue;
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateTime_MaxValue_Get")]
	internal static void* /* System.DateTime */ System_DateTime_MaxValue_Get()
	{
	
		System.DateTime __returnValue = System.DateTime.MaxValue;
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateTime_UnixEpoch_Get")]
	internal static void* /* System.DateTime */ System_DateTime_UnixEpoch_Get()
	{
	
		System.DateTime __returnValue = System.DateTime.UnixEpoch;
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateTime_Create_17")]
	internal static void* /* System.DateTime */ System_DateTime_Create_17(void** /* System.Exception */ __outException)
	{
	
	    try {
			System.DateTime __returnValue = new System.DateTime();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateTime_TypeOf")]
	internal static void* /* System.Type */ System_DateTime_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.DateTime);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateTime_Destroy")]
	internal static void /* System.Void */ System_DateTime_Destroy(void* /* System.DateTime */ __self)
	{
	
		InteropUtils.FreeIfAllocated(__self);
	}
	
}


internal unsafe class System_TimeSpan
{
	[UnmanagedCallersOnly(EntryPoint = "System_TimeSpan_Add")]
	internal static void* /* System.TimeSpan */ System_TimeSpan_Add(void* /* System.TimeSpan */ __self, void* /* System.TimeSpan */ ts, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.TimeSpan __selfConverted = InteropUtils.GetInstance<System.TimeSpan>(__self);
	
		System.TimeSpan tsConverted = InteropUtils.GetInstance<System.TimeSpan>(ts);
	
	    try {
			System.TimeSpan __returnValue = __selfConverted.Add(tsConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeSpan_Compare")]
	internal static int /* System.Int32 */ System_TimeSpan_Compare(void* /* System.TimeSpan */ t1, void* /* System.TimeSpan */ t2, void** /* System.Exception */ __outException)
	{
		System.TimeSpan t1Converted = InteropUtils.GetInstance<System.TimeSpan>(t1);
		System.TimeSpan t2Converted = InteropUtils.GetInstance<System.TimeSpan>(t2);
	
	    try {
			System.Int32 __returnValue = System.TimeSpan.Compare(t1Converted, t2Converted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeSpan_CompareTo")]
	internal static int /* System.Int32 */ System_TimeSpan_CompareTo(void* /* System.TimeSpan */ __self, void* /* System.Object */ value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.TimeSpan __selfConverted = InteropUtils.GetInstance<System.TimeSpan>(__self);
	
		System.Object valueConverted = InteropUtils.GetInstance<System.Object>(value);
	
	    try {
			System.Int32 __returnValue = __selfConverted.CompareTo(valueConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeSpan_CompareTo_1")]
	internal static int /* System.Int32 */ System_TimeSpan_CompareTo_1(void* /* System.TimeSpan */ __self, void* /* System.TimeSpan */ value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.TimeSpan __selfConverted = InteropUtils.GetInstance<System.TimeSpan>(__self);
	
		System.TimeSpan valueConverted = InteropUtils.GetInstance<System.TimeSpan>(value);
	
	    try {
			System.Int32 __returnValue = __selfConverted.CompareTo(valueConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeSpan_FromDays")]
	internal static void* /* System.TimeSpan */ System_TimeSpan_FromDays(double /* System.Double */ value, void** /* System.Exception */ __outException)
	{
	
	    try {
			System.TimeSpan __returnValue = System.TimeSpan.FromDays(value);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeSpan_Duration")]
	internal static void* /* System.TimeSpan */ System_TimeSpan_Duration(void* /* System.TimeSpan */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.TimeSpan __selfConverted = InteropUtils.GetInstance<System.TimeSpan>(__self);
	
	
	    try {
			System.TimeSpan __returnValue = __selfConverted.Duration();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeSpan_Equals")]
	internal static byte /* System.Boolean */ System_TimeSpan_Equals(void* /* System.TimeSpan */ __self, void* /* System.Object */ value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.TimeSpan __selfConverted = InteropUtils.GetInstance<System.TimeSpan>(__self);
	
		System.Object valueConverted = InteropUtils.GetInstance<System.Object>(value);
	
	    try {
			System.Boolean __returnValue = __selfConverted.Equals(valueConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeSpan_Equals_1")]
	internal static byte /* System.Boolean */ System_TimeSpan_Equals_1(void* /* System.TimeSpan */ __self, void* /* System.TimeSpan */ obj, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.TimeSpan __selfConverted = InteropUtils.GetInstance<System.TimeSpan>(__self);
	
		System.TimeSpan objConverted = InteropUtils.GetInstance<System.TimeSpan>(obj);
	
	    try {
			System.Boolean __returnValue = __selfConverted.Equals(objConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeSpan_Equals_2")]
	internal static byte /* System.Boolean */ System_TimeSpan_Equals_2(void* /* System.TimeSpan */ t1, void* /* System.TimeSpan */ t2, void** /* System.Exception */ __outException)
	{
		System.TimeSpan t1Converted = InteropUtils.GetInstance<System.TimeSpan>(t1);
		System.TimeSpan t2Converted = InteropUtils.GetInstance<System.TimeSpan>(t2);
	
	    try {
			System.Boolean __returnValue = System.TimeSpan.Equals(t1Converted, t2Converted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeSpan_GetHashCode")]
	internal static int /* System.Int32 */ System_TimeSpan_GetHashCode(void* /* System.TimeSpan */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.TimeSpan __selfConverted = InteropUtils.GetInstance<System.TimeSpan>(__self);
	
	
	    try {
			System.Int32 __returnValue = __selfConverted.GetHashCode();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeSpan_FromHours")]
	internal static void* /* System.TimeSpan */ System_TimeSpan_FromHours(double /* System.Double */ value, void** /* System.Exception */ __outException)
	{
	
	    try {
			System.TimeSpan __returnValue = System.TimeSpan.FromHours(value);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeSpan_FromMilliseconds")]
	internal static void* /* System.TimeSpan */ System_TimeSpan_FromMilliseconds(double /* System.Double */ value, void** /* System.Exception */ __outException)
	{
	
	    try {
			System.TimeSpan __returnValue = System.TimeSpan.FromMilliseconds(value);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeSpan_FromMicroseconds")]
	internal static void* /* System.TimeSpan */ System_TimeSpan_FromMicroseconds(double /* System.Double */ value, void** /* System.Exception */ __outException)
	{
	
	    try {
			System.TimeSpan __returnValue = System.TimeSpan.FromMicroseconds(value);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeSpan_FromMinutes")]
	internal static void* /* System.TimeSpan */ System_TimeSpan_FromMinutes(double /* System.Double */ value, void** /* System.Exception */ __outException)
	{
	
	    try {
			System.TimeSpan __returnValue = System.TimeSpan.FromMinutes(value);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeSpan_Negate")]
	internal static void* /* System.TimeSpan */ System_TimeSpan_Negate(void* /* System.TimeSpan */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.TimeSpan __selfConverted = InteropUtils.GetInstance<System.TimeSpan>(__self);
	
	
	    try {
			System.TimeSpan __returnValue = __selfConverted.Negate();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeSpan_FromSeconds")]
	internal static void* /* System.TimeSpan */ System_TimeSpan_FromSeconds(double /* System.Double */ value, void** /* System.Exception */ __outException)
	{
	
	    try {
			System.TimeSpan __returnValue = System.TimeSpan.FromSeconds(value);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeSpan_Subtract")]
	internal static void* /* System.TimeSpan */ System_TimeSpan_Subtract(void* /* System.TimeSpan */ __self, void* /* System.TimeSpan */ ts, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.TimeSpan __selfConverted = InteropUtils.GetInstance<System.TimeSpan>(__self);
	
		System.TimeSpan tsConverted = InteropUtils.GetInstance<System.TimeSpan>(ts);
	
	    try {
			System.TimeSpan __returnValue = __selfConverted.Subtract(tsConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeSpan_Multiply")]
	internal static void* /* System.TimeSpan */ System_TimeSpan_Multiply(void* /* System.TimeSpan */ __self, double /* System.Double */ factor, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.TimeSpan __selfConverted = InteropUtils.GetInstance<System.TimeSpan>(__self);
	
	
	    try {
			System.TimeSpan __returnValue = __selfConverted.Multiply(factor);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeSpan_Divide")]
	internal static void* /* System.TimeSpan */ System_TimeSpan_Divide(void* /* System.TimeSpan */ __self, double /* System.Double */ divisor, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.TimeSpan __selfConverted = InteropUtils.GetInstance<System.TimeSpan>(__self);
	
	
	    try {
			System.TimeSpan __returnValue = __selfConverted.Divide(divisor);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeSpan_Divide_1")]
	internal static double /* System.Double */ System_TimeSpan_Divide_1(void* /* System.TimeSpan */ __self, void* /* System.TimeSpan */ ts, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.TimeSpan __selfConverted = InteropUtils.GetInstance<System.TimeSpan>(__self);
	
		System.TimeSpan tsConverted = InteropUtils.GetInstance<System.TimeSpan>(ts);
	
	    try {
			System.Double __returnValue = __selfConverted.Divide(tsConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeSpan_FromTicks")]
	internal static void* /* System.TimeSpan */ System_TimeSpan_FromTicks(long /* System.Int64 */ value, void** /* System.Exception */ __outException)
	{
	
	    try {
			System.TimeSpan __returnValue = System.TimeSpan.FromTicks(value);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeSpan_Parse")]
	internal static void* /* System.TimeSpan */ System_TimeSpan_Parse(void* /* System.String */ s, void** /* System.Exception */ __outException)
	{
		System.String sConverted = InteropUtils.GetInstance<System.String>(s);
	
	    try {
			System.TimeSpan __returnValue = System.TimeSpan.Parse(sConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeSpan_Parse_1")]
	internal static void* /* System.TimeSpan */ System_TimeSpan_Parse_1(void* /* System.String */ input, void* /* System.IFormatProvider */ formatProvider, void** /* System.Exception */ __outException)
	{
		System.String inputConverted = InteropUtils.GetInstance<System.String>(input);
		System.IFormatProvider formatProviderConverted = InteropUtils.GetInstance<System.IFormatProvider>(formatProvider);
	
	    try {
			System.TimeSpan __returnValue = System.TimeSpan.Parse(inputConverted, formatProviderConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeSpan_ParseExact")]
	internal static void* /* System.TimeSpan */ System_TimeSpan_ParseExact(void* /* System.String */ input, void* /* System.String */ format, void* /* System.IFormatProvider */ formatProvider, void** /* System.Exception */ __outException)
	{
		System.String inputConverted = InteropUtils.GetInstance<System.String>(input);
		System.String formatConverted = InteropUtils.GetInstance<System.String>(format);
		System.IFormatProvider formatProviderConverted = InteropUtils.GetInstance<System.IFormatProvider>(formatProvider);
	
	    try {
			System.TimeSpan __returnValue = System.TimeSpan.ParseExact(inputConverted, formatConverted, formatProviderConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeSpan_ParseExact_1")]
	internal static void* /* System.TimeSpan */ System_TimeSpan_ParseExact_1(void* /* System.String */ input, void* /* System.String[] */ formats, void* /* System.IFormatProvider */ formatProvider, void** /* System.Exception */ __outException)
	{
		System.String inputConverted = InteropUtils.GetInstance<System.String>(input);
		System.String[] formatsConverted = InteropUtils.GetInstance<System.String[]>(formats);
		System.IFormatProvider formatProviderConverted = InteropUtils.GetInstance<System.IFormatProvider>(formatProvider);
	
	    try {
			System.TimeSpan __returnValue = System.TimeSpan.ParseExact(inputConverted, formatsConverted, formatProviderConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeSpan_ParseExact_2")]
	internal static void* /* System.TimeSpan */ System_TimeSpan_ParseExact_2(void* /* System.String */ input, void* /* System.String */ format, void* /* System.IFormatProvider */ formatProvider, System.Globalization.TimeSpanStyles /* System.Globalization.TimeSpanStyles */ styles, void** /* System.Exception */ __outException)
	{
		System.String inputConverted = InteropUtils.GetInstance<System.String>(input);
		System.String formatConverted = InteropUtils.GetInstance<System.String>(format);
		System.IFormatProvider formatProviderConverted = InteropUtils.GetInstance<System.IFormatProvider>(formatProvider);
	
	    try {
			System.TimeSpan __returnValue = System.TimeSpan.ParseExact(inputConverted, formatConverted, formatProviderConverted, styles);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeSpan_ParseExact_3")]
	internal static void* /* System.TimeSpan */ System_TimeSpan_ParseExact_3(void* /* System.String */ input, void* /* System.String[] */ formats, void* /* System.IFormatProvider */ formatProvider, System.Globalization.TimeSpanStyles /* System.Globalization.TimeSpanStyles */ styles, void** /* System.Exception */ __outException)
	{
		System.String inputConverted = InteropUtils.GetInstance<System.String>(input);
		System.String[] formatsConverted = InteropUtils.GetInstance<System.String[]>(formats);
		System.IFormatProvider formatProviderConverted = InteropUtils.GetInstance<System.IFormatProvider>(formatProvider);
	
	    try {
			System.TimeSpan __returnValue = System.TimeSpan.ParseExact(inputConverted, formatsConverted, formatProviderConverted, styles);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeSpan_TryParse")]
	internal static byte /* System.Boolean */ System_TimeSpan_TryParse(void* /* System.String */ s, void** /* System.TimeSpan */ result, void** /* System.Exception */ __outException)
	{
		System.String sConverted = InteropUtils.GetInstance<System.String>(s);
		System.TimeSpan resultConverted;
	
	    try {
			System.Boolean __returnValue = System.TimeSpan.TryParse(sConverted, out resultConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			if (result is not null) {
				*result = resultConverted.AllocateGCHandleAndGetAddress();
			}
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			if (result is not null) {
				*result = null;
			}
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeSpan_TryParse_1")]
	internal static byte /* System.Boolean */ System_TimeSpan_TryParse_1(void* /* System.String */ input, void* /* System.IFormatProvider */ formatProvider, void** /* System.TimeSpan */ result, void** /* System.Exception */ __outException)
	{
		System.String inputConverted = InteropUtils.GetInstance<System.String>(input);
		System.IFormatProvider formatProviderConverted = InteropUtils.GetInstance<System.IFormatProvider>(formatProvider);
		System.TimeSpan resultConverted;
	
	    try {
			System.Boolean __returnValue = System.TimeSpan.TryParse(inputConverted, formatProviderConverted, out resultConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			if (result is not null) {
				*result = resultConverted.AllocateGCHandleAndGetAddress();
			}
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			if (result is not null) {
				*result = null;
			}
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeSpan_TryParseExact")]
	internal static byte /* System.Boolean */ System_TimeSpan_TryParseExact(void* /* System.String */ input, void* /* System.String */ format, void* /* System.IFormatProvider */ formatProvider, void** /* System.TimeSpan */ result, void** /* System.Exception */ __outException)
	{
		System.String inputConverted = InteropUtils.GetInstance<System.String>(input);
		System.String formatConverted = InteropUtils.GetInstance<System.String>(format);
		System.IFormatProvider formatProviderConverted = InteropUtils.GetInstance<System.IFormatProvider>(formatProvider);
		System.TimeSpan resultConverted;
	
	    try {
			System.Boolean __returnValue = System.TimeSpan.TryParseExact(inputConverted, formatConverted, formatProviderConverted, out resultConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			if (result is not null) {
				*result = resultConverted.AllocateGCHandleAndGetAddress();
			}
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			if (result is not null) {
				*result = null;
			}
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeSpan_TryParseExact_1")]
	internal static byte /* System.Boolean */ System_TimeSpan_TryParseExact_1(void* /* System.String */ input, void* /* System.String[] */ formats, void* /* System.IFormatProvider */ formatProvider, void** /* System.TimeSpan */ result, void** /* System.Exception */ __outException)
	{
		System.String inputConverted = InteropUtils.GetInstance<System.String>(input);
		System.String[] formatsConverted = InteropUtils.GetInstance<System.String[]>(formats);
		System.IFormatProvider formatProviderConverted = InteropUtils.GetInstance<System.IFormatProvider>(formatProvider);
		System.TimeSpan resultConverted;
	
	    try {
			System.Boolean __returnValue = System.TimeSpan.TryParseExact(inputConverted, formatsConverted, formatProviderConverted, out resultConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			if (result is not null) {
				*result = resultConverted.AllocateGCHandleAndGetAddress();
			}
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			if (result is not null) {
				*result = null;
			}
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeSpan_TryParseExact_2")]
	internal static byte /* System.Boolean */ System_TimeSpan_TryParseExact_2(void* /* System.String */ input, void* /* System.String */ format, void* /* System.IFormatProvider */ formatProvider, System.Globalization.TimeSpanStyles /* System.Globalization.TimeSpanStyles */ styles, void** /* System.TimeSpan */ result, void** /* System.Exception */ __outException)
	{
		System.String inputConverted = InteropUtils.GetInstance<System.String>(input);
		System.String formatConverted = InteropUtils.GetInstance<System.String>(format);
		System.IFormatProvider formatProviderConverted = InteropUtils.GetInstance<System.IFormatProvider>(formatProvider);
		System.TimeSpan resultConverted;
	
	    try {
			System.Boolean __returnValue = System.TimeSpan.TryParseExact(inputConverted, formatConverted, formatProviderConverted, styles, out resultConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			if (result is not null) {
				*result = resultConverted.AllocateGCHandleAndGetAddress();
			}
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			if (result is not null) {
				*result = null;
			}
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeSpan_TryParseExact_3")]
	internal static byte /* System.Boolean */ System_TimeSpan_TryParseExact_3(void* /* System.String */ input, void* /* System.String[] */ formats, void* /* System.IFormatProvider */ formatProvider, System.Globalization.TimeSpanStyles /* System.Globalization.TimeSpanStyles */ styles, void** /* System.TimeSpan */ result, void** /* System.Exception */ __outException)
	{
		System.String inputConverted = InteropUtils.GetInstance<System.String>(input);
		System.String[] formatsConverted = InteropUtils.GetInstance<System.String[]>(formats);
		System.IFormatProvider formatProviderConverted = InteropUtils.GetInstance<System.IFormatProvider>(formatProvider);
		System.TimeSpan resultConverted;
	
	    try {
			System.Boolean __returnValue = System.TimeSpan.TryParseExact(inputConverted, formatsConverted, formatProviderConverted, styles, out resultConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			if (result is not null) {
				*result = resultConverted.AllocateGCHandleAndGetAddress();
			}
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			if (result is not null) {
				*result = null;
			}
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeSpan_ToString")]
	internal static void* /* System.String */ System_TimeSpan_ToString(void* /* System.TimeSpan */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.TimeSpan __selfConverted = InteropUtils.GetInstance<System.TimeSpan>(__self);
	
	
	    try {
			System.String __returnValue = __selfConverted.ToString();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeSpan_ToString_1")]
	internal static void* /* System.String */ System_TimeSpan_ToString_1(void* /* System.TimeSpan */ __self, void* /* System.String */ format, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.TimeSpan __selfConverted = InteropUtils.GetInstance<System.TimeSpan>(__self);
	
		System.String formatConverted = InteropUtils.GetInstance<System.String>(format);
	
	    try {
			System.String __returnValue = __selfConverted.ToString(formatConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeSpan_ToString_2")]
	internal static void* /* System.String */ System_TimeSpan_ToString_2(void* /* System.TimeSpan */ __self, void* /* System.String */ format, void* /* System.IFormatProvider */ formatProvider, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.TimeSpan __selfConverted = InteropUtils.GetInstance<System.TimeSpan>(__self);
	
		System.String formatConverted = InteropUtils.GetInstance<System.String>(format);
		System.IFormatProvider formatProviderConverted = InteropUtils.GetInstance<System.IFormatProvider>(formatProvider);
	
	    try {
			System.String __returnValue = __selfConverted.ToString(formatConverted, formatProviderConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeSpan_Create")]
	internal static void* /* System.TimeSpan */ System_TimeSpan_Create(long /* System.Int64 */ ticks, void** /* System.Exception */ __outException)
	{
	
	    try {
			System.TimeSpan __returnValue = new System.TimeSpan(ticks);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeSpan_Create_1")]
	internal static void* /* System.TimeSpan */ System_TimeSpan_Create_1(int /* System.Int32 */ hours, int /* System.Int32 */ minutes, int /* System.Int32 */ seconds, void** /* System.Exception */ __outException)
	{
	
	    try {
			System.TimeSpan __returnValue = new System.TimeSpan(hours, minutes, seconds);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeSpan_Create_2")]
	internal static void* /* System.TimeSpan */ System_TimeSpan_Create_2(int /* System.Int32 */ days, int /* System.Int32 */ hours, int /* System.Int32 */ minutes, int /* System.Int32 */ seconds, void** /* System.Exception */ __outException)
	{
	
	    try {
			System.TimeSpan __returnValue = new System.TimeSpan(days, hours, minutes, seconds);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeSpan_Create_3")]
	internal static void* /* System.TimeSpan */ System_TimeSpan_Create_3(int /* System.Int32 */ days, int /* System.Int32 */ hours, int /* System.Int32 */ minutes, int /* System.Int32 */ seconds, int /* System.Int32 */ milliseconds, void** /* System.Exception */ __outException)
	{
	
	    try {
			System.TimeSpan __returnValue = new System.TimeSpan(days, hours, minutes, seconds, milliseconds);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeSpan_Create_4")]
	internal static void* /* System.TimeSpan */ System_TimeSpan_Create_4(int /* System.Int32 */ days, int /* System.Int32 */ hours, int /* System.Int32 */ minutes, int /* System.Int32 */ seconds, int /* System.Int32 */ milliseconds, int /* System.Int32 */ microseconds, void** /* System.Exception */ __outException)
	{
	
	    try {
			System.TimeSpan __returnValue = new System.TimeSpan(days, hours, minutes, seconds, milliseconds, microseconds);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeSpan_Ticks_Get")]
	internal static long /* System.Int64 */ System_TimeSpan_Ticks_Get(void* /* System.TimeSpan */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.TimeSpan __selfConverted = InteropUtils.GetInstance<System.TimeSpan>(__self);
	
	
	    try {
			System.Int64 __returnValue = __selfConverted.Ticks;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeSpan_Days_Get")]
	internal static int /* System.Int32 */ System_TimeSpan_Days_Get(void* /* System.TimeSpan */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.TimeSpan __selfConverted = InteropUtils.GetInstance<System.TimeSpan>(__self);
	
	
	    try {
			System.Int32 __returnValue = __selfConverted.Days;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeSpan_Hours_Get")]
	internal static int /* System.Int32 */ System_TimeSpan_Hours_Get(void* /* System.TimeSpan */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.TimeSpan __selfConverted = InteropUtils.GetInstance<System.TimeSpan>(__self);
	
	
	    try {
			System.Int32 __returnValue = __selfConverted.Hours;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeSpan_Milliseconds_Get")]
	internal static int /* System.Int32 */ System_TimeSpan_Milliseconds_Get(void* /* System.TimeSpan */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.TimeSpan __selfConverted = InteropUtils.GetInstance<System.TimeSpan>(__self);
	
	
	    try {
			System.Int32 __returnValue = __selfConverted.Milliseconds;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeSpan_Microseconds_Get")]
	internal static int /* System.Int32 */ System_TimeSpan_Microseconds_Get(void* /* System.TimeSpan */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.TimeSpan __selfConverted = InteropUtils.GetInstance<System.TimeSpan>(__self);
	
	
	    try {
			System.Int32 __returnValue = __selfConverted.Microseconds;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeSpan_Nanoseconds_Get")]
	internal static int /* System.Int32 */ System_TimeSpan_Nanoseconds_Get(void* /* System.TimeSpan */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.TimeSpan __selfConverted = InteropUtils.GetInstance<System.TimeSpan>(__self);
	
	
	    try {
			System.Int32 __returnValue = __selfConverted.Nanoseconds;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeSpan_Minutes_Get")]
	internal static int /* System.Int32 */ System_TimeSpan_Minutes_Get(void* /* System.TimeSpan */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.TimeSpan __selfConverted = InteropUtils.GetInstance<System.TimeSpan>(__self);
	
	
	    try {
			System.Int32 __returnValue = __selfConverted.Minutes;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeSpan_Seconds_Get")]
	internal static int /* System.Int32 */ System_TimeSpan_Seconds_Get(void* /* System.TimeSpan */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.TimeSpan __selfConverted = InteropUtils.GetInstance<System.TimeSpan>(__self);
	
	
	    try {
			System.Int32 __returnValue = __selfConverted.Seconds;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeSpan_TotalDays_Get")]
	internal static double /* System.Double */ System_TimeSpan_TotalDays_Get(void* /* System.TimeSpan */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.TimeSpan __selfConverted = InteropUtils.GetInstance<System.TimeSpan>(__self);
	
	
	    try {
			System.Double __returnValue = __selfConverted.TotalDays;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeSpan_TotalHours_Get")]
	internal static double /* System.Double */ System_TimeSpan_TotalHours_Get(void* /* System.TimeSpan */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.TimeSpan __selfConverted = InteropUtils.GetInstance<System.TimeSpan>(__self);
	
	
	    try {
			System.Double __returnValue = __selfConverted.TotalHours;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeSpan_TotalMilliseconds_Get")]
	internal static double /* System.Double */ System_TimeSpan_TotalMilliseconds_Get(void* /* System.TimeSpan */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.TimeSpan __selfConverted = InteropUtils.GetInstance<System.TimeSpan>(__self);
	
	
	    try {
			System.Double __returnValue = __selfConverted.TotalMilliseconds;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeSpan_TotalMicroseconds_Get")]
	internal static double /* System.Double */ System_TimeSpan_TotalMicroseconds_Get(void* /* System.TimeSpan */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.TimeSpan __selfConverted = InteropUtils.GetInstance<System.TimeSpan>(__self);
	
	
	    try {
			System.Double __returnValue = __selfConverted.TotalMicroseconds;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeSpan_TotalNanoseconds_Get")]
	internal static double /* System.Double */ System_TimeSpan_TotalNanoseconds_Get(void* /* System.TimeSpan */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.TimeSpan __selfConverted = InteropUtils.GetInstance<System.TimeSpan>(__self);
	
	
	    try {
			System.Double __returnValue = __selfConverted.TotalNanoseconds;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeSpan_TotalMinutes_Get")]
	internal static double /* System.Double */ System_TimeSpan_TotalMinutes_Get(void* /* System.TimeSpan */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.TimeSpan __selfConverted = InteropUtils.GetInstance<System.TimeSpan>(__self);
	
	
	    try {
			System.Double __returnValue = __selfConverted.TotalMinutes;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeSpan_TotalSeconds_Get")]
	internal static double /* System.Double */ System_TimeSpan_TotalSeconds_Get(void* /* System.TimeSpan */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.TimeSpan __selfConverted = InteropUtils.GetInstance<System.TimeSpan>(__self);
	
	
	    try {
			System.Double __returnValue = __selfConverted.TotalSeconds;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeSpan_Zero_Get")]
	internal static void* /* System.TimeSpan */ System_TimeSpan_Zero_Get()
	{
	
		System.TimeSpan __returnValue = System.TimeSpan.Zero;
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeSpan_MaxValue_Get")]
	internal static void* /* System.TimeSpan */ System_TimeSpan_MaxValue_Get()
	{
	
		System.TimeSpan __returnValue = System.TimeSpan.MaxValue;
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeSpan_MinValue_Get")]
	internal static void* /* System.TimeSpan */ System_TimeSpan_MinValue_Get()
	{
	
		System.TimeSpan __returnValue = System.TimeSpan.MinValue;
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeSpan_NanosecondsPerTick_Get")]
	internal static long /* System.Int64 */ System_TimeSpan_NanosecondsPerTick_Get()
	{
	
		System.Int64 __returnValue = System.TimeSpan.NanosecondsPerTick;
		return __returnValue;
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeSpan_TicksPerMicrosecond_Get")]
	internal static long /* System.Int64 */ System_TimeSpan_TicksPerMicrosecond_Get()
	{
	
		System.Int64 __returnValue = System.TimeSpan.TicksPerMicrosecond;
		return __returnValue;
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeSpan_TicksPerMillisecond_Get")]
	internal static long /* System.Int64 */ System_TimeSpan_TicksPerMillisecond_Get()
	{
	
		System.Int64 __returnValue = System.TimeSpan.TicksPerMillisecond;
		return __returnValue;
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeSpan_TicksPerSecond_Get")]
	internal static long /* System.Int64 */ System_TimeSpan_TicksPerSecond_Get()
	{
	
		System.Int64 __returnValue = System.TimeSpan.TicksPerSecond;
		return __returnValue;
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeSpan_TicksPerMinute_Get")]
	internal static long /* System.Int64 */ System_TimeSpan_TicksPerMinute_Get()
	{
	
		System.Int64 __returnValue = System.TimeSpan.TicksPerMinute;
		return __returnValue;
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeSpan_TicksPerHour_Get")]
	internal static long /* System.Int64 */ System_TimeSpan_TicksPerHour_Get()
	{
	
		System.Int64 __returnValue = System.TimeSpan.TicksPerHour;
		return __returnValue;
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeSpan_TicksPerDay_Get")]
	internal static long /* System.Int64 */ System_TimeSpan_TicksPerDay_Get()
	{
	
		System.Int64 __returnValue = System.TimeSpan.TicksPerDay;
		return __returnValue;
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeSpan_Create_5")]
	internal static void* /* System.TimeSpan */ System_TimeSpan_Create_5(void** /* System.Exception */ __outException)
	{
	
	    try {
			System.TimeSpan __returnValue = new System.TimeSpan();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeSpan_TypeOf")]
	internal static void* /* System.Type */ System_TimeSpan_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.TimeSpan);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeSpan_Destroy")]
	internal static void /* System.Void */ System_TimeSpan_Destroy(void* /* System.TimeSpan */ __self)
	{
	
		InteropUtils.FreeIfAllocated(__self);
	}
	
}




internal unsafe class System_Globalization_TimeSpanStyles
{
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_TimeSpanStyles_TypeOf")]
	internal static void* /* System.Type */ System_Globalization_TimeSpanStyles_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.Globalization.TimeSpanStyles);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
}



internal unsafe class System_DateTimeKind
{
	[UnmanagedCallersOnly(EntryPoint = "System_DateTimeKind_TypeOf")]
	internal static void* /* System.Type */ System_DateTimeKind_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.DateTimeKind);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
}


internal unsafe class System_DayOfWeek
{
	[UnmanagedCallersOnly(EntryPoint = "System_DayOfWeek_TypeOf")]
	internal static void* /* System.Type */ System_DayOfWeek_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.DayOfWeek);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
}


internal unsafe class System_Globalization_DateTimeStyles
{
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_DateTimeStyles_TypeOf")]
	internal static void* /* System.Type */ System_Globalization_DateTimeStyles_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.Globalization.DateTimeStyles);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
}



internal unsafe class System_DateOnly
{
	[UnmanagedCallersOnly(EntryPoint = "System_DateOnly_FromDayNumber")]
	internal static void* /* System.DateOnly */ System_DateOnly_FromDayNumber(int /* System.Int32 */ dayNumber, void** /* System.Exception */ __outException)
	{
	
	    try {
			System.DateOnly __returnValue = System.DateOnly.FromDayNumber(dayNumber);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateOnly_AddDays")]
	internal static void* /* System.DateOnly */ System_DateOnly_AddDays(void* /* System.DateOnly */ __self, int /* System.Int32 */ value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.DateOnly __selfConverted = InteropUtils.GetInstance<System.DateOnly>(__self);
	
	
	    try {
			System.DateOnly __returnValue = __selfConverted.AddDays(value);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateOnly_AddMonths")]
	internal static void* /* System.DateOnly */ System_DateOnly_AddMonths(void* /* System.DateOnly */ __self, int /* System.Int32 */ value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.DateOnly __selfConverted = InteropUtils.GetInstance<System.DateOnly>(__self);
	
	
	    try {
			System.DateOnly __returnValue = __selfConverted.AddMonths(value);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateOnly_AddYears")]
	internal static void* /* System.DateOnly */ System_DateOnly_AddYears(void* /* System.DateOnly */ __self, int /* System.Int32 */ value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.DateOnly __selfConverted = InteropUtils.GetInstance<System.DateOnly>(__self);
	
	
	    try {
			System.DateOnly __returnValue = __selfConverted.AddYears(value);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateOnly_Deconstruct")]
	internal static void /* System.Void */ System_DateOnly_Deconstruct(void* /* System.DateOnly */ __self, int* /* System.Int32 */ year, int* /* System.Int32 */ month, int* /* System.Int32 */ day, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.DateOnly __selfConverted = InteropUtils.GetInstance<System.DateOnly>(__self);
	
		System.Int32 yearConverted;
		System.Int32 monthConverted;
		System.Int32 dayConverted;
	
	    try {
			__selfConverted.Deconstruct(out yearConverted, out monthConverted, out dayConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			if (year is not null) {
				*year = yearConverted;
			}
	
			if (month is not null) {
				*month = monthConverted;
			}
	
			if (day is not null) {
				*day = dayConverted;
			}
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			if (year is not null) {
				*year = -1;
			}
	
			if (month is not null) {
				*month = -1;
			}
	
			if (day is not null) {
				*day = -1;
			}
	
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateOnly_ToDateTime")]
	internal static void* /* System.DateTime */ System_DateOnly_ToDateTime(void* /* System.DateOnly */ __self, void* /* System.TimeOnly */ time, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.DateOnly __selfConverted = InteropUtils.GetInstance<System.DateOnly>(__self);
	
		System.TimeOnly timeConverted = InteropUtils.GetInstance<System.TimeOnly>(time);
	
	    try {
			System.DateTime __returnValue = __selfConverted.ToDateTime(timeConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateOnly_ToDateTime_1")]
	internal static void* /* System.DateTime */ System_DateOnly_ToDateTime_1(void* /* System.DateOnly */ __self, void* /* System.TimeOnly */ time, System.DateTimeKind /* System.DateTimeKind */ kind, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.DateOnly __selfConverted = InteropUtils.GetInstance<System.DateOnly>(__self);
	
		System.TimeOnly timeConverted = InteropUtils.GetInstance<System.TimeOnly>(time);
	
	    try {
			System.DateTime __returnValue = __selfConverted.ToDateTime(timeConverted, kind);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateOnly_FromDateTime")]
	internal static void* /* System.DateOnly */ System_DateOnly_FromDateTime(void* /* System.DateTime */ dateTime, void** /* System.Exception */ __outException)
	{
		System.DateTime dateTimeConverted = InteropUtils.GetInstance<System.DateTime>(dateTime);
	
	    try {
			System.DateOnly __returnValue = System.DateOnly.FromDateTime(dateTimeConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateOnly_CompareTo")]
	internal static int /* System.Int32 */ System_DateOnly_CompareTo(void* /* System.DateOnly */ __self, void* /* System.DateOnly */ value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.DateOnly __selfConverted = InteropUtils.GetInstance<System.DateOnly>(__self);
	
		System.DateOnly valueConverted = InteropUtils.GetInstance<System.DateOnly>(value);
	
	    try {
			System.Int32 __returnValue = __selfConverted.CompareTo(valueConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateOnly_CompareTo_1")]
	internal static int /* System.Int32 */ System_DateOnly_CompareTo_1(void* /* System.DateOnly */ __self, void* /* System.Object */ value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.DateOnly __selfConverted = InteropUtils.GetInstance<System.DateOnly>(__self);
	
		System.Object valueConverted = InteropUtils.GetInstance<System.Object>(value);
	
	    try {
			System.Int32 __returnValue = __selfConverted.CompareTo(valueConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateOnly_Equals")]
	internal static byte /* System.Boolean */ System_DateOnly_Equals(void* /* System.DateOnly */ __self, void* /* System.DateOnly */ value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.DateOnly __selfConverted = InteropUtils.GetInstance<System.DateOnly>(__self);
	
		System.DateOnly valueConverted = InteropUtils.GetInstance<System.DateOnly>(value);
	
	    try {
			System.Boolean __returnValue = __selfConverted.Equals(valueConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateOnly_Equals_1")]
	internal static byte /* System.Boolean */ System_DateOnly_Equals_1(void* /* System.DateOnly */ __self, void* /* System.Object */ value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.DateOnly __selfConverted = InteropUtils.GetInstance<System.DateOnly>(__self);
	
		System.Object valueConverted = InteropUtils.GetInstance<System.Object>(value);
	
	    try {
			System.Boolean __returnValue = __selfConverted.Equals(valueConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateOnly_GetHashCode")]
	internal static int /* System.Int32 */ System_DateOnly_GetHashCode(void* /* System.DateOnly */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.DateOnly __selfConverted = InteropUtils.GetInstance<System.DateOnly>(__self);
	
	
	    try {
			System.Int32 __returnValue = __selfConverted.GetHashCode();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateOnly_Parse")]
	internal static void* /* System.DateOnly */ System_DateOnly_Parse(void* /* System.String */ s, void** /* System.Exception */ __outException)
	{
		System.String sConverted = InteropUtils.GetInstance<System.String>(s);
	
	    try {
			System.DateOnly __returnValue = System.DateOnly.Parse(sConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateOnly_Parse_1")]
	internal static void* /* System.DateOnly */ System_DateOnly_Parse_1(void* /* System.String */ s, void* /* System.IFormatProvider */ provider, System.Globalization.DateTimeStyles /* System.Globalization.DateTimeStyles */ style, void** /* System.Exception */ __outException)
	{
		System.String sConverted = InteropUtils.GetInstance<System.String>(s);
		System.IFormatProvider providerConverted = InteropUtils.GetInstance<System.IFormatProvider>(provider);
	
	    try {
			System.DateOnly __returnValue = System.DateOnly.Parse(sConverted, providerConverted, style);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateOnly_ParseExact")]
	internal static void* /* System.DateOnly */ System_DateOnly_ParseExact(void* /* System.String */ s, void* /* System.String */ format, void** /* System.Exception */ __outException)
	{
		System.String sConverted = InteropUtils.GetInstance<System.String>(s);
		System.String formatConverted = InteropUtils.GetInstance<System.String>(format);
	
	    try {
			System.DateOnly __returnValue = System.DateOnly.ParseExact(sConverted, formatConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateOnly_ParseExact_1")]
	internal static void* /* System.DateOnly */ System_DateOnly_ParseExact_1(void* /* System.String */ s, void* /* System.String */ format, void* /* System.IFormatProvider */ provider, System.Globalization.DateTimeStyles /* System.Globalization.DateTimeStyles */ style, void** /* System.Exception */ __outException)
	{
		System.String sConverted = InteropUtils.GetInstance<System.String>(s);
		System.String formatConverted = InteropUtils.GetInstance<System.String>(format);
		System.IFormatProvider providerConverted = InteropUtils.GetInstance<System.IFormatProvider>(provider);
	
	    try {
			System.DateOnly __returnValue = System.DateOnly.ParseExact(sConverted, formatConverted, providerConverted, style);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateOnly_ParseExact_2")]
	internal static void* /* System.DateOnly */ System_DateOnly_ParseExact_2(void* /* System.String */ s, void* /* System.String[] */ formats, void** /* System.Exception */ __outException)
	{
		System.String sConverted = InteropUtils.GetInstance<System.String>(s);
		System.String[] formatsConverted = InteropUtils.GetInstance<System.String[]>(formats);
	
	    try {
			System.DateOnly __returnValue = System.DateOnly.ParseExact(sConverted, formatsConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateOnly_ParseExact_3")]
	internal static void* /* System.DateOnly */ System_DateOnly_ParseExact_3(void* /* System.String */ s, void* /* System.String[] */ formats, void* /* System.IFormatProvider */ provider, System.Globalization.DateTimeStyles /* System.Globalization.DateTimeStyles */ style, void** /* System.Exception */ __outException)
	{
		System.String sConverted = InteropUtils.GetInstance<System.String>(s);
		System.String[] formatsConverted = InteropUtils.GetInstance<System.String[]>(formats);
		System.IFormatProvider providerConverted = InteropUtils.GetInstance<System.IFormatProvider>(provider);
	
	    try {
			System.DateOnly __returnValue = System.DateOnly.ParseExact(sConverted, formatsConverted, providerConverted, style);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateOnly_TryParse")]
	internal static byte /* System.Boolean */ System_DateOnly_TryParse(void* /* System.String */ s, void** /* System.DateOnly */ result, void** /* System.Exception */ __outException)
	{
		System.String sConverted = InteropUtils.GetInstance<System.String>(s);
		System.DateOnly resultConverted;
	
	    try {
			System.Boolean __returnValue = System.DateOnly.TryParse(sConverted, out resultConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			if (result is not null) {
				*result = resultConverted.AllocateGCHandleAndGetAddress();
			}
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			if (result is not null) {
				*result = null;
			}
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateOnly_TryParse_1")]
	internal static byte /* System.Boolean */ System_DateOnly_TryParse_1(void* /* System.String */ s, void* /* System.IFormatProvider */ provider, System.Globalization.DateTimeStyles /* System.Globalization.DateTimeStyles */ style, void** /* System.DateOnly */ result, void** /* System.Exception */ __outException)
	{
		System.String sConverted = InteropUtils.GetInstance<System.String>(s);
		System.IFormatProvider providerConverted = InteropUtils.GetInstance<System.IFormatProvider>(provider);
		System.DateOnly resultConverted;
	
	    try {
			System.Boolean __returnValue = System.DateOnly.TryParse(sConverted, providerConverted, style, out resultConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			if (result is not null) {
				*result = resultConverted.AllocateGCHandleAndGetAddress();
			}
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			if (result is not null) {
				*result = null;
			}
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateOnly_TryParseExact")]
	internal static byte /* System.Boolean */ System_DateOnly_TryParseExact(void* /* System.String */ s, void* /* System.String */ format, void** /* System.DateOnly */ result, void** /* System.Exception */ __outException)
	{
		System.String sConverted = InteropUtils.GetInstance<System.String>(s);
		System.String formatConverted = InteropUtils.GetInstance<System.String>(format);
		System.DateOnly resultConverted;
	
	    try {
			System.Boolean __returnValue = System.DateOnly.TryParseExact(sConverted, formatConverted, out resultConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			if (result is not null) {
				*result = resultConverted.AllocateGCHandleAndGetAddress();
			}
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			if (result is not null) {
				*result = null;
			}
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateOnly_TryParseExact_1")]
	internal static byte /* System.Boolean */ System_DateOnly_TryParseExact_1(void* /* System.String */ s, void* /* System.String */ format, void* /* System.IFormatProvider */ provider, System.Globalization.DateTimeStyles /* System.Globalization.DateTimeStyles */ style, void** /* System.DateOnly */ result, void** /* System.Exception */ __outException)
	{
		System.String sConverted = InteropUtils.GetInstance<System.String>(s);
		System.String formatConverted = InteropUtils.GetInstance<System.String>(format);
		System.IFormatProvider providerConverted = InteropUtils.GetInstance<System.IFormatProvider>(provider);
		System.DateOnly resultConverted;
	
	    try {
			System.Boolean __returnValue = System.DateOnly.TryParseExact(sConverted, formatConverted, providerConverted, style, out resultConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			if (result is not null) {
				*result = resultConverted.AllocateGCHandleAndGetAddress();
			}
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			if (result is not null) {
				*result = null;
			}
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateOnly_TryParseExact_2")]
	internal static byte /* System.Boolean */ System_DateOnly_TryParseExact_2(void* /* System.String */ s, void* /* System.String[] */ formats, void** /* System.DateOnly */ result, void** /* System.Exception */ __outException)
	{
		System.String sConverted = InteropUtils.GetInstance<System.String>(s);
		System.String[] formatsConverted = InteropUtils.GetInstance<System.String[]>(formats);
		System.DateOnly resultConverted;
	
	    try {
			System.Boolean __returnValue = System.DateOnly.TryParseExact(sConverted, formatsConverted, out resultConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			if (result is not null) {
				*result = resultConverted.AllocateGCHandleAndGetAddress();
			}
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			if (result is not null) {
				*result = null;
			}
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateOnly_TryParseExact_3")]
	internal static byte /* System.Boolean */ System_DateOnly_TryParseExact_3(void* /* System.String */ s, void* /* System.String[] */ formats, void* /* System.IFormatProvider */ provider, System.Globalization.DateTimeStyles /* System.Globalization.DateTimeStyles */ style, void** /* System.DateOnly */ result, void** /* System.Exception */ __outException)
	{
		System.String sConverted = InteropUtils.GetInstance<System.String>(s);
		System.String[] formatsConverted = InteropUtils.GetInstance<System.String[]>(formats);
		System.IFormatProvider providerConverted = InteropUtils.GetInstance<System.IFormatProvider>(provider);
		System.DateOnly resultConverted;
	
	    try {
			System.Boolean __returnValue = System.DateOnly.TryParseExact(sConverted, formatsConverted, providerConverted, style, out resultConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			if (result is not null) {
				*result = resultConverted.AllocateGCHandleAndGetAddress();
			}
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			if (result is not null) {
				*result = null;
			}
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateOnly_ToLongDateString")]
	internal static void* /* System.String */ System_DateOnly_ToLongDateString(void* /* System.DateOnly */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.DateOnly __selfConverted = InteropUtils.GetInstance<System.DateOnly>(__self);
	
	
	    try {
			System.String __returnValue = __selfConverted.ToLongDateString();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateOnly_ToShortDateString")]
	internal static void* /* System.String */ System_DateOnly_ToShortDateString(void* /* System.DateOnly */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.DateOnly __selfConverted = InteropUtils.GetInstance<System.DateOnly>(__self);
	
	
	    try {
			System.String __returnValue = __selfConverted.ToShortDateString();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateOnly_ToString")]
	internal static void* /* System.String */ System_DateOnly_ToString(void* /* System.DateOnly */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.DateOnly __selfConverted = InteropUtils.GetInstance<System.DateOnly>(__self);
	
	
	    try {
			System.String __returnValue = __selfConverted.ToString();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateOnly_ToString_1")]
	internal static void* /* System.String */ System_DateOnly_ToString_1(void* /* System.DateOnly */ __self, void* /* System.String */ format, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.DateOnly __selfConverted = InteropUtils.GetInstance<System.DateOnly>(__self);
	
		System.String formatConverted = InteropUtils.GetInstance<System.String>(format);
	
	    try {
			System.String __returnValue = __selfConverted.ToString(formatConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateOnly_ToString_2")]
	internal static void* /* System.String */ System_DateOnly_ToString_2(void* /* System.DateOnly */ __self, void* /* System.IFormatProvider */ provider, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.DateOnly __selfConverted = InteropUtils.GetInstance<System.DateOnly>(__self);
	
		System.IFormatProvider providerConverted = InteropUtils.GetInstance<System.IFormatProvider>(provider);
	
	    try {
			System.String __returnValue = __selfConverted.ToString(providerConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateOnly_ToString_3")]
	internal static void* /* System.String */ System_DateOnly_ToString_3(void* /* System.DateOnly */ __self, void* /* System.String */ format, void* /* System.IFormatProvider */ provider, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.DateOnly __selfConverted = InteropUtils.GetInstance<System.DateOnly>(__self);
	
		System.String formatConverted = InteropUtils.GetInstance<System.String>(format);
		System.IFormatProvider providerConverted = InteropUtils.GetInstance<System.IFormatProvider>(provider);
	
	    try {
			System.String __returnValue = __selfConverted.ToString(formatConverted, providerConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateOnly_Parse_2")]
	internal static void* /* System.DateOnly */ System_DateOnly_Parse_2(void* /* System.String */ s, void* /* System.IFormatProvider */ provider, void** /* System.Exception */ __outException)
	{
		System.String sConverted = InteropUtils.GetInstance<System.String>(s);
		System.IFormatProvider providerConverted = InteropUtils.GetInstance<System.IFormatProvider>(provider);
	
	    try {
			System.DateOnly __returnValue = System.DateOnly.Parse(sConverted, providerConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateOnly_TryParse_2")]
	internal static byte /* System.Boolean */ System_DateOnly_TryParse_2(void* /* System.String */ s, void* /* System.IFormatProvider */ provider, void** /* System.DateOnly */ result, void** /* System.Exception */ __outException)
	{
		System.String sConverted = InteropUtils.GetInstance<System.String>(s);
		System.IFormatProvider providerConverted = InteropUtils.GetInstance<System.IFormatProvider>(provider);
		System.DateOnly resultConverted;
	
	    try {
			System.Boolean __returnValue = System.DateOnly.TryParse(sConverted, providerConverted, out resultConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			if (result is not null) {
				*result = resultConverted.AllocateGCHandleAndGetAddress();
			}
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			if (result is not null) {
				*result = null;
			}
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateOnly_Create")]
	internal static void* /* System.DateOnly */ System_DateOnly_Create(int /* System.Int32 */ year, int /* System.Int32 */ month, int /* System.Int32 */ day, void** /* System.Exception */ __outException)
	{
	
	    try {
			System.DateOnly __returnValue = new System.DateOnly(year, month, day);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateOnly_Create_1")]
	internal static void* /* System.DateOnly */ System_DateOnly_Create_1(int /* System.Int32 */ year, int /* System.Int32 */ month, int /* System.Int32 */ day, void* /* System.Globalization.Calendar */ calendar, void** /* System.Exception */ __outException)
	{
		System.Globalization.Calendar calendarConverted = InteropUtils.GetInstance<System.Globalization.Calendar>(calendar);
	
	    try {
			System.DateOnly __returnValue = new System.DateOnly(year, month, day, calendarConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateOnly_MinValue_Get")]
	internal static void* /* System.DateOnly */ System_DateOnly_MinValue_Get(void** /* System.Exception */ __outException)
	{
	
	    try {
			System.DateOnly __returnValue = System.DateOnly.MinValue;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateOnly_MaxValue_Get")]
	internal static void* /* System.DateOnly */ System_DateOnly_MaxValue_Get(void** /* System.Exception */ __outException)
	{
	
	    try {
			System.DateOnly __returnValue = System.DateOnly.MaxValue;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateOnly_Year_Get")]
	internal static int /* System.Int32 */ System_DateOnly_Year_Get(void* /* System.DateOnly */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.DateOnly __selfConverted = InteropUtils.GetInstance<System.DateOnly>(__self);
	
	
	    try {
			System.Int32 __returnValue = __selfConverted.Year;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateOnly_Month_Get")]
	internal static int /* System.Int32 */ System_DateOnly_Month_Get(void* /* System.DateOnly */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.DateOnly __selfConverted = InteropUtils.GetInstance<System.DateOnly>(__self);
	
	
	    try {
			System.Int32 __returnValue = __selfConverted.Month;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateOnly_Day_Get")]
	internal static int /* System.Int32 */ System_DateOnly_Day_Get(void* /* System.DateOnly */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.DateOnly __selfConverted = InteropUtils.GetInstance<System.DateOnly>(__self);
	
	
	    try {
			System.Int32 __returnValue = __selfConverted.Day;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateOnly_DayOfWeek_Get")]
	internal static System.DayOfWeek /* System.DayOfWeek */ System_DateOnly_DayOfWeek_Get(void* /* System.DateOnly */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.DateOnly __selfConverted = InteropUtils.GetInstance<System.DateOnly>(__self);
	
	
	    try {
			System.DayOfWeek __returnValue = __selfConverted.DayOfWeek;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return default(System.DayOfWeek);
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateOnly_DayOfYear_Get")]
	internal static int /* System.Int32 */ System_DateOnly_DayOfYear_Get(void* /* System.DateOnly */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.DateOnly __selfConverted = InteropUtils.GetInstance<System.DateOnly>(__self);
	
	
	    try {
			System.Int32 __returnValue = __selfConverted.DayOfYear;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateOnly_DayNumber_Get")]
	internal static int /* System.Int32 */ System_DateOnly_DayNumber_Get(void* /* System.DateOnly */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.DateOnly __selfConverted = InteropUtils.GetInstance<System.DateOnly>(__self);
	
	
	    try {
			System.Int32 __returnValue = __selfConverted.DayNumber;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateOnly_Create_2")]
	internal static void* /* System.DateOnly */ System_DateOnly_Create_2(void** /* System.Exception */ __outException)
	{
	
	    try {
			System.DateOnly __returnValue = new System.DateOnly();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateOnly_TypeOf")]
	internal static void* /* System.Type */ System_DateOnly_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.DateOnly);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateOnly_Destroy")]
	internal static void /* System.Void */ System_DateOnly_Destroy(void* /* System.DateOnly */ __self)
	{
	
		InteropUtils.FreeIfAllocated(__self);
	}
	
}


internal unsafe class System_TimeOnly
{
	[UnmanagedCallersOnly(EntryPoint = "System_TimeOnly_Add")]
	internal static void* /* System.TimeOnly */ System_TimeOnly_Add(void* /* System.TimeOnly */ __self, void* /* System.TimeSpan */ value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.TimeOnly __selfConverted = InteropUtils.GetInstance<System.TimeOnly>(__self);
	
		System.TimeSpan valueConverted = InteropUtils.GetInstance<System.TimeSpan>(value);
	
	    try {
			System.TimeOnly __returnValue = __selfConverted.Add(valueConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeOnly_Add_1")]
	internal static void* /* System.TimeOnly */ System_TimeOnly_Add_1(void* /* System.TimeOnly */ __self, void* /* System.TimeSpan */ value, int* /* System.Int32 */ wrappedDays, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.TimeOnly __selfConverted = InteropUtils.GetInstance<System.TimeOnly>(__self);
	
		System.TimeSpan valueConverted = InteropUtils.GetInstance<System.TimeSpan>(value);
		System.Int32 wrappedDaysConverted;
	
	    try {
			System.TimeOnly __returnValue = __selfConverted.Add(valueConverted, out wrappedDaysConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			if (wrappedDays is not null) {
				*wrappedDays = wrappedDaysConverted;
			}
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			if (wrappedDays is not null) {
				*wrappedDays = -1;
			}
	
			return null;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeOnly_AddHours")]
	internal static void* /* System.TimeOnly */ System_TimeOnly_AddHours(void* /* System.TimeOnly */ __self, double /* System.Double */ value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.TimeOnly __selfConverted = InteropUtils.GetInstance<System.TimeOnly>(__self);
	
	
	    try {
			System.TimeOnly __returnValue = __selfConverted.AddHours(value);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeOnly_AddHours_1")]
	internal static void* /* System.TimeOnly */ System_TimeOnly_AddHours_1(void* /* System.TimeOnly */ __self, double /* System.Double */ value, int* /* System.Int32 */ wrappedDays, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.TimeOnly __selfConverted = InteropUtils.GetInstance<System.TimeOnly>(__self);
	
		System.Int32 wrappedDaysConverted;
	
	    try {
			System.TimeOnly __returnValue = __selfConverted.AddHours(value, out wrappedDaysConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			if (wrappedDays is not null) {
				*wrappedDays = wrappedDaysConverted;
			}
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			if (wrappedDays is not null) {
				*wrappedDays = -1;
			}
	
			return null;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeOnly_AddMinutes")]
	internal static void* /* System.TimeOnly */ System_TimeOnly_AddMinutes(void* /* System.TimeOnly */ __self, double /* System.Double */ value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.TimeOnly __selfConverted = InteropUtils.GetInstance<System.TimeOnly>(__self);
	
	
	    try {
			System.TimeOnly __returnValue = __selfConverted.AddMinutes(value);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeOnly_AddMinutes_1")]
	internal static void* /* System.TimeOnly */ System_TimeOnly_AddMinutes_1(void* /* System.TimeOnly */ __self, double /* System.Double */ value, int* /* System.Int32 */ wrappedDays, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.TimeOnly __selfConverted = InteropUtils.GetInstance<System.TimeOnly>(__self);
	
		System.Int32 wrappedDaysConverted;
	
	    try {
			System.TimeOnly __returnValue = __selfConverted.AddMinutes(value, out wrappedDaysConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			if (wrappedDays is not null) {
				*wrappedDays = wrappedDaysConverted;
			}
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			if (wrappedDays is not null) {
				*wrappedDays = -1;
			}
	
			return null;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeOnly_IsBetween")]
	internal static byte /* System.Boolean */ System_TimeOnly_IsBetween(void* /* System.TimeOnly */ __self, void* /* System.TimeOnly */ start, void* /* System.TimeOnly */ end, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.TimeOnly __selfConverted = InteropUtils.GetInstance<System.TimeOnly>(__self);
	
		System.TimeOnly startConverted = InteropUtils.GetInstance<System.TimeOnly>(start);
		System.TimeOnly endConverted = InteropUtils.GetInstance<System.TimeOnly>(end);
	
	    try {
			System.Boolean __returnValue = __selfConverted.IsBetween(startConverted, endConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeOnly_Deconstruct")]
	internal static void /* System.Void */ System_TimeOnly_Deconstruct(void* /* System.TimeOnly */ __self, int* /* System.Int32 */ hour, int* /* System.Int32 */ minute, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.TimeOnly __selfConverted = InteropUtils.GetInstance<System.TimeOnly>(__self);
	
		System.Int32 hourConverted;
		System.Int32 minuteConverted;
	
	    try {
			__selfConverted.Deconstruct(out hourConverted, out minuteConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			if (hour is not null) {
				*hour = hourConverted;
			}
	
			if (minute is not null) {
				*minute = minuteConverted;
			}
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			if (hour is not null) {
				*hour = -1;
			}
	
			if (minute is not null) {
				*minute = -1;
			}
	
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeOnly_Deconstruct_1")]
	internal static void /* System.Void */ System_TimeOnly_Deconstruct_1(void* /* System.TimeOnly */ __self, int* /* System.Int32 */ hour, int* /* System.Int32 */ minute, int* /* System.Int32 */ second, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.TimeOnly __selfConverted = InteropUtils.GetInstance<System.TimeOnly>(__self);
	
		System.Int32 hourConverted;
		System.Int32 minuteConverted;
		System.Int32 secondConverted;
	
	    try {
			__selfConverted.Deconstruct(out hourConverted, out minuteConverted, out secondConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			if (hour is not null) {
				*hour = hourConverted;
			}
	
			if (minute is not null) {
				*minute = minuteConverted;
			}
	
			if (second is not null) {
				*second = secondConverted;
			}
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			if (hour is not null) {
				*hour = -1;
			}
	
			if (minute is not null) {
				*minute = -1;
			}
	
			if (second is not null) {
				*second = -1;
			}
	
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeOnly_Deconstruct_2")]
	internal static void /* System.Void */ System_TimeOnly_Deconstruct_2(void* /* System.TimeOnly */ __self, int* /* System.Int32 */ hour, int* /* System.Int32 */ minute, int* /* System.Int32 */ second, int* /* System.Int32 */ millisecond, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.TimeOnly __selfConverted = InteropUtils.GetInstance<System.TimeOnly>(__self);
	
		System.Int32 hourConverted;
		System.Int32 minuteConverted;
		System.Int32 secondConverted;
		System.Int32 millisecondConverted;
	
	    try {
			__selfConverted.Deconstruct(out hourConverted, out minuteConverted, out secondConverted, out millisecondConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			if (hour is not null) {
				*hour = hourConverted;
			}
	
			if (minute is not null) {
				*minute = minuteConverted;
			}
	
			if (second is not null) {
				*second = secondConverted;
			}
	
			if (millisecond is not null) {
				*millisecond = millisecondConverted;
			}
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			if (hour is not null) {
				*hour = -1;
			}
	
			if (minute is not null) {
				*minute = -1;
			}
	
			if (second is not null) {
				*second = -1;
			}
	
			if (millisecond is not null) {
				*millisecond = -1;
			}
	
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeOnly_Deconstruct_3")]
	internal static void /* System.Void */ System_TimeOnly_Deconstruct_3(void* /* System.TimeOnly */ __self, int* /* System.Int32 */ hour, int* /* System.Int32 */ minute, int* /* System.Int32 */ second, int* /* System.Int32 */ millisecond, int* /* System.Int32 */ microsecond, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.TimeOnly __selfConverted = InteropUtils.GetInstance<System.TimeOnly>(__self);
	
		System.Int32 hourConverted;
		System.Int32 minuteConverted;
		System.Int32 secondConverted;
		System.Int32 millisecondConverted;
		System.Int32 microsecondConverted;
	
	    try {
			__selfConverted.Deconstruct(out hourConverted, out minuteConverted, out secondConverted, out millisecondConverted, out microsecondConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			if (hour is not null) {
				*hour = hourConverted;
			}
	
			if (minute is not null) {
				*minute = minuteConverted;
			}
	
			if (second is not null) {
				*second = secondConverted;
			}
	
			if (millisecond is not null) {
				*millisecond = millisecondConverted;
			}
	
			if (microsecond is not null) {
				*microsecond = microsecondConverted;
			}
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			if (hour is not null) {
				*hour = -1;
			}
	
			if (minute is not null) {
				*minute = -1;
			}
	
			if (second is not null) {
				*second = -1;
			}
	
			if (millisecond is not null) {
				*millisecond = -1;
			}
	
			if (microsecond is not null) {
				*microsecond = -1;
			}
	
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeOnly_FromTimeSpan")]
	internal static void* /* System.TimeOnly */ System_TimeOnly_FromTimeSpan(void* /* System.TimeSpan */ timeSpan, void** /* System.Exception */ __outException)
	{
		System.TimeSpan timeSpanConverted = InteropUtils.GetInstance<System.TimeSpan>(timeSpan);
	
	    try {
			System.TimeOnly __returnValue = System.TimeOnly.FromTimeSpan(timeSpanConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeOnly_FromDateTime")]
	internal static void* /* System.TimeOnly */ System_TimeOnly_FromDateTime(void* /* System.DateTime */ dateTime, void** /* System.Exception */ __outException)
	{
		System.DateTime dateTimeConverted = InteropUtils.GetInstance<System.DateTime>(dateTime);
	
	    try {
			System.TimeOnly __returnValue = System.TimeOnly.FromDateTime(dateTimeConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeOnly_ToTimeSpan")]
	internal static void* /* System.TimeSpan */ System_TimeOnly_ToTimeSpan(void* /* System.TimeOnly */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.TimeOnly __selfConverted = InteropUtils.GetInstance<System.TimeOnly>(__self);
	
	
	    try {
			System.TimeSpan __returnValue = __selfConverted.ToTimeSpan();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeOnly_CompareTo")]
	internal static int /* System.Int32 */ System_TimeOnly_CompareTo(void* /* System.TimeOnly */ __self, void* /* System.TimeOnly */ value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.TimeOnly __selfConverted = InteropUtils.GetInstance<System.TimeOnly>(__self);
	
		System.TimeOnly valueConverted = InteropUtils.GetInstance<System.TimeOnly>(value);
	
	    try {
			System.Int32 __returnValue = __selfConverted.CompareTo(valueConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeOnly_CompareTo_1")]
	internal static int /* System.Int32 */ System_TimeOnly_CompareTo_1(void* /* System.TimeOnly */ __self, void* /* System.Object */ value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.TimeOnly __selfConverted = InteropUtils.GetInstance<System.TimeOnly>(__self);
	
		System.Object valueConverted = InteropUtils.GetInstance<System.Object>(value);
	
	    try {
			System.Int32 __returnValue = __selfConverted.CompareTo(valueConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeOnly_Equals")]
	internal static byte /* System.Boolean */ System_TimeOnly_Equals(void* /* System.TimeOnly */ __self, void* /* System.TimeOnly */ value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.TimeOnly __selfConverted = InteropUtils.GetInstance<System.TimeOnly>(__self);
	
		System.TimeOnly valueConverted = InteropUtils.GetInstance<System.TimeOnly>(value);
	
	    try {
			System.Boolean __returnValue = __selfConverted.Equals(valueConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeOnly_Equals_1")]
	internal static byte /* System.Boolean */ System_TimeOnly_Equals_1(void* /* System.TimeOnly */ __self, void* /* System.Object */ value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.TimeOnly __selfConverted = InteropUtils.GetInstance<System.TimeOnly>(__self);
	
		System.Object valueConverted = InteropUtils.GetInstance<System.Object>(value);
	
	    try {
			System.Boolean __returnValue = __selfConverted.Equals(valueConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeOnly_GetHashCode")]
	internal static int /* System.Int32 */ System_TimeOnly_GetHashCode(void* /* System.TimeOnly */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.TimeOnly __selfConverted = InteropUtils.GetInstance<System.TimeOnly>(__self);
	
	
	    try {
			System.Int32 __returnValue = __selfConverted.GetHashCode();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeOnly_Parse")]
	internal static void* /* System.TimeOnly */ System_TimeOnly_Parse(void* /* System.String */ s, void** /* System.Exception */ __outException)
	{
		System.String sConverted = InteropUtils.GetInstance<System.String>(s);
	
	    try {
			System.TimeOnly __returnValue = System.TimeOnly.Parse(sConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeOnly_Parse_1")]
	internal static void* /* System.TimeOnly */ System_TimeOnly_Parse_1(void* /* System.String */ s, void* /* System.IFormatProvider */ provider, System.Globalization.DateTimeStyles /* System.Globalization.DateTimeStyles */ style, void** /* System.Exception */ __outException)
	{
		System.String sConverted = InteropUtils.GetInstance<System.String>(s);
		System.IFormatProvider providerConverted = InteropUtils.GetInstance<System.IFormatProvider>(provider);
	
	    try {
			System.TimeOnly __returnValue = System.TimeOnly.Parse(sConverted, providerConverted, style);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeOnly_ParseExact")]
	internal static void* /* System.TimeOnly */ System_TimeOnly_ParseExact(void* /* System.String */ s, void* /* System.String */ format, void** /* System.Exception */ __outException)
	{
		System.String sConverted = InteropUtils.GetInstance<System.String>(s);
		System.String formatConverted = InteropUtils.GetInstance<System.String>(format);
	
	    try {
			System.TimeOnly __returnValue = System.TimeOnly.ParseExact(sConverted, formatConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeOnly_ParseExact_1")]
	internal static void* /* System.TimeOnly */ System_TimeOnly_ParseExact_1(void* /* System.String */ s, void* /* System.String */ format, void* /* System.IFormatProvider */ provider, System.Globalization.DateTimeStyles /* System.Globalization.DateTimeStyles */ style, void** /* System.Exception */ __outException)
	{
		System.String sConverted = InteropUtils.GetInstance<System.String>(s);
		System.String formatConverted = InteropUtils.GetInstance<System.String>(format);
		System.IFormatProvider providerConverted = InteropUtils.GetInstance<System.IFormatProvider>(provider);
	
	    try {
			System.TimeOnly __returnValue = System.TimeOnly.ParseExact(sConverted, formatConverted, providerConverted, style);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeOnly_ParseExact_2")]
	internal static void* /* System.TimeOnly */ System_TimeOnly_ParseExact_2(void* /* System.String */ s, void* /* System.String[] */ formats, void** /* System.Exception */ __outException)
	{
		System.String sConverted = InteropUtils.GetInstance<System.String>(s);
		System.String[] formatsConverted = InteropUtils.GetInstance<System.String[]>(formats);
	
	    try {
			System.TimeOnly __returnValue = System.TimeOnly.ParseExact(sConverted, formatsConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeOnly_ParseExact_3")]
	internal static void* /* System.TimeOnly */ System_TimeOnly_ParseExact_3(void* /* System.String */ s, void* /* System.String[] */ formats, void* /* System.IFormatProvider */ provider, System.Globalization.DateTimeStyles /* System.Globalization.DateTimeStyles */ style, void** /* System.Exception */ __outException)
	{
		System.String sConverted = InteropUtils.GetInstance<System.String>(s);
		System.String[] formatsConverted = InteropUtils.GetInstance<System.String[]>(formats);
		System.IFormatProvider providerConverted = InteropUtils.GetInstance<System.IFormatProvider>(provider);
	
	    try {
			System.TimeOnly __returnValue = System.TimeOnly.ParseExact(sConverted, formatsConverted, providerConverted, style);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeOnly_TryParse")]
	internal static byte /* System.Boolean */ System_TimeOnly_TryParse(void* /* System.String */ s, void** /* System.TimeOnly */ result, void** /* System.Exception */ __outException)
	{
		System.String sConverted = InteropUtils.GetInstance<System.String>(s);
		System.TimeOnly resultConverted;
	
	    try {
			System.Boolean __returnValue = System.TimeOnly.TryParse(sConverted, out resultConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			if (result is not null) {
				*result = resultConverted.AllocateGCHandleAndGetAddress();
			}
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			if (result is not null) {
				*result = null;
			}
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeOnly_TryParse_1")]
	internal static byte /* System.Boolean */ System_TimeOnly_TryParse_1(void* /* System.String */ s, void* /* System.IFormatProvider */ provider, System.Globalization.DateTimeStyles /* System.Globalization.DateTimeStyles */ style, void** /* System.TimeOnly */ result, void** /* System.Exception */ __outException)
	{
		System.String sConverted = InteropUtils.GetInstance<System.String>(s);
		System.IFormatProvider providerConverted = InteropUtils.GetInstance<System.IFormatProvider>(provider);
		System.TimeOnly resultConverted;
	
	    try {
			System.Boolean __returnValue = System.TimeOnly.TryParse(sConverted, providerConverted, style, out resultConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			if (result is not null) {
				*result = resultConverted.AllocateGCHandleAndGetAddress();
			}
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			if (result is not null) {
				*result = null;
			}
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeOnly_TryParseExact")]
	internal static byte /* System.Boolean */ System_TimeOnly_TryParseExact(void* /* System.String */ s, void* /* System.String */ format, void** /* System.TimeOnly */ result, void** /* System.Exception */ __outException)
	{
		System.String sConverted = InteropUtils.GetInstance<System.String>(s);
		System.String formatConverted = InteropUtils.GetInstance<System.String>(format);
		System.TimeOnly resultConverted;
	
	    try {
			System.Boolean __returnValue = System.TimeOnly.TryParseExact(sConverted, formatConverted, out resultConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			if (result is not null) {
				*result = resultConverted.AllocateGCHandleAndGetAddress();
			}
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			if (result is not null) {
				*result = null;
			}
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeOnly_TryParseExact_1")]
	internal static byte /* System.Boolean */ System_TimeOnly_TryParseExact_1(void* /* System.String */ s, void* /* System.String */ format, void* /* System.IFormatProvider */ provider, System.Globalization.DateTimeStyles /* System.Globalization.DateTimeStyles */ style, void** /* System.TimeOnly */ result, void** /* System.Exception */ __outException)
	{
		System.String sConverted = InteropUtils.GetInstance<System.String>(s);
		System.String formatConverted = InteropUtils.GetInstance<System.String>(format);
		System.IFormatProvider providerConverted = InteropUtils.GetInstance<System.IFormatProvider>(provider);
		System.TimeOnly resultConverted;
	
	    try {
			System.Boolean __returnValue = System.TimeOnly.TryParseExact(sConverted, formatConverted, providerConverted, style, out resultConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			if (result is not null) {
				*result = resultConverted.AllocateGCHandleAndGetAddress();
			}
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			if (result is not null) {
				*result = null;
			}
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeOnly_TryParseExact_2")]
	internal static byte /* System.Boolean */ System_TimeOnly_TryParseExact_2(void* /* System.String */ s, void* /* System.String[] */ formats, void** /* System.TimeOnly */ result, void** /* System.Exception */ __outException)
	{
		System.String sConverted = InteropUtils.GetInstance<System.String>(s);
		System.String[] formatsConverted = InteropUtils.GetInstance<System.String[]>(formats);
		System.TimeOnly resultConverted;
	
	    try {
			System.Boolean __returnValue = System.TimeOnly.TryParseExact(sConverted, formatsConverted, out resultConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			if (result is not null) {
				*result = resultConverted.AllocateGCHandleAndGetAddress();
			}
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			if (result is not null) {
				*result = null;
			}
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeOnly_TryParseExact_3")]
	internal static byte /* System.Boolean */ System_TimeOnly_TryParseExact_3(void* /* System.String */ s, void* /* System.String[] */ formats, void* /* System.IFormatProvider */ provider, System.Globalization.DateTimeStyles /* System.Globalization.DateTimeStyles */ style, void** /* System.TimeOnly */ result, void** /* System.Exception */ __outException)
	{
		System.String sConverted = InteropUtils.GetInstance<System.String>(s);
		System.String[] formatsConverted = InteropUtils.GetInstance<System.String[]>(formats);
		System.IFormatProvider providerConverted = InteropUtils.GetInstance<System.IFormatProvider>(provider);
		System.TimeOnly resultConverted;
	
	    try {
			System.Boolean __returnValue = System.TimeOnly.TryParseExact(sConverted, formatsConverted, providerConverted, style, out resultConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			if (result is not null) {
				*result = resultConverted.AllocateGCHandleAndGetAddress();
			}
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			if (result is not null) {
				*result = null;
			}
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeOnly_ToLongTimeString")]
	internal static void* /* System.String */ System_TimeOnly_ToLongTimeString(void* /* System.TimeOnly */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.TimeOnly __selfConverted = InteropUtils.GetInstance<System.TimeOnly>(__self);
	
	
	    try {
			System.String __returnValue = __selfConverted.ToLongTimeString();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeOnly_ToShortTimeString")]
	internal static void* /* System.String */ System_TimeOnly_ToShortTimeString(void* /* System.TimeOnly */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.TimeOnly __selfConverted = InteropUtils.GetInstance<System.TimeOnly>(__self);
	
	
	    try {
			System.String __returnValue = __selfConverted.ToShortTimeString();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeOnly_ToString")]
	internal static void* /* System.String */ System_TimeOnly_ToString(void* /* System.TimeOnly */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.TimeOnly __selfConverted = InteropUtils.GetInstance<System.TimeOnly>(__self);
	
	
	    try {
			System.String __returnValue = __selfConverted.ToString();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeOnly_ToString_1")]
	internal static void* /* System.String */ System_TimeOnly_ToString_1(void* /* System.TimeOnly */ __self, void* /* System.String */ format, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.TimeOnly __selfConverted = InteropUtils.GetInstance<System.TimeOnly>(__self);
	
		System.String formatConverted = InteropUtils.GetInstance<System.String>(format);
	
	    try {
			System.String __returnValue = __selfConverted.ToString(formatConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeOnly_ToString_2")]
	internal static void* /* System.String */ System_TimeOnly_ToString_2(void* /* System.TimeOnly */ __self, void* /* System.IFormatProvider */ provider, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.TimeOnly __selfConverted = InteropUtils.GetInstance<System.TimeOnly>(__self);
	
		System.IFormatProvider providerConverted = InteropUtils.GetInstance<System.IFormatProvider>(provider);
	
	    try {
			System.String __returnValue = __selfConverted.ToString(providerConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeOnly_ToString_3")]
	internal static void* /* System.String */ System_TimeOnly_ToString_3(void* /* System.TimeOnly */ __self, void* /* System.String */ format, void* /* System.IFormatProvider */ provider, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.TimeOnly __selfConverted = InteropUtils.GetInstance<System.TimeOnly>(__self);
	
		System.String formatConverted = InteropUtils.GetInstance<System.String>(format);
		System.IFormatProvider providerConverted = InteropUtils.GetInstance<System.IFormatProvider>(provider);
	
	    try {
			System.String __returnValue = __selfConverted.ToString(formatConverted, providerConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeOnly_Parse_2")]
	internal static void* /* System.TimeOnly */ System_TimeOnly_Parse_2(void* /* System.String */ s, void* /* System.IFormatProvider */ provider, void** /* System.Exception */ __outException)
	{
		System.String sConverted = InteropUtils.GetInstance<System.String>(s);
		System.IFormatProvider providerConverted = InteropUtils.GetInstance<System.IFormatProvider>(provider);
	
	    try {
			System.TimeOnly __returnValue = System.TimeOnly.Parse(sConverted, providerConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeOnly_TryParse_2")]
	internal static byte /* System.Boolean */ System_TimeOnly_TryParse_2(void* /* System.String */ s, void* /* System.IFormatProvider */ provider, void** /* System.TimeOnly */ result, void** /* System.Exception */ __outException)
	{
		System.String sConverted = InteropUtils.GetInstance<System.String>(s);
		System.IFormatProvider providerConverted = InteropUtils.GetInstance<System.IFormatProvider>(provider);
		System.TimeOnly resultConverted;
	
	    try {
			System.Boolean __returnValue = System.TimeOnly.TryParse(sConverted, providerConverted, out resultConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			if (result is not null) {
				*result = resultConverted.AllocateGCHandleAndGetAddress();
			}
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			if (result is not null) {
				*result = null;
			}
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeOnly_Create")]
	internal static void* /* System.TimeOnly */ System_TimeOnly_Create(int /* System.Int32 */ hour, int /* System.Int32 */ minute, void** /* System.Exception */ __outException)
	{
	
	    try {
			System.TimeOnly __returnValue = new System.TimeOnly(hour, minute);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeOnly_Create_1")]
	internal static void* /* System.TimeOnly */ System_TimeOnly_Create_1(int /* System.Int32 */ hour, int /* System.Int32 */ minute, int /* System.Int32 */ second, void** /* System.Exception */ __outException)
	{
	
	    try {
			System.TimeOnly __returnValue = new System.TimeOnly(hour, minute, second);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeOnly_Create_2")]
	internal static void* /* System.TimeOnly */ System_TimeOnly_Create_2(int /* System.Int32 */ hour, int /* System.Int32 */ minute, int /* System.Int32 */ second, int /* System.Int32 */ millisecond, void** /* System.Exception */ __outException)
	{
	
	    try {
			System.TimeOnly __returnValue = new System.TimeOnly(hour, minute, second, millisecond);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeOnly_Create_3")]
	internal static void* /* System.TimeOnly */ System_TimeOnly_Create_3(int /* System.Int32 */ hour, int /* System.Int32 */ minute, int /* System.Int32 */ second, int /* System.Int32 */ millisecond, int /* System.Int32 */ microsecond, void** /* System.Exception */ __outException)
	{
	
	    try {
			System.TimeOnly __returnValue = new System.TimeOnly(hour, minute, second, millisecond, microsecond);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeOnly_Create_4")]
	internal static void* /* System.TimeOnly */ System_TimeOnly_Create_4(long /* System.Int64 */ ticks, void** /* System.Exception */ __outException)
	{
	
	    try {
			System.TimeOnly __returnValue = new System.TimeOnly(ticks);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeOnly_MinValue_Get")]
	internal static void* /* System.TimeOnly */ System_TimeOnly_MinValue_Get(void** /* System.Exception */ __outException)
	{
	
	    try {
			System.TimeOnly __returnValue = System.TimeOnly.MinValue;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeOnly_MaxValue_Get")]
	internal static void* /* System.TimeOnly */ System_TimeOnly_MaxValue_Get(void** /* System.Exception */ __outException)
	{
	
	    try {
			System.TimeOnly __returnValue = System.TimeOnly.MaxValue;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeOnly_Hour_Get")]
	internal static int /* System.Int32 */ System_TimeOnly_Hour_Get(void* /* System.TimeOnly */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.TimeOnly __selfConverted = InteropUtils.GetInstance<System.TimeOnly>(__self);
	
	
	    try {
			System.Int32 __returnValue = __selfConverted.Hour;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeOnly_Minute_Get")]
	internal static int /* System.Int32 */ System_TimeOnly_Minute_Get(void* /* System.TimeOnly */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.TimeOnly __selfConverted = InteropUtils.GetInstance<System.TimeOnly>(__self);
	
	
	    try {
			System.Int32 __returnValue = __selfConverted.Minute;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeOnly_Second_Get")]
	internal static int /* System.Int32 */ System_TimeOnly_Second_Get(void* /* System.TimeOnly */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.TimeOnly __selfConverted = InteropUtils.GetInstance<System.TimeOnly>(__self);
	
	
	    try {
			System.Int32 __returnValue = __selfConverted.Second;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeOnly_Millisecond_Get")]
	internal static int /* System.Int32 */ System_TimeOnly_Millisecond_Get(void* /* System.TimeOnly */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.TimeOnly __selfConverted = InteropUtils.GetInstance<System.TimeOnly>(__self);
	
	
	    try {
			System.Int32 __returnValue = __selfConverted.Millisecond;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeOnly_Microsecond_Get")]
	internal static int /* System.Int32 */ System_TimeOnly_Microsecond_Get(void* /* System.TimeOnly */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.TimeOnly __selfConverted = InteropUtils.GetInstance<System.TimeOnly>(__self);
	
	
	    try {
			System.Int32 __returnValue = __selfConverted.Microsecond;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeOnly_Nanosecond_Get")]
	internal static int /* System.Int32 */ System_TimeOnly_Nanosecond_Get(void* /* System.TimeOnly */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.TimeOnly __selfConverted = InteropUtils.GetInstance<System.TimeOnly>(__self);
	
	
	    try {
			System.Int32 __returnValue = __selfConverted.Nanosecond;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeOnly_Ticks_Get")]
	internal static long /* System.Int64 */ System_TimeOnly_Ticks_Get(void* /* System.TimeOnly */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.TimeOnly __selfConverted = InteropUtils.GetInstance<System.TimeOnly>(__self);
	
	
	    try {
			System.Int64 __returnValue = __selfConverted.Ticks;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeOnly_Create_5")]
	internal static void* /* System.TimeOnly */ System_TimeOnly_Create_5(void** /* System.Exception */ __outException)
	{
	
	    try {
			System.TimeOnly __returnValue = new System.TimeOnly();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeOnly_TypeOf")]
	internal static void* /* System.Type */ System_TimeOnly_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.TimeOnly);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeOnly_Destroy")]
	internal static void /* System.Void */ System_TimeOnly_Destroy(void* /* System.TimeOnly */ __self)
	{
	
		InteropUtils.FreeIfAllocated(__self);
	}
	
}




internal unsafe class System_Globalization_Calendar
{
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_Calendar_Clone")]
	internal static void* /* System.Object */ System_Globalization_Calendar_Clone(void* /* System.Globalization.Calendar */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.Calendar __selfConverted = InteropUtils.GetInstance<System.Globalization.Calendar>(__self);
	
	
	    try {
			System.Object __returnValue = __selfConverted.Clone();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_Calendar_ReadOnly")]
	internal static void* /* System.Globalization.Calendar */ System_Globalization_Calendar_ReadOnly(void* /* System.Globalization.Calendar */ calendar, void** /* System.Exception */ __outException)
	{
		System.Globalization.Calendar calendarConverted = InteropUtils.GetInstance<System.Globalization.Calendar>(calendar);
	
	    try {
			System.Globalization.Calendar __returnValue = System.Globalization.Calendar.ReadOnly(calendarConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_Calendar_AddMilliseconds")]
	internal static void* /* System.DateTime */ System_Globalization_Calendar_AddMilliseconds(void* /* System.Globalization.Calendar */ __self, void* /* System.DateTime */ time, double /* System.Double */ milliseconds, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.Calendar __selfConverted = InteropUtils.GetInstance<System.Globalization.Calendar>(__self);
	
		System.DateTime timeConverted = InteropUtils.GetInstance<System.DateTime>(time);
	
	    try {
			System.DateTime __returnValue = __selfConverted.AddMilliseconds(timeConverted, milliseconds);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_Calendar_AddDays")]
	internal static void* /* System.DateTime */ System_Globalization_Calendar_AddDays(void* /* System.Globalization.Calendar */ __self, void* /* System.DateTime */ time, int /* System.Int32 */ days, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.Calendar __selfConverted = InteropUtils.GetInstance<System.Globalization.Calendar>(__self);
	
		System.DateTime timeConverted = InteropUtils.GetInstance<System.DateTime>(time);
	
	    try {
			System.DateTime __returnValue = __selfConverted.AddDays(timeConverted, days);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_Calendar_AddHours")]
	internal static void* /* System.DateTime */ System_Globalization_Calendar_AddHours(void* /* System.Globalization.Calendar */ __self, void* /* System.DateTime */ time, int /* System.Int32 */ hours, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.Calendar __selfConverted = InteropUtils.GetInstance<System.Globalization.Calendar>(__self);
	
		System.DateTime timeConverted = InteropUtils.GetInstance<System.DateTime>(time);
	
	    try {
			System.DateTime __returnValue = __selfConverted.AddHours(timeConverted, hours);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_Calendar_AddMinutes")]
	internal static void* /* System.DateTime */ System_Globalization_Calendar_AddMinutes(void* /* System.Globalization.Calendar */ __self, void* /* System.DateTime */ time, int /* System.Int32 */ minutes, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.Calendar __selfConverted = InteropUtils.GetInstance<System.Globalization.Calendar>(__self);
	
		System.DateTime timeConverted = InteropUtils.GetInstance<System.DateTime>(time);
	
	    try {
			System.DateTime __returnValue = __selfConverted.AddMinutes(timeConverted, minutes);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_Calendar_AddMonths")]
	internal static void* /* System.DateTime */ System_Globalization_Calendar_AddMonths(void* /* System.Globalization.Calendar */ __self, void* /* System.DateTime */ time, int /* System.Int32 */ months, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.Calendar __selfConverted = InteropUtils.GetInstance<System.Globalization.Calendar>(__self);
	
		System.DateTime timeConverted = InteropUtils.GetInstance<System.DateTime>(time);
	
	    try {
			System.DateTime __returnValue = __selfConverted.AddMonths(timeConverted, months);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_Calendar_AddSeconds")]
	internal static void* /* System.DateTime */ System_Globalization_Calendar_AddSeconds(void* /* System.Globalization.Calendar */ __self, void* /* System.DateTime */ time, int /* System.Int32 */ seconds, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.Calendar __selfConverted = InteropUtils.GetInstance<System.Globalization.Calendar>(__self);
	
		System.DateTime timeConverted = InteropUtils.GetInstance<System.DateTime>(time);
	
	    try {
			System.DateTime __returnValue = __selfConverted.AddSeconds(timeConverted, seconds);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_Calendar_AddWeeks")]
	internal static void* /* System.DateTime */ System_Globalization_Calendar_AddWeeks(void* /* System.Globalization.Calendar */ __self, void* /* System.DateTime */ time, int /* System.Int32 */ weeks, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.Calendar __selfConverted = InteropUtils.GetInstance<System.Globalization.Calendar>(__self);
	
		System.DateTime timeConverted = InteropUtils.GetInstance<System.DateTime>(time);
	
	    try {
			System.DateTime __returnValue = __selfConverted.AddWeeks(timeConverted, weeks);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_Calendar_AddYears")]
	internal static void* /* System.DateTime */ System_Globalization_Calendar_AddYears(void* /* System.Globalization.Calendar */ __self, void* /* System.DateTime */ time, int /* System.Int32 */ years, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.Calendar __selfConverted = InteropUtils.GetInstance<System.Globalization.Calendar>(__self);
	
		System.DateTime timeConverted = InteropUtils.GetInstance<System.DateTime>(time);
	
	    try {
			System.DateTime __returnValue = __selfConverted.AddYears(timeConverted, years);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_Calendar_GetDayOfMonth")]
	internal static int /* System.Int32 */ System_Globalization_Calendar_GetDayOfMonth(void* /* System.Globalization.Calendar */ __self, void* /* System.DateTime */ time, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.Calendar __selfConverted = InteropUtils.GetInstance<System.Globalization.Calendar>(__self);
	
		System.DateTime timeConverted = InteropUtils.GetInstance<System.DateTime>(time);
	
	    try {
			System.Int32 __returnValue = __selfConverted.GetDayOfMonth(timeConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_Calendar_GetDayOfWeek")]
	internal static System.DayOfWeek /* System.DayOfWeek */ System_Globalization_Calendar_GetDayOfWeek(void* /* System.Globalization.Calendar */ __self, void* /* System.DateTime */ time, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.Calendar __selfConverted = InteropUtils.GetInstance<System.Globalization.Calendar>(__self);
	
		System.DateTime timeConverted = InteropUtils.GetInstance<System.DateTime>(time);
	
	    try {
			System.DayOfWeek __returnValue = __selfConverted.GetDayOfWeek(timeConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return default(System.DayOfWeek);
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_Calendar_GetDayOfYear")]
	internal static int /* System.Int32 */ System_Globalization_Calendar_GetDayOfYear(void* /* System.Globalization.Calendar */ __self, void* /* System.DateTime */ time, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.Calendar __selfConverted = InteropUtils.GetInstance<System.Globalization.Calendar>(__self);
	
		System.DateTime timeConverted = InteropUtils.GetInstance<System.DateTime>(time);
	
	    try {
			System.Int32 __returnValue = __selfConverted.GetDayOfYear(timeConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_Calendar_GetDaysInMonth")]
	internal static int /* System.Int32 */ System_Globalization_Calendar_GetDaysInMonth(void* /* System.Globalization.Calendar */ __self, int /* System.Int32 */ year, int /* System.Int32 */ month, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.Calendar __selfConverted = InteropUtils.GetInstance<System.Globalization.Calendar>(__self);
	
	
	    try {
			System.Int32 __returnValue = __selfConverted.GetDaysInMonth(year, month);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_Calendar_GetDaysInMonth_1")]
	internal static int /* System.Int32 */ System_Globalization_Calendar_GetDaysInMonth_1(void* /* System.Globalization.Calendar */ __self, int /* System.Int32 */ year, int /* System.Int32 */ month, int /* System.Int32 */ era, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.Calendar __selfConverted = InteropUtils.GetInstance<System.Globalization.Calendar>(__self);
	
	
	    try {
			System.Int32 __returnValue = __selfConverted.GetDaysInMonth(year, month, era);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_Calendar_GetDaysInYear")]
	internal static int /* System.Int32 */ System_Globalization_Calendar_GetDaysInYear(void* /* System.Globalization.Calendar */ __self, int /* System.Int32 */ year, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.Calendar __selfConverted = InteropUtils.GetInstance<System.Globalization.Calendar>(__self);
	
	
	    try {
			System.Int32 __returnValue = __selfConverted.GetDaysInYear(year);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_Calendar_GetDaysInYear_1")]
	internal static int /* System.Int32 */ System_Globalization_Calendar_GetDaysInYear_1(void* /* System.Globalization.Calendar */ __self, int /* System.Int32 */ year, int /* System.Int32 */ era, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.Calendar __selfConverted = InteropUtils.GetInstance<System.Globalization.Calendar>(__self);
	
	
	    try {
			System.Int32 __returnValue = __selfConverted.GetDaysInYear(year, era);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_Calendar_GetEra")]
	internal static int /* System.Int32 */ System_Globalization_Calendar_GetEra(void* /* System.Globalization.Calendar */ __self, void* /* System.DateTime */ time, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.Calendar __selfConverted = InteropUtils.GetInstance<System.Globalization.Calendar>(__self);
	
		System.DateTime timeConverted = InteropUtils.GetInstance<System.DateTime>(time);
	
	    try {
			System.Int32 __returnValue = __selfConverted.GetEra(timeConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_Calendar_GetHour")]
	internal static int /* System.Int32 */ System_Globalization_Calendar_GetHour(void* /* System.Globalization.Calendar */ __self, void* /* System.DateTime */ time, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.Calendar __selfConverted = InteropUtils.GetInstance<System.Globalization.Calendar>(__self);
	
		System.DateTime timeConverted = InteropUtils.GetInstance<System.DateTime>(time);
	
	    try {
			System.Int32 __returnValue = __selfConverted.GetHour(timeConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_Calendar_GetMilliseconds")]
	internal static double /* System.Double */ System_Globalization_Calendar_GetMilliseconds(void* /* System.Globalization.Calendar */ __self, void* /* System.DateTime */ time, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.Calendar __selfConverted = InteropUtils.GetInstance<System.Globalization.Calendar>(__self);
	
		System.DateTime timeConverted = InteropUtils.GetInstance<System.DateTime>(time);
	
	    try {
			System.Double __returnValue = __selfConverted.GetMilliseconds(timeConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_Calendar_GetMinute")]
	internal static int /* System.Int32 */ System_Globalization_Calendar_GetMinute(void* /* System.Globalization.Calendar */ __self, void* /* System.DateTime */ time, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.Calendar __selfConverted = InteropUtils.GetInstance<System.Globalization.Calendar>(__self);
	
		System.DateTime timeConverted = InteropUtils.GetInstance<System.DateTime>(time);
	
	    try {
			System.Int32 __returnValue = __selfConverted.GetMinute(timeConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_Calendar_GetMonth")]
	internal static int /* System.Int32 */ System_Globalization_Calendar_GetMonth(void* /* System.Globalization.Calendar */ __self, void* /* System.DateTime */ time, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.Calendar __selfConverted = InteropUtils.GetInstance<System.Globalization.Calendar>(__self);
	
		System.DateTime timeConverted = InteropUtils.GetInstance<System.DateTime>(time);
	
	    try {
			System.Int32 __returnValue = __selfConverted.GetMonth(timeConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_Calendar_GetMonthsInYear")]
	internal static int /* System.Int32 */ System_Globalization_Calendar_GetMonthsInYear(void* /* System.Globalization.Calendar */ __self, int /* System.Int32 */ year, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.Calendar __selfConverted = InteropUtils.GetInstance<System.Globalization.Calendar>(__self);
	
	
	    try {
			System.Int32 __returnValue = __selfConverted.GetMonthsInYear(year);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_Calendar_GetMonthsInYear_1")]
	internal static int /* System.Int32 */ System_Globalization_Calendar_GetMonthsInYear_1(void* /* System.Globalization.Calendar */ __self, int /* System.Int32 */ year, int /* System.Int32 */ era, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.Calendar __selfConverted = InteropUtils.GetInstance<System.Globalization.Calendar>(__self);
	
	
	    try {
			System.Int32 __returnValue = __selfConverted.GetMonthsInYear(year, era);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_Calendar_GetSecond")]
	internal static int /* System.Int32 */ System_Globalization_Calendar_GetSecond(void* /* System.Globalization.Calendar */ __self, void* /* System.DateTime */ time, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.Calendar __selfConverted = InteropUtils.GetInstance<System.Globalization.Calendar>(__self);
	
		System.DateTime timeConverted = InteropUtils.GetInstance<System.DateTime>(time);
	
	    try {
			System.Int32 __returnValue = __selfConverted.GetSecond(timeConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_Calendar_GetWeekOfYear")]
	internal static int /* System.Int32 */ System_Globalization_Calendar_GetWeekOfYear(void* /* System.Globalization.Calendar */ __self, void* /* System.DateTime */ time, System.Globalization.CalendarWeekRule /* System.Globalization.CalendarWeekRule */ rule, System.DayOfWeek /* System.DayOfWeek */ firstDayOfWeek, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.Calendar __selfConverted = InteropUtils.GetInstance<System.Globalization.Calendar>(__self);
	
		System.DateTime timeConverted = InteropUtils.GetInstance<System.DateTime>(time);
	
	    try {
			System.Int32 __returnValue = __selfConverted.GetWeekOfYear(timeConverted, rule, firstDayOfWeek);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_Calendar_GetYear")]
	internal static int /* System.Int32 */ System_Globalization_Calendar_GetYear(void* /* System.Globalization.Calendar */ __self, void* /* System.DateTime */ time, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.Calendar __selfConverted = InteropUtils.GetInstance<System.Globalization.Calendar>(__self);
	
		System.DateTime timeConverted = InteropUtils.GetInstance<System.DateTime>(time);
	
	    try {
			System.Int32 __returnValue = __selfConverted.GetYear(timeConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_Calendar_IsLeapDay")]
	internal static byte /* System.Boolean */ System_Globalization_Calendar_IsLeapDay(void* /* System.Globalization.Calendar */ __self, int /* System.Int32 */ year, int /* System.Int32 */ month, int /* System.Int32 */ day, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.Calendar __selfConverted = InteropUtils.GetInstance<System.Globalization.Calendar>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.IsLeapDay(year, month, day);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_Calendar_IsLeapDay_1")]
	internal static byte /* System.Boolean */ System_Globalization_Calendar_IsLeapDay_1(void* /* System.Globalization.Calendar */ __self, int /* System.Int32 */ year, int /* System.Int32 */ month, int /* System.Int32 */ day, int /* System.Int32 */ era, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.Calendar __selfConverted = InteropUtils.GetInstance<System.Globalization.Calendar>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.IsLeapDay(year, month, day, era);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_Calendar_IsLeapMonth")]
	internal static byte /* System.Boolean */ System_Globalization_Calendar_IsLeapMonth(void* /* System.Globalization.Calendar */ __self, int /* System.Int32 */ year, int /* System.Int32 */ month, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.Calendar __selfConverted = InteropUtils.GetInstance<System.Globalization.Calendar>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.IsLeapMonth(year, month);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_Calendar_IsLeapMonth_1")]
	internal static byte /* System.Boolean */ System_Globalization_Calendar_IsLeapMonth_1(void* /* System.Globalization.Calendar */ __self, int /* System.Int32 */ year, int /* System.Int32 */ month, int /* System.Int32 */ era, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.Calendar __selfConverted = InteropUtils.GetInstance<System.Globalization.Calendar>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.IsLeapMonth(year, month, era);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_Calendar_GetLeapMonth")]
	internal static int /* System.Int32 */ System_Globalization_Calendar_GetLeapMonth(void* /* System.Globalization.Calendar */ __self, int /* System.Int32 */ year, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.Calendar __selfConverted = InteropUtils.GetInstance<System.Globalization.Calendar>(__self);
	
	
	    try {
			System.Int32 __returnValue = __selfConverted.GetLeapMonth(year);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_Calendar_GetLeapMonth_1")]
	internal static int /* System.Int32 */ System_Globalization_Calendar_GetLeapMonth_1(void* /* System.Globalization.Calendar */ __self, int /* System.Int32 */ year, int /* System.Int32 */ era, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.Calendar __selfConverted = InteropUtils.GetInstance<System.Globalization.Calendar>(__self);
	
	
	    try {
			System.Int32 __returnValue = __selfConverted.GetLeapMonth(year, era);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_Calendar_IsLeapYear")]
	internal static byte /* System.Boolean */ System_Globalization_Calendar_IsLeapYear(void* /* System.Globalization.Calendar */ __self, int /* System.Int32 */ year, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.Calendar __selfConverted = InteropUtils.GetInstance<System.Globalization.Calendar>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.IsLeapYear(year);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_Calendar_IsLeapYear_1")]
	internal static byte /* System.Boolean */ System_Globalization_Calendar_IsLeapYear_1(void* /* System.Globalization.Calendar */ __self, int /* System.Int32 */ year, int /* System.Int32 */ era, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.Calendar __selfConverted = InteropUtils.GetInstance<System.Globalization.Calendar>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.IsLeapYear(year, era);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_Calendar_ToDateTime")]
	internal static void* /* System.DateTime */ System_Globalization_Calendar_ToDateTime(void* /* System.Globalization.Calendar */ __self, int /* System.Int32 */ year, int /* System.Int32 */ month, int /* System.Int32 */ day, int /* System.Int32 */ hour, int /* System.Int32 */ minute, int /* System.Int32 */ second, int /* System.Int32 */ millisecond, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.Calendar __selfConverted = InteropUtils.GetInstance<System.Globalization.Calendar>(__self);
	
	
	    try {
			System.DateTime __returnValue = __selfConverted.ToDateTime(year, month, day, hour, minute, second, millisecond);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_Calendar_ToDateTime_1")]
	internal static void* /* System.DateTime */ System_Globalization_Calendar_ToDateTime_1(void* /* System.Globalization.Calendar */ __self, int /* System.Int32 */ year, int /* System.Int32 */ month, int /* System.Int32 */ day, int /* System.Int32 */ hour, int /* System.Int32 */ minute, int /* System.Int32 */ second, int /* System.Int32 */ millisecond, int /* System.Int32 */ era, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.Calendar __selfConverted = InteropUtils.GetInstance<System.Globalization.Calendar>(__self);
	
	
	    try {
			System.DateTime __returnValue = __selfConverted.ToDateTime(year, month, day, hour, minute, second, millisecond, era);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_Calendar_ToFourDigitYear")]
	internal static int /* System.Int32 */ System_Globalization_Calendar_ToFourDigitYear(void* /* System.Globalization.Calendar */ __self, int /* System.Int32 */ year, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.Calendar __selfConverted = InteropUtils.GetInstance<System.Globalization.Calendar>(__self);
	
	
	    try {
			System.Int32 __returnValue = __selfConverted.ToFourDigitYear(year);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_Calendar_MinSupportedDateTime_Get")]
	internal static void* /* System.DateTime */ System_Globalization_Calendar_MinSupportedDateTime_Get(void* /* System.Globalization.Calendar */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.Calendar __selfConverted = InteropUtils.GetInstance<System.Globalization.Calendar>(__self);
	
	
	    try {
			System.DateTime __returnValue = __selfConverted.MinSupportedDateTime;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_Calendar_MaxSupportedDateTime_Get")]
	internal static void* /* System.DateTime */ System_Globalization_Calendar_MaxSupportedDateTime_Get(void* /* System.Globalization.Calendar */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.Calendar __selfConverted = InteropUtils.GetInstance<System.Globalization.Calendar>(__self);
	
	
	    try {
			System.DateTime __returnValue = __selfConverted.MaxSupportedDateTime;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_Calendar_AlgorithmType_Get")]
	internal static System.Globalization.CalendarAlgorithmType /* System.Globalization.CalendarAlgorithmType */ System_Globalization_Calendar_AlgorithmType_Get(void* /* System.Globalization.Calendar */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.Calendar __selfConverted = InteropUtils.GetInstance<System.Globalization.Calendar>(__self);
	
	
	    try {
			System.Globalization.CalendarAlgorithmType __returnValue = __selfConverted.AlgorithmType;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return default(System.Globalization.CalendarAlgorithmType);
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_Calendar_IsReadOnly_Get")]
	internal static byte /* System.Boolean */ System_Globalization_Calendar_IsReadOnly_Get(void* /* System.Globalization.Calendar */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.Calendar __selfConverted = InteropUtils.GetInstance<System.Globalization.Calendar>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.IsReadOnly;
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_Calendar_Eras_Get")]
	internal static void* /* System.Int32[] */ System_Globalization_Calendar_Eras_Get(void* /* System.Globalization.Calendar */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.Calendar __selfConverted = InteropUtils.GetInstance<System.Globalization.Calendar>(__self);
	
	
	    try {
			System.Int32[] __returnValue = __selfConverted.Eras;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_Calendar_TwoDigitYearMax_Get")]
	internal static int /* System.Int32 */ System_Globalization_Calendar_TwoDigitYearMax_Get(void* /* System.Globalization.Calendar */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.Calendar __selfConverted = InteropUtils.GetInstance<System.Globalization.Calendar>(__self);
	
	
	    try {
			System.Int32 __returnValue = __selfConverted.TwoDigitYearMax;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_Calendar_TwoDigitYearMax_Set")]
	internal static void /* System.Void */ System_Globalization_Calendar_TwoDigitYearMax_Set(void* /* System.Globalization.Calendar */ __self, int /* System.Int32 */ __value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.Calendar __selfConverted = InteropUtils.GetInstance<System.Globalization.Calendar>(__self);
	
	
	    try {
			__selfConverted.TwoDigitYearMax = __value;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_Calendar_CurrentEra_Get")]
	internal static int /* System.Int32 */ System_Globalization_Calendar_CurrentEra_Get()
	{
	
		System.Int32 __returnValue = System.Globalization.Calendar.CurrentEra;
		return __returnValue;
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_Calendar_TypeOf")]
	internal static void* /* System.Type */ System_Globalization_Calendar_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.Globalization.Calendar);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_Calendar_Destroy")]
	internal static void /* System.Void */ System_Globalization_Calendar_Destroy(void* /* System.Globalization.Calendar */ __self)
	{
	
		InteropUtils.FreeIfAllocated(__self);
	}
	
}


internal unsafe class System_Globalization_CalendarAlgorithmType
{
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_CalendarAlgorithmType_TypeOf")]
	internal static void* /* System.Type */ System_Globalization_CalendarAlgorithmType_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.Globalization.CalendarAlgorithmType);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
}


internal unsafe class System_Globalization_CalendarWeekRule
{
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_CalendarWeekRule_TypeOf")]
	internal static void* /* System.Type */ System_Globalization_CalendarWeekRule_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.Globalization.CalendarWeekRule);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
}


internal unsafe class System_Runtime_Serialization_IFormatterConverter
{
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_Serialization_IFormatterConverter_Convert")]
	internal static void* /* System.Object */ System_Runtime_Serialization_IFormatterConverter_Convert(void* /* System.Runtime.Serialization.IFormatterConverter */ __self, void* /* System.Object */ value, void* /* System.Type */ type, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Runtime.Serialization.IFormatterConverter __selfConverted = InteropUtils.GetInstance<System.Runtime.Serialization.IFormatterConverter>(__self);
	
		System.Object valueConverted = InteropUtils.GetInstance<System.Object>(value);
		System.Type typeConverted = InteropUtils.GetInstance<System.Type>(type);
	
	    try {
			System.Object __returnValue = __selfConverted.Convert(valueConverted, typeConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_Serialization_IFormatterConverter_Convert_1")]
	internal static void* /* System.Object */ System_Runtime_Serialization_IFormatterConverter_Convert_1(void* /* System.Runtime.Serialization.IFormatterConverter */ __self, void* /* System.Object */ value, System.TypeCode /* System.TypeCode */ typeCode, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Runtime.Serialization.IFormatterConverter __selfConverted = InteropUtils.GetInstance<System.Runtime.Serialization.IFormatterConverter>(__self);
	
		System.Object valueConverted = InteropUtils.GetInstance<System.Object>(value);
	
	    try {
			System.Object __returnValue = __selfConverted.Convert(valueConverted, typeCode);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_Serialization_IFormatterConverter_ToBoolean")]
	internal static byte /* System.Boolean */ System_Runtime_Serialization_IFormatterConverter_ToBoolean(void* /* System.Runtime.Serialization.IFormatterConverter */ __self, void* /* System.Object */ value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Runtime.Serialization.IFormatterConverter __selfConverted = InteropUtils.GetInstance<System.Runtime.Serialization.IFormatterConverter>(__self);
	
		System.Object valueConverted = InteropUtils.GetInstance<System.Object>(value);
	
	    try {
			System.Boolean __returnValue = __selfConverted.ToBoolean(valueConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_Serialization_IFormatterConverter_ToChar")]
	internal static char /* System.Char */ System_Runtime_Serialization_IFormatterConverter_ToChar(void* /* System.Runtime.Serialization.IFormatterConverter */ __self, void* /* System.Object */ value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Runtime.Serialization.IFormatterConverter __selfConverted = InteropUtils.GetInstance<System.Runtime.Serialization.IFormatterConverter>(__self);
	
		System.Object valueConverted = InteropUtils.GetInstance<System.Object>(value);
	
	    try {
			System.Char __returnValue = __selfConverted.ToChar(valueConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return (char)0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_Serialization_IFormatterConverter_ToSByte")]
	internal static sbyte /* System.SByte */ System_Runtime_Serialization_IFormatterConverter_ToSByte(void* /* System.Runtime.Serialization.IFormatterConverter */ __self, void* /* System.Object */ value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Runtime.Serialization.IFormatterConverter __selfConverted = InteropUtils.GetInstance<System.Runtime.Serialization.IFormatterConverter>(__self);
	
		System.Object valueConverted = InteropUtils.GetInstance<System.Object>(value);
	
	    try {
			System.SByte __returnValue = __selfConverted.ToSByte(valueConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_Serialization_IFormatterConverter_ToByte")]
	internal static byte /* System.Byte */ System_Runtime_Serialization_IFormatterConverter_ToByte(void* /* System.Runtime.Serialization.IFormatterConverter */ __self, void* /* System.Object */ value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Runtime.Serialization.IFormatterConverter __selfConverted = InteropUtils.GetInstance<System.Runtime.Serialization.IFormatterConverter>(__self);
	
		System.Object valueConverted = InteropUtils.GetInstance<System.Object>(value);
	
	    try {
			System.Byte __returnValue = __selfConverted.ToByte(valueConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_Serialization_IFormatterConverter_ToInt16")]
	internal static short /* System.Int16 */ System_Runtime_Serialization_IFormatterConverter_ToInt16(void* /* System.Runtime.Serialization.IFormatterConverter */ __self, void* /* System.Object */ value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Runtime.Serialization.IFormatterConverter __selfConverted = InteropUtils.GetInstance<System.Runtime.Serialization.IFormatterConverter>(__self);
	
		System.Object valueConverted = InteropUtils.GetInstance<System.Object>(value);
	
	    try {
			System.Int16 __returnValue = __selfConverted.ToInt16(valueConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_Serialization_IFormatterConverter_ToUInt16")]
	internal static ushort /* System.UInt16 */ System_Runtime_Serialization_IFormatterConverter_ToUInt16(void* /* System.Runtime.Serialization.IFormatterConverter */ __self, void* /* System.Object */ value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Runtime.Serialization.IFormatterConverter __selfConverted = InteropUtils.GetInstance<System.Runtime.Serialization.IFormatterConverter>(__self);
	
		System.Object valueConverted = InteropUtils.GetInstance<System.Object>(value);
	
	    try {
			System.UInt16 __returnValue = __selfConverted.ToUInt16(valueConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_Serialization_IFormatterConverter_ToInt32")]
	internal static int /* System.Int32 */ System_Runtime_Serialization_IFormatterConverter_ToInt32(void* /* System.Runtime.Serialization.IFormatterConverter */ __self, void* /* System.Object */ value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Runtime.Serialization.IFormatterConverter __selfConverted = InteropUtils.GetInstance<System.Runtime.Serialization.IFormatterConverter>(__self);
	
		System.Object valueConverted = InteropUtils.GetInstance<System.Object>(value);
	
	    try {
			System.Int32 __returnValue = __selfConverted.ToInt32(valueConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_Serialization_IFormatterConverter_ToUInt32")]
	internal static uint /* System.UInt32 */ System_Runtime_Serialization_IFormatterConverter_ToUInt32(void* /* System.Runtime.Serialization.IFormatterConverter */ __self, void* /* System.Object */ value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Runtime.Serialization.IFormatterConverter __selfConverted = InteropUtils.GetInstance<System.Runtime.Serialization.IFormatterConverter>(__self);
	
		System.Object valueConverted = InteropUtils.GetInstance<System.Object>(value);
	
	    try {
			System.UInt32 __returnValue = __selfConverted.ToUInt32(valueConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_Serialization_IFormatterConverter_ToInt64")]
	internal static long /* System.Int64 */ System_Runtime_Serialization_IFormatterConverter_ToInt64(void* /* System.Runtime.Serialization.IFormatterConverter */ __self, void* /* System.Object */ value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Runtime.Serialization.IFormatterConverter __selfConverted = InteropUtils.GetInstance<System.Runtime.Serialization.IFormatterConverter>(__self);
	
		System.Object valueConverted = InteropUtils.GetInstance<System.Object>(value);
	
	    try {
			System.Int64 __returnValue = __selfConverted.ToInt64(valueConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_Serialization_IFormatterConverter_ToUInt64")]
	internal static ulong /* System.UInt64 */ System_Runtime_Serialization_IFormatterConverter_ToUInt64(void* /* System.Runtime.Serialization.IFormatterConverter */ __self, void* /* System.Object */ value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Runtime.Serialization.IFormatterConverter __selfConverted = InteropUtils.GetInstance<System.Runtime.Serialization.IFormatterConverter>(__self);
	
		System.Object valueConverted = InteropUtils.GetInstance<System.Object>(value);
	
	    try {
			System.UInt64 __returnValue = __selfConverted.ToUInt64(valueConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_Serialization_IFormatterConverter_ToSingle")]
	internal static float /* System.Single */ System_Runtime_Serialization_IFormatterConverter_ToSingle(void* /* System.Runtime.Serialization.IFormatterConverter */ __self, void* /* System.Object */ value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Runtime.Serialization.IFormatterConverter __selfConverted = InteropUtils.GetInstance<System.Runtime.Serialization.IFormatterConverter>(__self);
	
		System.Object valueConverted = InteropUtils.GetInstance<System.Object>(value);
	
	    try {
			System.Single __returnValue = __selfConverted.ToSingle(valueConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_Serialization_IFormatterConverter_ToDouble")]
	internal static double /* System.Double */ System_Runtime_Serialization_IFormatterConverter_ToDouble(void* /* System.Runtime.Serialization.IFormatterConverter */ __self, void* /* System.Object */ value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Runtime.Serialization.IFormatterConverter __selfConverted = InteropUtils.GetInstance<System.Runtime.Serialization.IFormatterConverter>(__self);
	
		System.Object valueConverted = InteropUtils.GetInstance<System.Object>(value);
	
	    try {
			System.Double __returnValue = __selfConverted.ToDouble(valueConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_Serialization_IFormatterConverter_ToDecimal")]
	internal static void* /* System.Decimal */ System_Runtime_Serialization_IFormatterConverter_ToDecimal(void* /* System.Runtime.Serialization.IFormatterConverter */ __self, void* /* System.Object */ value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Runtime.Serialization.IFormatterConverter __selfConverted = InteropUtils.GetInstance<System.Runtime.Serialization.IFormatterConverter>(__self);
	
		System.Object valueConverted = InteropUtils.GetInstance<System.Object>(value);
	
	    try {
			System.Decimal __returnValue = __selfConverted.ToDecimal(valueConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_Serialization_IFormatterConverter_ToDateTime")]
	internal static void* /* System.DateTime */ System_Runtime_Serialization_IFormatterConverter_ToDateTime(void* /* System.Runtime.Serialization.IFormatterConverter */ __self, void* /* System.Object */ value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Runtime.Serialization.IFormatterConverter __selfConverted = InteropUtils.GetInstance<System.Runtime.Serialization.IFormatterConverter>(__self);
	
		System.Object valueConverted = InteropUtils.GetInstance<System.Object>(value);
	
	    try {
			System.DateTime __returnValue = __selfConverted.ToDateTime(valueConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_Serialization_IFormatterConverter_ToString")]
	internal static void* /* System.String */ System_Runtime_Serialization_IFormatterConverter_ToString(void* /* System.Runtime.Serialization.IFormatterConverter */ __self, void* /* System.Object */ value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Runtime.Serialization.IFormatterConverter __selfConverted = InteropUtils.GetInstance<System.Runtime.Serialization.IFormatterConverter>(__self);
	
		System.Object valueConverted = InteropUtils.GetInstance<System.Object>(value);
	
	    try {
			System.String __returnValue = __selfConverted.ToString(valueConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_Serialization_IFormatterConverter_TypeOf")]
	internal static void* /* System.Type */ System_Runtime_Serialization_IFormatterConverter_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.Runtime.Serialization.IFormatterConverter);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_Serialization_IFormatterConverter_Destroy")]
	internal static void /* System.Void */ System_Runtime_Serialization_IFormatterConverter_Destroy(void* /* System.Runtime.Serialization.IFormatterConverter */ __self)
	{
	
		InteropUtils.FreeIfAllocated(__self);
	}
	
}


internal unsafe class System_Runtime_Serialization_StreamingContext
{
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_Serialization_StreamingContext_Equals")]
	internal static byte /* System.Boolean */ System_Runtime_Serialization_StreamingContext_Equals(void* /* System.Runtime.Serialization.StreamingContext */ __self, void* /* System.Object */ obj, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Runtime.Serialization.StreamingContext __selfConverted = InteropUtils.GetInstance<System.Runtime.Serialization.StreamingContext>(__self);
	
		System.Object objConverted = InteropUtils.GetInstance<System.Object>(obj);
	
	    try {
			System.Boolean __returnValue = __selfConverted.Equals(objConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_Serialization_StreamingContext_GetHashCode")]
	internal static int /* System.Int32 */ System_Runtime_Serialization_StreamingContext_GetHashCode(void* /* System.Runtime.Serialization.StreamingContext */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Runtime.Serialization.StreamingContext __selfConverted = InteropUtils.GetInstance<System.Runtime.Serialization.StreamingContext>(__self);
	
	
	    try {
			System.Int32 __returnValue = __selfConverted.GetHashCode();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_Serialization_StreamingContext_Create")]
	internal static void* /* System.Runtime.Serialization.StreamingContext */ System_Runtime_Serialization_StreamingContext_Create(System.Runtime.Serialization.StreamingContextStates /* System.Runtime.Serialization.StreamingContextStates */ state, void** /* System.Exception */ __outException)
	{
	
	    try {
			System.Runtime.Serialization.StreamingContext __returnValue = new System.Runtime.Serialization.StreamingContext(state);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_Serialization_StreamingContext_Create_1")]
	internal static void* /* System.Runtime.Serialization.StreamingContext */ System_Runtime_Serialization_StreamingContext_Create_1(System.Runtime.Serialization.StreamingContextStates /* System.Runtime.Serialization.StreamingContextStates */ state, void* /* System.Object */ additional, void** /* System.Exception */ __outException)
	{
		System.Object additionalConverted = InteropUtils.GetInstance<System.Object>(additional);
	
	    try {
			System.Runtime.Serialization.StreamingContext __returnValue = new System.Runtime.Serialization.StreamingContext(state, additionalConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_Serialization_StreamingContext_State_Get")]
	internal static System.Runtime.Serialization.StreamingContextStates /* System.Runtime.Serialization.StreamingContextStates */ System_Runtime_Serialization_StreamingContext_State_Get(void* /* System.Runtime.Serialization.StreamingContext */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Runtime.Serialization.StreamingContext __selfConverted = InteropUtils.GetInstance<System.Runtime.Serialization.StreamingContext>(__self);
	
	
	    try {
			System.Runtime.Serialization.StreamingContextStates __returnValue = __selfConverted.State;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return default(System.Runtime.Serialization.StreamingContextStates);
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_Serialization_StreamingContext_Context_Get")]
	internal static void* /* System.Object */ System_Runtime_Serialization_StreamingContext_Context_Get(void* /* System.Runtime.Serialization.StreamingContext */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Runtime.Serialization.StreamingContext __selfConverted = InteropUtils.GetInstance<System.Runtime.Serialization.StreamingContext>(__self);
	
	
	    try {
			System.Object __returnValue = __selfConverted.Context;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_Serialization_StreamingContext_Create_2")]
	internal static void* /* System.Runtime.Serialization.StreamingContext */ System_Runtime_Serialization_StreamingContext_Create_2(void** /* System.Exception */ __outException)
	{
	
	    try {
			System.Runtime.Serialization.StreamingContext __returnValue = new System.Runtime.Serialization.StreamingContext();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_Serialization_StreamingContext_TypeOf")]
	internal static void* /* System.Type */ System_Runtime_Serialization_StreamingContext_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.Runtime.Serialization.StreamingContext);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_Serialization_StreamingContext_Destroy")]
	internal static void /* System.Void */ System_Runtime_Serialization_StreamingContext_Destroy(void* /* System.Runtime.Serialization.StreamingContext */ __self)
	{
	
		InteropUtils.FreeIfAllocated(__self);
	}
	
}


internal unsafe class System_Runtime_Serialization_StreamingContextStates
{
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_Serialization_StreamingContextStates_TypeOf")]
	internal static void* /* System.Type */ System_Runtime_Serialization_StreamingContextStates_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.Runtime.Serialization.StreamingContextStates);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
}


internal unsafe class System_Reflection_AssemblyName
{
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_AssemblyName_Clone")]
	internal static void* /* System.Object */ System_Reflection_AssemblyName_Clone(void* /* System.Reflection.AssemblyName */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.AssemblyName __selfConverted = InteropUtils.GetInstance<System.Reflection.AssemblyName>(__self);
	
	
	    try {
			System.Object __returnValue = __selfConverted.Clone();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_AssemblyName_GetAssemblyName")]
	internal static void* /* System.Reflection.AssemblyName */ System_Reflection_AssemblyName_GetAssemblyName(void* /* System.String */ assemblyFile, void** /* System.Exception */ __outException)
	{
		System.String assemblyFileConverted = InteropUtils.GetInstance<System.String>(assemblyFile);
	
	    try {
			System.Reflection.AssemblyName __returnValue = System.Reflection.AssemblyName.GetAssemblyName(assemblyFileConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_AssemblyName_GetPublicKey")]
	internal static void* /* System.Byte[] */ System_Reflection_AssemblyName_GetPublicKey(void* /* System.Reflection.AssemblyName */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.AssemblyName __selfConverted = InteropUtils.GetInstance<System.Reflection.AssemblyName>(__self);
	
	
	    try {
			System.Byte[] __returnValue = __selfConverted.GetPublicKey();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_AssemblyName_SetPublicKey")]
	internal static void /* System.Void */ System_Reflection_AssemblyName_SetPublicKey(void* /* System.Reflection.AssemblyName */ __self, void* /* System.Byte[] */ publicKey, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.AssemblyName __selfConverted = InteropUtils.GetInstance<System.Reflection.AssemblyName>(__self);
	
		System.Byte[] publicKeyConverted = InteropUtils.GetInstance<System.Byte[]>(publicKey);
	
	    try {
			__selfConverted.SetPublicKey(publicKeyConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_AssemblyName_GetPublicKeyToken")]
	internal static void* /* System.Byte[] */ System_Reflection_AssemblyName_GetPublicKeyToken(void* /* System.Reflection.AssemblyName */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.AssemblyName __selfConverted = InteropUtils.GetInstance<System.Reflection.AssemblyName>(__self);
	
	
	    try {
			System.Byte[] __returnValue = __selfConverted.GetPublicKeyToken();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_AssemblyName_SetPublicKeyToken")]
	internal static void /* System.Void */ System_Reflection_AssemblyName_SetPublicKeyToken(void* /* System.Reflection.AssemblyName */ __self, void* /* System.Byte[] */ publicKeyToken, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.AssemblyName __selfConverted = InteropUtils.GetInstance<System.Reflection.AssemblyName>(__self);
	
		System.Byte[] publicKeyTokenConverted = InteropUtils.GetInstance<System.Byte[]>(publicKeyToken);
	
	    try {
			__selfConverted.SetPublicKeyToken(publicKeyTokenConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_AssemblyName_ToString")]
	internal static void* /* System.String */ System_Reflection_AssemblyName_ToString(void* /* System.Reflection.AssemblyName */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.AssemblyName __selfConverted = InteropUtils.GetInstance<System.Reflection.AssemblyName>(__self);
	
	
	    try {
			System.String __returnValue = __selfConverted.ToString();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_AssemblyName_GetObjectData")]
	internal static void /* System.Void */ System_Reflection_AssemblyName_GetObjectData(void* /* System.Reflection.AssemblyName */ __self, void* /* System.Runtime.Serialization.SerializationInfo */ info, void* /* System.Runtime.Serialization.StreamingContext */ context, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.AssemblyName __selfConverted = InteropUtils.GetInstance<System.Reflection.AssemblyName>(__self);
	
		System.Runtime.Serialization.SerializationInfo infoConverted = InteropUtils.GetInstance<System.Runtime.Serialization.SerializationInfo>(info);
		System.Runtime.Serialization.StreamingContext contextConverted = InteropUtils.GetInstance<System.Runtime.Serialization.StreamingContext>(context);
	
	    try {
			__selfConverted.GetObjectData(infoConverted, contextConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_AssemblyName_OnDeserialization")]
	internal static void /* System.Void */ System_Reflection_AssemblyName_OnDeserialization(void* /* System.Reflection.AssemblyName */ __self, void* /* System.Object */ sender, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.AssemblyName __selfConverted = InteropUtils.GetInstance<System.Reflection.AssemblyName>(__self);
	
		System.Object senderConverted = InteropUtils.GetInstance<System.Object>(sender);
	
	    try {
			__selfConverted.OnDeserialization(senderConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_AssemblyName_ReferenceMatchesDefinition")]
	internal static byte /* System.Boolean */ System_Reflection_AssemblyName_ReferenceMatchesDefinition(void* /* System.Reflection.AssemblyName */ reference, void* /* System.Reflection.AssemblyName */ definition, void** /* System.Exception */ __outException)
	{
		System.Reflection.AssemblyName referenceConverted = InteropUtils.GetInstance<System.Reflection.AssemblyName>(reference);
		System.Reflection.AssemblyName definitionConverted = InteropUtils.GetInstance<System.Reflection.AssemblyName>(definition);
	
	    try {
			System.Boolean __returnValue = System.Reflection.AssemblyName.ReferenceMatchesDefinition(referenceConverted, definitionConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_AssemblyName_Create")]
	internal static void* /* System.Reflection.AssemblyName */ System_Reflection_AssemblyName_Create(void* /* System.String */ assemblyName, void** /* System.Exception */ __outException)
	{
		System.String assemblyNameConverted = InteropUtils.GetInstance<System.String>(assemblyName);
	
	    try {
			System.Reflection.AssemblyName __returnValue = new System.Reflection.AssemblyName(assemblyNameConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_AssemblyName_Create_1")]
	internal static void* /* System.Reflection.AssemblyName */ System_Reflection_AssemblyName_Create_1(void** /* System.Exception */ __outException)
	{
	
	    try {
			System.Reflection.AssemblyName __returnValue = new System.Reflection.AssemblyName();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_AssemblyName_Name_Get")]
	internal static void* /* System.String */ System_Reflection_AssemblyName_Name_Get(void* /* System.Reflection.AssemblyName */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.AssemblyName __selfConverted = InteropUtils.GetInstance<System.Reflection.AssemblyName>(__self);
	
	
	    try {
			System.String __returnValue = __selfConverted.Name;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_AssemblyName_Name_Set")]
	internal static void /* System.Void */ System_Reflection_AssemblyName_Name_Set(void* /* System.Reflection.AssemblyName */ __self, void* /* System.String */ __value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.AssemblyName __selfConverted = InteropUtils.GetInstance<System.Reflection.AssemblyName>(__self);
	
	
	    try {
			__selfConverted.Name = InteropUtils.GetInstance<System.String>(__value);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_AssemblyName_Version_Get")]
	internal static void* /* System.Version */ System_Reflection_AssemblyName_Version_Get(void* /* System.Reflection.AssemblyName */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.AssemblyName __selfConverted = InteropUtils.GetInstance<System.Reflection.AssemblyName>(__self);
	
	
	    try {
			System.Version __returnValue = __selfConverted.Version;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_AssemblyName_Version_Set")]
	internal static void /* System.Void */ System_Reflection_AssemblyName_Version_Set(void* /* System.Reflection.AssemblyName */ __self, void* /* System.Version */ __value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.AssemblyName __selfConverted = InteropUtils.GetInstance<System.Reflection.AssemblyName>(__self);
	
	
	    try {
			__selfConverted.Version = InteropUtils.GetInstance<System.Version>(__value);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_AssemblyName_CultureInfo_Get")]
	internal static void* /* System.Globalization.CultureInfo */ System_Reflection_AssemblyName_CultureInfo_Get(void* /* System.Reflection.AssemblyName */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.AssemblyName __selfConverted = InteropUtils.GetInstance<System.Reflection.AssemblyName>(__self);
	
	
	    try {
			System.Globalization.CultureInfo __returnValue = __selfConverted.CultureInfo;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_AssemblyName_CultureInfo_Set")]
	internal static void /* System.Void */ System_Reflection_AssemblyName_CultureInfo_Set(void* /* System.Reflection.AssemblyName */ __self, void* /* System.Globalization.CultureInfo */ __value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.AssemblyName __selfConverted = InteropUtils.GetInstance<System.Reflection.AssemblyName>(__self);
	
	
	    try {
			__selfConverted.CultureInfo = InteropUtils.GetInstance<System.Globalization.CultureInfo>(__value);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_AssemblyName_CultureName_Get")]
	internal static void* /* System.String */ System_Reflection_AssemblyName_CultureName_Get(void* /* System.Reflection.AssemblyName */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.AssemblyName __selfConverted = InteropUtils.GetInstance<System.Reflection.AssemblyName>(__self);
	
	
	    try {
			System.String __returnValue = __selfConverted.CultureName;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_AssemblyName_CultureName_Set")]
	internal static void /* System.Void */ System_Reflection_AssemblyName_CultureName_Set(void* /* System.Reflection.AssemblyName */ __self, void* /* System.String */ __value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.AssemblyName __selfConverted = InteropUtils.GetInstance<System.Reflection.AssemblyName>(__self);
	
	
	    try {
			__selfConverted.CultureName = InteropUtils.GetInstance<System.String>(__value);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_AssemblyName_CodeBase_Get")]
	internal static void* /* System.String */ System_Reflection_AssemblyName_CodeBase_Get(void* /* System.Reflection.AssemblyName */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.AssemblyName __selfConverted = InteropUtils.GetInstance<System.Reflection.AssemblyName>(__self);
	
	
	    try {
			System.String __returnValue = __selfConverted.CodeBase;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_AssemblyName_CodeBase_Set")]
	internal static void /* System.Void */ System_Reflection_AssemblyName_CodeBase_Set(void* /* System.Reflection.AssemblyName */ __self, void* /* System.String */ __value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.AssemblyName __selfConverted = InteropUtils.GetInstance<System.Reflection.AssemblyName>(__self);
	
	
	    try {
			__selfConverted.CodeBase = InteropUtils.GetInstance<System.String>(__value);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_AssemblyName_EscapedCodeBase_Get")]
	internal static void* /* System.String */ System_Reflection_AssemblyName_EscapedCodeBase_Get(void* /* System.Reflection.AssemblyName */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.AssemblyName __selfConverted = InteropUtils.GetInstance<System.Reflection.AssemblyName>(__self);
	
	
	    try {
			System.String __returnValue = __selfConverted.EscapedCodeBase;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_AssemblyName_ProcessorArchitecture_Get")]
	internal static System.Reflection.ProcessorArchitecture /* System.Reflection.ProcessorArchitecture */ System_Reflection_AssemblyName_ProcessorArchitecture_Get(void* /* System.Reflection.AssemblyName */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.AssemblyName __selfConverted = InteropUtils.GetInstance<System.Reflection.AssemblyName>(__self);
	
	
	    try {
			System.Reflection.ProcessorArchitecture __returnValue = __selfConverted.ProcessorArchitecture;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return default(System.Reflection.ProcessorArchitecture);
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_AssemblyName_ProcessorArchitecture_Set")]
	internal static void /* System.Void */ System_Reflection_AssemblyName_ProcessorArchitecture_Set(void* /* System.Reflection.AssemblyName */ __self, System.Reflection.ProcessorArchitecture /* System.Reflection.ProcessorArchitecture */ __value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.AssemblyName __selfConverted = InteropUtils.GetInstance<System.Reflection.AssemblyName>(__self);
	
	
	    try {
			__selfConverted.ProcessorArchitecture = __value;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_AssemblyName_ContentType_Get")]
	internal static System.Reflection.AssemblyContentType /* System.Reflection.AssemblyContentType */ System_Reflection_AssemblyName_ContentType_Get(void* /* System.Reflection.AssemblyName */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.AssemblyName __selfConverted = InteropUtils.GetInstance<System.Reflection.AssemblyName>(__self);
	
	
	    try {
			System.Reflection.AssemblyContentType __returnValue = __selfConverted.ContentType;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return default(System.Reflection.AssemblyContentType);
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_AssemblyName_ContentType_Set")]
	internal static void /* System.Void */ System_Reflection_AssemblyName_ContentType_Set(void* /* System.Reflection.AssemblyName */ __self, System.Reflection.AssemblyContentType /* System.Reflection.AssemblyContentType */ __value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.AssemblyName __selfConverted = InteropUtils.GetInstance<System.Reflection.AssemblyName>(__self);
	
	
	    try {
			__selfConverted.ContentType = __value;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_AssemblyName_Flags_Get")]
	internal static System.Reflection.AssemblyNameFlags /* System.Reflection.AssemblyNameFlags */ System_Reflection_AssemblyName_Flags_Get(void* /* System.Reflection.AssemblyName */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.AssemblyName __selfConverted = InteropUtils.GetInstance<System.Reflection.AssemblyName>(__self);
	
	
	    try {
			System.Reflection.AssemblyNameFlags __returnValue = __selfConverted.Flags;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return default(System.Reflection.AssemblyNameFlags);
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_AssemblyName_Flags_Set")]
	internal static void /* System.Void */ System_Reflection_AssemblyName_Flags_Set(void* /* System.Reflection.AssemblyName */ __self, System.Reflection.AssemblyNameFlags /* System.Reflection.AssemblyNameFlags */ __value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.AssemblyName __selfConverted = InteropUtils.GetInstance<System.Reflection.AssemblyName>(__self);
	
	
	    try {
			__selfConverted.Flags = __value;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_AssemblyName_HashAlgorithm_Get")]
	internal static System.Configuration.Assemblies.AssemblyHashAlgorithm /* System.Configuration.Assemblies.AssemblyHashAlgorithm */ System_Reflection_AssemblyName_HashAlgorithm_Get(void* /* System.Reflection.AssemblyName */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.AssemblyName __selfConverted = InteropUtils.GetInstance<System.Reflection.AssemblyName>(__self);
	
	
	    try {
			System.Configuration.Assemblies.AssemblyHashAlgorithm __returnValue = __selfConverted.HashAlgorithm;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return default(System.Configuration.Assemblies.AssemblyHashAlgorithm);
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_AssemblyName_HashAlgorithm_Set")]
	internal static void /* System.Void */ System_Reflection_AssemblyName_HashAlgorithm_Set(void* /* System.Reflection.AssemblyName */ __self, System.Configuration.Assemblies.AssemblyHashAlgorithm /* System.Configuration.Assemblies.AssemblyHashAlgorithm */ __value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.AssemblyName __selfConverted = InteropUtils.GetInstance<System.Reflection.AssemblyName>(__self);
	
	
	    try {
			__selfConverted.HashAlgorithm = __value;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_AssemblyName_VersionCompatibility_Get")]
	internal static System.Configuration.Assemblies.AssemblyVersionCompatibility /* System.Configuration.Assemblies.AssemblyVersionCompatibility */ System_Reflection_AssemblyName_VersionCompatibility_Get(void* /* System.Reflection.AssemblyName */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.AssemblyName __selfConverted = InteropUtils.GetInstance<System.Reflection.AssemblyName>(__self);
	
	
	    try {
			System.Configuration.Assemblies.AssemblyVersionCompatibility __returnValue = __selfConverted.VersionCompatibility;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return default(System.Configuration.Assemblies.AssemblyVersionCompatibility);
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_AssemblyName_VersionCompatibility_Set")]
	internal static void /* System.Void */ System_Reflection_AssemblyName_VersionCompatibility_Set(void* /* System.Reflection.AssemblyName */ __self, System.Configuration.Assemblies.AssemblyVersionCompatibility /* System.Configuration.Assemblies.AssemblyVersionCompatibility */ __value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.AssemblyName __selfConverted = InteropUtils.GetInstance<System.Reflection.AssemblyName>(__self);
	
	
	    try {
			__selfConverted.VersionCompatibility = __value;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_AssemblyName_KeyPair_Get")]
	internal static void* /* System.Reflection.StrongNameKeyPair */ System_Reflection_AssemblyName_KeyPair_Get(void* /* System.Reflection.AssemblyName */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.AssemblyName __selfConverted = InteropUtils.GetInstance<System.Reflection.AssemblyName>(__self);
	
	
	    try {
			System.Reflection.StrongNameKeyPair __returnValue = __selfConverted.KeyPair;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_AssemblyName_KeyPair_Set")]
	internal static void /* System.Void */ System_Reflection_AssemblyName_KeyPair_Set(void* /* System.Reflection.AssemblyName */ __self, void* /* System.Reflection.StrongNameKeyPair */ __value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.AssemblyName __selfConverted = InteropUtils.GetInstance<System.Reflection.AssemblyName>(__self);
	
	
	    try {
			__selfConverted.KeyPair = InteropUtils.GetInstance<System.Reflection.StrongNameKeyPair>(__value);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_AssemblyName_FullName_Get")]
	internal static void* /* System.String */ System_Reflection_AssemblyName_FullName_Get(void* /* System.Reflection.AssemblyName */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.AssemblyName __selfConverted = InteropUtils.GetInstance<System.Reflection.AssemblyName>(__self);
	
	
	    try {
			System.String __returnValue = __selfConverted.FullName;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_AssemblyName_TypeOf")]
	internal static void* /* System.Type */ System_Reflection_AssemblyName_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.Reflection.AssemblyName);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_AssemblyName_Destroy")]
	internal static void /* System.Void */ System_Reflection_AssemblyName_Destroy(void* /* System.Reflection.AssemblyName */ __self)
	{
	
		InteropUtils.FreeIfAllocated(__self);
	}
	
}


internal unsafe class System_Version
{
	[UnmanagedCallersOnly(EntryPoint = "System_Version_Clone")]
	internal static void* /* System.Object */ System_Version_Clone(void* /* System.Version */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Version __selfConverted = InteropUtils.GetInstance<System.Version>(__self);
	
	
	    try {
			System.Object __returnValue = __selfConverted.Clone();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Version_CompareTo")]
	internal static int /* System.Int32 */ System_Version_CompareTo(void* /* System.Version */ __self, void* /* System.Object */ version, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Version __selfConverted = InteropUtils.GetInstance<System.Version>(__self);
	
		System.Object versionConverted = InteropUtils.GetInstance<System.Object>(version);
	
	    try {
			System.Int32 __returnValue = __selfConverted.CompareTo(versionConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Version_CompareTo_1")]
	internal static int /* System.Int32 */ System_Version_CompareTo_1(void* /* System.Version */ __self, void* /* System.Version */ value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Version __selfConverted = InteropUtils.GetInstance<System.Version>(__self);
	
		System.Version valueConverted = InteropUtils.GetInstance<System.Version>(value);
	
	    try {
			System.Int32 __returnValue = __selfConverted.CompareTo(valueConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Version_Equals")]
	internal static byte /* System.Boolean */ System_Version_Equals(void* /* System.Version */ __self, void* /* System.Object */ obj, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Version __selfConverted = InteropUtils.GetInstance<System.Version>(__self);
	
		System.Object objConverted = InteropUtils.GetInstance<System.Object>(obj);
	
	    try {
			System.Boolean __returnValue = __selfConverted.Equals(objConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Version_Equals_1")]
	internal static byte /* System.Boolean */ System_Version_Equals_1(void* /* System.Version */ __self, void* /* System.Version */ obj, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Version __selfConverted = InteropUtils.GetInstance<System.Version>(__self);
	
		System.Version objConverted = InteropUtils.GetInstance<System.Version>(obj);
	
	    try {
			System.Boolean __returnValue = __selfConverted.Equals(objConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Version_GetHashCode")]
	internal static int /* System.Int32 */ System_Version_GetHashCode(void* /* System.Version */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Version __selfConverted = InteropUtils.GetInstance<System.Version>(__self);
	
	
	    try {
			System.Int32 __returnValue = __selfConverted.GetHashCode();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Version_ToString")]
	internal static void* /* System.String */ System_Version_ToString(void* /* System.Version */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Version __selfConverted = InteropUtils.GetInstance<System.Version>(__self);
	
	
	    try {
			System.String __returnValue = __selfConverted.ToString();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Version_ToString_1")]
	internal static void* /* System.String */ System_Version_ToString_1(void* /* System.Version */ __self, int /* System.Int32 */ fieldCount, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Version __selfConverted = InteropUtils.GetInstance<System.Version>(__self);
	
	
	    try {
			System.String __returnValue = __selfConverted.ToString(fieldCount);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Version_Parse")]
	internal static void* /* System.Version */ System_Version_Parse(void* /* System.String */ input, void** /* System.Exception */ __outException)
	{
		System.String inputConverted = InteropUtils.GetInstance<System.String>(input);
	
	    try {
			System.Version __returnValue = System.Version.Parse(inputConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Version_TryParse")]
	internal static byte /* System.Boolean */ System_Version_TryParse(void* /* System.String */ input, void** /* System.Version */ result, void** /* System.Exception */ __outException)
	{
		System.String inputConverted = InteropUtils.GetInstance<System.String>(input);
		System.Version resultConverted;
	
	    try {
			System.Boolean __returnValue = System.Version.TryParse(inputConverted, out resultConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			if (result is not null) {
				*result = resultConverted.AllocateGCHandleAndGetAddress();
			}
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			if (result is not null) {
				*result = null;
			}
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Version_Create")]
	internal static void* /* System.Version */ System_Version_Create(int /* System.Int32 */ major, int /* System.Int32 */ minor, int /* System.Int32 */ build, int /* System.Int32 */ revision, void** /* System.Exception */ __outException)
	{
	
	    try {
			System.Version __returnValue = new System.Version(major, minor, build, revision);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Version_Create_1")]
	internal static void* /* System.Version */ System_Version_Create_1(int /* System.Int32 */ major, int /* System.Int32 */ minor, int /* System.Int32 */ build, void** /* System.Exception */ __outException)
	{
	
	    try {
			System.Version __returnValue = new System.Version(major, minor, build);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Version_Create_2")]
	internal static void* /* System.Version */ System_Version_Create_2(int /* System.Int32 */ major, int /* System.Int32 */ minor, void** /* System.Exception */ __outException)
	{
	
	    try {
			System.Version __returnValue = new System.Version(major, minor);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Version_Create_3")]
	internal static void* /* System.Version */ System_Version_Create_3(void* /* System.String */ version, void** /* System.Exception */ __outException)
	{
		System.String versionConverted = InteropUtils.GetInstance<System.String>(version);
	
	    try {
			System.Version __returnValue = new System.Version(versionConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Version_Create_4")]
	internal static void* /* System.Version */ System_Version_Create_4(void** /* System.Exception */ __outException)
	{
	
	    try {
			System.Version __returnValue = new System.Version();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Version_Major_Get")]
	internal static int /* System.Int32 */ System_Version_Major_Get(void* /* System.Version */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Version __selfConverted = InteropUtils.GetInstance<System.Version>(__self);
	
	
	    try {
			System.Int32 __returnValue = __selfConverted.Major;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Version_Minor_Get")]
	internal static int /* System.Int32 */ System_Version_Minor_Get(void* /* System.Version */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Version __selfConverted = InteropUtils.GetInstance<System.Version>(__self);
	
	
	    try {
			System.Int32 __returnValue = __selfConverted.Minor;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Version_Build_Get")]
	internal static int /* System.Int32 */ System_Version_Build_Get(void* /* System.Version */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Version __selfConverted = InteropUtils.GetInstance<System.Version>(__self);
	
	
	    try {
			System.Int32 __returnValue = __selfConverted.Build;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Version_Revision_Get")]
	internal static int /* System.Int32 */ System_Version_Revision_Get(void* /* System.Version */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Version __selfConverted = InteropUtils.GetInstance<System.Version>(__self);
	
	
	    try {
			System.Int32 __returnValue = __selfConverted.Revision;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Version_MajorRevision_Get")]
	internal static short /* System.Int16 */ System_Version_MajorRevision_Get(void* /* System.Version */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Version __selfConverted = InteropUtils.GetInstance<System.Version>(__self);
	
	
	    try {
			System.Int16 __returnValue = __selfConverted.MajorRevision;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Version_MinorRevision_Get")]
	internal static short /* System.Int16 */ System_Version_MinorRevision_Get(void* /* System.Version */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Version __selfConverted = InteropUtils.GetInstance<System.Version>(__self);
	
	
	    try {
			System.Int16 __returnValue = __selfConverted.MinorRevision;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Version_TypeOf")]
	internal static void* /* System.Type */ System_Version_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.Version);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Version_Destroy")]
	internal static void /* System.Void */ System_Version_Destroy(void* /* System.Version */ __self)
	{
	
		InteropUtils.FreeIfAllocated(__self);
	}
	
}



internal unsafe class System_Reflection_ProcessorArchitecture
{
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_ProcessorArchitecture_TypeOf")]
	internal static void* /* System.Type */ System_Reflection_ProcessorArchitecture_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.Reflection.ProcessorArchitecture);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
}


internal unsafe class System_Reflection_AssemblyContentType
{
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_AssemblyContentType_TypeOf")]
	internal static void* /* System.Type */ System_Reflection_AssemblyContentType_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.Reflection.AssemblyContentType);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
}



internal unsafe class System_Reflection_AssemblyNameFlags
{
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_AssemblyNameFlags_TypeOf")]
	internal static void* /* System.Type */ System_Reflection_AssemblyNameFlags_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.Reflection.AssemblyNameFlags);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
}


internal unsafe class System_Configuration_Assemblies_AssemblyHashAlgorithm
{
	[UnmanagedCallersOnly(EntryPoint = "System_Configuration_Assemblies_AssemblyHashAlgorithm_TypeOf")]
	internal static void* /* System.Type */ System_Configuration_Assemblies_AssemblyHashAlgorithm_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.Configuration.Assemblies.AssemblyHashAlgorithm);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
}


internal unsafe class System_Configuration_Assemblies_AssemblyVersionCompatibility
{
	[UnmanagedCallersOnly(EntryPoint = "System_Configuration_Assemblies_AssemblyVersionCompatibility_TypeOf")]
	internal static void* /* System.Type */ System_Configuration_Assemblies_AssemblyVersionCompatibility_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.Configuration.Assemblies.AssemblyVersionCompatibility);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
}


internal unsafe class System_Reflection_StrongNameKeyPair
{
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_StrongNameKeyPair_Create")]
	internal static void* /* System.Reflection.StrongNameKeyPair */ System_Reflection_StrongNameKeyPair_Create(void* /* System.IO.FileStream */ keyPairFile, void** /* System.Exception */ __outException)
	{
		System.IO.FileStream keyPairFileConverted = InteropUtils.GetInstance<System.IO.FileStream>(keyPairFile);
	
	    try {
			System.Reflection.StrongNameKeyPair __returnValue = new System.Reflection.StrongNameKeyPair(keyPairFileConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_StrongNameKeyPair_Create_1")]
	internal static void* /* System.Reflection.StrongNameKeyPair */ System_Reflection_StrongNameKeyPair_Create_1(void* /* System.Byte[] */ keyPairArray, void** /* System.Exception */ __outException)
	{
		System.Byte[] keyPairArrayConverted = InteropUtils.GetInstance<System.Byte[]>(keyPairArray);
	
	    try {
			System.Reflection.StrongNameKeyPair __returnValue = new System.Reflection.StrongNameKeyPair(keyPairArrayConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_StrongNameKeyPair_Create_2")]
	internal static void* /* System.Reflection.StrongNameKeyPair */ System_Reflection_StrongNameKeyPair_Create_2(void* /* System.String */ keyPairContainer, void** /* System.Exception */ __outException)
	{
		System.String keyPairContainerConverted = InteropUtils.GetInstance<System.String>(keyPairContainer);
	
	    try {
			System.Reflection.StrongNameKeyPair __returnValue = new System.Reflection.StrongNameKeyPair(keyPairContainerConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_StrongNameKeyPair_PublicKey_Get")]
	internal static void* /* System.Byte[] */ System_Reflection_StrongNameKeyPair_PublicKey_Get(void* /* System.Reflection.StrongNameKeyPair */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.StrongNameKeyPair __selfConverted = InteropUtils.GetInstance<System.Reflection.StrongNameKeyPair>(__self);
	
	
	    try {
			System.Byte[] __returnValue = __selfConverted.PublicKey;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_StrongNameKeyPair_TypeOf")]
	internal static void* /* System.Type */ System_Reflection_StrongNameKeyPair_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.Reflection.StrongNameKeyPair);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_StrongNameKeyPair_Destroy")]
	internal static void /* System.Void */ System_Reflection_StrongNameKeyPair_Destroy(void* /* System.Reflection.StrongNameKeyPair */ __self)
	{
	
		InteropUtils.FreeIfAllocated(__self);
	}
	
}


internal unsafe class System_IO_FileStream
{
	[UnmanagedCallersOnly(EntryPoint = "System_IO_FileStream_Lock")]
	internal static void /* System.Void */ System_IO_FileStream_Lock(void* /* System.IO.FileStream */ __self, long /* System.Int64 */ position, long /* System.Int64 */ length, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.IO.FileStream __selfConverted = InteropUtils.GetInstance<System.IO.FileStream>(__self);
	
	
	    try {
			__selfConverted.Lock(position, length);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_IO_FileStream_Unlock")]
	internal static void /* System.Void */ System_IO_FileStream_Unlock(void* /* System.IO.FileStream */ __self, long /* System.Int64 */ position, long /* System.Int64 */ length, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.IO.FileStream __selfConverted = InteropUtils.GetInstance<System.IO.FileStream>(__self);
	
	
	    try {
			__selfConverted.Unlock(position, length);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_IO_FileStream_FlushAsync")]
	internal static void* /* System.Threading.Tasks.Task */ System_IO_FileStream_FlushAsync(void* /* System.IO.FileStream */ __self, void* /* System.Threading.CancellationToken */ cancellationToken, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.IO.FileStream __selfConverted = InteropUtils.GetInstance<System.IO.FileStream>(__self);
	
		System.Threading.CancellationToken cancellationTokenConverted = InteropUtils.GetInstance<System.Threading.CancellationToken>(cancellationToken);
	
	    try {
			System.Threading.Tasks.Task __returnValue = __selfConverted.FlushAsync(cancellationTokenConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_IO_FileStream_Read")]
	internal static int /* System.Int32 */ System_IO_FileStream_Read(void* /* System.IO.FileStream */ __self, void* /* System.Byte[] */ buffer, int /* System.Int32 */ offset, int /* System.Int32 */ count, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.IO.FileStream __selfConverted = InteropUtils.GetInstance<System.IO.FileStream>(__self);
	
		System.Byte[] bufferConverted = InteropUtils.GetInstance<System.Byte[]>(buffer);
	
	    try {
			System.Int32 __returnValue = __selfConverted.Read(bufferConverted, offset, count);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_IO_FileStream_Write")]
	internal static void /* System.Void */ System_IO_FileStream_Write(void* /* System.IO.FileStream */ __self, void* /* System.Byte[] */ buffer, int /* System.Int32 */ offset, int /* System.Int32 */ count, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.IO.FileStream __selfConverted = InteropUtils.GetInstance<System.IO.FileStream>(__self);
	
		System.Byte[] bufferConverted = InteropUtils.GetInstance<System.Byte[]>(buffer);
	
	    try {
			__selfConverted.Write(bufferConverted, offset, count);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_IO_FileStream_WriteAsync")]
	internal static void* /* System.Threading.Tasks.Task */ System_IO_FileStream_WriteAsync(void* /* System.IO.FileStream */ __self, void* /* System.Byte[] */ buffer, int /* System.Int32 */ offset, int /* System.Int32 */ count, void* /* System.Threading.CancellationToken */ cancellationToken, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.IO.FileStream __selfConverted = InteropUtils.GetInstance<System.IO.FileStream>(__self);
	
		System.Byte[] bufferConverted = InteropUtils.GetInstance<System.Byte[]>(buffer);
		System.Threading.CancellationToken cancellationTokenConverted = InteropUtils.GetInstance<System.Threading.CancellationToken>(cancellationToken);
	
	    try {
			System.Threading.Tasks.Task __returnValue = __selfConverted.WriteAsync(bufferConverted, offset, count, cancellationTokenConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_IO_FileStream_Flush_1")]
	internal static void /* System.Void */ System_IO_FileStream_Flush_1(void* /* System.IO.FileStream */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.IO.FileStream __selfConverted = InteropUtils.GetInstance<System.IO.FileStream>(__self);
	
	
	    try {
			__selfConverted.Flush();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_IO_FileStream_Flush_2")]
	internal static void /* System.Void */ System_IO_FileStream_Flush_2(void* /* System.IO.FileStream */ __self, byte /* System.Boolean */ flushToDisk, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.IO.FileStream __selfConverted = InteropUtils.GetInstance<System.IO.FileStream>(__self);
	
		System.Boolean flushToDiskConverted = flushToDisk.ToBool();
	
	    try {
			__selfConverted.Flush(flushToDiskConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_IO_FileStream_SetLength")]
	internal static void /* System.Void */ System_IO_FileStream_SetLength(void* /* System.IO.FileStream */ __self, long /* System.Int64 */ value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.IO.FileStream __selfConverted = InteropUtils.GetInstance<System.IO.FileStream>(__self);
	
	
	    try {
			__selfConverted.SetLength(value);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_IO_FileStream_ReadByte")]
	internal static int /* System.Int32 */ System_IO_FileStream_ReadByte(void* /* System.IO.FileStream */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.IO.FileStream __selfConverted = InteropUtils.GetInstance<System.IO.FileStream>(__self);
	
	
	    try {
			System.Int32 __returnValue = __selfConverted.ReadByte();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_IO_FileStream_WriteByte")]
	internal static void /* System.Void */ System_IO_FileStream_WriteByte(void* /* System.IO.FileStream */ __self, byte /* System.Byte */ value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.IO.FileStream __selfConverted = InteropUtils.GetInstance<System.IO.FileStream>(__self);
	
	
	    try {
			__selfConverted.WriteByte(value);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_IO_FileStream_DisposeAsync")]
	internal static void* /* System.Threading.Tasks.ValueTask */ System_IO_FileStream_DisposeAsync(void* /* System.IO.FileStream */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.IO.FileStream __selfConverted = InteropUtils.GetInstance<System.IO.FileStream>(__self);
	
	
	    try {
			System.Threading.Tasks.ValueTask __returnValue = __selfConverted.DisposeAsync();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_IO_FileStream_CopyTo")]
	internal static void /* System.Void */ System_IO_FileStream_CopyTo(void* /* System.IO.FileStream */ __self, void* /* System.IO.Stream */ destination, int /* System.Int32 */ bufferSize, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.IO.FileStream __selfConverted = InteropUtils.GetInstance<System.IO.FileStream>(__self);
	
		System.IO.Stream destinationConverted = InteropUtils.GetInstance<System.IO.Stream>(destination);
	
	    try {
			__selfConverted.CopyTo(destinationConverted, bufferSize);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_IO_FileStream_CopyToAsync")]
	internal static void* /* System.Threading.Tasks.Task */ System_IO_FileStream_CopyToAsync(void* /* System.IO.FileStream */ __self, void* /* System.IO.Stream */ destination, int /* System.Int32 */ bufferSize, void* /* System.Threading.CancellationToken */ cancellationToken, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.IO.FileStream __selfConverted = InteropUtils.GetInstance<System.IO.FileStream>(__self);
	
		System.IO.Stream destinationConverted = InteropUtils.GetInstance<System.IO.Stream>(destination);
		System.Threading.CancellationToken cancellationTokenConverted = InteropUtils.GetInstance<System.Threading.CancellationToken>(cancellationToken);
	
	    try {
			System.Threading.Tasks.Task __returnValue = __selfConverted.CopyToAsync(destinationConverted, bufferSize, cancellationTokenConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_IO_FileStream_BeginRead")]
	internal static void* /* System.IAsyncResult */ System_IO_FileStream_BeginRead(void* /* System.IO.FileStream */ __self, void* /* System.Byte[] */ buffer, int /* System.Int32 */ offset, int /* System.Int32 */ count, void* /* System.AsyncCallback */ callback, void* /* System.Object */ state, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.IO.FileStream __selfConverted = InteropUtils.GetInstance<System.IO.FileStream>(__self);
	
		System.Byte[] bufferConverted = InteropUtils.GetInstance<System.Byte[]>(buffer);
		System.AsyncCallback callbackConverted = InteropUtils.GetInstance<System_AsyncCallback>(callback)?.Trampoline;
		System.Object stateConverted = InteropUtils.GetInstance<System.Object>(state);
	
	    try {
			System.IAsyncResult __returnValue = __selfConverted.BeginRead(bufferConverted, offset, count, callbackConverted, stateConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_IO_FileStream_EndRead")]
	internal static int /* System.Int32 */ System_IO_FileStream_EndRead(void* /* System.IO.FileStream */ __self, void* /* System.IAsyncResult */ asyncResult, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.IO.FileStream __selfConverted = InteropUtils.GetInstance<System.IO.FileStream>(__self);
	
		System.IAsyncResult asyncResultConverted = InteropUtils.GetInstance<System.IAsyncResult>(asyncResult);
	
	    try {
			System.Int32 __returnValue = __selfConverted.EndRead(asyncResultConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_IO_FileStream_BeginWrite")]
	internal static void* /* System.IAsyncResult */ System_IO_FileStream_BeginWrite(void* /* System.IO.FileStream */ __self, void* /* System.Byte[] */ buffer, int /* System.Int32 */ offset, int /* System.Int32 */ count, void* /* System.AsyncCallback */ callback, void* /* System.Object */ state, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.IO.FileStream __selfConverted = InteropUtils.GetInstance<System.IO.FileStream>(__self);
	
		System.Byte[] bufferConverted = InteropUtils.GetInstance<System.Byte[]>(buffer);
		System.AsyncCallback callbackConverted = InteropUtils.GetInstance<System_AsyncCallback>(callback)?.Trampoline;
		System.Object stateConverted = InteropUtils.GetInstance<System.Object>(state);
	
	    try {
			System.IAsyncResult __returnValue = __selfConverted.BeginWrite(bufferConverted, offset, count, callbackConverted, stateConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_IO_FileStream_EndWrite")]
	internal static void /* System.Void */ System_IO_FileStream_EndWrite(void* /* System.IO.FileStream */ __self, void* /* System.IAsyncResult */ asyncResult, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.IO.FileStream __selfConverted = InteropUtils.GetInstance<System.IO.FileStream>(__self);
	
		System.IAsyncResult asyncResultConverted = InteropUtils.GetInstance<System.IAsyncResult>(asyncResult);
	
	    try {
			__selfConverted.EndWrite(asyncResultConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_IO_FileStream_Seek")]
	internal static long /* System.Int64 */ System_IO_FileStream_Seek(void* /* System.IO.FileStream */ __self, long /* System.Int64 */ offset, System.IO.SeekOrigin /* System.IO.SeekOrigin */ origin, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.IO.FileStream __selfConverted = InteropUtils.GetInstance<System.IO.FileStream>(__self);
	
	
	    try {
			System.Int64 __returnValue = __selfConverted.Seek(offset, origin);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_IO_FileStream_Create")]
	internal static void* /* System.IO.FileStream */ System_IO_FileStream_Create(nint /* System.IntPtr */ handle, System.IO.FileAccess /* System.IO.FileAccess */ access, void** /* System.Exception */ __outException)
	{
	
	    try {
			System.IO.FileStream __returnValue = new System.IO.FileStream(handle, access);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_IO_FileStream_Create_1")]
	internal static void* /* System.IO.FileStream */ System_IO_FileStream_Create_1(nint /* System.IntPtr */ handle, System.IO.FileAccess /* System.IO.FileAccess */ access, byte /* System.Boolean */ ownsHandle, void** /* System.Exception */ __outException)
	{
		System.Boolean ownsHandleConverted = ownsHandle.ToBool();
	
	    try {
			System.IO.FileStream __returnValue = new System.IO.FileStream(handle, access, ownsHandleConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_IO_FileStream_Create_2")]
	internal static void* /* System.IO.FileStream */ System_IO_FileStream_Create_2(nint /* System.IntPtr */ handle, System.IO.FileAccess /* System.IO.FileAccess */ access, byte /* System.Boolean */ ownsHandle, int /* System.Int32 */ bufferSize, void** /* System.Exception */ __outException)
	{
		System.Boolean ownsHandleConverted = ownsHandle.ToBool();
	
	    try {
			System.IO.FileStream __returnValue = new System.IO.FileStream(handle, access, ownsHandleConverted, bufferSize);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_IO_FileStream_Create_3")]
	internal static void* /* System.IO.FileStream */ System_IO_FileStream_Create_3(nint /* System.IntPtr */ handle, System.IO.FileAccess /* System.IO.FileAccess */ access, byte /* System.Boolean */ ownsHandle, int /* System.Int32 */ bufferSize, byte /* System.Boolean */ isAsync, void** /* System.Exception */ __outException)
	{
		System.Boolean ownsHandleConverted = ownsHandle.ToBool();
		System.Boolean isAsyncConverted = isAsync.ToBool();
	
	    try {
			System.IO.FileStream __returnValue = new System.IO.FileStream(handle, access, ownsHandleConverted, bufferSize, isAsyncConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_IO_FileStream_Create_4")]
	internal static void* /* System.IO.FileStream */ System_IO_FileStream_Create_4(void* /* Microsoft.Win32.SafeHandles.SafeFileHandle */ handle, System.IO.FileAccess /* System.IO.FileAccess */ access, void** /* System.Exception */ __outException)
	{
		Microsoft.Win32.SafeHandles.SafeFileHandle handleConverted = InteropUtils.GetInstance<Microsoft.Win32.SafeHandles.SafeFileHandle>(handle);
	
	    try {
			System.IO.FileStream __returnValue = new System.IO.FileStream(handleConverted, access);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_IO_FileStream_Create_5")]
	internal static void* /* System.IO.FileStream */ System_IO_FileStream_Create_5(void* /* Microsoft.Win32.SafeHandles.SafeFileHandle */ handle, System.IO.FileAccess /* System.IO.FileAccess */ access, int /* System.Int32 */ bufferSize, void** /* System.Exception */ __outException)
	{
		Microsoft.Win32.SafeHandles.SafeFileHandle handleConverted = InteropUtils.GetInstance<Microsoft.Win32.SafeHandles.SafeFileHandle>(handle);
	
	    try {
			System.IO.FileStream __returnValue = new System.IO.FileStream(handleConverted, access, bufferSize);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_IO_FileStream_Create_6")]
	internal static void* /* System.IO.FileStream */ System_IO_FileStream_Create_6(void* /* Microsoft.Win32.SafeHandles.SafeFileHandle */ handle, System.IO.FileAccess /* System.IO.FileAccess */ access, int /* System.Int32 */ bufferSize, byte /* System.Boolean */ isAsync, void** /* System.Exception */ __outException)
	{
		Microsoft.Win32.SafeHandles.SafeFileHandle handleConverted = InteropUtils.GetInstance<Microsoft.Win32.SafeHandles.SafeFileHandle>(handle);
		System.Boolean isAsyncConverted = isAsync.ToBool();
	
	    try {
			System.IO.FileStream __returnValue = new System.IO.FileStream(handleConverted, access, bufferSize, isAsyncConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_IO_FileStream_Create_7")]
	internal static void* /* System.IO.FileStream */ System_IO_FileStream_Create_7(void* /* System.String */ path, System.IO.FileMode /* System.IO.FileMode */ mode, void** /* System.Exception */ __outException)
	{
		System.String pathConverted = InteropUtils.GetInstance<System.String>(path);
	
	    try {
			System.IO.FileStream __returnValue = new System.IO.FileStream(pathConverted, mode);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_IO_FileStream_Create_8")]
	internal static void* /* System.IO.FileStream */ System_IO_FileStream_Create_8(void* /* System.String */ path, System.IO.FileMode /* System.IO.FileMode */ mode, System.IO.FileAccess /* System.IO.FileAccess */ access, void** /* System.Exception */ __outException)
	{
		System.String pathConverted = InteropUtils.GetInstance<System.String>(path);
	
	    try {
			System.IO.FileStream __returnValue = new System.IO.FileStream(pathConverted, mode, access);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_IO_FileStream_Create_9")]
	internal static void* /* System.IO.FileStream */ System_IO_FileStream_Create_9(void* /* System.String */ path, System.IO.FileMode /* System.IO.FileMode */ mode, System.IO.FileAccess /* System.IO.FileAccess */ access, System.IO.FileShare /* System.IO.FileShare */ share, void** /* System.Exception */ __outException)
	{
		System.String pathConverted = InteropUtils.GetInstance<System.String>(path);
	
	    try {
			System.IO.FileStream __returnValue = new System.IO.FileStream(pathConverted, mode, access, share);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_IO_FileStream_Create_10")]
	internal static void* /* System.IO.FileStream */ System_IO_FileStream_Create_10(void* /* System.String */ path, System.IO.FileMode /* System.IO.FileMode */ mode, System.IO.FileAccess /* System.IO.FileAccess */ access, System.IO.FileShare /* System.IO.FileShare */ share, int /* System.Int32 */ bufferSize, void** /* System.Exception */ __outException)
	{
		System.String pathConverted = InteropUtils.GetInstance<System.String>(path);
	
	    try {
			System.IO.FileStream __returnValue = new System.IO.FileStream(pathConverted, mode, access, share, bufferSize);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_IO_FileStream_Create_11")]
	internal static void* /* System.IO.FileStream */ System_IO_FileStream_Create_11(void* /* System.String */ path, System.IO.FileMode /* System.IO.FileMode */ mode, System.IO.FileAccess /* System.IO.FileAccess */ access, System.IO.FileShare /* System.IO.FileShare */ share, int /* System.Int32 */ bufferSize, byte /* System.Boolean */ useAsync, void** /* System.Exception */ __outException)
	{
		System.String pathConverted = InteropUtils.GetInstance<System.String>(path);
		System.Boolean useAsyncConverted = useAsync.ToBool();
	
	    try {
			System.IO.FileStream __returnValue = new System.IO.FileStream(pathConverted, mode, access, share, bufferSize, useAsyncConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_IO_FileStream_Create_12")]
	internal static void* /* System.IO.FileStream */ System_IO_FileStream_Create_12(void* /* System.String */ path, System.IO.FileMode /* System.IO.FileMode */ mode, System.IO.FileAccess /* System.IO.FileAccess */ access, System.IO.FileShare /* System.IO.FileShare */ share, int /* System.Int32 */ bufferSize, System.IO.FileOptions /* System.IO.FileOptions */ options, void** /* System.Exception */ __outException)
	{
		System.String pathConverted = InteropUtils.GetInstance<System.String>(path);
	
	    try {
			System.IO.FileStream __returnValue = new System.IO.FileStream(pathConverted, mode, access, share, bufferSize, options);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_IO_FileStream_Create_13")]
	internal static void* /* System.IO.FileStream */ System_IO_FileStream_Create_13(void* /* System.String */ path, void* /* System.IO.FileStreamOptions */ options, void** /* System.Exception */ __outException)
	{
		System.String pathConverted = InteropUtils.GetInstance<System.String>(path);
		System.IO.FileStreamOptions optionsConverted = InteropUtils.GetInstance<System.IO.FileStreamOptions>(options);
	
	    try {
			System.IO.FileStream __returnValue = new System.IO.FileStream(pathConverted, optionsConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_IO_FileStream_Handle_Get")]
	internal static nint /* System.IntPtr */ System_IO_FileStream_Handle_Get(void* /* System.IO.FileStream */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.IO.FileStream __selfConverted = InteropUtils.GetInstance<System.IO.FileStream>(__self);
	
	
	    try {
			System.IntPtr __returnValue = __selfConverted.Handle;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return nint.Zero;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_IO_FileStream_CanRead_Get")]
	internal static byte /* System.Boolean */ System_IO_FileStream_CanRead_Get(void* /* System.IO.FileStream */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.IO.FileStream __selfConverted = InteropUtils.GetInstance<System.IO.FileStream>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.CanRead;
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_IO_FileStream_CanWrite_Get")]
	internal static byte /* System.Boolean */ System_IO_FileStream_CanWrite_Get(void* /* System.IO.FileStream */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.IO.FileStream __selfConverted = InteropUtils.GetInstance<System.IO.FileStream>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.CanWrite;
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_IO_FileStream_SafeFileHandle_Get")]
	internal static void* /* Microsoft.Win32.SafeHandles.SafeFileHandle */ System_IO_FileStream_SafeFileHandle_Get(void* /* System.IO.FileStream */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.IO.FileStream __selfConverted = InteropUtils.GetInstance<System.IO.FileStream>(__self);
	
	
	    try {
			Microsoft.Win32.SafeHandles.SafeFileHandle __returnValue = __selfConverted.SafeFileHandle;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_IO_FileStream_Name_Get")]
	internal static void* /* System.String */ System_IO_FileStream_Name_Get(void* /* System.IO.FileStream */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.IO.FileStream __selfConverted = InteropUtils.GetInstance<System.IO.FileStream>(__self);
	
	
	    try {
			System.String __returnValue = __selfConverted.Name;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_IO_FileStream_IsAsync_Get")]
	internal static byte /* System.Boolean */ System_IO_FileStream_IsAsync_Get(void* /* System.IO.FileStream */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.IO.FileStream __selfConverted = InteropUtils.GetInstance<System.IO.FileStream>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.IsAsync;
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_IO_FileStream_Length_Get")]
	internal static long /* System.Int64 */ System_IO_FileStream_Length_Get(void* /* System.IO.FileStream */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.IO.FileStream __selfConverted = InteropUtils.GetInstance<System.IO.FileStream>(__self);
	
	
	    try {
			System.Int64 __returnValue = __selfConverted.Length;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_IO_FileStream_Position_Get")]
	internal static long /* System.Int64 */ System_IO_FileStream_Position_Get(void* /* System.IO.FileStream */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.IO.FileStream __selfConverted = InteropUtils.GetInstance<System.IO.FileStream>(__self);
	
	
	    try {
			System.Int64 __returnValue = __selfConverted.Position;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_IO_FileStream_Position_Set")]
	internal static void /* System.Void */ System_IO_FileStream_Position_Set(void* /* System.IO.FileStream */ __self, long /* System.Int64 */ __value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.IO.FileStream __selfConverted = InteropUtils.GetInstance<System.IO.FileStream>(__self);
	
	
	    try {
			__selfConverted.Position = __value;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_IO_FileStream_CanSeek_Get")]
	internal static byte /* System.Boolean */ System_IO_FileStream_CanSeek_Get(void* /* System.IO.FileStream */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.IO.FileStream __selfConverted = InteropUtils.GetInstance<System.IO.FileStream>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.CanSeek;
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_IO_FileStream_TypeOf")]
	internal static void* /* System.Type */ System_IO_FileStream_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.IO.FileStream);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_IO_FileStream_Destroy")]
	internal static void /* System.Void */ System_IO_FileStream_Destroy(void* /* System.IO.FileStream */ __self)
	{
	
		InteropUtils.FreeIfAllocated(__self);
	}
	
}


internal unsafe class System_IO_Stream
{
	[UnmanagedCallersOnly(EntryPoint = "System_IO_Stream_CopyTo")]
	internal static void /* System.Void */ System_IO_Stream_CopyTo(void* /* System.IO.Stream */ __self, void* /* System.IO.Stream */ destination, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.IO.Stream __selfConverted = InteropUtils.GetInstance<System.IO.Stream>(__self);
	
		System.IO.Stream destinationConverted = InteropUtils.GetInstance<System.IO.Stream>(destination);
	
	    try {
			__selfConverted.CopyTo(destinationConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_IO_Stream_CopyTo_1")]
	internal static void /* System.Void */ System_IO_Stream_CopyTo_1(void* /* System.IO.Stream */ __self, void* /* System.IO.Stream */ destination, int /* System.Int32 */ bufferSize, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.IO.Stream __selfConverted = InteropUtils.GetInstance<System.IO.Stream>(__self);
	
		System.IO.Stream destinationConverted = InteropUtils.GetInstance<System.IO.Stream>(destination);
	
	    try {
			__selfConverted.CopyTo(destinationConverted, bufferSize);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_IO_Stream_CopyToAsync")]
	internal static void* /* System.Threading.Tasks.Task */ System_IO_Stream_CopyToAsync(void* /* System.IO.Stream */ __self, void* /* System.IO.Stream */ destination, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.IO.Stream __selfConverted = InteropUtils.GetInstance<System.IO.Stream>(__self);
	
		System.IO.Stream destinationConverted = InteropUtils.GetInstance<System.IO.Stream>(destination);
	
	    try {
			System.Threading.Tasks.Task __returnValue = __selfConverted.CopyToAsync(destinationConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_IO_Stream_CopyToAsync_1")]
	internal static void* /* System.Threading.Tasks.Task */ System_IO_Stream_CopyToAsync_1(void* /* System.IO.Stream */ __self, void* /* System.IO.Stream */ destination, int /* System.Int32 */ bufferSize, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.IO.Stream __selfConverted = InteropUtils.GetInstance<System.IO.Stream>(__self);
	
		System.IO.Stream destinationConverted = InteropUtils.GetInstance<System.IO.Stream>(destination);
	
	    try {
			System.Threading.Tasks.Task __returnValue = __selfConverted.CopyToAsync(destinationConverted, bufferSize);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_IO_Stream_CopyToAsync_2")]
	internal static void* /* System.Threading.Tasks.Task */ System_IO_Stream_CopyToAsync_2(void* /* System.IO.Stream */ __self, void* /* System.IO.Stream */ destination, void* /* System.Threading.CancellationToken */ cancellationToken, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.IO.Stream __selfConverted = InteropUtils.GetInstance<System.IO.Stream>(__self);
	
		System.IO.Stream destinationConverted = InteropUtils.GetInstance<System.IO.Stream>(destination);
		System.Threading.CancellationToken cancellationTokenConverted = InteropUtils.GetInstance<System.Threading.CancellationToken>(cancellationToken);
	
	    try {
			System.Threading.Tasks.Task __returnValue = __selfConverted.CopyToAsync(destinationConverted, cancellationTokenConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_IO_Stream_CopyToAsync_3")]
	internal static void* /* System.Threading.Tasks.Task */ System_IO_Stream_CopyToAsync_3(void* /* System.IO.Stream */ __self, void* /* System.IO.Stream */ destination, int /* System.Int32 */ bufferSize, void* /* System.Threading.CancellationToken */ cancellationToken, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.IO.Stream __selfConverted = InteropUtils.GetInstance<System.IO.Stream>(__self);
	
		System.IO.Stream destinationConverted = InteropUtils.GetInstance<System.IO.Stream>(destination);
		System.Threading.CancellationToken cancellationTokenConverted = InteropUtils.GetInstance<System.Threading.CancellationToken>(cancellationToken);
	
	    try {
			System.Threading.Tasks.Task __returnValue = __selfConverted.CopyToAsync(destinationConverted, bufferSize, cancellationTokenConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_IO_Stream_Dispose")]
	internal static void /* System.Void */ System_IO_Stream_Dispose(void* /* System.IO.Stream */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.IO.Stream __selfConverted = InteropUtils.GetInstance<System.IO.Stream>(__self);
	
	
	    try {
			__selfConverted.Dispose();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_IO_Stream_Close")]
	internal static void /* System.Void */ System_IO_Stream_Close(void* /* System.IO.Stream */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.IO.Stream __selfConverted = InteropUtils.GetInstance<System.IO.Stream>(__self);
	
	
	    try {
			__selfConverted.Close();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_IO_Stream_DisposeAsync")]
	internal static void* /* System.Threading.Tasks.ValueTask */ System_IO_Stream_DisposeAsync(void* /* System.IO.Stream */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.IO.Stream __selfConverted = InteropUtils.GetInstance<System.IO.Stream>(__self);
	
	
	    try {
			System.Threading.Tasks.ValueTask __returnValue = __selfConverted.DisposeAsync();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_IO_Stream_Flush")]
	internal static void /* System.Void */ System_IO_Stream_Flush(void* /* System.IO.Stream */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.IO.Stream __selfConverted = InteropUtils.GetInstance<System.IO.Stream>(__self);
	
	
	    try {
			__selfConverted.Flush();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_IO_Stream_FlushAsync")]
	internal static void* /* System.Threading.Tasks.Task */ System_IO_Stream_FlushAsync(void* /* System.IO.Stream */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.IO.Stream __selfConverted = InteropUtils.GetInstance<System.IO.Stream>(__self);
	
	
	    try {
			System.Threading.Tasks.Task __returnValue = __selfConverted.FlushAsync();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_IO_Stream_FlushAsync_1")]
	internal static void* /* System.Threading.Tasks.Task */ System_IO_Stream_FlushAsync_1(void* /* System.IO.Stream */ __self, void* /* System.Threading.CancellationToken */ cancellationToken, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.IO.Stream __selfConverted = InteropUtils.GetInstance<System.IO.Stream>(__self);
	
		System.Threading.CancellationToken cancellationTokenConverted = InteropUtils.GetInstance<System.Threading.CancellationToken>(cancellationToken);
	
	    try {
			System.Threading.Tasks.Task __returnValue = __selfConverted.FlushAsync(cancellationTokenConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_IO_Stream_BeginRead")]
	internal static void* /* System.IAsyncResult */ System_IO_Stream_BeginRead(void* /* System.IO.Stream */ __self, void* /* System.Byte[] */ buffer, int /* System.Int32 */ offset, int /* System.Int32 */ count, void* /* System.AsyncCallback */ callback, void* /* System.Object */ state, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.IO.Stream __selfConverted = InteropUtils.GetInstance<System.IO.Stream>(__self);
	
		System.Byte[] bufferConverted = InteropUtils.GetInstance<System.Byte[]>(buffer);
		System.AsyncCallback callbackConverted = InteropUtils.GetInstance<System_AsyncCallback>(callback)?.Trampoline;
		System.Object stateConverted = InteropUtils.GetInstance<System.Object>(state);
	
	    try {
			System.IAsyncResult __returnValue = __selfConverted.BeginRead(bufferConverted, offset, count, callbackConverted, stateConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_IO_Stream_EndRead")]
	internal static int /* System.Int32 */ System_IO_Stream_EndRead(void* /* System.IO.Stream */ __self, void* /* System.IAsyncResult */ asyncResult, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.IO.Stream __selfConverted = InteropUtils.GetInstance<System.IO.Stream>(__self);
	
		System.IAsyncResult asyncResultConverted = InteropUtils.GetInstance<System.IAsyncResult>(asyncResult);
	
	    try {
			System.Int32 __returnValue = __selfConverted.EndRead(asyncResultConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_IO_Stream_ReadExactlyAsync")]
	internal static void* /* System.Threading.Tasks.ValueTask */ System_IO_Stream_ReadExactlyAsync(void* /* System.IO.Stream */ __self, void* /* System.Byte[] */ buffer, int /* System.Int32 */ offset, int /* System.Int32 */ count, void* /* System.Threading.CancellationToken */ cancellationToken, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.IO.Stream __selfConverted = InteropUtils.GetInstance<System.IO.Stream>(__self);
	
		System.Byte[] bufferConverted = InteropUtils.GetInstance<System.Byte[]>(buffer);
		System.Threading.CancellationToken cancellationTokenConverted = InteropUtils.GetInstance<System.Threading.CancellationToken>(cancellationToken);
	
	    try {
			System.Threading.Tasks.ValueTask __returnValue = __selfConverted.ReadExactlyAsync(bufferConverted, offset, count, cancellationTokenConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_IO_Stream_BeginWrite")]
	internal static void* /* System.IAsyncResult */ System_IO_Stream_BeginWrite(void* /* System.IO.Stream */ __self, void* /* System.Byte[] */ buffer, int /* System.Int32 */ offset, int /* System.Int32 */ count, void* /* System.AsyncCallback */ callback, void* /* System.Object */ state, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.IO.Stream __selfConverted = InteropUtils.GetInstance<System.IO.Stream>(__self);
	
		System.Byte[] bufferConverted = InteropUtils.GetInstance<System.Byte[]>(buffer);
		System.AsyncCallback callbackConverted = InteropUtils.GetInstance<System_AsyncCallback>(callback)?.Trampoline;
		System.Object stateConverted = InteropUtils.GetInstance<System.Object>(state);
	
	    try {
			System.IAsyncResult __returnValue = __selfConverted.BeginWrite(bufferConverted, offset, count, callbackConverted, stateConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_IO_Stream_EndWrite")]
	internal static void /* System.Void */ System_IO_Stream_EndWrite(void* /* System.IO.Stream */ __self, void* /* System.IAsyncResult */ asyncResult, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.IO.Stream __selfConverted = InteropUtils.GetInstance<System.IO.Stream>(__self);
	
		System.IAsyncResult asyncResultConverted = InteropUtils.GetInstance<System.IAsyncResult>(asyncResult);
	
	    try {
			__selfConverted.EndWrite(asyncResultConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_IO_Stream_WriteAsync")]
	internal static void* /* System.Threading.Tasks.Task */ System_IO_Stream_WriteAsync(void* /* System.IO.Stream */ __self, void* /* System.Byte[] */ buffer, int /* System.Int32 */ offset, int /* System.Int32 */ count, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.IO.Stream __selfConverted = InteropUtils.GetInstance<System.IO.Stream>(__self);
	
		System.Byte[] bufferConverted = InteropUtils.GetInstance<System.Byte[]>(buffer);
	
	    try {
			System.Threading.Tasks.Task __returnValue = __selfConverted.WriteAsync(bufferConverted, offset, count);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_IO_Stream_WriteAsync_1")]
	internal static void* /* System.Threading.Tasks.Task */ System_IO_Stream_WriteAsync_1(void* /* System.IO.Stream */ __self, void* /* System.Byte[] */ buffer, int /* System.Int32 */ offset, int /* System.Int32 */ count, void* /* System.Threading.CancellationToken */ cancellationToken, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.IO.Stream __selfConverted = InteropUtils.GetInstance<System.IO.Stream>(__self);
	
		System.Byte[] bufferConverted = InteropUtils.GetInstance<System.Byte[]>(buffer);
		System.Threading.CancellationToken cancellationTokenConverted = InteropUtils.GetInstance<System.Threading.CancellationToken>(cancellationToken);
	
	    try {
			System.Threading.Tasks.Task __returnValue = __selfConverted.WriteAsync(bufferConverted, offset, count, cancellationTokenConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_IO_Stream_Seek")]
	internal static long /* System.Int64 */ System_IO_Stream_Seek(void* /* System.IO.Stream */ __self, long /* System.Int64 */ offset, System.IO.SeekOrigin /* System.IO.SeekOrigin */ origin, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.IO.Stream __selfConverted = InteropUtils.GetInstance<System.IO.Stream>(__self);
	
	
	    try {
			System.Int64 __returnValue = __selfConverted.Seek(offset, origin);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_IO_Stream_SetLength")]
	internal static void /* System.Void */ System_IO_Stream_SetLength(void* /* System.IO.Stream */ __self, long /* System.Int64 */ value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.IO.Stream __selfConverted = InteropUtils.GetInstance<System.IO.Stream>(__self);
	
	
	    try {
			__selfConverted.SetLength(value);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_IO_Stream_Read_1")]
	internal static int /* System.Int32 */ System_IO_Stream_Read_1(void* /* System.IO.Stream */ __self, void* /* System.Byte[] */ buffer, int /* System.Int32 */ offset, int /* System.Int32 */ count, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.IO.Stream __selfConverted = InteropUtils.GetInstance<System.IO.Stream>(__self);
	
		System.Byte[] bufferConverted = InteropUtils.GetInstance<System.Byte[]>(buffer);
	
	    try {
			System.Int32 __returnValue = __selfConverted.Read(bufferConverted, offset, count);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_IO_Stream_ReadByte")]
	internal static int /* System.Int32 */ System_IO_Stream_ReadByte(void* /* System.IO.Stream */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.IO.Stream __selfConverted = InteropUtils.GetInstance<System.IO.Stream>(__self);
	
	
	    try {
			System.Int32 __returnValue = __selfConverted.ReadByte();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_IO_Stream_ReadExactly_1")]
	internal static void /* System.Void */ System_IO_Stream_ReadExactly_1(void* /* System.IO.Stream */ __self, void* /* System.Byte[] */ buffer, int /* System.Int32 */ offset, int /* System.Int32 */ count, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.IO.Stream __selfConverted = InteropUtils.GetInstance<System.IO.Stream>(__self);
	
		System.Byte[] bufferConverted = InteropUtils.GetInstance<System.Byte[]>(buffer);
	
	    try {
			__selfConverted.ReadExactly(bufferConverted, offset, count);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_IO_Stream_Write_1")]
	internal static void /* System.Void */ System_IO_Stream_Write_1(void* /* System.IO.Stream */ __self, void* /* System.Byte[] */ buffer, int /* System.Int32 */ offset, int /* System.Int32 */ count, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.IO.Stream __selfConverted = InteropUtils.GetInstance<System.IO.Stream>(__self);
	
		System.Byte[] bufferConverted = InteropUtils.GetInstance<System.Byte[]>(buffer);
	
	    try {
			__selfConverted.Write(bufferConverted, offset, count);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_IO_Stream_WriteByte")]
	internal static void /* System.Void */ System_IO_Stream_WriteByte(void* /* System.IO.Stream */ __self, byte /* System.Byte */ value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.IO.Stream __selfConverted = InteropUtils.GetInstance<System.IO.Stream>(__self);
	
	
	    try {
			__selfConverted.WriteByte(value);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_IO_Stream_Synchronized")]
	internal static void* /* System.IO.Stream */ System_IO_Stream_Synchronized(void* /* System.IO.Stream */ stream, void** /* System.Exception */ __outException)
	{
		System.IO.Stream streamConverted = InteropUtils.GetInstance<System.IO.Stream>(stream);
	
	    try {
			System.IO.Stream __returnValue = System.IO.Stream.Synchronized(streamConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_IO_Stream_CanRead_Get")]
	internal static byte /* System.Boolean */ System_IO_Stream_CanRead_Get(void* /* System.IO.Stream */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.IO.Stream __selfConverted = InteropUtils.GetInstance<System.IO.Stream>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.CanRead;
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_IO_Stream_CanWrite_Get")]
	internal static byte /* System.Boolean */ System_IO_Stream_CanWrite_Get(void* /* System.IO.Stream */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.IO.Stream __selfConverted = InteropUtils.GetInstance<System.IO.Stream>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.CanWrite;
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_IO_Stream_CanSeek_Get")]
	internal static byte /* System.Boolean */ System_IO_Stream_CanSeek_Get(void* /* System.IO.Stream */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.IO.Stream __selfConverted = InteropUtils.GetInstance<System.IO.Stream>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.CanSeek;
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_IO_Stream_CanTimeout_Get")]
	internal static byte /* System.Boolean */ System_IO_Stream_CanTimeout_Get(void* /* System.IO.Stream */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.IO.Stream __selfConverted = InteropUtils.GetInstance<System.IO.Stream>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.CanTimeout;
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_IO_Stream_Length_Get")]
	internal static long /* System.Int64 */ System_IO_Stream_Length_Get(void* /* System.IO.Stream */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.IO.Stream __selfConverted = InteropUtils.GetInstance<System.IO.Stream>(__self);
	
	
	    try {
			System.Int64 __returnValue = __selfConverted.Length;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_IO_Stream_Position_Get")]
	internal static long /* System.Int64 */ System_IO_Stream_Position_Get(void* /* System.IO.Stream */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.IO.Stream __selfConverted = InteropUtils.GetInstance<System.IO.Stream>(__self);
	
	
	    try {
			System.Int64 __returnValue = __selfConverted.Position;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_IO_Stream_Position_Set")]
	internal static void /* System.Void */ System_IO_Stream_Position_Set(void* /* System.IO.Stream */ __self, long /* System.Int64 */ __value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.IO.Stream __selfConverted = InteropUtils.GetInstance<System.IO.Stream>(__self);
	
	
	    try {
			__selfConverted.Position = __value;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_IO_Stream_ReadTimeout_Get")]
	internal static int /* System.Int32 */ System_IO_Stream_ReadTimeout_Get(void* /* System.IO.Stream */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.IO.Stream __selfConverted = InteropUtils.GetInstance<System.IO.Stream>(__self);
	
	
	    try {
			System.Int32 __returnValue = __selfConverted.ReadTimeout;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_IO_Stream_ReadTimeout_Set")]
	internal static void /* System.Void */ System_IO_Stream_ReadTimeout_Set(void* /* System.IO.Stream */ __self, int /* System.Int32 */ __value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.IO.Stream __selfConverted = InteropUtils.GetInstance<System.IO.Stream>(__self);
	
	
	    try {
			__selfConverted.ReadTimeout = __value;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_IO_Stream_WriteTimeout_Get")]
	internal static int /* System.Int32 */ System_IO_Stream_WriteTimeout_Get(void* /* System.IO.Stream */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.IO.Stream __selfConverted = InteropUtils.GetInstance<System.IO.Stream>(__self);
	
	
	    try {
			System.Int32 __returnValue = __selfConverted.WriteTimeout;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_IO_Stream_WriteTimeout_Set")]
	internal static void /* System.Void */ System_IO_Stream_WriteTimeout_Set(void* /* System.IO.Stream */ __self, int /* System.Int32 */ __value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.IO.Stream __selfConverted = InteropUtils.GetInstance<System.IO.Stream>(__self);
	
	
	    try {
			__selfConverted.WriteTimeout = __value;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_IO_Stream_Null_Get")]
	internal static void* /* System.IO.Stream */ System_IO_Stream_Null_Get()
	{
	
		System.IO.Stream __returnValue = System.IO.Stream.Null;
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_IO_Stream_TypeOf")]
	internal static void* /* System.Type */ System_IO_Stream_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.IO.Stream);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_IO_Stream_Destroy")]
	internal static void /* System.Void */ System_IO_Stream_Destroy(void* /* System.IO.Stream */ __self)
	{
	
		InteropUtils.FreeIfAllocated(__self);
	}
	
}


internal unsafe class System_MarshalByRefObject
{
	[UnmanagedCallersOnly(EntryPoint = "System_MarshalByRefObject_GetLifetimeService")]
	internal static void* /* System.Object */ System_MarshalByRefObject_GetLifetimeService(void* /* System.MarshalByRefObject */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.MarshalByRefObject __selfConverted = InteropUtils.GetInstance<System.MarshalByRefObject>(__self);
	
	
	    try {
			System.Object __returnValue = __selfConverted.GetLifetimeService();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_MarshalByRefObject_InitializeLifetimeService")]
	internal static void* /* System.Object */ System_MarshalByRefObject_InitializeLifetimeService(void* /* System.MarshalByRefObject */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.MarshalByRefObject __selfConverted = InteropUtils.GetInstance<System.MarshalByRefObject>(__self);
	
	
	    try {
			System.Object __returnValue = __selfConverted.InitializeLifetimeService();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_MarshalByRefObject_TypeOf")]
	internal static void* /* System.Type */ System_MarshalByRefObject_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.MarshalByRefObject);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_MarshalByRefObject_Destroy")]
	internal static void /* System.Void */ System_MarshalByRefObject_Destroy(void* /* System.MarshalByRefObject */ __self)
	{
	
		InteropUtils.FreeIfAllocated(__self);
	}
	
}


internal unsafe class System_IDisposable
{
	[UnmanagedCallersOnly(EntryPoint = "System_IDisposable_Dispose")]
	internal static void /* System.Void */ System_IDisposable_Dispose(void* /* System.IDisposable */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.IDisposable __selfConverted = InteropUtils.GetInstance<System.IDisposable>(__self);
	
	
	    try {
			__selfConverted.Dispose();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_IDisposable_TypeOf")]
	internal static void* /* System.Type */ System_IDisposable_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.IDisposable);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_IDisposable_Destroy")]
	internal static void /* System.Void */ System_IDisposable_Destroy(void* /* System.IDisposable */ __self)
	{
	
		InteropUtils.FreeIfAllocated(__self);
	}
	
}


internal unsafe class System_IAsyncDisposable
{
	[UnmanagedCallersOnly(EntryPoint = "System_IAsyncDisposable_DisposeAsync")]
	internal static void* /* System.Threading.Tasks.ValueTask */ System_IAsyncDisposable_DisposeAsync(void* /* System.IAsyncDisposable */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.IAsyncDisposable __selfConverted = InteropUtils.GetInstance<System.IAsyncDisposable>(__self);
	
	
	    try {
			System.Threading.Tasks.ValueTask __returnValue = __selfConverted.DisposeAsync();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_IAsyncDisposable_TypeOf")]
	internal static void* /* System.Type */ System_IAsyncDisposable_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.IAsyncDisposable);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_IAsyncDisposable_Destroy")]
	internal static void /* System.Void */ System_IAsyncDisposable_Destroy(void* /* System.IAsyncDisposable */ __self)
	{
	
		InteropUtils.FreeIfAllocated(__self);
	}
	
}


internal unsafe class System_Threading_Tasks_ValueTask
{
	[UnmanagedCallersOnly(EntryPoint = "System_Threading_Tasks_ValueTask_FromCanceled")]
	internal static void* /* System.Threading.Tasks.ValueTask */ System_Threading_Tasks_ValueTask_FromCanceled(void* /* System.Threading.CancellationToken */ cancellationToken, void** /* System.Exception */ __outException)
	{
		System.Threading.CancellationToken cancellationTokenConverted = InteropUtils.GetInstance<System.Threading.CancellationToken>(cancellationToken);
	
	    try {
			System.Threading.Tasks.ValueTask __returnValue = System.Threading.Tasks.ValueTask.FromCanceled(cancellationTokenConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Threading_Tasks_ValueTask_FromException")]
	internal static void* /* System.Threading.Tasks.ValueTask */ System_Threading_Tasks_ValueTask_FromException(void* /* System.Exception */ exception, void** /* System.Exception */ __outException)
	{
		System.Exception exceptionConverted = InteropUtils.GetInstance<System.Exception>(exception);
	
	    try {
			System.Threading.Tasks.ValueTask __returnValue = System.Threading.Tasks.ValueTask.FromException(exceptionConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Threading_Tasks_ValueTask_GetHashCode")]
	internal static int /* System.Int32 */ System_Threading_Tasks_ValueTask_GetHashCode(void* /* System.Threading.Tasks.ValueTask */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Threading.Tasks.ValueTask __selfConverted = InteropUtils.GetInstance<System.Threading.Tasks.ValueTask>(__self);
	
	
	    try {
			System.Int32 __returnValue = __selfConverted.GetHashCode();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Threading_Tasks_ValueTask_Equals")]
	internal static byte /* System.Boolean */ System_Threading_Tasks_ValueTask_Equals(void* /* System.Threading.Tasks.ValueTask */ __self, void* /* System.Object */ obj, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Threading.Tasks.ValueTask __selfConverted = InteropUtils.GetInstance<System.Threading.Tasks.ValueTask>(__self);
	
		System.Object objConverted = InteropUtils.GetInstance<System.Object>(obj);
	
	    try {
			System.Boolean __returnValue = __selfConverted.Equals(objConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Threading_Tasks_ValueTask_Equals_1")]
	internal static byte /* System.Boolean */ System_Threading_Tasks_ValueTask_Equals_1(void* /* System.Threading.Tasks.ValueTask */ __self, void* /* System.Threading.Tasks.ValueTask */ other, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Threading.Tasks.ValueTask __selfConverted = InteropUtils.GetInstance<System.Threading.Tasks.ValueTask>(__self);
	
		System.Threading.Tasks.ValueTask otherConverted = InteropUtils.GetInstance<System.Threading.Tasks.ValueTask>(other);
	
	    try {
			System.Boolean __returnValue = __selfConverted.Equals(otherConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Threading_Tasks_ValueTask_AsTask")]
	internal static void* /* System.Threading.Tasks.Task */ System_Threading_Tasks_ValueTask_AsTask(void* /* System.Threading.Tasks.ValueTask */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Threading.Tasks.ValueTask __selfConverted = InteropUtils.GetInstance<System.Threading.Tasks.ValueTask>(__self);
	
	
	    try {
			System.Threading.Tasks.Task __returnValue = __selfConverted.AsTask();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Threading_Tasks_ValueTask_Preserve")]
	internal static void* /* System.Threading.Tasks.ValueTask */ System_Threading_Tasks_ValueTask_Preserve(void* /* System.Threading.Tasks.ValueTask */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Threading.Tasks.ValueTask __selfConverted = InteropUtils.GetInstance<System.Threading.Tasks.ValueTask>(__self);
	
	
	    try {
			System.Threading.Tasks.ValueTask __returnValue = __selfConverted.Preserve();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Threading_Tasks_ValueTask_GetAwaiter")]
	internal static void* /* System.Runtime.CompilerServices.ValueTaskAwaiter */ System_Threading_Tasks_ValueTask_GetAwaiter(void* /* System.Threading.Tasks.ValueTask */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Threading.Tasks.ValueTask __selfConverted = InteropUtils.GetInstance<System.Threading.Tasks.ValueTask>(__self);
	
	
	    try {
			System.Runtime.CompilerServices.ValueTaskAwaiter __returnValue = __selfConverted.GetAwaiter();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Threading_Tasks_ValueTask_ConfigureAwait")]
	internal static void* /* System.Runtime.CompilerServices.ConfiguredValueTaskAwaitable */ System_Threading_Tasks_ValueTask_ConfigureAwait(void* /* System.Threading.Tasks.ValueTask */ __self, byte /* System.Boolean */ continueOnCapturedContext, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Threading.Tasks.ValueTask __selfConverted = InteropUtils.GetInstance<System.Threading.Tasks.ValueTask>(__self);
	
		System.Boolean continueOnCapturedContextConverted = continueOnCapturedContext.ToBool();
	
	    try {
			System.Runtime.CompilerServices.ConfiguredValueTaskAwaitable __returnValue = __selfConverted.ConfigureAwait(continueOnCapturedContextConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Threading_Tasks_ValueTask_Create")]
	internal static void* /* System.Threading.Tasks.ValueTask */ System_Threading_Tasks_ValueTask_Create(void* /* System.Threading.Tasks.Task */ task, void** /* System.Exception */ __outException)
	{
		System.Threading.Tasks.Task taskConverted = InteropUtils.GetInstance<System.Threading.Tasks.Task>(task);
	
	    try {
			System.Threading.Tasks.ValueTask __returnValue = new System.Threading.Tasks.ValueTask(taskConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Threading_Tasks_ValueTask_Create_1")]
	internal static void* /* System.Threading.Tasks.ValueTask */ System_Threading_Tasks_ValueTask_Create_1(void* /* System.Threading.Tasks.Sources.IValueTaskSource */ source, short /* System.Int16 */ token, void** /* System.Exception */ __outException)
	{
		System.Threading.Tasks.Sources.IValueTaskSource sourceConverted = InteropUtils.GetInstance<System.Threading.Tasks.Sources.IValueTaskSource>(source);
	
	    try {
			System.Threading.Tasks.ValueTask __returnValue = new System.Threading.Tasks.ValueTask(sourceConverted, token);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Threading_Tasks_ValueTask_CompletedTask_Get")]
	internal static void* /* System.Threading.Tasks.ValueTask */ System_Threading_Tasks_ValueTask_CompletedTask_Get(void** /* System.Exception */ __outException)
	{
	
	    try {
			System.Threading.Tasks.ValueTask __returnValue = System.Threading.Tasks.ValueTask.CompletedTask;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Threading_Tasks_ValueTask_IsCompleted_Get")]
	internal static byte /* System.Boolean */ System_Threading_Tasks_ValueTask_IsCompleted_Get(void* /* System.Threading.Tasks.ValueTask */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Threading.Tasks.ValueTask __selfConverted = InteropUtils.GetInstance<System.Threading.Tasks.ValueTask>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.IsCompleted;
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Threading_Tasks_ValueTask_IsCompletedSuccessfully_Get")]
	internal static byte /* System.Boolean */ System_Threading_Tasks_ValueTask_IsCompletedSuccessfully_Get(void* /* System.Threading.Tasks.ValueTask */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Threading.Tasks.ValueTask __selfConverted = InteropUtils.GetInstance<System.Threading.Tasks.ValueTask>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.IsCompletedSuccessfully;
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Threading_Tasks_ValueTask_IsFaulted_Get")]
	internal static byte /* System.Boolean */ System_Threading_Tasks_ValueTask_IsFaulted_Get(void* /* System.Threading.Tasks.ValueTask */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Threading.Tasks.ValueTask __selfConverted = InteropUtils.GetInstance<System.Threading.Tasks.ValueTask>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.IsFaulted;
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Threading_Tasks_ValueTask_IsCanceled_Get")]
	internal static byte /* System.Boolean */ System_Threading_Tasks_ValueTask_IsCanceled_Get(void* /* System.Threading.Tasks.ValueTask */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Threading.Tasks.ValueTask __selfConverted = InteropUtils.GetInstance<System.Threading.Tasks.ValueTask>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.IsCanceled;
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Threading_Tasks_ValueTask_Create_2")]
	internal static void* /* System.Threading.Tasks.ValueTask */ System_Threading_Tasks_ValueTask_Create_2(void** /* System.Exception */ __outException)
	{
	
	    try {
			System.Threading.Tasks.ValueTask __returnValue = new System.Threading.Tasks.ValueTask();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Threading_Tasks_ValueTask_TypeOf")]
	internal static void* /* System.Type */ System_Threading_Tasks_ValueTask_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.Threading.Tasks.ValueTask);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Threading_Tasks_ValueTask_Destroy")]
	internal static void /* System.Void */ System_Threading_Tasks_ValueTask_Destroy(void* /* System.Threading.Tasks.ValueTask */ __self)
	{
	
		InteropUtils.FreeIfAllocated(__self);
	}
	
}


internal unsafe class System_Threading_CancellationToken
{
	[UnmanagedCallersOnly(EntryPoint = "System_Threading_CancellationToken_Register")]
	internal static void* /* System.Threading.CancellationTokenRegistration */ System_Threading_CancellationToken_Register(void* /* System.Threading.CancellationToken */ __self, void* /* System.Action */ callback, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Threading.CancellationToken __selfConverted = InteropUtils.GetInstance<System.Threading.CancellationToken>(__self);
	
		System.Action callbackConverted = InteropUtils.GetInstance<System_Action>(callback)?.Trampoline;
	
	    try {
			System.Threading.CancellationTokenRegistration __returnValue = __selfConverted.Register(callbackConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Threading_CancellationToken_Register_1")]
	internal static void* /* System.Threading.CancellationTokenRegistration */ System_Threading_CancellationToken_Register_1(void* /* System.Threading.CancellationToken */ __self, void* /* System.Action */ callback, byte /* System.Boolean */ useSynchronizationContext, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Threading.CancellationToken __selfConverted = InteropUtils.GetInstance<System.Threading.CancellationToken>(__self);
	
		System.Action callbackConverted = InteropUtils.GetInstance<System_Action>(callback)?.Trampoline;
		System.Boolean useSynchronizationContextConverted = useSynchronizationContext.ToBool();
	
	    try {
			System.Threading.CancellationTokenRegistration __returnValue = __selfConverted.Register(callbackConverted, useSynchronizationContextConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Threading_CancellationToken_Equals")]
	internal static byte /* System.Boolean */ System_Threading_CancellationToken_Equals(void* /* System.Threading.CancellationToken */ __self, void* /* System.Threading.CancellationToken */ other, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Threading.CancellationToken __selfConverted = InteropUtils.GetInstance<System.Threading.CancellationToken>(__self);
	
		System.Threading.CancellationToken otherConverted = InteropUtils.GetInstance<System.Threading.CancellationToken>(other);
	
	    try {
			System.Boolean __returnValue = __selfConverted.Equals(otherConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Threading_CancellationToken_Equals_1")]
	internal static byte /* System.Boolean */ System_Threading_CancellationToken_Equals_1(void* /* System.Threading.CancellationToken */ __self, void* /* System.Object */ other, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Threading.CancellationToken __selfConverted = InteropUtils.GetInstance<System.Threading.CancellationToken>(__self);
	
		System.Object otherConverted = InteropUtils.GetInstance<System.Object>(other);
	
	    try {
			System.Boolean __returnValue = __selfConverted.Equals(otherConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Threading_CancellationToken_GetHashCode")]
	internal static int /* System.Int32 */ System_Threading_CancellationToken_GetHashCode(void* /* System.Threading.CancellationToken */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Threading.CancellationToken __selfConverted = InteropUtils.GetInstance<System.Threading.CancellationToken>(__self);
	
	
	    try {
			System.Int32 __returnValue = __selfConverted.GetHashCode();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Threading_CancellationToken_ThrowIfCancellationRequested")]
	internal static void /* System.Void */ System_Threading_CancellationToken_ThrowIfCancellationRequested(void* /* System.Threading.CancellationToken */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Threading.CancellationToken __selfConverted = InteropUtils.GetInstance<System.Threading.CancellationToken>(__self);
	
	
	    try {
			__selfConverted.ThrowIfCancellationRequested();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Threading_CancellationToken_Create")]
	internal static void* /* System.Threading.CancellationToken */ System_Threading_CancellationToken_Create(byte /* System.Boolean */ canceled, void** /* System.Exception */ __outException)
	{
		System.Boolean canceledConverted = canceled.ToBool();
	
	    try {
			System.Threading.CancellationToken __returnValue = new System.Threading.CancellationToken(canceledConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Threading_CancellationToken_None_Get")]
	internal static void* /* System.Threading.CancellationToken */ System_Threading_CancellationToken_None_Get(void** /* System.Exception */ __outException)
	{
	
	    try {
			System.Threading.CancellationToken __returnValue = System.Threading.CancellationToken.None;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Threading_CancellationToken_IsCancellationRequested_Get")]
	internal static byte /* System.Boolean */ System_Threading_CancellationToken_IsCancellationRequested_Get(void* /* System.Threading.CancellationToken */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Threading.CancellationToken __selfConverted = InteropUtils.GetInstance<System.Threading.CancellationToken>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.IsCancellationRequested;
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Threading_CancellationToken_CanBeCanceled_Get")]
	internal static byte /* System.Boolean */ System_Threading_CancellationToken_CanBeCanceled_Get(void* /* System.Threading.CancellationToken */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Threading.CancellationToken __selfConverted = InteropUtils.GetInstance<System.Threading.CancellationToken>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.CanBeCanceled;
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Threading_CancellationToken_WaitHandle_Get")]
	internal static void* /* System.Threading.WaitHandle */ System_Threading_CancellationToken_WaitHandle_Get(void* /* System.Threading.CancellationToken */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Threading.CancellationToken __selfConverted = InteropUtils.GetInstance<System.Threading.CancellationToken>(__self);
	
	
	    try {
			System.Threading.WaitHandle __returnValue = __selfConverted.WaitHandle;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Threading_CancellationToken_Create_1")]
	internal static void* /* System.Threading.CancellationToken */ System_Threading_CancellationToken_Create_1(void** /* System.Exception */ __outException)
	{
	
	    try {
			System.Threading.CancellationToken __returnValue = new System.Threading.CancellationToken();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Threading_CancellationToken_TypeOf")]
	internal static void* /* System.Type */ System_Threading_CancellationToken_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.Threading.CancellationToken);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Threading_CancellationToken_Destroy")]
	internal static void /* System.Void */ System_Threading_CancellationToken_Destroy(void* /* System.Threading.CancellationToken */ __self)
	{
	
		InteropUtils.FreeIfAllocated(__self);
	}
	
}


internal unsafe class System_Threading_WaitHandle
{
	[UnmanagedCallersOnly(EntryPoint = "System_Threading_WaitHandle_Close")]
	internal static void /* System.Void */ System_Threading_WaitHandle_Close(void* /* System.Threading.WaitHandle */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Threading.WaitHandle __selfConverted = InteropUtils.GetInstance<System.Threading.WaitHandle>(__self);
	
	
	    try {
			__selfConverted.Close();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Threading_WaitHandle_Dispose")]
	internal static void /* System.Void */ System_Threading_WaitHandle_Dispose(void* /* System.Threading.WaitHandle */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Threading.WaitHandle __selfConverted = InteropUtils.GetInstance<System.Threading.WaitHandle>(__self);
	
	
	    try {
			__selfConverted.Dispose();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Threading_WaitHandle_WaitOne")]
	internal static byte /* System.Boolean */ System_Threading_WaitHandle_WaitOne(void* /* System.Threading.WaitHandle */ __self, int /* System.Int32 */ millisecondsTimeout, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Threading.WaitHandle __selfConverted = InteropUtils.GetInstance<System.Threading.WaitHandle>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.WaitOne(millisecondsTimeout);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Threading_WaitHandle_WaitOne_1")]
	internal static byte /* System.Boolean */ System_Threading_WaitHandle_WaitOne_1(void* /* System.Threading.WaitHandle */ __self, void* /* System.TimeSpan */ timeout, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Threading.WaitHandle __selfConverted = InteropUtils.GetInstance<System.Threading.WaitHandle>(__self);
	
		System.TimeSpan timeoutConverted = InteropUtils.GetInstance<System.TimeSpan>(timeout);
	
	    try {
			System.Boolean __returnValue = __selfConverted.WaitOne(timeoutConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Threading_WaitHandle_WaitOne_2")]
	internal static byte /* System.Boolean */ System_Threading_WaitHandle_WaitOne_2(void* /* System.Threading.WaitHandle */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Threading.WaitHandle __selfConverted = InteropUtils.GetInstance<System.Threading.WaitHandle>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.WaitOne();
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Threading_WaitHandle_WaitOne_3")]
	internal static byte /* System.Boolean */ System_Threading_WaitHandle_WaitOne_3(void* /* System.Threading.WaitHandle */ __self, int /* System.Int32 */ millisecondsTimeout, byte /* System.Boolean */ exitContext, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Threading.WaitHandle __selfConverted = InteropUtils.GetInstance<System.Threading.WaitHandle>(__self);
	
		System.Boolean exitContextConverted = exitContext.ToBool();
	
	    try {
			System.Boolean __returnValue = __selfConverted.WaitOne(millisecondsTimeout, exitContextConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Threading_WaitHandle_WaitOne_4")]
	internal static byte /* System.Boolean */ System_Threading_WaitHandle_WaitOne_4(void* /* System.Threading.WaitHandle */ __self, void* /* System.TimeSpan */ timeout, byte /* System.Boolean */ exitContext, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Threading.WaitHandle __selfConverted = InteropUtils.GetInstance<System.Threading.WaitHandle>(__self);
	
		System.TimeSpan timeoutConverted = InteropUtils.GetInstance<System.TimeSpan>(timeout);
		System.Boolean exitContextConverted = exitContext.ToBool();
	
	    try {
			System.Boolean __returnValue = __selfConverted.WaitOne(timeoutConverted, exitContextConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Threading_WaitHandle_WaitAll")]
	internal static byte /* System.Boolean */ System_Threading_WaitHandle_WaitAll(void* /* System.Threading.WaitHandle[] */ waitHandles, int /* System.Int32 */ millisecondsTimeout, void** /* System.Exception */ __outException)
	{
		System.Threading.WaitHandle[] waitHandlesConverted = InteropUtils.GetInstance<System.Threading.WaitHandle[]>(waitHandles);
	
	    try {
			System.Boolean __returnValue = System.Threading.WaitHandle.WaitAll(waitHandlesConverted, millisecondsTimeout);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Threading_WaitHandle_WaitAll_1")]
	internal static byte /* System.Boolean */ System_Threading_WaitHandle_WaitAll_1(void* /* System.Threading.WaitHandle[] */ waitHandles, void* /* System.TimeSpan */ timeout, void** /* System.Exception */ __outException)
	{
		System.Threading.WaitHandle[] waitHandlesConverted = InteropUtils.GetInstance<System.Threading.WaitHandle[]>(waitHandles);
		System.TimeSpan timeoutConverted = InteropUtils.GetInstance<System.TimeSpan>(timeout);
	
	    try {
			System.Boolean __returnValue = System.Threading.WaitHandle.WaitAll(waitHandlesConverted, timeoutConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Threading_WaitHandle_WaitAll_2")]
	internal static byte /* System.Boolean */ System_Threading_WaitHandle_WaitAll_2(void* /* System.Threading.WaitHandle[] */ waitHandles, void** /* System.Exception */ __outException)
	{
		System.Threading.WaitHandle[] waitHandlesConverted = InteropUtils.GetInstance<System.Threading.WaitHandle[]>(waitHandles);
	
	    try {
			System.Boolean __returnValue = System.Threading.WaitHandle.WaitAll(waitHandlesConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Threading_WaitHandle_WaitAll_3")]
	internal static byte /* System.Boolean */ System_Threading_WaitHandle_WaitAll_3(void* /* System.Threading.WaitHandle[] */ waitHandles, int /* System.Int32 */ millisecondsTimeout, byte /* System.Boolean */ exitContext, void** /* System.Exception */ __outException)
	{
		System.Threading.WaitHandle[] waitHandlesConverted = InteropUtils.GetInstance<System.Threading.WaitHandle[]>(waitHandles);
		System.Boolean exitContextConverted = exitContext.ToBool();
	
	    try {
			System.Boolean __returnValue = System.Threading.WaitHandle.WaitAll(waitHandlesConverted, millisecondsTimeout, exitContextConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Threading_WaitHandle_WaitAll_4")]
	internal static byte /* System.Boolean */ System_Threading_WaitHandle_WaitAll_4(void* /* System.Threading.WaitHandle[] */ waitHandles, void* /* System.TimeSpan */ timeout, byte /* System.Boolean */ exitContext, void** /* System.Exception */ __outException)
	{
		System.Threading.WaitHandle[] waitHandlesConverted = InteropUtils.GetInstance<System.Threading.WaitHandle[]>(waitHandles);
		System.TimeSpan timeoutConverted = InteropUtils.GetInstance<System.TimeSpan>(timeout);
		System.Boolean exitContextConverted = exitContext.ToBool();
	
	    try {
			System.Boolean __returnValue = System.Threading.WaitHandle.WaitAll(waitHandlesConverted, timeoutConverted, exitContextConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Threading_WaitHandle_WaitAny")]
	internal static int /* System.Int32 */ System_Threading_WaitHandle_WaitAny(void* /* System.Threading.WaitHandle[] */ waitHandles, int /* System.Int32 */ millisecondsTimeout, void** /* System.Exception */ __outException)
	{
		System.Threading.WaitHandle[] waitHandlesConverted = InteropUtils.GetInstance<System.Threading.WaitHandle[]>(waitHandles);
	
	    try {
			System.Int32 __returnValue = System.Threading.WaitHandle.WaitAny(waitHandlesConverted, millisecondsTimeout);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Threading_WaitHandle_WaitAny_1")]
	internal static int /* System.Int32 */ System_Threading_WaitHandle_WaitAny_1(void* /* System.Threading.WaitHandle[] */ waitHandles, void* /* System.TimeSpan */ timeout, void** /* System.Exception */ __outException)
	{
		System.Threading.WaitHandle[] waitHandlesConverted = InteropUtils.GetInstance<System.Threading.WaitHandle[]>(waitHandles);
		System.TimeSpan timeoutConverted = InteropUtils.GetInstance<System.TimeSpan>(timeout);
	
	    try {
			System.Int32 __returnValue = System.Threading.WaitHandle.WaitAny(waitHandlesConverted, timeoutConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Threading_WaitHandle_WaitAny_2")]
	internal static int /* System.Int32 */ System_Threading_WaitHandle_WaitAny_2(void* /* System.Threading.WaitHandle[] */ waitHandles, void** /* System.Exception */ __outException)
	{
		System.Threading.WaitHandle[] waitHandlesConverted = InteropUtils.GetInstance<System.Threading.WaitHandle[]>(waitHandles);
	
	    try {
			System.Int32 __returnValue = System.Threading.WaitHandle.WaitAny(waitHandlesConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Threading_WaitHandle_WaitAny_3")]
	internal static int /* System.Int32 */ System_Threading_WaitHandle_WaitAny_3(void* /* System.Threading.WaitHandle[] */ waitHandles, int /* System.Int32 */ millisecondsTimeout, byte /* System.Boolean */ exitContext, void** /* System.Exception */ __outException)
	{
		System.Threading.WaitHandle[] waitHandlesConverted = InteropUtils.GetInstance<System.Threading.WaitHandle[]>(waitHandles);
		System.Boolean exitContextConverted = exitContext.ToBool();
	
	    try {
			System.Int32 __returnValue = System.Threading.WaitHandle.WaitAny(waitHandlesConverted, millisecondsTimeout, exitContextConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Threading_WaitHandle_WaitAny_4")]
	internal static int /* System.Int32 */ System_Threading_WaitHandle_WaitAny_4(void* /* System.Threading.WaitHandle[] */ waitHandles, void* /* System.TimeSpan */ timeout, byte /* System.Boolean */ exitContext, void** /* System.Exception */ __outException)
	{
		System.Threading.WaitHandle[] waitHandlesConverted = InteropUtils.GetInstance<System.Threading.WaitHandle[]>(waitHandles);
		System.TimeSpan timeoutConverted = InteropUtils.GetInstance<System.TimeSpan>(timeout);
		System.Boolean exitContextConverted = exitContext.ToBool();
	
	    try {
			System.Int32 __returnValue = System.Threading.WaitHandle.WaitAny(waitHandlesConverted, timeoutConverted, exitContextConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Threading_WaitHandle_SignalAndWait")]
	internal static byte /* System.Boolean */ System_Threading_WaitHandle_SignalAndWait(void* /* System.Threading.WaitHandle */ toSignal, void* /* System.Threading.WaitHandle */ toWaitOn, void** /* System.Exception */ __outException)
	{
		System.Threading.WaitHandle toSignalConverted = InteropUtils.GetInstance<System.Threading.WaitHandle>(toSignal);
		System.Threading.WaitHandle toWaitOnConverted = InteropUtils.GetInstance<System.Threading.WaitHandle>(toWaitOn);
	
	    try {
			System.Boolean __returnValue = System.Threading.WaitHandle.SignalAndWait(toSignalConverted, toWaitOnConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Threading_WaitHandle_SignalAndWait_1")]
	internal static byte /* System.Boolean */ System_Threading_WaitHandle_SignalAndWait_1(void* /* System.Threading.WaitHandle */ toSignal, void* /* System.Threading.WaitHandle */ toWaitOn, void* /* System.TimeSpan */ timeout, byte /* System.Boolean */ exitContext, void** /* System.Exception */ __outException)
	{
		System.Threading.WaitHandle toSignalConverted = InteropUtils.GetInstance<System.Threading.WaitHandle>(toSignal);
		System.Threading.WaitHandle toWaitOnConverted = InteropUtils.GetInstance<System.Threading.WaitHandle>(toWaitOn);
		System.TimeSpan timeoutConverted = InteropUtils.GetInstance<System.TimeSpan>(timeout);
		System.Boolean exitContextConverted = exitContext.ToBool();
	
	    try {
			System.Boolean __returnValue = System.Threading.WaitHandle.SignalAndWait(toSignalConverted, toWaitOnConverted, timeoutConverted, exitContextConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Threading_WaitHandle_SignalAndWait_2")]
	internal static byte /* System.Boolean */ System_Threading_WaitHandle_SignalAndWait_2(void* /* System.Threading.WaitHandle */ toSignal, void* /* System.Threading.WaitHandle */ toWaitOn, int /* System.Int32 */ millisecondsTimeout, byte /* System.Boolean */ exitContext, void** /* System.Exception */ __outException)
	{
		System.Threading.WaitHandle toSignalConverted = InteropUtils.GetInstance<System.Threading.WaitHandle>(toSignal);
		System.Threading.WaitHandle toWaitOnConverted = InteropUtils.GetInstance<System.Threading.WaitHandle>(toWaitOn);
		System.Boolean exitContextConverted = exitContext.ToBool();
	
	    try {
			System.Boolean __returnValue = System.Threading.WaitHandle.SignalAndWait(toSignalConverted, toWaitOnConverted, millisecondsTimeout, exitContextConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Threading_WaitHandle_Handle_Get")]
	internal static nint /* System.IntPtr */ System_Threading_WaitHandle_Handle_Get(void* /* System.Threading.WaitHandle */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Threading.WaitHandle __selfConverted = InteropUtils.GetInstance<System.Threading.WaitHandle>(__self);
	
	
	    try {
			System.IntPtr __returnValue = __selfConverted.Handle;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return nint.Zero;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Threading_WaitHandle_Handle_Set")]
	internal static void /* System.Void */ System_Threading_WaitHandle_Handle_Set(void* /* System.Threading.WaitHandle */ __self, nint /* System.IntPtr */ __value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Threading.WaitHandle __selfConverted = InteropUtils.GetInstance<System.Threading.WaitHandle>(__self);
	
	
	    try {
			__selfConverted.Handle = __value;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Threading_WaitHandle_SafeWaitHandle_Get")]
	internal static void* /* Microsoft.Win32.SafeHandles.SafeWaitHandle */ System_Threading_WaitHandle_SafeWaitHandle_Get(void* /* System.Threading.WaitHandle */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Threading.WaitHandle __selfConverted = InteropUtils.GetInstance<System.Threading.WaitHandle>(__self);
	
	
	    try {
			Microsoft.Win32.SafeHandles.SafeWaitHandle __returnValue = __selfConverted.SafeWaitHandle;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Threading_WaitHandle_SafeWaitHandle_Set")]
	internal static void /* System.Void */ System_Threading_WaitHandle_SafeWaitHandle_Set(void* /* System.Threading.WaitHandle */ __self, void* /* Microsoft.Win32.SafeHandles.SafeWaitHandle */ __value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Threading.WaitHandle __selfConverted = InteropUtils.GetInstance<System.Threading.WaitHandle>(__self);
	
	
	    try {
			__selfConverted.SafeWaitHandle = InteropUtils.GetInstance<Microsoft.Win32.SafeHandles.SafeWaitHandle>(__value);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Threading_WaitHandle_WaitTimeout_Get")]
	internal static int /* System.Int32 */ System_Threading_WaitHandle_WaitTimeout_Get()
	{
	
		System.Int32 __returnValue = System.Threading.WaitHandle.WaitTimeout;
		return __returnValue;
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Threading_WaitHandle_TypeOf")]
	internal static void* /* System.Type */ System_Threading_WaitHandle_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.Threading.WaitHandle);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Threading_WaitHandle_Destroy")]
	internal static void /* System.Void */ System_Threading_WaitHandle_Destroy(void* /* System.Threading.WaitHandle */ __self)
	{
	
		InteropUtils.FreeIfAllocated(__self);
	}
	
}


internal unsafe class System_IntPtr
{
	[UnmanagedCallersOnly(EntryPoint = "System_IntPtr_TypeOf")]
	internal static void* /* System.Type */ System_IntPtr_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.IntPtr);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
}



internal unsafe class Microsoft_Win32_SafeHandles_SafeWaitHandle
{
	[UnmanagedCallersOnly(EntryPoint = "Microsoft_Win32_SafeHandles_SafeWaitHandle_Create")]
	internal static void* /* Microsoft.Win32.SafeHandles.SafeWaitHandle */ Microsoft_Win32_SafeHandles_SafeWaitHandle_Create(void** /* System.Exception */ __outException)
	{
	
	    try {
			Microsoft.Win32.SafeHandles.SafeWaitHandle __returnValue = new Microsoft.Win32.SafeHandles.SafeWaitHandle();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "Microsoft_Win32_SafeHandles_SafeWaitHandle_Create_1")]
	internal static void* /* Microsoft.Win32.SafeHandles.SafeWaitHandle */ Microsoft_Win32_SafeHandles_SafeWaitHandle_Create_1(nint /* System.IntPtr */ existingHandle, byte /* System.Boolean */ ownsHandle, void** /* System.Exception */ __outException)
	{
		System.Boolean ownsHandleConverted = ownsHandle.ToBool();
	
	    try {
			Microsoft.Win32.SafeHandles.SafeWaitHandle __returnValue = new Microsoft.Win32.SafeHandles.SafeWaitHandle(existingHandle, ownsHandleConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "Microsoft_Win32_SafeHandles_SafeWaitHandle_TypeOf")]
	internal static void* /* System.Type */ Microsoft_Win32_SafeHandles_SafeWaitHandle_TypeOf()
	{
	
		System.Type __returnValue = typeof(Microsoft.Win32.SafeHandles.SafeWaitHandle);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
	[UnmanagedCallersOnly(EntryPoint = "Microsoft_Win32_SafeHandles_SafeWaitHandle_Destroy")]
	internal static void /* System.Void */ Microsoft_Win32_SafeHandles_SafeWaitHandle_Destroy(void* /* Microsoft.Win32.SafeHandles.SafeWaitHandle */ __self)
	{
	
		InteropUtils.FreeIfAllocated(__self);
	}
	
}


internal unsafe class Microsoft_Win32_SafeHandles_SafeHandleZeroOrMinusOneIsInvalid
{
	[UnmanagedCallersOnly(EntryPoint = "Microsoft_Win32_SafeHandles_SafeHandleZeroOrMinusOneIsInvalid_IsInvalid_Get")]
	internal static byte /* System.Boolean */ Microsoft_Win32_SafeHandles_SafeHandleZeroOrMinusOneIsInvalid_IsInvalid_Get(void* /* Microsoft.Win32.SafeHandles.SafeHandleZeroOrMinusOneIsInvalid */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		Microsoft.Win32.SafeHandles.SafeHandleZeroOrMinusOneIsInvalid __selfConverted = InteropUtils.GetInstance<Microsoft.Win32.SafeHandles.SafeHandleZeroOrMinusOneIsInvalid>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.IsInvalid;
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "Microsoft_Win32_SafeHandles_SafeHandleZeroOrMinusOneIsInvalid_TypeOf")]
	internal static void* /* System.Type */ Microsoft_Win32_SafeHandles_SafeHandleZeroOrMinusOneIsInvalid_TypeOf()
	{
	
		System.Type __returnValue = typeof(Microsoft.Win32.SafeHandles.SafeHandleZeroOrMinusOneIsInvalid);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
	[UnmanagedCallersOnly(EntryPoint = "Microsoft_Win32_SafeHandles_SafeHandleZeroOrMinusOneIsInvalid_Destroy")]
	internal static void /* System.Void */ Microsoft_Win32_SafeHandles_SafeHandleZeroOrMinusOneIsInvalid_Destroy(void* /* Microsoft.Win32.SafeHandles.SafeHandleZeroOrMinusOneIsInvalid */ __self)
	{
	
		InteropUtils.FreeIfAllocated(__self);
	}
	
}


internal unsafe class System_Runtime_InteropServices_SafeHandle
{
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_InteropServices_SafeHandle_DangerousGetHandle")]
	internal static nint /* System.IntPtr */ System_Runtime_InteropServices_SafeHandle_DangerousGetHandle(void* /* System.Runtime.InteropServices.SafeHandle */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Runtime.InteropServices.SafeHandle __selfConverted = InteropUtils.GetInstance<System.Runtime.InteropServices.SafeHandle>(__self);
	
	
	    try {
			System.IntPtr __returnValue = __selfConverted.DangerousGetHandle();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return nint.Zero;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_InteropServices_SafeHandle_Close")]
	internal static void /* System.Void */ System_Runtime_InteropServices_SafeHandle_Close(void* /* System.Runtime.InteropServices.SafeHandle */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Runtime.InteropServices.SafeHandle __selfConverted = InteropUtils.GetInstance<System.Runtime.InteropServices.SafeHandle>(__self);
	
	
	    try {
			__selfConverted.Close();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_InteropServices_SafeHandle_Dispose")]
	internal static void /* System.Void */ System_Runtime_InteropServices_SafeHandle_Dispose(void* /* System.Runtime.InteropServices.SafeHandle */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Runtime.InteropServices.SafeHandle __selfConverted = InteropUtils.GetInstance<System.Runtime.InteropServices.SafeHandle>(__self);
	
	
	    try {
			__selfConverted.Dispose();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_InteropServices_SafeHandle_SetHandleAsInvalid")]
	internal static void /* System.Void */ System_Runtime_InteropServices_SafeHandle_SetHandleAsInvalid(void* /* System.Runtime.InteropServices.SafeHandle */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Runtime.InteropServices.SafeHandle __selfConverted = InteropUtils.GetInstance<System.Runtime.InteropServices.SafeHandle>(__self);
	
	
	    try {
			__selfConverted.SetHandleAsInvalid();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_InteropServices_SafeHandle_DangerousAddRef")]
	internal static void /* System.Void */ System_Runtime_InteropServices_SafeHandle_DangerousAddRef(void* /* System.Runtime.InteropServices.SafeHandle */ __self, byte* /* System.Boolean */ success, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Runtime.InteropServices.SafeHandle __selfConverted = InteropUtils.GetInstance<System.Runtime.InteropServices.SafeHandle>(__self);
	
		System.Boolean successConverted;
	
		if (success is not null) {
			successConverted = (*success).ToBool();
		} else {
			successConverted = default(System.Boolean);
		}
	
	
	    try {
			__selfConverted.DangerousAddRef(ref successConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			if (success is not null) {
				*success = successConverted.ToCBool();
			}
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_InteropServices_SafeHandle_DangerousRelease")]
	internal static void /* System.Void */ System_Runtime_InteropServices_SafeHandle_DangerousRelease(void* /* System.Runtime.InteropServices.SafeHandle */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Runtime.InteropServices.SafeHandle __selfConverted = InteropUtils.GetInstance<System.Runtime.InteropServices.SafeHandle>(__self);
	
	
	    try {
			__selfConverted.DangerousRelease();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_InteropServices_SafeHandle_IsClosed_Get")]
	internal static byte /* System.Boolean */ System_Runtime_InteropServices_SafeHandle_IsClosed_Get(void* /* System.Runtime.InteropServices.SafeHandle */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Runtime.InteropServices.SafeHandle __selfConverted = InteropUtils.GetInstance<System.Runtime.InteropServices.SafeHandle>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.IsClosed;
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_InteropServices_SafeHandle_IsInvalid_Get")]
	internal static byte /* System.Boolean */ System_Runtime_InteropServices_SafeHandle_IsInvalid_Get(void* /* System.Runtime.InteropServices.SafeHandle */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Runtime.InteropServices.SafeHandle __selfConverted = InteropUtils.GetInstance<System.Runtime.InteropServices.SafeHandle>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.IsInvalid;
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_InteropServices_SafeHandle_TypeOf")]
	internal static void* /* System.Type */ System_Runtime_InteropServices_SafeHandle_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.Runtime.InteropServices.SafeHandle);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_InteropServices_SafeHandle_Destroy")]
	internal static void /* System.Void */ System_Runtime_InteropServices_SafeHandle_Destroy(void* /* System.Runtime.InteropServices.SafeHandle */ __self)
	{
	
		InteropUtils.FreeIfAllocated(__self);
	}
	
}


internal unsafe class System_Runtime_ConstrainedExecution_CriticalFinalizerObject
{
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_ConstrainedExecution_CriticalFinalizerObject_TypeOf")]
	internal static void* /* System.Type */ System_Runtime_ConstrainedExecution_CriticalFinalizerObject_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.Runtime.ConstrainedExecution.CriticalFinalizerObject);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_ConstrainedExecution_CriticalFinalizerObject_Destroy")]
	internal static void /* System.Void */ System_Runtime_ConstrainedExecution_CriticalFinalizerObject_Destroy(void* /* System.Runtime.ConstrainedExecution.CriticalFinalizerObject */ __self)
	{
	
		InteropUtils.FreeIfAllocated(__self);
	}
	
}





internal unsafe class System_Threading_CancellationTokenRegistration
{
	[UnmanagedCallersOnly(EntryPoint = "System_Threading_CancellationTokenRegistration_Dispose")]
	internal static void /* System.Void */ System_Threading_CancellationTokenRegistration_Dispose(void* /* System.Threading.CancellationTokenRegistration */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Threading.CancellationTokenRegistration __selfConverted = InteropUtils.GetInstance<System.Threading.CancellationTokenRegistration>(__self);
	
	
	    try {
			__selfConverted.Dispose();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Threading_CancellationTokenRegistration_DisposeAsync")]
	internal static void* /* System.Threading.Tasks.ValueTask */ System_Threading_CancellationTokenRegistration_DisposeAsync(void* /* System.Threading.CancellationTokenRegistration */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Threading.CancellationTokenRegistration __selfConverted = InteropUtils.GetInstance<System.Threading.CancellationTokenRegistration>(__self);
	
	
	    try {
			System.Threading.Tasks.ValueTask __returnValue = __selfConverted.DisposeAsync();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Threading_CancellationTokenRegistration_Unregister")]
	internal static byte /* System.Boolean */ System_Threading_CancellationTokenRegistration_Unregister(void* /* System.Threading.CancellationTokenRegistration */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Threading.CancellationTokenRegistration __selfConverted = InteropUtils.GetInstance<System.Threading.CancellationTokenRegistration>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.Unregister();
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Threading_CancellationTokenRegistration_Equals")]
	internal static byte /* System.Boolean */ System_Threading_CancellationTokenRegistration_Equals(void* /* System.Threading.CancellationTokenRegistration */ __self, void* /* System.Object */ obj, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Threading.CancellationTokenRegistration __selfConverted = InteropUtils.GetInstance<System.Threading.CancellationTokenRegistration>(__self);
	
		System.Object objConverted = InteropUtils.GetInstance<System.Object>(obj);
	
	    try {
			System.Boolean __returnValue = __selfConverted.Equals(objConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Threading_CancellationTokenRegistration_Equals_1")]
	internal static byte /* System.Boolean */ System_Threading_CancellationTokenRegistration_Equals_1(void* /* System.Threading.CancellationTokenRegistration */ __self, void* /* System.Threading.CancellationTokenRegistration */ other, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Threading.CancellationTokenRegistration __selfConverted = InteropUtils.GetInstance<System.Threading.CancellationTokenRegistration>(__self);
	
		System.Threading.CancellationTokenRegistration otherConverted = InteropUtils.GetInstance<System.Threading.CancellationTokenRegistration>(other);
	
	    try {
			System.Boolean __returnValue = __selfConverted.Equals(otherConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Threading_CancellationTokenRegistration_GetHashCode")]
	internal static int /* System.Int32 */ System_Threading_CancellationTokenRegistration_GetHashCode(void* /* System.Threading.CancellationTokenRegistration */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Threading.CancellationTokenRegistration __selfConverted = InteropUtils.GetInstance<System.Threading.CancellationTokenRegistration>(__self);
	
	
	    try {
			System.Int32 __returnValue = __selfConverted.GetHashCode();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Threading_CancellationTokenRegistration_Token_Get")]
	internal static void* /* System.Threading.CancellationToken */ System_Threading_CancellationTokenRegistration_Token_Get(void* /* System.Threading.CancellationTokenRegistration */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Threading.CancellationTokenRegistration __selfConverted = InteropUtils.GetInstance<System.Threading.CancellationTokenRegistration>(__self);
	
	
	    try {
			System.Threading.CancellationToken __returnValue = __selfConverted.Token;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Threading_CancellationTokenRegistration_Create")]
	internal static void* /* System.Threading.CancellationTokenRegistration */ System_Threading_CancellationTokenRegistration_Create(void** /* System.Exception */ __outException)
	{
	
	    try {
			System.Threading.CancellationTokenRegistration __returnValue = new System.Threading.CancellationTokenRegistration();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Threading_CancellationTokenRegistration_TypeOf")]
	internal static void* /* System.Type */ System_Threading_CancellationTokenRegistration_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.Threading.CancellationTokenRegistration);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Threading_CancellationTokenRegistration_Destroy")]
	internal static void /* System.Void */ System_Threading_CancellationTokenRegistration_Destroy(void* /* System.Threading.CancellationTokenRegistration */ __self)
	{
	
		InteropUtils.FreeIfAllocated(__self);
	}
	
}


internal unsafe class System_Action
{
	internal void* Context { get; }
	internal delegate* unmanaged<void* /* context */, void /* System.Void */ /* return type */> CFunction { get; }
	internal delegate* unmanaged<void*, void> CDestructorFunction { get; }

	private WeakReference<System.Action> m_trampoline;
	internal System.Action Trampoline
	{
		get {
			System.Action? trampoline;

			if (m_trampoline is not null) {
				m_trampoline.TryGetTarget(out trampoline);
			} else {
				trampoline = null;
			}

			if (trampoline is null) {
				trampoline = CreateTrampoline();
				m_trampoline = new(trampoline);
			}

			return trampoline;
		}
	}

	private System_Action(void* context, delegate* unmanaged<void* /* context */, void /* System.Void */ /* return type */> cFunction, delegate* unmanaged<void*, void> cDestructorFunction)
	{
		Context = context;
		CFunction = cFunction;
		CDestructorFunction = cDestructorFunction;
	}

	internal System_Action(System.Action originalDelegate)
	{
		m_trampoline = new(originalDelegate);
	}

	~System_Action()
	{
		if (CDestructorFunction is null) {
			return;
		}

		CDestructorFunction(Context);
	}

	private System.Action? CreateTrampoline()
	{
		if (CFunction is null) {
			return null;
		}

		System.Type typeOfSelf = typeof(System_Action);
		string nameOfInvocationMethod = nameof(__InvokeByCallingCFunction);
		System.Reflection.BindingFlags bindingFlags = System.Reflection.BindingFlags.Instance | BindingFlags.NonPublic;
		System.Reflection.MethodInfo? invocationMethod = typeOfSelf.GetMethod(nameOfInvocationMethod, bindingFlags);

		if (invocationMethod is null) {
			throw new Exception("Failed to retrieve delegate invocation method");
		}

		System.Action trampoline = (System.Action)System.Delegate.CreateDelegate(typeof(System.Action), this, invocationMethod);

		return trampoline;
	}

	private void __InvokeByCallingCFunction()
	{
	

		CFunction(Context);
	}

	[UnmanagedCallersOnly(EntryPoint = "System_Action_Create")]
	public static void* Create(void* context, delegate* unmanaged<void* /* context */, void /* System.Void */ /* return type */> cFunction, delegate* unmanaged<void*, void> cDestructorFunction)
	{
		var self = new System_Action(context, cFunction, cDestructorFunction);
		void* selfHandle = self.AllocateGCHandleAndGetAddress();

		return selfHandle;
	}

	[UnmanagedCallersOnly(EntryPoint = "System_Action_Invoke")]
	public static void /* System.Void */ Invoke(void* self, void** __outException)
	{
		if (self is null) {
			throw new ArgumentNullException(nameof(self));
		}

		try {
			var selfConverted = InteropUtils.GetInstance<System_Action>(self);

		

			selfConverted.Trampoline();
		} catch (Exception __exception) {
			if (__outException is not null) {
				void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();

				*__outException = __exceptionHandleAddress;
			}

		}
	}

	[UnmanagedCallersOnly(EntryPoint = "System_Action_Context_Get")]
	public static void* Context_Get(void* self)
	{
		if (self is null) {
			throw new ArgumentNullException(nameof(self));
		}

		var selfConverted = InteropUtils.GetInstance<System_Action>(self);

		return selfConverted.Context;
	}

	[UnmanagedCallersOnly(EntryPoint = "System_Action_CFunction_Get")]
	public static delegate* unmanaged<void* /* context */, void /* System.Void */ /* return type */> CFunction_Get(void* self)
	{
		if (self is null) {
			throw new ArgumentNullException(nameof(self));
		}

		var selfConverted = InteropUtils.GetInstance<System_Action>(self);

		return selfConverted.CFunction;
	}

	[UnmanagedCallersOnly(EntryPoint = "System_Action_CDestructorFunction_Get")]
	public static delegate* unmanaged<void*, void> CDestructorFunction_Get(void* self)
	{
		if (self is null) {
			throw new ArgumentNullException(nameof(self));
		}

		var selfConverted = InteropUtils.GetInstance<System_Action>(self);

		return selfConverted.CDestructorFunction;
	}

	[UnmanagedCallersOnly(EntryPoint = "System_Action_TypeOf")]
	internal static void* /* System.Type */ System_Action_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.Action);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	

	[UnmanagedCallersOnly(EntryPoint = "System_Action_Destroy")]
	internal static void /* System.Void */ System_Action_Destroy(void* /* System.Action */ __self)
	{
	
		InteropUtils.FreeIfAllocated(__self);
	}
	
}


internal unsafe class System_MulticastDelegate
{
	internal void* Context { get; }
	internal delegate* unmanaged<void* /* context */, void /* System.Void */ /* return type */> CFunction { get; }
	internal delegate* unmanaged<void*, void> CDestructorFunction { get; }

	private WeakReference<System.MulticastDelegate> m_trampoline;
	internal System.MulticastDelegate Trampoline
	{
		get {
			System.MulticastDelegate? trampoline;

			if (m_trampoline is not null) {
				m_trampoline.TryGetTarget(out trampoline);
			} else {
				trampoline = null;
			}

			if (trampoline is null) {
				trampoline = CreateTrampoline();
				m_trampoline = new(trampoline);
			}

			return trampoline;
		}
	}

	private System_MulticastDelegate(void* context, delegate* unmanaged<void* /* context */, void /* System.Void */ /* return type */> cFunction, delegate* unmanaged<void*, void> cDestructorFunction)
	{
		Context = context;
		CFunction = cFunction;
		CDestructorFunction = cDestructorFunction;
	}

	internal System_MulticastDelegate(System.MulticastDelegate originalDelegate)
	{
		m_trampoline = new(originalDelegate);
	}

	~System_MulticastDelegate()
	{
		if (CDestructorFunction is null) {
			return;
		}

		CDestructorFunction(Context);
	}

	private System.MulticastDelegate? CreateTrampoline()
	{
		if (CFunction is null) {
			return null;
		}

		System.Type typeOfSelf = typeof(System_MulticastDelegate);
		string nameOfInvocationMethod = nameof(__InvokeByCallingCFunction);
		System.Reflection.BindingFlags bindingFlags = System.Reflection.BindingFlags.Instance | BindingFlags.NonPublic;
		System.Reflection.MethodInfo? invocationMethod = typeOfSelf.GetMethod(nameOfInvocationMethod, bindingFlags);

		if (invocationMethod is null) {
			throw new Exception("Failed to retrieve delegate invocation method");
		}

		System.MulticastDelegate trampoline = (System.MulticastDelegate)System.Delegate.CreateDelegate(typeof(System.MulticastDelegate), this, invocationMethod);

		return trampoline;
	}

	private void __InvokeByCallingCFunction()
	{
	

		CFunction(Context);
	}

	[UnmanagedCallersOnly(EntryPoint = "System_MulticastDelegate_Create")]
	public static void* Create(void* context, delegate* unmanaged<void* /* context */, void /* System.Void */ /* return type */> cFunction, delegate* unmanaged<void*, void> cDestructorFunction)
	{
		var self = new System_MulticastDelegate(context, cFunction, cDestructorFunction);
		void* selfHandle = self.AllocateGCHandleAndGetAddress();

		return selfHandle;
	}

	[UnmanagedCallersOnly(EntryPoint = "System_MulticastDelegate_Invoke")]
	public static void /* System.Void */ Invoke(void* self, void** __outException)
	{
		if (self is null) {
			throw new ArgumentNullException(nameof(self));
		}

		try {
			var selfConverted = InteropUtils.GetInstance<System_MulticastDelegate>(self);

		

			selfConverted.Trampoline.DynamicInvoke();
		} catch (Exception __exception) {
			if (__outException is not null) {
				void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();

				*__outException = __exceptionHandleAddress;
			}

		}
	}

	[UnmanagedCallersOnly(EntryPoint = "System_MulticastDelegate_Context_Get")]
	public static void* Context_Get(void* self)
	{
		if (self is null) {
			throw new ArgumentNullException(nameof(self));
		}

		var selfConverted = InteropUtils.GetInstance<System_MulticastDelegate>(self);

		return selfConverted.Context;
	}

	[UnmanagedCallersOnly(EntryPoint = "System_MulticastDelegate_CFunction_Get")]
	public static delegate* unmanaged<void* /* context */, void /* System.Void */ /* return type */> CFunction_Get(void* self)
	{
		if (self is null) {
			throw new ArgumentNullException(nameof(self));
		}

		var selfConverted = InteropUtils.GetInstance<System_MulticastDelegate>(self);

		return selfConverted.CFunction;
	}

	[UnmanagedCallersOnly(EntryPoint = "System_MulticastDelegate_CDestructorFunction_Get")]
	public static delegate* unmanaged<void*, void> CDestructorFunction_Get(void* self)
	{
		if (self is null) {
			throw new ArgumentNullException(nameof(self));
		}

		var selfConverted = InteropUtils.GetInstance<System_MulticastDelegate>(self);

		return selfConverted.CDestructorFunction;
	}

	[UnmanagedCallersOnly(EntryPoint = "System_MulticastDelegate_TypeOf")]
	internal static void* /* System.Type */ System_MulticastDelegate_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.MulticastDelegate);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	

	[UnmanagedCallersOnly(EntryPoint = "System_MulticastDelegate_Destroy")]
	internal static void /* System.Void */ System_MulticastDelegate_Destroy(void* /* System.MulticastDelegate */ __self)
	{
	
		InteropUtils.FreeIfAllocated(__self);
	}
	
}


internal unsafe class System_Delegate
{
	internal void* Context { get; }
	internal delegate* unmanaged<void* /* context */, void /* System.Void */ /* return type */> CFunction { get; }
	internal delegate* unmanaged<void*, void> CDestructorFunction { get; }

	private WeakReference<System.Delegate> m_trampoline;
	internal System.Delegate Trampoline
	{
		get {
			System.Delegate? trampoline;

			if (m_trampoline is not null) {
				m_trampoline.TryGetTarget(out trampoline);
			} else {
				trampoline = null;
			}

			if (trampoline is null) {
				trampoline = CreateTrampoline();
				m_trampoline = new(trampoline);
			}

			return trampoline;
		}
	}

	private System_Delegate(void* context, delegate* unmanaged<void* /* context */, void /* System.Void */ /* return type */> cFunction, delegate* unmanaged<void*, void> cDestructorFunction)
	{
		Context = context;
		CFunction = cFunction;
		CDestructorFunction = cDestructorFunction;
	}

	internal System_Delegate(System.Delegate originalDelegate)
	{
		m_trampoline = new(originalDelegate);
	}

	~System_Delegate()
	{
		if (CDestructorFunction is null) {
			return;
		}

		CDestructorFunction(Context);
	}

	private System.Delegate? CreateTrampoline()
	{
		if (CFunction is null) {
			return null;
		}

		System.Type typeOfSelf = typeof(System_Delegate);
		string nameOfInvocationMethod = nameof(__InvokeByCallingCFunction);
		System.Reflection.BindingFlags bindingFlags = System.Reflection.BindingFlags.Instance | BindingFlags.NonPublic;
		System.Reflection.MethodInfo? invocationMethod = typeOfSelf.GetMethod(nameOfInvocationMethod, bindingFlags);

		if (invocationMethod is null) {
			throw new Exception("Failed to retrieve delegate invocation method");
		}

		System.Delegate trampoline = (System.Delegate)System.Delegate.CreateDelegate(typeof(System.Delegate), this, invocationMethod);

		return trampoline;
	}

	private void __InvokeByCallingCFunction()
	{
	

		CFunction(Context);
	}

	[UnmanagedCallersOnly(EntryPoint = "System_Delegate_Create")]
	public static void* Create(void* context, delegate* unmanaged<void* /* context */, void /* System.Void */ /* return type */> cFunction, delegate* unmanaged<void*, void> cDestructorFunction)
	{
		var self = new System_Delegate(context, cFunction, cDestructorFunction);
		void* selfHandle = self.AllocateGCHandleAndGetAddress();

		return selfHandle;
	}

	[UnmanagedCallersOnly(EntryPoint = "System_Delegate_Invoke")]
	public static void /* System.Void */ Invoke(void* self, void** __outException)
	{
		if (self is null) {
			throw new ArgumentNullException(nameof(self));
		}

		try {
			var selfConverted = InteropUtils.GetInstance<System_Delegate>(self);

		

			selfConverted.Trampoline.DynamicInvoke();
		} catch (Exception __exception) {
			if (__outException is not null) {
				void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();

				*__outException = __exceptionHandleAddress;
			}

		}
	}

	[UnmanagedCallersOnly(EntryPoint = "System_Delegate_Context_Get")]
	public static void* Context_Get(void* self)
	{
		if (self is null) {
			throw new ArgumentNullException(nameof(self));
		}

		var selfConverted = InteropUtils.GetInstance<System_Delegate>(self);

		return selfConverted.Context;
	}

	[UnmanagedCallersOnly(EntryPoint = "System_Delegate_CFunction_Get")]
	public static delegate* unmanaged<void* /* context */, void /* System.Void */ /* return type */> CFunction_Get(void* self)
	{
		if (self is null) {
			throw new ArgumentNullException(nameof(self));
		}

		var selfConverted = InteropUtils.GetInstance<System_Delegate>(self);

		return selfConverted.CFunction;
	}

	[UnmanagedCallersOnly(EntryPoint = "System_Delegate_CDestructorFunction_Get")]
	public static delegate* unmanaged<void*, void> CDestructorFunction_Get(void* self)
	{
		if (self is null) {
			throw new ArgumentNullException(nameof(self));
		}

		var selfConverted = InteropUtils.GetInstance<System_Delegate>(self);

		return selfConverted.CDestructorFunction;
	}

	[UnmanagedCallersOnly(EntryPoint = "System_Delegate_TypeOf")]
	internal static void* /* System.Type */ System_Delegate_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.Delegate);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	

	[UnmanagedCallersOnly(EntryPoint = "System_Delegate_Destroy")]
	internal static void /* System.Void */ System_Delegate_Destroy(void* /* System.Delegate */ __self)
	{
	
		InteropUtils.FreeIfAllocated(__self);
	}
	
}


internal unsafe class System_Exception
{
	[UnmanagedCallersOnly(EntryPoint = "System_Exception_GetBaseException")]
	internal static void* /* System.Exception */ System_Exception_GetBaseException(void* /* System.Exception */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Exception __selfConverted = InteropUtils.GetInstance<System.Exception>(__self);
	
	
	    try {
			System.Exception __returnValue = __selfConverted.GetBaseException();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Exception_GetObjectData")]
	internal static void /* System.Void */ System_Exception_GetObjectData(void* /* System.Exception */ __self, void* /* System.Runtime.Serialization.SerializationInfo */ info, void* /* System.Runtime.Serialization.StreamingContext */ context, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Exception __selfConverted = InteropUtils.GetInstance<System.Exception>(__self);
	
		System.Runtime.Serialization.SerializationInfo infoConverted = InteropUtils.GetInstance<System.Runtime.Serialization.SerializationInfo>(info);
		System.Runtime.Serialization.StreamingContext contextConverted = InteropUtils.GetInstance<System.Runtime.Serialization.StreamingContext>(context);
	
	    try {
			__selfConverted.GetObjectData(infoConverted, contextConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Exception_ToString")]
	internal static void* /* System.String */ System_Exception_ToString(void* /* System.Exception */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Exception __selfConverted = InteropUtils.GetInstance<System.Exception>(__self);
	
	
	    try {
			System.String __returnValue = __selfConverted.ToString();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Exception_GetType")]
	internal static void* /* System.Type */ System_Exception_GetType(void* /* System.Exception */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Exception __selfConverted = InteropUtils.GetInstance<System.Exception>(__self);
	
	
	    try {
			System.Type __returnValue = __selfConverted.GetType();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Exception_Create")]
	internal static void* /* System.Exception */ System_Exception_Create(void** /* System.Exception */ __outException)
	{
	
	    try {
			System.Exception __returnValue = new System.Exception();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Exception_Create_1")]
	internal static void* /* System.Exception */ System_Exception_Create_1(void* /* System.String */ message, void** /* System.Exception */ __outException)
	{
		System.String messageConverted = InteropUtils.GetInstance<System.String>(message);
	
	    try {
			System.Exception __returnValue = new System.Exception(messageConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Exception_Create_2")]
	internal static void* /* System.Exception */ System_Exception_Create_2(void* /* System.String */ message, void* /* System.Exception */ innerException, void** /* System.Exception */ __outException)
	{
		System.String messageConverted = InteropUtils.GetInstance<System.String>(message);
		System.Exception innerExceptionConverted = InteropUtils.GetInstance<System.Exception>(innerException);
	
	    try {
			System.Exception __returnValue = new System.Exception(messageConverted, innerExceptionConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Exception_TargetSite_Get")]
	internal static void* /* System.Reflection.MethodBase */ System_Exception_TargetSite_Get(void* /* System.Exception */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Exception __selfConverted = InteropUtils.GetInstance<System.Exception>(__self);
	
	
	    try {
			System.Reflection.MethodBase __returnValue = __selfConverted.TargetSite;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Exception_Message_Get")]
	internal static void* /* System.String */ System_Exception_Message_Get(void* /* System.Exception */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Exception __selfConverted = InteropUtils.GetInstance<System.Exception>(__self);
	
	
	    try {
			System.String __returnValue = __selfConverted.Message;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Exception_Data_Get")]
	internal static void* /* System.Collections.IDictionary */ System_Exception_Data_Get(void* /* System.Exception */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Exception __selfConverted = InteropUtils.GetInstance<System.Exception>(__self);
	
	
	    try {
			System.Collections.IDictionary __returnValue = __selfConverted.Data;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Exception_InnerException_Get")]
	internal static void* /* System.Exception */ System_Exception_InnerException_Get(void* /* System.Exception */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Exception __selfConverted = InteropUtils.GetInstance<System.Exception>(__self);
	
	
	    try {
			System.Exception __returnValue = __selfConverted.InnerException;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Exception_HelpLink_Get")]
	internal static void* /* System.String */ System_Exception_HelpLink_Get(void* /* System.Exception */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Exception __selfConverted = InteropUtils.GetInstance<System.Exception>(__self);
	
	
	    try {
			System.String __returnValue = __selfConverted.HelpLink;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Exception_HelpLink_Set")]
	internal static void /* System.Void */ System_Exception_HelpLink_Set(void* /* System.Exception */ __self, void* /* System.String */ __value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Exception __selfConverted = InteropUtils.GetInstance<System.Exception>(__self);
	
	
	    try {
			__selfConverted.HelpLink = InteropUtils.GetInstance<System.String>(__value);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Exception_Source_Get")]
	internal static void* /* System.String */ System_Exception_Source_Get(void* /* System.Exception */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Exception __selfConverted = InteropUtils.GetInstance<System.Exception>(__self);
	
	
	    try {
			System.String __returnValue = __selfConverted.Source;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Exception_Source_Set")]
	internal static void /* System.Void */ System_Exception_Source_Set(void* /* System.Exception */ __self, void* /* System.String */ __value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Exception __selfConverted = InteropUtils.GetInstance<System.Exception>(__self);
	
	
	    try {
			__selfConverted.Source = InteropUtils.GetInstance<System.String>(__value);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Exception_HResult_Get")]
	internal static int /* System.Int32 */ System_Exception_HResult_Get(void* /* System.Exception */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Exception __selfConverted = InteropUtils.GetInstance<System.Exception>(__self);
	
	
	    try {
			System.Int32 __returnValue = __selfConverted.HResult;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Exception_HResult_Set")]
	internal static void /* System.Void */ System_Exception_HResult_Set(void* /* System.Exception */ __self, int /* System.Int32 */ __value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Exception __selfConverted = InteropUtils.GetInstance<System.Exception>(__self);
	
	
	    try {
			__selfConverted.HResult = __value;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Exception_StackTrace_Get")]
	internal static void* /* System.String */ System_Exception_StackTrace_Get(void* /* System.Exception */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Exception __selfConverted = InteropUtils.GetInstance<System.Exception>(__self);
	
	
	    try {
			System.String __returnValue = __selfConverted.StackTrace;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Exception_TypeOf")]
	internal static void* /* System.Type */ System_Exception_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.Exception);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Exception_Destroy")]
	internal static void /* System.Void */ System_Exception_Destroy(void* /* System.Exception */ __self)
	{
	
		InteropUtils.FreeIfAllocated(__self);
	}
	
}


internal unsafe class System_Reflection_MethodBase
{
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_MethodBase_GetMethodFromHandle")]
	internal static void* /* System.Reflection.MethodBase */ System_Reflection_MethodBase_GetMethodFromHandle(void* /* System.RuntimeMethodHandle */ handle, void** /* System.Exception */ __outException)
	{
		System.RuntimeMethodHandle handleConverted = InteropUtils.GetInstance<System.RuntimeMethodHandle>(handle);
	
	    try {
			System.Reflection.MethodBase __returnValue = System.Reflection.MethodBase.GetMethodFromHandle(handleConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_MethodBase_GetMethodFromHandle_1")]
	internal static void* /* System.Reflection.MethodBase */ System_Reflection_MethodBase_GetMethodFromHandle_1(void* /* System.RuntimeMethodHandle */ handle, void* /* System.RuntimeTypeHandle */ declaringType, void** /* System.Exception */ __outException)
	{
		System.RuntimeMethodHandle handleConverted = InteropUtils.GetInstance<System.RuntimeMethodHandle>(handle);
		System.RuntimeTypeHandle declaringTypeConverted = InteropUtils.GetInstance<System.RuntimeTypeHandle>(declaringType);
	
	    try {
			System.Reflection.MethodBase __returnValue = System.Reflection.MethodBase.GetMethodFromHandle(handleConverted, declaringTypeConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_MethodBase_GetCurrentMethod")]
	internal static void* /* System.Reflection.MethodBase */ System_Reflection_MethodBase_GetCurrentMethod(void** /* System.Exception */ __outException)
	{
	
	    try {
			System.Reflection.MethodBase __returnValue = System.Reflection.MethodBase.GetCurrentMethod();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_MethodBase_GetParameters")]
	internal static void* /* System.Reflection.ParameterInfo[] */ System_Reflection_MethodBase_GetParameters(void* /* System.Reflection.MethodBase */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.MethodBase __selfConverted = InteropUtils.GetInstance<System.Reflection.MethodBase>(__self);
	
	
	    try {
			System.Reflection.ParameterInfo[] __returnValue = __selfConverted.GetParameters();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_MethodBase_GetMethodImplementationFlags")]
	internal static System.Reflection.MethodImplAttributes /* System.Reflection.MethodImplAttributes */ System_Reflection_MethodBase_GetMethodImplementationFlags(void* /* System.Reflection.MethodBase */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.MethodBase __selfConverted = InteropUtils.GetInstance<System.Reflection.MethodBase>(__self);
	
	
	    try {
			System.Reflection.MethodImplAttributes __returnValue = __selfConverted.GetMethodImplementationFlags();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return default(System.Reflection.MethodImplAttributes);
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_MethodBase_GetMethodBody")]
	internal static void* /* System.Reflection.MethodBody */ System_Reflection_MethodBase_GetMethodBody(void* /* System.Reflection.MethodBase */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.MethodBase __selfConverted = InteropUtils.GetInstance<System.Reflection.MethodBase>(__self);
	
	
	    try {
			System.Reflection.MethodBody __returnValue = __selfConverted.GetMethodBody();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_MethodBase_GetGenericArguments")]
	internal static void* /* System.Type[] */ System_Reflection_MethodBase_GetGenericArguments(void* /* System.Reflection.MethodBase */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.MethodBase __selfConverted = InteropUtils.GetInstance<System.Reflection.MethodBase>(__self);
	
	
	    try {
			System.Type[] __returnValue = __selfConverted.GetGenericArguments();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_MethodBase_Invoke")]
	internal static void* /* System.Object */ System_Reflection_MethodBase_Invoke(void* /* System.Reflection.MethodBase */ __self, void* /* System.Object */ obj, void* /* System.Object[] */ parameters, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.MethodBase __selfConverted = InteropUtils.GetInstance<System.Reflection.MethodBase>(__self);
	
		System.Object objConverted = InteropUtils.GetInstance<System.Object>(obj);
		System.Object[] parametersConverted = InteropUtils.GetInstance<System.Object[]>(parameters);
	
	    try {
			System.Object __returnValue = __selfConverted.Invoke(objConverted, parametersConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_MethodBase_Invoke_1")]
	internal static void* /* System.Object */ System_Reflection_MethodBase_Invoke_1(void* /* System.Reflection.MethodBase */ __self, void* /* System.Object */ obj, System.Reflection.BindingFlags /* System.Reflection.BindingFlags */ invokeAttr, void* /* System.Reflection.Binder */ binder, void* /* System.Object[] */ parameters, void* /* System.Globalization.CultureInfo */ culture, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.MethodBase __selfConverted = InteropUtils.GetInstance<System.Reflection.MethodBase>(__self);
	
		System.Object objConverted = InteropUtils.GetInstance<System.Object>(obj);
		System.Reflection.Binder binderConverted = InteropUtils.GetInstance<System.Reflection.Binder>(binder);
		System.Object[] parametersConverted = InteropUtils.GetInstance<System.Object[]>(parameters);
		System.Globalization.CultureInfo cultureConverted = InteropUtils.GetInstance<System.Globalization.CultureInfo>(culture);
	
	    try {
			System.Object __returnValue = __selfConverted.Invoke(objConverted, invokeAttr, binderConverted, parametersConverted, cultureConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_MethodBase_Equals")]
	internal static byte /* System.Boolean */ System_Reflection_MethodBase_Equals(void* /* System.Reflection.MethodBase */ __self, void* /* System.Object */ obj, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.MethodBase __selfConverted = InteropUtils.GetInstance<System.Reflection.MethodBase>(__self);
	
		System.Object objConverted = InteropUtils.GetInstance<System.Object>(obj);
	
	    try {
			System.Boolean __returnValue = __selfConverted.Equals(objConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_MethodBase_GetHashCode")]
	internal static int /* System.Int32 */ System_Reflection_MethodBase_GetHashCode(void* /* System.Reflection.MethodBase */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.MethodBase __selfConverted = InteropUtils.GetInstance<System.Reflection.MethodBase>(__self);
	
	
	    try {
			System.Int32 __returnValue = __selfConverted.GetHashCode();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_MethodBase_Attributes_Get")]
	internal static System.Reflection.MethodAttributes /* System.Reflection.MethodAttributes */ System_Reflection_MethodBase_Attributes_Get(void* /* System.Reflection.MethodBase */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.MethodBase __selfConverted = InteropUtils.GetInstance<System.Reflection.MethodBase>(__self);
	
	
	    try {
			System.Reflection.MethodAttributes __returnValue = __selfConverted.Attributes;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return default(System.Reflection.MethodAttributes);
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_MethodBase_MethodImplementationFlags_Get")]
	internal static System.Reflection.MethodImplAttributes /* System.Reflection.MethodImplAttributes */ System_Reflection_MethodBase_MethodImplementationFlags_Get(void* /* System.Reflection.MethodBase */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.MethodBase __selfConverted = InteropUtils.GetInstance<System.Reflection.MethodBase>(__self);
	
	
	    try {
			System.Reflection.MethodImplAttributes __returnValue = __selfConverted.MethodImplementationFlags;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return default(System.Reflection.MethodImplAttributes);
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_MethodBase_CallingConvention_Get")]
	internal static System.Reflection.CallingConventions /* System.Reflection.CallingConventions */ System_Reflection_MethodBase_CallingConvention_Get(void* /* System.Reflection.MethodBase */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.MethodBase __selfConverted = InteropUtils.GetInstance<System.Reflection.MethodBase>(__self);
	
	
	    try {
			System.Reflection.CallingConventions __returnValue = __selfConverted.CallingConvention;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return default(System.Reflection.CallingConventions);
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_MethodBase_IsAbstract_Get")]
	internal static byte /* System.Boolean */ System_Reflection_MethodBase_IsAbstract_Get(void* /* System.Reflection.MethodBase */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.MethodBase __selfConverted = InteropUtils.GetInstance<System.Reflection.MethodBase>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.IsAbstract;
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_MethodBase_IsConstructor_Get")]
	internal static byte /* System.Boolean */ System_Reflection_MethodBase_IsConstructor_Get(void* /* System.Reflection.MethodBase */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.MethodBase __selfConverted = InteropUtils.GetInstance<System.Reflection.MethodBase>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.IsConstructor;
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_MethodBase_IsFinal_Get")]
	internal static byte /* System.Boolean */ System_Reflection_MethodBase_IsFinal_Get(void* /* System.Reflection.MethodBase */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.MethodBase __selfConverted = InteropUtils.GetInstance<System.Reflection.MethodBase>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.IsFinal;
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_MethodBase_IsHideBySig_Get")]
	internal static byte /* System.Boolean */ System_Reflection_MethodBase_IsHideBySig_Get(void* /* System.Reflection.MethodBase */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.MethodBase __selfConverted = InteropUtils.GetInstance<System.Reflection.MethodBase>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.IsHideBySig;
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_MethodBase_IsSpecialName_Get")]
	internal static byte /* System.Boolean */ System_Reflection_MethodBase_IsSpecialName_Get(void* /* System.Reflection.MethodBase */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.MethodBase __selfConverted = InteropUtils.GetInstance<System.Reflection.MethodBase>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.IsSpecialName;
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_MethodBase_IsStatic_Get")]
	internal static byte /* System.Boolean */ System_Reflection_MethodBase_IsStatic_Get(void* /* System.Reflection.MethodBase */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.MethodBase __selfConverted = InteropUtils.GetInstance<System.Reflection.MethodBase>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.IsStatic;
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_MethodBase_IsVirtual_Get")]
	internal static byte /* System.Boolean */ System_Reflection_MethodBase_IsVirtual_Get(void* /* System.Reflection.MethodBase */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.MethodBase __selfConverted = InteropUtils.GetInstance<System.Reflection.MethodBase>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.IsVirtual;
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_MethodBase_IsAssembly_Get")]
	internal static byte /* System.Boolean */ System_Reflection_MethodBase_IsAssembly_Get(void* /* System.Reflection.MethodBase */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.MethodBase __selfConverted = InteropUtils.GetInstance<System.Reflection.MethodBase>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.IsAssembly;
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_MethodBase_IsFamily_Get")]
	internal static byte /* System.Boolean */ System_Reflection_MethodBase_IsFamily_Get(void* /* System.Reflection.MethodBase */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.MethodBase __selfConverted = InteropUtils.GetInstance<System.Reflection.MethodBase>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.IsFamily;
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_MethodBase_IsFamilyAndAssembly_Get")]
	internal static byte /* System.Boolean */ System_Reflection_MethodBase_IsFamilyAndAssembly_Get(void* /* System.Reflection.MethodBase */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.MethodBase __selfConverted = InteropUtils.GetInstance<System.Reflection.MethodBase>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.IsFamilyAndAssembly;
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_MethodBase_IsFamilyOrAssembly_Get")]
	internal static byte /* System.Boolean */ System_Reflection_MethodBase_IsFamilyOrAssembly_Get(void* /* System.Reflection.MethodBase */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.MethodBase __selfConverted = InteropUtils.GetInstance<System.Reflection.MethodBase>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.IsFamilyOrAssembly;
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_MethodBase_IsPrivate_Get")]
	internal static byte /* System.Boolean */ System_Reflection_MethodBase_IsPrivate_Get(void* /* System.Reflection.MethodBase */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.MethodBase __selfConverted = InteropUtils.GetInstance<System.Reflection.MethodBase>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.IsPrivate;
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_MethodBase_IsPublic_Get")]
	internal static byte /* System.Boolean */ System_Reflection_MethodBase_IsPublic_Get(void* /* System.Reflection.MethodBase */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.MethodBase __selfConverted = InteropUtils.GetInstance<System.Reflection.MethodBase>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.IsPublic;
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_MethodBase_IsConstructedGenericMethod_Get")]
	internal static byte /* System.Boolean */ System_Reflection_MethodBase_IsConstructedGenericMethod_Get(void* /* System.Reflection.MethodBase */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.MethodBase __selfConverted = InteropUtils.GetInstance<System.Reflection.MethodBase>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.IsConstructedGenericMethod;
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_MethodBase_IsGenericMethod_Get")]
	internal static byte /* System.Boolean */ System_Reflection_MethodBase_IsGenericMethod_Get(void* /* System.Reflection.MethodBase */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.MethodBase __selfConverted = InteropUtils.GetInstance<System.Reflection.MethodBase>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.IsGenericMethod;
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_MethodBase_IsGenericMethodDefinition_Get")]
	internal static byte /* System.Boolean */ System_Reflection_MethodBase_IsGenericMethodDefinition_Get(void* /* System.Reflection.MethodBase */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.MethodBase __selfConverted = InteropUtils.GetInstance<System.Reflection.MethodBase>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.IsGenericMethodDefinition;
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_MethodBase_ContainsGenericParameters_Get")]
	internal static byte /* System.Boolean */ System_Reflection_MethodBase_ContainsGenericParameters_Get(void* /* System.Reflection.MethodBase */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.MethodBase __selfConverted = InteropUtils.GetInstance<System.Reflection.MethodBase>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.ContainsGenericParameters;
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_MethodBase_MethodHandle_Get")]
	internal static void* /* System.RuntimeMethodHandle */ System_Reflection_MethodBase_MethodHandle_Get(void* /* System.Reflection.MethodBase */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.MethodBase __selfConverted = InteropUtils.GetInstance<System.Reflection.MethodBase>(__self);
	
	
	    try {
			System.RuntimeMethodHandle __returnValue = __selfConverted.MethodHandle;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_MethodBase_IsSecurityCritical_Get")]
	internal static byte /* System.Boolean */ System_Reflection_MethodBase_IsSecurityCritical_Get(void* /* System.Reflection.MethodBase */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.MethodBase __selfConverted = InteropUtils.GetInstance<System.Reflection.MethodBase>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.IsSecurityCritical;
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_MethodBase_IsSecuritySafeCritical_Get")]
	internal static byte /* System.Boolean */ System_Reflection_MethodBase_IsSecuritySafeCritical_Get(void* /* System.Reflection.MethodBase */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.MethodBase __selfConverted = InteropUtils.GetInstance<System.Reflection.MethodBase>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.IsSecuritySafeCritical;
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_MethodBase_IsSecurityTransparent_Get")]
	internal static byte /* System.Boolean */ System_Reflection_MethodBase_IsSecurityTransparent_Get(void* /* System.Reflection.MethodBase */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.MethodBase __selfConverted = InteropUtils.GetInstance<System.Reflection.MethodBase>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.IsSecurityTransparent;
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_MethodBase_TypeOf")]
	internal static void* /* System.Type */ System_Reflection_MethodBase_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.Reflection.MethodBase);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_MethodBase_Destroy")]
	internal static void /* System.Void */ System_Reflection_MethodBase_Destroy(void* /* System.Reflection.MethodBase */ __self)
	{
	
		InteropUtils.FreeIfAllocated(__self);
	}
	
}


internal unsafe class System_RuntimeMethodHandle
{
	[UnmanagedCallersOnly(EntryPoint = "System_RuntimeMethodHandle_GetObjectData")]
	internal static void /* System.Void */ System_RuntimeMethodHandle_GetObjectData(void* /* System.RuntimeMethodHandle */ __self, void* /* System.Runtime.Serialization.SerializationInfo */ info, void* /* System.Runtime.Serialization.StreamingContext */ context, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.RuntimeMethodHandle __selfConverted = InteropUtils.GetInstance<System.RuntimeMethodHandle>(__self);
	
		System.Runtime.Serialization.SerializationInfo infoConverted = InteropUtils.GetInstance<System.Runtime.Serialization.SerializationInfo>(info);
		System.Runtime.Serialization.StreamingContext contextConverted = InteropUtils.GetInstance<System.Runtime.Serialization.StreamingContext>(context);
	
	    try {
			__selfConverted.GetObjectData(infoConverted, contextConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_RuntimeMethodHandle_GetHashCode")]
	internal static int /* System.Int32 */ System_RuntimeMethodHandle_GetHashCode(void* /* System.RuntimeMethodHandle */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.RuntimeMethodHandle __selfConverted = InteropUtils.GetInstance<System.RuntimeMethodHandle>(__self);
	
	
	    try {
			System.Int32 __returnValue = __selfConverted.GetHashCode();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_RuntimeMethodHandle_Equals")]
	internal static byte /* System.Boolean */ System_RuntimeMethodHandle_Equals(void* /* System.RuntimeMethodHandle */ __self, void* /* System.Object */ obj, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.RuntimeMethodHandle __selfConverted = InteropUtils.GetInstance<System.RuntimeMethodHandle>(__self);
	
		System.Object objConverted = InteropUtils.GetInstance<System.Object>(obj);
	
	    try {
			System.Boolean __returnValue = __selfConverted.Equals(objConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_RuntimeMethodHandle_FromIntPtr")]
	internal static void* /* System.RuntimeMethodHandle */ System_RuntimeMethodHandle_FromIntPtr(nint /* System.IntPtr */ value, void** /* System.Exception */ __outException)
	{
	
	    try {
			System.RuntimeMethodHandle __returnValue = System.RuntimeMethodHandle.FromIntPtr(value);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_RuntimeMethodHandle_ToIntPtr")]
	internal static nint /* System.IntPtr */ System_RuntimeMethodHandle_ToIntPtr(void* /* System.RuntimeMethodHandle */ value, void** /* System.Exception */ __outException)
	{
		System.RuntimeMethodHandle valueConverted = InteropUtils.GetInstance<System.RuntimeMethodHandle>(value);
	
	    try {
			System.IntPtr __returnValue = System.RuntimeMethodHandle.ToIntPtr(valueConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return nint.Zero;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_RuntimeMethodHandle_Equals_1")]
	internal static byte /* System.Boolean */ System_RuntimeMethodHandle_Equals_1(void* /* System.RuntimeMethodHandle */ __self, void* /* System.RuntimeMethodHandle */ handle, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.RuntimeMethodHandle __selfConverted = InteropUtils.GetInstance<System.RuntimeMethodHandle>(__self);
	
		System.RuntimeMethodHandle handleConverted = InteropUtils.GetInstance<System.RuntimeMethodHandle>(handle);
	
	    try {
			System.Boolean __returnValue = __selfConverted.Equals(handleConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_RuntimeMethodHandle_GetFunctionPointer")]
	internal static nint /* System.IntPtr */ System_RuntimeMethodHandle_GetFunctionPointer(void* /* System.RuntimeMethodHandle */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.RuntimeMethodHandle __selfConverted = InteropUtils.GetInstance<System.RuntimeMethodHandle>(__self);
	
	
	    try {
			System.IntPtr __returnValue = __selfConverted.GetFunctionPointer();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return nint.Zero;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_RuntimeMethodHandle_Value_Get")]
	internal static nint /* System.IntPtr */ System_RuntimeMethodHandle_Value_Get(void* /* System.RuntimeMethodHandle */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.RuntimeMethodHandle __selfConverted = InteropUtils.GetInstance<System.RuntimeMethodHandle>(__self);
	
	
	    try {
			System.IntPtr __returnValue = __selfConverted.Value;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return nint.Zero;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_RuntimeMethodHandle_Create")]
	internal static void* /* System.RuntimeMethodHandle */ System_RuntimeMethodHandle_Create(void** /* System.Exception */ __outException)
	{
	
	    try {
			System.RuntimeMethodHandle __returnValue = new System.RuntimeMethodHandle();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_RuntimeMethodHandle_TypeOf")]
	internal static void* /* System.Type */ System_RuntimeMethodHandle_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.RuntimeMethodHandle);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_RuntimeMethodHandle_Destroy")]
	internal static void /* System.Void */ System_RuntimeMethodHandle_Destroy(void* /* System.RuntimeMethodHandle */ __self)
	{
	
		InteropUtils.FreeIfAllocated(__self);
	}
	
}


internal unsafe class System_RuntimeTypeHandle
{
	[UnmanagedCallersOnly(EntryPoint = "System_RuntimeTypeHandle_FromIntPtr")]
	internal static void* /* System.RuntimeTypeHandle */ System_RuntimeTypeHandle_FromIntPtr(nint /* System.IntPtr */ value, void** /* System.Exception */ __outException)
	{
	
	    try {
			System.RuntimeTypeHandle __returnValue = System.RuntimeTypeHandle.FromIntPtr(value);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_RuntimeTypeHandle_ToIntPtr")]
	internal static nint /* System.IntPtr */ System_RuntimeTypeHandle_ToIntPtr(void* /* System.RuntimeTypeHandle */ value, void** /* System.Exception */ __outException)
	{
		System.RuntimeTypeHandle valueConverted = InteropUtils.GetInstance<System.RuntimeTypeHandle>(value);
	
	    try {
			System.IntPtr __returnValue = System.RuntimeTypeHandle.ToIntPtr(valueConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return nint.Zero;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_RuntimeTypeHandle_GetHashCode")]
	internal static int /* System.Int32 */ System_RuntimeTypeHandle_GetHashCode(void* /* System.RuntimeTypeHandle */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.RuntimeTypeHandle __selfConverted = InteropUtils.GetInstance<System.RuntimeTypeHandle>(__self);
	
	
	    try {
			System.Int32 __returnValue = __selfConverted.GetHashCode();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_RuntimeTypeHandle_Equals")]
	internal static byte /* System.Boolean */ System_RuntimeTypeHandle_Equals(void* /* System.RuntimeTypeHandle */ __self, void* /* System.Object */ obj, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.RuntimeTypeHandle __selfConverted = InteropUtils.GetInstance<System.RuntimeTypeHandle>(__self);
	
		System.Object objConverted = InteropUtils.GetInstance<System.Object>(obj);
	
	    try {
			System.Boolean __returnValue = __selfConverted.Equals(objConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_RuntimeTypeHandle_Equals_1")]
	internal static byte /* System.Boolean */ System_RuntimeTypeHandle_Equals_1(void* /* System.RuntimeTypeHandle */ __self, void* /* System.RuntimeTypeHandle */ handle, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.RuntimeTypeHandle __selfConverted = InteropUtils.GetInstance<System.RuntimeTypeHandle>(__self);
	
		System.RuntimeTypeHandle handleConverted = InteropUtils.GetInstance<System.RuntimeTypeHandle>(handle);
	
	    try {
			System.Boolean __returnValue = __selfConverted.Equals(handleConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_RuntimeTypeHandle_GetModuleHandle")]
	internal static void* /* System.ModuleHandle */ System_RuntimeTypeHandle_GetModuleHandle(void* /* System.RuntimeTypeHandle */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.RuntimeTypeHandle __selfConverted = InteropUtils.GetInstance<System.RuntimeTypeHandle>(__self);
	
	
	    try {
			System.ModuleHandle __returnValue = __selfConverted.GetModuleHandle();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_RuntimeTypeHandle_GetObjectData")]
	internal static void /* System.Void */ System_RuntimeTypeHandle_GetObjectData(void* /* System.RuntimeTypeHandle */ __self, void* /* System.Runtime.Serialization.SerializationInfo */ info, void* /* System.Runtime.Serialization.StreamingContext */ context, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.RuntimeTypeHandle __selfConverted = InteropUtils.GetInstance<System.RuntimeTypeHandle>(__self);
	
		System.Runtime.Serialization.SerializationInfo infoConverted = InteropUtils.GetInstance<System.Runtime.Serialization.SerializationInfo>(info);
		System.Runtime.Serialization.StreamingContext contextConverted = InteropUtils.GetInstance<System.Runtime.Serialization.StreamingContext>(context);
	
	    try {
			__selfConverted.GetObjectData(infoConverted, contextConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_RuntimeTypeHandle_Value_Get")]
	internal static nint /* System.IntPtr */ System_RuntimeTypeHandle_Value_Get(void* /* System.RuntimeTypeHandle */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.RuntimeTypeHandle __selfConverted = InteropUtils.GetInstance<System.RuntimeTypeHandle>(__self);
	
	
	    try {
			System.IntPtr __returnValue = __selfConverted.Value;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return nint.Zero;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_RuntimeTypeHandle_Create")]
	internal static void* /* System.RuntimeTypeHandle */ System_RuntimeTypeHandle_Create(void** /* System.Exception */ __outException)
	{
	
	    try {
			System.RuntimeTypeHandle __returnValue = new System.RuntimeTypeHandle();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_RuntimeTypeHandle_TypeOf")]
	internal static void* /* System.Type */ System_RuntimeTypeHandle_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.RuntimeTypeHandle);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_RuntimeTypeHandle_Destroy")]
	internal static void /* System.Void */ System_RuntimeTypeHandle_Destroy(void* /* System.RuntimeTypeHandle */ __self)
	{
	
		InteropUtils.FreeIfAllocated(__self);
	}
	
}


internal unsafe class System_ModuleHandle
{
	[UnmanagedCallersOnly(EntryPoint = "System_ModuleHandle_GetHashCode")]
	internal static int /* System.Int32 */ System_ModuleHandle_GetHashCode(void* /* System.ModuleHandle */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.ModuleHandle __selfConverted = InteropUtils.GetInstance<System.ModuleHandle>(__self);
	
	
	    try {
			System.Int32 __returnValue = __selfConverted.GetHashCode();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_ModuleHandle_Equals")]
	internal static byte /* System.Boolean */ System_ModuleHandle_Equals(void* /* System.ModuleHandle */ __self, void* /* System.Object */ obj, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.ModuleHandle __selfConverted = InteropUtils.GetInstance<System.ModuleHandle>(__self);
	
		System.Object objConverted = InteropUtils.GetInstance<System.Object>(obj);
	
	    try {
			System.Boolean __returnValue = __selfConverted.Equals(objConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_ModuleHandle_Equals_1")]
	internal static byte /* System.Boolean */ System_ModuleHandle_Equals_1(void* /* System.ModuleHandle */ __self, void* /* System.ModuleHandle */ handle, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.ModuleHandle __selfConverted = InteropUtils.GetInstance<System.ModuleHandle>(__self);
	
		System.ModuleHandle handleConverted = InteropUtils.GetInstance<System.ModuleHandle>(handle);
	
	    try {
			System.Boolean __returnValue = __selfConverted.Equals(handleConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_ModuleHandle_GetRuntimeTypeHandleFromMetadataToken")]
	internal static void* /* System.RuntimeTypeHandle */ System_ModuleHandle_GetRuntimeTypeHandleFromMetadataToken(void* /* System.ModuleHandle */ __self, int /* System.Int32 */ typeToken, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.ModuleHandle __selfConverted = InteropUtils.GetInstance<System.ModuleHandle>(__self);
	
	
	    try {
			System.RuntimeTypeHandle __returnValue = __selfConverted.GetRuntimeTypeHandleFromMetadataToken(typeToken);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_ModuleHandle_ResolveTypeHandle")]
	internal static void* /* System.RuntimeTypeHandle */ System_ModuleHandle_ResolveTypeHandle(void* /* System.ModuleHandle */ __self, int /* System.Int32 */ typeToken, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.ModuleHandle __selfConverted = InteropUtils.GetInstance<System.ModuleHandle>(__self);
	
	
	    try {
			System.RuntimeTypeHandle __returnValue = __selfConverted.ResolveTypeHandle(typeToken);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_ModuleHandle_ResolveTypeHandle_1")]
	internal static void* /* System.RuntimeTypeHandle */ System_ModuleHandle_ResolveTypeHandle_1(void* /* System.ModuleHandle */ __self, int /* System.Int32 */ typeToken, void* /* System.RuntimeTypeHandle[] */ typeInstantiationContext, void* /* System.RuntimeTypeHandle[] */ methodInstantiationContext, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.ModuleHandle __selfConverted = InteropUtils.GetInstance<System.ModuleHandle>(__self);
	
		System.RuntimeTypeHandle[] typeInstantiationContextConverted = InteropUtils.GetInstance<System.RuntimeTypeHandle[]>(typeInstantiationContext);
		System.RuntimeTypeHandle[] methodInstantiationContextConverted = InteropUtils.GetInstance<System.RuntimeTypeHandle[]>(methodInstantiationContext);
	
	    try {
			System.RuntimeTypeHandle __returnValue = __selfConverted.ResolveTypeHandle(typeToken, typeInstantiationContextConverted, methodInstantiationContextConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_ModuleHandle_GetRuntimeMethodHandleFromMetadataToken")]
	internal static void* /* System.RuntimeMethodHandle */ System_ModuleHandle_GetRuntimeMethodHandleFromMetadataToken(void* /* System.ModuleHandle */ __self, int /* System.Int32 */ methodToken, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.ModuleHandle __selfConverted = InteropUtils.GetInstance<System.ModuleHandle>(__self);
	
	
	    try {
			System.RuntimeMethodHandle __returnValue = __selfConverted.GetRuntimeMethodHandleFromMetadataToken(methodToken);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_ModuleHandle_ResolveMethodHandle")]
	internal static void* /* System.RuntimeMethodHandle */ System_ModuleHandle_ResolveMethodHandle(void* /* System.ModuleHandle */ __self, int /* System.Int32 */ methodToken, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.ModuleHandle __selfConverted = InteropUtils.GetInstance<System.ModuleHandle>(__self);
	
	
	    try {
			System.RuntimeMethodHandle __returnValue = __selfConverted.ResolveMethodHandle(methodToken);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_ModuleHandle_ResolveMethodHandle_1")]
	internal static void* /* System.RuntimeMethodHandle */ System_ModuleHandle_ResolveMethodHandle_1(void* /* System.ModuleHandle */ __self, int /* System.Int32 */ methodToken, void* /* System.RuntimeTypeHandle[] */ typeInstantiationContext, void* /* System.RuntimeTypeHandle[] */ methodInstantiationContext, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.ModuleHandle __selfConverted = InteropUtils.GetInstance<System.ModuleHandle>(__self);
	
		System.RuntimeTypeHandle[] typeInstantiationContextConverted = InteropUtils.GetInstance<System.RuntimeTypeHandle[]>(typeInstantiationContext);
		System.RuntimeTypeHandle[] methodInstantiationContextConverted = InteropUtils.GetInstance<System.RuntimeTypeHandle[]>(methodInstantiationContext);
	
	    try {
			System.RuntimeMethodHandle __returnValue = __selfConverted.ResolveMethodHandle(methodToken, typeInstantiationContextConverted, methodInstantiationContextConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_ModuleHandle_GetRuntimeFieldHandleFromMetadataToken")]
	internal static void* /* System.RuntimeFieldHandle */ System_ModuleHandle_GetRuntimeFieldHandleFromMetadataToken(void* /* System.ModuleHandle */ __self, int /* System.Int32 */ fieldToken, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.ModuleHandle __selfConverted = InteropUtils.GetInstance<System.ModuleHandle>(__self);
	
	
	    try {
			System.RuntimeFieldHandle __returnValue = __selfConverted.GetRuntimeFieldHandleFromMetadataToken(fieldToken);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_ModuleHandle_ResolveFieldHandle")]
	internal static void* /* System.RuntimeFieldHandle */ System_ModuleHandle_ResolveFieldHandle(void* /* System.ModuleHandle */ __self, int /* System.Int32 */ fieldToken, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.ModuleHandle __selfConverted = InteropUtils.GetInstance<System.ModuleHandle>(__self);
	
	
	    try {
			System.RuntimeFieldHandle __returnValue = __selfConverted.ResolveFieldHandle(fieldToken);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_ModuleHandle_ResolveFieldHandle_1")]
	internal static void* /* System.RuntimeFieldHandle */ System_ModuleHandle_ResolveFieldHandle_1(void* /* System.ModuleHandle */ __self, int /* System.Int32 */ fieldToken, void* /* System.RuntimeTypeHandle[] */ typeInstantiationContext, void* /* System.RuntimeTypeHandle[] */ methodInstantiationContext, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.ModuleHandle __selfConverted = InteropUtils.GetInstance<System.ModuleHandle>(__self);
	
		System.RuntimeTypeHandle[] typeInstantiationContextConverted = InteropUtils.GetInstance<System.RuntimeTypeHandle[]>(typeInstantiationContext);
		System.RuntimeTypeHandle[] methodInstantiationContextConverted = InteropUtils.GetInstance<System.RuntimeTypeHandle[]>(methodInstantiationContext);
	
	    try {
			System.RuntimeFieldHandle __returnValue = __selfConverted.ResolveFieldHandle(fieldToken, typeInstantiationContextConverted, methodInstantiationContextConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_ModuleHandle_MDStreamVersion_Get")]
	internal static int /* System.Int32 */ System_ModuleHandle_MDStreamVersion_Get(void* /* System.ModuleHandle */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.ModuleHandle __selfConverted = InteropUtils.GetInstance<System.ModuleHandle>(__self);
	
	
	    try {
			System.Int32 __returnValue = __selfConverted.MDStreamVersion;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_ModuleHandle_EmptyHandle_Get")]
	internal static void* /* System.ModuleHandle */ System_ModuleHandle_EmptyHandle_Get()
	{
	
		System.ModuleHandle __returnValue = System.ModuleHandle.EmptyHandle;
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_ModuleHandle_Create")]
	internal static void* /* System.ModuleHandle */ System_ModuleHandle_Create(void** /* System.Exception */ __outException)
	{
	
	    try {
			System.ModuleHandle __returnValue = new System.ModuleHandle();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_ModuleHandle_TypeOf")]
	internal static void* /* System.Type */ System_ModuleHandle_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.ModuleHandle);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_ModuleHandle_Destroy")]
	internal static void /* System.Void */ System_ModuleHandle_Destroy(void* /* System.ModuleHandle */ __self)
	{
	
		InteropUtils.FreeIfAllocated(__self);
	}
	
}




internal unsafe class System_RuntimeFieldHandle
{
	[UnmanagedCallersOnly(EntryPoint = "System_RuntimeFieldHandle_GetHashCode")]
	internal static int /* System.Int32 */ System_RuntimeFieldHandle_GetHashCode(void* /* System.RuntimeFieldHandle */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.RuntimeFieldHandle __selfConverted = InteropUtils.GetInstance<System.RuntimeFieldHandle>(__self);
	
	
	    try {
			System.Int32 __returnValue = __selfConverted.GetHashCode();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_RuntimeFieldHandle_Equals")]
	internal static byte /* System.Boolean */ System_RuntimeFieldHandle_Equals(void* /* System.RuntimeFieldHandle */ __self, void* /* System.Object */ obj, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.RuntimeFieldHandle __selfConverted = InteropUtils.GetInstance<System.RuntimeFieldHandle>(__self);
	
		System.Object objConverted = InteropUtils.GetInstance<System.Object>(obj);
	
	    try {
			System.Boolean __returnValue = __selfConverted.Equals(objConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_RuntimeFieldHandle_Equals_1")]
	internal static byte /* System.Boolean */ System_RuntimeFieldHandle_Equals_1(void* /* System.RuntimeFieldHandle */ __self, void* /* System.RuntimeFieldHandle */ handle, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.RuntimeFieldHandle __selfConverted = InteropUtils.GetInstance<System.RuntimeFieldHandle>(__self);
	
		System.RuntimeFieldHandle handleConverted = InteropUtils.GetInstance<System.RuntimeFieldHandle>(handle);
	
	    try {
			System.Boolean __returnValue = __selfConverted.Equals(handleConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_RuntimeFieldHandle_FromIntPtr")]
	internal static void* /* System.RuntimeFieldHandle */ System_RuntimeFieldHandle_FromIntPtr(nint /* System.IntPtr */ value, void** /* System.Exception */ __outException)
	{
	
	    try {
			System.RuntimeFieldHandle __returnValue = System.RuntimeFieldHandle.FromIntPtr(value);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_RuntimeFieldHandle_ToIntPtr")]
	internal static nint /* System.IntPtr */ System_RuntimeFieldHandle_ToIntPtr(void* /* System.RuntimeFieldHandle */ value, void** /* System.Exception */ __outException)
	{
		System.RuntimeFieldHandle valueConverted = InteropUtils.GetInstance<System.RuntimeFieldHandle>(value);
	
	    try {
			System.IntPtr __returnValue = System.RuntimeFieldHandle.ToIntPtr(valueConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return nint.Zero;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_RuntimeFieldHandle_GetObjectData")]
	internal static void /* System.Void */ System_RuntimeFieldHandle_GetObjectData(void* /* System.RuntimeFieldHandle */ __self, void* /* System.Runtime.Serialization.SerializationInfo */ info, void* /* System.Runtime.Serialization.StreamingContext */ context, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.RuntimeFieldHandle __selfConverted = InteropUtils.GetInstance<System.RuntimeFieldHandle>(__self);
	
		System.Runtime.Serialization.SerializationInfo infoConverted = InteropUtils.GetInstance<System.Runtime.Serialization.SerializationInfo>(info);
		System.Runtime.Serialization.StreamingContext contextConverted = InteropUtils.GetInstance<System.Runtime.Serialization.StreamingContext>(context);
	
	    try {
			__selfConverted.GetObjectData(infoConverted, contextConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_RuntimeFieldHandle_Value_Get")]
	internal static nint /* System.IntPtr */ System_RuntimeFieldHandle_Value_Get(void* /* System.RuntimeFieldHandle */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.RuntimeFieldHandle __selfConverted = InteropUtils.GetInstance<System.RuntimeFieldHandle>(__self);
	
	
	    try {
			System.IntPtr __returnValue = __selfConverted.Value;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return nint.Zero;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_RuntimeFieldHandle_Create")]
	internal static void* /* System.RuntimeFieldHandle */ System_RuntimeFieldHandle_Create(void** /* System.Exception */ __outException)
	{
	
	    try {
			System.RuntimeFieldHandle __returnValue = new System.RuntimeFieldHandle();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_RuntimeFieldHandle_TypeOf")]
	internal static void* /* System.Type */ System_RuntimeFieldHandle_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.RuntimeFieldHandle);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_RuntimeFieldHandle_Destroy")]
	internal static void /* System.Void */ System_RuntimeFieldHandle_Destroy(void* /* System.RuntimeFieldHandle */ __self)
	{
	
		InteropUtils.FreeIfAllocated(__self);
	}
	
}



internal unsafe class System_Reflection_ParameterInfo
{
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_ParameterInfo_IsDefined")]
	internal static byte /* System.Boolean */ System_Reflection_ParameterInfo_IsDefined(void* /* System.Reflection.ParameterInfo */ __self, void* /* System.Type */ attributeType, byte /* System.Boolean */ inherit, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.ParameterInfo __selfConverted = InteropUtils.GetInstance<System.Reflection.ParameterInfo>(__self);
	
		System.Type attributeTypeConverted = InteropUtils.GetInstance<System.Type>(attributeType);
		System.Boolean inheritConverted = inherit.ToBool();
	
	    try {
			System.Boolean __returnValue = __selfConverted.IsDefined(attributeTypeConverted, inheritConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_ParameterInfo_GetCustomAttributes")]
	internal static void* /* System.Object[] */ System_Reflection_ParameterInfo_GetCustomAttributes(void* /* System.Reflection.ParameterInfo */ __self, byte /* System.Boolean */ inherit, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.ParameterInfo __selfConverted = InteropUtils.GetInstance<System.Reflection.ParameterInfo>(__self);
	
		System.Boolean inheritConverted = inherit.ToBool();
	
	    try {
			System.Object[] __returnValue = __selfConverted.GetCustomAttributes(inheritConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_ParameterInfo_GetCustomAttributes_1")]
	internal static void* /* System.Object[] */ System_Reflection_ParameterInfo_GetCustomAttributes_1(void* /* System.Reflection.ParameterInfo */ __self, void* /* System.Type */ attributeType, byte /* System.Boolean */ inherit, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.ParameterInfo __selfConverted = InteropUtils.GetInstance<System.Reflection.ParameterInfo>(__self);
	
		System.Type attributeTypeConverted = InteropUtils.GetInstance<System.Type>(attributeType);
		System.Boolean inheritConverted = inherit.ToBool();
	
	    try {
			System.Object[] __returnValue = __selfConverted.GetCustomAttributes(attributeTypeConverted, inheritConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_ParameterInfo_GetModifiedParameterType")]
	internal static void* /* System.Type */ System_Reflection_ParameterInfo_GetModifiedParameterType(void* /* System.Reflection.ParameterInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.ParameterInfo __selfConverted = InteropUtils.GetInstance<System.Reflection.ParameterInfo>(__self);
	
	
	    try {
			System.Type __returnValue = __selfConverted.GetModifiedParameterType();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_ParameterInfo_GetOptionalCustomModifiers")]
	internal static void* /* System.Type[] */ System_Reflection_ParameterInfo_GetOptionalCustomModifiers(void* /* System.Reflection.ParameterInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.ParameterInfo __selfConverted = InteropUtils.GetInstance<System.Reflection.ParameterInfo>(__self);
	
	
	    try {
			System.Type[] __returnValue = __selfConverted.GetOptionalCustomModifiers();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_ParameterInfo_GetRequiredCustomModifiers")]
	internal static void* /* System.Type[] */ System_Reflection_ParameterInfo_GetRequiredCustomModifiers(void* /* System.Reflection.ParameterInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.ParameterInfo __selfConverted = InteropUtils.GetInstance<System.Reflection.ParameterInfo>(__self);
	
	
	    try {
			System.Type[] __returnValue = __selfConverted.GetRequiredCustomModifiers();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_ParameterInfo_GetRealObject")]
	internal static void* /* System.Object */ System_Reflection_ParameterInfo_GetRealObject(void* /* System.Reflection.ParameterInfo */ __self, void* /* System.Runtime.Serialization.StreamingContext */ context, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.ParameterInfo __selfConverted = InteropUtils.GetInstance<System.Reflection.ParameterInfo>(__self);
	
		System.Runtime.Serialization.StreamingContext contextConverted = InteropUtils.GetInstance<System.Runtime.Serialization.StreamingContext>(context);
	
	    try {
			System.Object __returnValue = __selfConverted.GetRealObject(contextConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_ParameterInfo_ToString")]
	internal static void* /* System.String */ System_Reflection_ParameterInfo_ToString(void* /* System.Reflection.ParameterInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.ParameterInfo __selfConverted = InteropUtils.GetInstance<System.Reflection.ParameterInfo>(__self);
	
	
	    try {
			System.String __returnValue = __selfConverted.ToString();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_ParameterInfo_Attributes_Get")]
	internal static System.Reflection.ParameterAttributes /* System.Reflection.ParameterAttributes */ System_Reflection_ParameterInfo_Attributes_Get(void* /* System.Reflection.ParameterInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.ParameterInfo __selfConverted = InteropUtils.GetInstance<System.Reflection.ParameterInfo>(__self);
	
	
	    try {
			System.Reflection.ParameterAttributes __returnValue = __selfConverted.Attributes;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return default(System.Reflection.ParameterAttributes);
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_ParameterInfo_Member_Get")]
	internal static void* /* System.Reflection.MemberInfo */ System_Reflection_ParameterInfo_Member_Get(void* /* System.Reflection.ParameterInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.ParameterInfo __selfConverted = InteropUtils.GetInstance<System.Reflection.ParameterInfo>(__self);
	
	
	    try {
			System.Reflection.MemberInfo __returnValue = __selfConverted.Member;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_ParameterInfo_Name_Get")]
	internal static void* /* System.String */ System_Reflection_ParameterInfo_Name_Get(void* /* System.Reflection.ParameterInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.ParameterInfo __selfConverted = InteropUtils.GetInstance<System.Reflection.ParameterInfo>(__self);
	
	
	    try {
			System.String __returnValue = __selfConverted.Name;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_ParameterInfo_ParameterType_Get")]
	internal static void* /* System.Type */ System_Reflection_ParameterInfo_ParameterType_Get(void* /* System.Reflection.ParameterInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.ParameterInfo __selfConverted = InteropUtils.GetInstance<System.Reflection.ParameterInfo>(__self);
	
	
	    try {
			System.Type __returnValue = __selfConverted.ParameterType;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_ParameterInfo_Position_Get")]
	internal static int /* System.Int32 */ System_Reflection_ParameterInfo_Position_Get(void* /* System.Reflection.ParameterInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.ParameterInfo __selfConverted = InteropUtils.GetInstance<System.Reflection.ParameterInfo>(__self);
	
	
	    try {
			System.Int32 __returnValue = __selfConverted.Position;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_ParameterInfo_IsIn_Get")]
	internal static byte /* System.Boolean */ System_Reflection_ParameterInfo_IsIn_Get(void* /* System.Reflection.ParameterInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.ParameterInfo __selfConverted = InteropUtils.GetInstance<System.Reflection.ParameterInfo>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.IsIn;
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_ParameterInfo_IsLcid_Get")]
	internal static byte /* System.Boolean */ System_Reflection_ParameterInfo_IsLcid_Get(void* /* System.Reflection.ParameterInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.ParameterInfo __selfConverted = InteropUtils.GetInstance<System.Reflection.ParameterInfo>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.IsLcid;
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_ParameterInfo_IsOptional_Get")]
	internal static byte /* System.Boolean */ System_Reflection_ParameterInfo_IsOptional_Get(void* /* System.Reflection.ParameterInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.ParameterInfo __selfConverted = InteropUtils.GetInstance<System.Reflection.ParameterInfo>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.IsOptional;
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_ParameterInfo_IsOut_Get")]
	internal static byte /* System.Boolean */ System_Reflection_ParameterInfo_IsOut_Get(void* /* System.Reflection.ParameterInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.ParameterInfo __selfConverted = InteropUtils.GetInstance<System.Reflection.ParameterInfo>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.IsOut;
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_ParameterInfo_IsRetval_Get")]
	internal static byte /* System.Boolean */ System_Reflection_ParameterInfo_IsRetval_Get(void* /* System.Reflection.ParameterInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.ParameterInfo __selfConverted = InteropUtils.GetInstance<System.Reflection.ParameterInfo>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.IsRetval;
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_ParameterInfo_DefaultValue_Get")]
	internal static void* /* System.Object */ System_Reflection_ParameterInfo_DefaultValue_Get(void* /* System.Reflection.ParameterInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.ParameterInfo __selfConverted = InteropUtils.GetInstance<System.Reflection.ParameterInfo>(__self);
	
	
	    try {
			System.Object __returnValue = __selfConverted.DefaultValue;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_ParameterInfo_RawDefaultValue_Get")]
	internal static void* /* System.Object */ System_Reflection_ParameterInfo_RawDefaultValue_Get(void* /* System.Reflection.ParameterInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.ParameterInfo __selfConverted = InteropUtils.GetInstance<System.Reflection.ParameterInfo>(__self);
	
	
	    try {
			System.Object __returnValue = __selfConverted.RawDefaultValue;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_ParameterInfo_HasDefaultValue_Get")]
	internal static byte /* System.Boolean */ System_Reflection_ParameterInfo_HasDefaultValue_Get(void* /* System.Reflection.ParameterInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.ParameterInfo __selfConverted = InteropUtils.GetInstance<System.Reflection.ParameterInfo>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.HasDefaultValue;
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_ParameterInfo_MetadataToken_Get")]
	internal static int /* System.Int32 */ System_Reflection_ParameterInfo_MetadataToken_Get(void* /* System.Reflection.ParameterInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.ParameterInfo __selfConverted = InteropUtils.GetInstance<System.Reflection.ParameterInfo>(__self);
	
	
	    try {
			System.Int32 __returnValue = __selfConverted.MetadataToken;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_ParameterInfo_TypeOf")]
	internal static void* /* System.Type */ System_Reflection_ParameterInfo_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.Reflection.ParameterInfo);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_ParameterInfo_Destroy")]
	internal static void /* System.Void */ System_Reflection_ParameterInfo_Destroy(void* /* System.Reflection.ParameterInfo */ __self)
	{
	
		InteropUtils.FreeIfAllocated(__self);
	}
	
}


internal unsafe class System_Runtime_Serialization_IObjectReference
{
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_Serialization_IObjectReference_GetRealObject")]
	internal static void* /* System.Object */ System_Runtime_Serialization_IObjectReference_GetRealObject(void* /* System.Runtime.Serialization.IObjectReference */ __self, void* /* System.Runtime.Serialization.StreamingContext */ context, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Runtime.Serialization.IObjectReference __selfConverted = InteropUtils.GetInstance<System.Runtime.Serialization.IObjectReference>(__self);
	
		System.Runtime.Serialization.StreamingContext contextConverted = InteropUtils.GetInstance<System.Runtime.Serialization.StreamingContext>(context);
	
	    try {
			System.Object __returnValue = __selfConverted.GetRealObject(contextConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_Serialization_IObjectReference_TypeOf")]
	internal static void* /* System.Type */ System_Runtime_Serialization_IObjectReference_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.Runtime.Serialization.IObjectReference);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_Serialization_IObjectReference_Destroy")]
	internal static void /* System.Void */ System_Runtime_Serialization_IObjectReference_Destroy(void* /* System.Runtime.Serialization.IObjectReference */ __self)
	{
	
		InteropUtils.FreeIfAllocated(__self);
	}
	
}


internal unsafe class System_Reflection_ParameterAttributes
{
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_ParameterAttributes_TypeOf")]
	internal static void* /* System.Type */ System_Reflection_ParameterAttributes_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.Reflection.ParameterAttributes);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
}





internal unsafe class System_Reflection_MethodAttributes
{
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_MethodAttributes_TypeOf")]
	internal static void* /* System.Type */ System_Reflection_MethodAttributes_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.Reflection.MethodAttributes);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
}


internal unsafe class System_Reflection_MethodImplAttributes
{
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_MethodImplAttributes_TypeOf")]
	internal static void* /* System.Type */ System_Reflection_MethodImplAttributes_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.Reflection.MethodImplAttributes);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
}


internal unsafe class System_Reflection_MethodBody
{
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_MethodBody_GetILAsByteArray")]
	internal static void* /* System.Byte[] */ System_Reflection_MethodBody_GetILAsByteArray(void* /* System.Reflection.MethodBody */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.MethodBody __selfConverted = InteropUtils.GetInstance<System.Reflection.MethodBody>(__self);
	
	
	    try {
			System.Byte[] __returnValue = __selfConverted.GetILAsByteArray();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_MethodBody_LocalSignatureMetadataToken_Get")]
	internal static int /* System.Int32 */ System_Reflection_MethodBody_LocalSignatureMetadataToken_Get(void* /* System.Reflection.MethodBody */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.MethodBody __selfConverted = InteropUtils.GetInstance<System.Reflection.MethodBody>(__self);
	
	
	    try {
			System.Int32 __returnValue = __selfConverted.LocalSignatureMetadataToken;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_MethodBody_MaxStackSize_Get")]
	internal static int /* System.Int32 */ System_Reflection_MethodBody_MaxStackSize_Get(void* /* System.Reflection.MethodBody */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.MethodBody __selfConverted = InteropUtils.GetInstance<System.Reflection.MethodBody>(__self);
	
	
	    try {
			System.Int32 __returnValue = __selfConverted.MaxStackSize;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_MethodBody_InitLocals_Get")]
	internal static byte /* System.Boolean */ System_Reflection_MethodBody_InitLocals_Get(void* /* System.Reflection.MethodBody */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.MethodBody __selfConverted = InteropUtils.GetInstance<System.Reflection.MethodBody>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.InitLocals;
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_MethodBody_TypeOf")]
	internal static void* /* System.Type */ System_Reflection_MethodBody_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.Reflection.MethodBody);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_MethodBody_Destroy")]
	internal static void /* System.Void */ System_Reflection_MethodBody_Destroy(void* /* System.Reflection.MethodBody */ __self)
	{
	
		InteropUtils.FreeIfAllocated(__self);
	}
	
}


internal unsafe class System_Reflection_CallingConventions
{
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_CallingConventions_TypeOf")]
	internal static void* /* System.Type */ System_Reflection_CallingConventions_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.Reflection.CallingConventions);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
}


internal unsafe class System_Reflection_BindingFlags
{
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_BindingFlags_TypeOf")]
	internal static void* /* System.Type */ System_Reflection_BindingFlags_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.Reflection.BindingFlags);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
}


internal unsafe class System_Reflection_Binder
{
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_Binder_BindToField")]
	internal static void* /* System.Reflection.FieldInfo */ System_Reflection_Binder_BindToField(void* /* System.Reflection.Binder */ __self, System.Reflection.BindingFlags /* System.Reflection.BindingFlags */ bindingAttr, void* /* System.Reflection.FieldInfo[] */ match, void* /* System.Object */ value, void* /* System.Globalization.CultureInfo */ culture, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.Binder __selfConverted = InteropUtils.GetInstance<System.Reflection.Binder>(__self);
	
		System.Reflection.FieldInfo[] matchConverted = InteropUtils.GetInstance<System.Reflection.FieldInfo[]>(match);
		System.Object valueConverted = InteropUtils.GetInstance<System.Object>(value);
		System.Globalization.CultureInfo cultureConverted = InteropUtils.GetInstance<System.Globalization.CultureInfo>(culture);
	
	    try {
			System.Reflection.FieldInfo __returnValue = __selfConverted.BindToField(bindingAttr, matchConverted, valueConverted, cultureConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_Binder_BindToMethod")]
	internal static void* /* System.Reflection.MethodBase */ System_Reflection_Binder_BindToMethod(void* /* System.Reflection.Binder */ __self, System.Reflection.BindingFlags /* System.Reflection.BindingFlags */ bindingAttr, void* /* System.Reflection.MethodBase[] */ match, void** /* System.Object[] */ args, void* /* System.Reflection.ParameterModifier[] */ modifiers, void* /* System.Globalization.CultureInfo */ culture, void* /* System.String[] */ names, void** /* System.Object */ state, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.Binder __selfConverted = InteropUtils.GetInstance<System.Reflection.Binder>(__self);
	
		System.Reflection.MethodBase[] matchConverted = InteropUtils.GetInstance<System.Reflection.MethodBase[]>(match);
		System.Object[] argsConverted;
	
		if (args is not null) {
			argsConverted = InteropUtils.GetInstance<System.Object[]>((*args));
		} else {
			argsConverted = default(System.Object[]);
		}
	
		System.Reflection.ParameterModifier[] modifiersConverted = InteropUtils.GetInstance<System.Reflection.ParameterModifier[]>(modifiers);
		System.Globalization.CultureInfo cultureConverted = InteropUtils.GetInstance<System.Globalization.CultureInfo>(culture);
		System.String[] namesConverted = InteropUtils.GetInstance<System.String[]>(names);
		System.Object stateConverted;
	
	    try {
			System.Reflection.MethodBase __returnValue = __selfConverted.BindToMethod(bindingAttr, matchConverted, ref argsConverted, modifiersConverted, cultureConverted, namesConverted, out stateConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			if (args is not null) {
				*args = argsConverted.AllocateGCHandleAndGetAddress();
			}
	
			if (state is not null) {
				*state = stateConverted.AllocateGCHandleAndGetAddress();
			}
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			if (state is not null) {
				*state = null;
			}
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_Binder_ChangeType")]
	internal static void* /* System.Object */ System_Reflection_Binder_ChangeType(void* /* System.Reflection.Binder */ __self, void* /* System.Object */ value, void* /* System.Type */ type, void* /* System.Globalization.CultureInfo */ culture, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.Binder __selfConverted = InteropUtils.GetInstance<System.Reflection.Binder>(__self);
	
		System.Object valueConverted = InteropUtils.GetInstance<System.Object>(value);
		System.Type typeConverted = InteropUtils.GetInstance<System.Type>(type);
		System.Globalization.CultureInfo cultureConverted = InteropUtils.GetInstance<System.Globalization.CultureInfo>(culture);
	
	    try {
			System.Object __returnValue = __selfConverted.ChangeType(valueConverted, typeConverted, cultureConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_Binder_ReorderArgumentArray")]
	internal static void /* System.Void */ System_Reflection_Binder_ReorderArgumentArray(void* /* System.Reflection.Binder */ __self, void** /* System.Object[] */ args, void* /* System.Object */ state, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.Binder __selfConverted = InteropUtils.GetInstance<System.Reflection.Binder>(__self);
	
		System.Object[] argsConverted;
	
		if (args is not null) {
			argsConverted = InteropUtils.GetInstance<System.Object[]>((*args));
		} else {
			argsConverted = default(System.Object[]);
		}
	
		System.Object stateConverted = InteropUtils.GetInstance<System.Object>(state);
	
	    try {
			__selfConverted.ReorderArgumentArray(ref argsConverted, stateConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			if (args is not null) {
				*args = argsConverted.AllocateGCHandleAndGetAddress();
			}
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_Binder_SelectMethod")]
	internal static void* /* System.Reflection.MethodBase */ System_Reflection_Binder_SelectMethod(void* /* System.Reflection.Binder */ __self, System.Reflection.BindingFlags /* System.Reflection.BindingFlags */ bindingAttr, void* /* System.Reflection.MethodBase[] */ match, void* /* System.Type[] */ types, void* /* System.Reflection.ParameterModifier[] */ modifiers, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.Binder __selfConverted = InteropUtils.GetInstance<System.Reflection.Binder>(__self);
	
		System.Reflection.MethodBase[] matchConverted = InteropUtils.GetInstance<System.Reflection.MethodBase[]>(match);
		System.Type[] typesConverted = InteropUtils.GetInstance<System.Type[]>(types);
		System.Reflection.ParameterModifier[] modifiersConverted = InteropUtils.GetInstance<System.Reflection.ParameterModifier[]>(modifiers);
	
	    try {
			System.Reflection.MethodBase __returnValue = __selfConverted.SelectMethod(bindingAttr, matchConverted, typesConverted, modifiersConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_Binder_SelectProperty")]
	internal static void* /* System.Reflection.PropertyInfo */ System_Reflection_Binder_SelectProperty(void* /* System.Reflection.Binder */ __self, System.Reflection.BindingFlags /* System.Reflection.BindingFlags */ bindingAttr, void* /* System.Reflection.PropertyInfo[] */ match, void* /* System.Type */ returnType, void* /* System.Type[] */ indexes, void* /* System.Reflection.ParameterModifier[] */ modifiers, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.Binder __selfConverted = InteropUtils.GetInstance<System.Reflection.Binder>(__self);
	
		System.Reflection.PropertyInfo[] matchConverted = InteropUtils.GetInstance<System.Reflection.PropertyInfo[]>(match);
		System.Type returnTypeConverted = InteropUtils.GetInstance<System.Type>(returnType);
		System.Type[] indexesConverted = InteropUtils.GetInstance<System.Type[]>(indexes);
		System.Reflection.ParameterModifier[] modifiersConverted = InteropUtils.GetInstance<System.Reflection.ParameterModifier[]>(modifiers);
	
	    try {
			System.Reflection.PropertyInfo __returnValue = __selfConverted.SelectProperty(bindingAttr, matchConverted, returnTypeConverted, indexesConverted, modifiersConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_Binder_TypeOf")]
	internal static void* /* System.Type */ System_Reflection_Binder_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.Reflection.Binder);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_Binder_Destroy")]
	internal static void /* System.Void */ System_Reflection_Binder_Destroy(void* /* System.Reflection.Binder */ __self)
	{
	
		InteropUtils.FreeIfAllocated(__self);
	}
	
}


internal unsafe class System_Reflection_FieldInfo
{
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_FieldInfo_GetFieldFromHandle")]
	internal static void* /* System.Reflection.FieldInfo */ System_Reflection_FieldInfo_GetFieldFromHandle(void* /* System.RuntimeFieldHandle */ handle, void** /* System.Exception */ __outException)
	{
		System.RuntimeFieldHandle handleConverted = InteropUtils.GetInstance<System.RuntimeFieldHandle>(handle);
	
	    try {
			System.Reflection.FieldInfo __returnValue = System.Reflection.FieldInfo.GetFieldFromHandle(handleConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_FieldInfo_GetFieldFromHandle_1")]
	internal static void* /* System.Reflection.FieldInfo */ System_Reflection_FieldInfo_GetFieldFromHandle_1(void* /* System.RuntimeFieldHandle */ handle, void* /* System.RuntimeTypeHandle */ declaringType, void** /* System.Exception */ __outException)
	{
		System.RuntimeFieldHandle handleConverted = InteropUtils.GetInstance<System.RuntimeFieldHandle>(handle);
		System.RuntimeTypeHandle declaringTypeConverted = InteropUtils.GetInstance<System.RuntimeTypeHandle>(declaringType);
	
	    try {
			System.Reflection.FieldInfo __returnValue = System.Reflection.FieldInfo.GetFieldFromHandle(handleConverted, declaringTypeConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_FieldInfo_Equals")]
	internal static byte /* System.Boolean */ System_Reflection_FieldInfo_Equals(void* /* System.Reflection.FieldInfo */ __self, void* /* System.Object */ obj, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.FieldInfo __selfConverted = InteropUtils.GetInstance<System.Reflection.FieldInfo>(__self);
	
		System.Object objConverted = InteropUtils.GetInstance<System.Object>(obj);
	
	    try {
			System.Boolean __returnValue = __selfConverted.Equals(objConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_FieldInfo_GetHashCode")]
	internal static int /* System.Int32 */ System_Reflection_FieldInfo_GetHashCode(void* /* System.Reflection.FieldInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.FieldInfo __selfConverted = InteropUtils.GetInstance<System.Reflection.FieldInfo>(__self);
	
	
	    try {
			System.Int32 __returnValue = __selfConverted.GetHashCode();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_FieldInfo_GetValue")]
	internal static void* /* System.Object */ System_Reflection_FieldInfo_GetValue(void* /* System.Reflection.FieldInfo */ __self, void* /* System.Object */ obj, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.FieldInfo __selfConverted = InteropUtils.GetInstance<System.Reflection.FieldInfo>(__self);
	
		System.Object objConverted = InteropUtils.GetInstance<System.Object>(obj);
	
	    try {
			System.Object __returnValue = __selfConverted.GetValue(objConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_FieldInfo_SetValue")]
	internal static void /* System.Void */ System_Reflection_FieldInfo_SetValue(void* /* System.Reflection.FieldInfo */ __self, void* /* System.Object */ obj, void* /* System.Object */ value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.FieldInfo __selfConverted = InteropUtils.GetInstance<System.Reflection.FieldInfo>(__self);
	
		System.Object objConverted = InteropUtils.GetInstance<System.Object>(obj);
		System.Object valueConverted = InteropUtils.GetInstance<System.Object>(value);
	
	    try {
			__selfConverted.SetValue(objConverted, valueConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_FieldInfo_SetValue_1")]
	internal static void /* System.Void */ System_Reflection_FieldInfo_SetValue_1(void* /* System.Reflection.FieldInfo */ __self, void* /* System.Object */ obj, void* /* System.Object */ value, System.Reflection.BindingFlags /* System.Reflection.BindingFlags */ invokeAttr, void* /* System.Reflection.Binder */ binder, void* /* System.Globalization.CultureInfo */ culture, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.FieldInfo __selfConverted = InteropUtils.GetInstance<System.Reflection.FieldInfo>(__self);
	
		System.Object objConverted = InteropUtils.GetInstance<System.Object>(obj);
		System.Object valueConverted = InteropUtils.GetInstance<System.Object>(value);
		System.Reflection.Binder binderConverted = InteropUtils.GetInstance<System.Reflection.Binder>(binder);
		System.Globalization.CultureInfo cultureConverted = InteropUtils.GetInstance<System.Globalization.CultureInfo>(culture);
	
	    try {
			__selfConverted.SetValue(objConverted, valueConverted, invokeAttr, binderConverted, cultureConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_FieldInfo_GetRawConstantValue")]
	internal static void* /* System.Object */ System_Reflection_FieldInfo_GetRawConstantValue(void* /* System.Reflection.FieldInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.FieldInfo __selfConverted = InteropUtils.GetInstance<System.Reflection.FieldInfo>(__self);
	
	
	    try {
			System.Object __returnValue = __selfConverted.GetRawConstantValue();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_FieldInfo_GetModifiedFieldType")]
	internal static void* /* System.Type */ System_Reflection_FieldInfo_GetModifiedFieldType(void* /* System.Reflection.FieldInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.FieldInfo __selfConverted = InteropUtils.GetInstance<System.Reflection.FieldInfo>(__self);
	
	
	    try {
			System.Type __returnValue = __selfConverted.GetModifiedFieldType();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_FieldInfo_GetOptionalCustomModifiers")]
	internal static void* /* System.Type[] */ System_Reflection_FieldInfo_GetOptionalCustomModifiers(void* /* System.Reflection.FieldInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.FieldInfo __selfConverted = InteropUtils.GetInstance<System.Reflection.FieldInfo>(__self);
	
	
	    try {
			System.Type[] __returnValue = __selfConverted.GetOptionalCustomModifiers();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_FieldInfo_GetRequiredCustomModifiers")]
	internal static void* /* System.Type[] */ System_Reflection_FieldInfo_GetRequiredCustomModifiers(void* /* System.Reflection.FieldInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.FieldInfo __selfConverted = InteropUtils.GetInstance<System.Reflection.FieldInfo>(__self);
	
	
	    try {
			System.Type[] __returnValue = __selfConverted.GetRequiredCustomModifiers();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_FieldInfo_MemberType_Get")]
	internal static System.Reflection.MemberTypes /* System.Reflection.MemberTypes */ System_Reflection_FieldInfo_MemberType_Get(void* /* System.Reflection.FieldInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.FieldInfo __selfConverted = InteropUtils.GetInstance<System.Reflection.FieldInfo>(__self);
	
	
	    try {
			System.Reflection.MemberTypes __returnValue = __selfConverted.MemberType;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return default(System.Reflection.MemberTypes);
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_FieldInfo_Attributes_Get")]
	internal static System.Reflection.FieldAttributes /* System.Reflection.FieldAttributes */ System_Reflection_FieldInfo_Attributes_Get(void* /* System.Reflection.FieldInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.FieldInfo __selfConverted = InteropUtils.GetInstance<System.Reflection.FieldInfo>(__self);
	
	
	    try {
			System.Reflection.FieldAttributes __returnValue = __selfConverted.Attributes;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return default(System.Reflection.FieldAttributes);
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_FieldInfo_FieldType_Get")]
	internal static void* /* System.Type */ System_Reflection_FieldInfo_FieldType_Get(void* /* System.Reflection.FieldInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.FieldInfo __selfConverted = InteropUtils.GetInstance<System.Reflection.FieldInfo>(__self);
	
	
	    try {
			System.Type __returnValue = __selfConverted.FieldType;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_FieldInfo_IsInitOnly_Get")]
	internal static byte /* System.Boolean */ System_Reflection_FieldInfo_IsInitOnly_Get(void* /* System.Reflection.FieldInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.FieldInfo __selfConverted = InteropUtils.GetInstance<System.Reflection.FieldInfo>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.IsInitOnly;
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_FieldInfo_IsLiteral_Get")]
	internal static byte /* System.Boolean */ System_Reflection_FieldInfo_IsLiteral_Get(void* /* System.Reflection.FieldInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.FieldInfo __selfConverted = InteropUtils.GetInstance<System.Reflection.FieldInfo>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.IsLiteral;
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_FieldInfo_IsNotSerialized_Get")]
	internal static byte /* System.Boolean */ System_Reflection_FieldInfo_IsNotSerialized_Get(void* /* System.Reflection.FieldInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.FieldInfo __selfConverted = InteropUtils.GetInstance<System.Reflection.FieldInfo>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.IsNotSerialized;
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_FieldInfo_IsPinvokeImpl_Get")]
	internal static byte /* System.Boolean */ System_Reflection_FieldInfo_IsPinvokeImpl_Get(void* /* System.Reflection.FieldInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.FieldInfo __selfConverted = InteropUtils.GetInstance<System.Reflection.FieldInfo>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.IsPinvokeImpl;
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_FieldInfo_IsSpecialName_Get")]
	internal static byte /* System.Boolean */ System_Reflection_FieldInfo_IsSpecialName_Get(void* /* System.Reflection.FieldInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.FieldInfo __selfConverted = InteropUtils.GetInstance<System.Reflection.FieldInfo>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.IsSpecialName;
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_FieldInfo_IsStatic_Get")]
	internal static byte /* System.Boolean */ System_Reflection_FieldInfo_IsStatic_Get(void* /* System.Reflection.FieldInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.FieldInfo __selfConverted = InteropUtils.GetInstance<System.Reflection.FieldInfo>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.IsStatic;
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_FieldInfo_IsAssembly_Get")]
	internal static byte /* System.Boolean */ System_Reflection_FieldInfo_IsAssembly_Get(void* /* System.Reflection.FieldInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.FieldInfo __selfConverted = InteropUtils.GetInstance<System.Reflection.FieldInfo>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.IsAssembly;
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_FieldInfo_IsFamily_Get")]
	internal static byte /* System.Boolean */ System_Reflection_FieldInfo_IsFamily_Get(void* /* System.Reflection.FieldInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.FieldInfo __selfConverted = InteropUtils.GetInstance<System.Reflection.FieldInfo>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.IsFamily;
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_FieldInfo_IsFamilyAndAssembly_Get")]
	internal static byte /* System.Boolean */ System_Reflection_FieldInfo_IsFamilyAndAssembly_Get(void* /* System.Reflection.FieldInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.FieldInfo __selfConverted = InteropUtils.GetInstance<System.Reflection.FieldInfo>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.IsFamilyAndAssembly;
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_FieldInfo_IsFamilyOrAssembly_Get")]
	internal static byte /* System.Boolean */ System_Reflection_FieldInfo_IsFamilyOrAssembly_Get(void* /* System.Reflection.FieldInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.FieldInfo __selfConverted = InteropUtils.GetInstance<System.Reflection.FieldInfo>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.IsFamilyOrAssembly;
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_FieldInfo_IsPrivate_Get")]
	internal static byte /* System.Boolean */ System_Reflection_FieldInfo_IsPrivate_Get(void* /* System.Reflection.FieldInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.FieldInfo __selfConverted = InteropUtils.GetInstance<System.Reflection.FieldInfo>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.IsPrivate;
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_FieldInfo_IsPublic_Get")]
	internal static byte /* System.Boolean */ System_Reflection_FieldInfo_IsPublic_Get(void* /* System.Reflection.FieldInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.FieldInfo __selfConverted = InteropUtils.GetInstance<System.Reflection.FieldInfo>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.IsPublic;
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_FieldInfo_IsSecurityCritical_Get")]
	internal static byte /* System.Boolean */ System_Reflection_FieldInfo_IsSecurityCritical_Get(void* /* System.Reflection.FieldInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.FieldInfo __selfConverted = InteropUtils.GetInstance<System.Reflection.FieldInfo>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.IsSecurityCritical;
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_FieldInfo_IsSecuritySafeCritical_Get")]
	internal static byte /* System.Boolean */ System_Reflection_FieldInfo_IsSecuritySafeCritical_Get(void* /* System.Reflection.FieldInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.FieldInfo __selfConverted = InteropUtils.GetInstance<System.Reflection.FieldInfo>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.IsSecuritySafeCritical;
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_FieldInfo_IsSecurityTransparent_Get")]
	internal static byte /* System.Boolean */ System_Reflection_FieldInfo_IsSecurityTransparent_Get(void* /* System.Reflection.FieldInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.FieldInfo __selfConverted = InteropUtils.GetInstance<System.Reflection.FieldInfo>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.IsSecurityTransparent;
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_FieldInfo_FieldHandle_Get")]
	internal static void* /* System.RuntimeFieldHandle */ System_Reflection_FieldInfo_FieldHandle_Get(void* /* System.Reflection.FieldInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.FieldInfo __selfConverted = InteropUtils.GetInstance<System.Reflection.FieldInfo>(__self);
	
	
	    try {
			System.RuntimeFieldHandle __returnValue = __selfConverted.FieldHandle;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_FieldInfo_TypeOf")]
	internal static void* /* System.Type */ System_Reflection_FieldInfo_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.Reflection.FieldInfo);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_FieldInfo_Destroy")]
	internal static void /* System.Void */ System_Reflection_FieldInfo_Destroy(void* /* System.Reflection.FieldInfo */ __self)
	{
	
		InteropUtils.FreeIfAllocated(__self);
	}
	
}


internal unsafe class System_Reflection_MemberTypes
{
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_MemberTypes_TypeOf")]
	internal static void* /* System.Type */ System_Reflection_MemberTypes_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.Reflection.MemberTypes);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
}


internal unsafe class System_Reflection_FieldAttributes
{
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_FieldAttributes_TypeOf")]
	internal static void* /* System.Type */ System_Reflection_FieldAttributes_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.Reflection.FieldAttributes);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
}








internal unsafe class System_Reflection_ParameterModifier
{
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_ParameterModifier_Create")]
	internal static void* /* System.Reflection.ParameterModifier */ System_Reflection_ParameterModifier_Create(int /* System.Int32 */ parameterCount, void** /* System.Exception */ __outException)
	{
	
	    try {
			System.Reflection.ParameterModifier __returnValue = new System.Reflection.ParameterModifier(parameterCount);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_ParameterModifier_Item_Get")]
	internal static byte /* System.Boolean */ System_Reflection_ParameterModifier_Item_Get(void* /* System.Reflection.ParameterModifier */ __self, int /* System.Int32 */ index, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.ParameterModifier __selfConverted = InteropUtils.GetInstance<System.Reflection.ParameterModifier>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted[index];
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_ParameterModifier_Item_Set")]
	internal static void /* System.Void */ System_Reflection_ParameterModifier_Item_Set(void* /* System.Reflection.ParameterModifier */ __self, int /* System.Int32 */ index, byte /* System.Boolean */ __value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.ParameterModifier __selfConverted = InteropUtils.GetInstance<System.Reflection.ParameterModifier>(__self);
	
	
	    try {
			__selfConverted[index]  = __value.ToBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_ParameterModifier_Create_1")]
	internal static void* /* System.Reflection.ParameterModifier */ System_Reflection_ParameterModifier_Create_1(void** /* System.Exception */ __outException)
	{
	
	    try {
			System.Reflection.ParameterModifier __returnValue = new System.Reflection.ParameterModifier();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_ParameterModifier_TypeOf")]
	internal static void* /* System.Type */ System_Reflection_ParameterModifier_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.Reflection.ParameterModifier);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_ParameterModifier_Destroy")]
	internal static void /* System.Void */ System_Reflection_ParameterModifier_Destroy(void* /* System.Reflection.ParameterModifier */ __self)
	{
	
		InteropUtils.FreeIfAllocated(__self);
	}
	
}




internal unsafe class System_Reflection_PropertyInfo
{
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_PropertyInfo_GetIndexParameters")]
	internal static void* /* System.Reflection.ParameterInfo[] */ System_Reflection_PropertyInfo_GetIndexParameters(void* /* System.Reflection.PropertyInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.PropertyInfo __selfConverted = InteropUtils.GetInstance<System.Reflection.PropertyInfo>(__self);
	
	
	    try {
			System.Reflection.ParameterInfo[] __returnValue = __selfConverted.GetIndexParameters();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_PropertyInfo_GetAccessors")]
	internal static void* /* System.Reflection.MethodInfo[] */ System_Reflection_PropertyInfo_GetAccessors(void* /* System.Reflection.PropertyInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.PropertyInfo __selfConverted = InteropUtils.GetInstance<System.Reflection.PropertyInfo>(__self);
	
	
	    try {
			System.Reflection.MethodInfo[] __returnValue = __selfConverted.GetAccessors();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_PropertyInfo_GetAccessors_1")]
	internal static void* /* System.Reflection.MethodInfo[] */ System_Reflection_PropertyInfo_GetAccessors_1(void* /* System.Reflection.PropertyInfo */ __self, byte /* System.Boolean */ nonPublic, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.PropertyInfo __selfConverted = InteropUtils.GetInstance<System.Reflection.PropertyInfo>(__self);
	
		System.Boolean nonPublicConverted = nonPublic.ToBool();
	
	    try {
			System.Reflection.MethodInfo[] __returnValue = __selfConverted.GetAccessors(nonPublicConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_PropertyInfo_GetGetMethod")]
	internal static void* /* System.Reflection.MethodInfo */ System_Reflection_PropertyInfo_GetGetMethod(void* /* System.Reflection.PropertyInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.PropertyInfo __selfConverted = InteropUtils.GetInstance<System.Reflection.PropertyInfo>(__self);
	
	
	    try {
			System.Reflection.MethodInfo __returnValue = __selfConverted.GetGetMethod();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_PropertyInfo_GetGetMethod_1")]
	internal static void* /* System.Reflection.MethodInfo */ System_Reflection_PropertyInfo_GetGetMethod_1(void* /* System.Reflection.PropertyInfo */ __self, byte /* System.Boolean */ nonPublic, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.PropertyInfo __selfConverted = InteropUtils.GetInstance<System.Reflection.PropertyInfo>(__self);
	
		System.Boolean nonPublicConverted = nonPublic.ToBool();
	
	    try {
			System.Reflection.MethodInfo __returnValue = __selfConverted.GetGetMethod(nonPublicConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_PropertyInfo_GetSetMethod")]
	internal static void* /* System.Reflection.MethodInfo */ System_Reflection_PropertyInfo_GetSetMethod(void* /* System.Reflection.PropertyInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.PropertyInfo __selfConverted = InteropUtils.GetInstance<System.Reflection.PropertyInfo>(__self);
	
	
	    try {
			System.Reflection.MethodInfo __returnValue = __selfConverted.GetSetMethod();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_PropertyInfo_GetSetMethod_1")]
	internal static void* /* System.Reflection.MethodInfo */ System_Reflection_PropertyInfo_GetSetMethod_1(void* /* System.Reflection.PropertyInfo */ __self, byte /* System.Boolean */ nonPublic, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.PropertyInfo __selfConverted = InteropUtils.GetInstance<System.Reflection.PropertyInfo>(__self);
	
		System.Boolean nonPublicConverted = nonPublic.ToBool();
	
	    try {
			System.Reflection.MethodInfo __returnValue = __selfConverted.GetSetMethod(nonPublicConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_PropertyInfo_GetModifiedPropertyType")]
	internal static void* /* System.Type */ System_Reflection_PropertyInfo_GetModifiedPropertyType(void* /* System.Reflection.PropertyInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.PropertyInfo __selfConverted = InteropUtils.GetInstance<System.Reflection.PropertyInfo>(__self);
	
	
	    try {
			System.Type __returnValue = __selfConverted.GetModifiedPropertyType();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_PropertyInfo_GetOptionalCustomModifiers")]
	internal static void* /* System.Type[] */ System_Reflection_PropertyInfo_GetOptionalCustomModifiers(void* /* System.Reflection.PropertyInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.PropertyInfo __selfConverted = InteropUtils.GetInstance<System.Reflection.PropertyInfo>(__self);
	
	
	    try {
			System.Type[] __returnValue = __selfConverted.GetOptionalCustomModifiers();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_PropertyInfo_GetRequiredCustomModifiers")]
	internal static void* /* System.Type[] */ System_Reflection_PropertyInfo_GetRequiredCustomModifiers(void* /* System.Reflection.PropertyInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.PropertyInfo __selfConverted = InteropUtils.GetInstance<System.Reflection.PropertyInfo>(__self);
	
	
	    try {
			System.Type[] __returnValue = __selfConverted.GetRequiredCustomModifiers();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_PropertyInfo_GetValue")]
	internal static void* /* System.Object */ System_Reflection_PropertyInfo_GetValue(void* /* System.Reflection.PropertyInfo */ __self, void* /* System.Object */ obj, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.PropertyInfo __selfConverted = InteropUtils.GetInstance<System.Reflection.PropertyInfo>(__self);
	
		System.Object objConverted = InteropUtils.GetInstance<System.Object>(obj);
	
	    try {
			System.Object __returnValue = __selfConverted.GetValue(objConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_PropertyInfo_GetValue_1")]
	internal static void* /* System.Object */ System_Reflection_PropertyInfo_GetValue_1(void* /* System.Reflection.PropertyInfo */ __self, void* /* System.Object */ obj, void* /* System.Object[] */ index, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.PropertyInfo __selfConverted = InteropUtils.GetInstance<System.Reflection.PropertyInfo>(__self);
	
		System.Object objConverted = InteropUtils.GetInstance<System.Object>(obj);
		System.Object[] indexConverted = InteropUtils.GetInstance<System.Object[]>(index);
	
	    try {
			System.Object __returnValue = __selfConverted.GetValue(objConverted, indexConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_PropertyInfo_GetValue_2")]
	internal static void* /* System.Object */ System_Reflection_PropertyInfo_GetValue_2(void* /* System.Reflection.PropertyInfo */ __self, void* /* System.Object */ obj, System.Reflection.BindingFlags /* System.Reflection.BindingFlags */ invokeAttr, void* /* System.Reflection.Binder */ binder, void* /* System.Object[] */ index, void* /* System.Globalization.CultureInfo */ culture, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.PropertyInfo __selfConverted = InteropUtils.GetInstance<System.Reflection.PropertyInfo>(__self);
	
		System.Object objConverted = InteropUtils.GetInstance<System.Object>(obj);
		System.Reflection.Binder binderConverted = InteropUtils.GetInstance<System.Reflection.Binder>(binder);
		System.Object[] indexConverted = InteropUtils.GetInstance<System.Object[]>(index);
		System.Globalization.CultureInfo cultureConverted = InteropUtils.GetInstance<System.Globalization.CultureInfo>(culture);
	
	    try {
			System.Object __returnValue = __selfConverted.GetValue(objConverted, invokeAttr, binderConverted, indexConverted, cultureConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_PropertyInfo_GetConstantValue")]
	internal static void* /* System.Object */ System_Reflection_PropertyInfo_GetConstantValue(void* /* System.Reflection.PropertyInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.PropertyInfo __selfConverted = InteropUtils.GetInstance<System.Reflection.PropertyInfo>(__self);
	
	
	    try {
			System.Object __returnValue = __selfConverted.GetConstantValue();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_PropertyInfo_GetRawConstantValue")]
	internal static void* /* System.Object */ System_Reflection_PropertyInfo_GetRawConstantValue(void* /* System.Reflection.PropertyInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.PropertyInfo __selfConverted = InteropUtils.GetInstance<System.Reflection.PropertyInfo>(__self);
	
	
	    try {
			System.Object __returnValue = __selfConverted.GetRawConstantValue();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_PropertyInfo_SetValue")]
	internal static void /* System.Void */ System_Reflection_PropertyInfo_SetValue(void* /* System.Reflection.PropertyInfo */ __self, void* /* System.Object */ obj, void* /* System.Object */ value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.PropertyInfo __selfConverted = InteropUtils.GetInstance<System.Reflection.PropertyInfo>(__self);
	
		System.Object objConverted = InteropUtils.GetInstance<System.Object>(obj);
		System.Object valueConverted = InteropUtils.GetInstance<System.Object>(value);
	
	    try {
			__selfConverted.SetValue(objConverted, valueConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_PropertyInfo_SetValue_1")]
	internal static void /* System.Void */ System_Reflection_PropertyInfo_SetValue_1(void* /* System.Reflection.PropertyInfo */ __self, void* /* System.Object */ obj, void* /* System.Object */ value, void* /* System.Object[] */ index, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.PropertyInfo __selfConverted = InteropUtils.GetInstance<System.Reflection.PropertyInfo>(__self);
	
		System.Object objConverted = InteropUtils.GetInstance<System.Object>(obj);
		System.Object valueConverted = InteropUtils.GetInstance<System.Object>(value);
		System.Object[] indexConverted = InteropUtils.GetInstance<System.Object[]>(index);
	
	    try {
			__selfConverted.SetValue(objConverted, valueConverted, indexConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_PropertyInfo_SetValue_2")]
	internal static void /* System.Void */ System_Reflection_PropertyInfo_SetValue_2(void* /* System.Reflection.PropertyInfo */ __self, void* /* System.Object */ obj, void* /* System.Object */ value, System.Reflection.BindingFlags /* System.Reflection.BindingFlags */ invokeAttr, void* /* System.Reflection.Binder */ binder, void* /* System.Object[] */ index, void* /* System.Globalization.CultureInfo */ culture, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.PropertyInfo __selfConverted = InteropUtils.GetInstance<System.Reflection.PropertyInfo>(__self);
	
		System.Object objConverted = InteropUtils.GetInstance<System.Object>(obj);
		System.Object valueConverted = InteropUtils.GetInstance<System.Object>(value);
		System.Reflection.Binder binderConverted = InteropUtils.GetInstance<System.Reflection.Binder>(binder);
		System.Object[] indexConverted = InteropUtils.GetInstance<System.Object[]>(index);
		System.Globalization.CultureInfo cultureConverted = InteropUtils.GetInstance<System.Globalization.CultureInfo>(culture);
	
	    try {
			__selfConverted.SetValue(objConverted, valueConverted, invokeAttr, binderConverted, indexConverted, cultureConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_PropertyInfo_Equals")]
	internal static byte /* System.Boolean */ System_Reflection_PropertyInfo_Equals(void* /* System.Reflection.PropertyInfo */ __self, void* /* System.Object */ obj, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.PropertyInfo __selfConverted = InteropUtils.GetInstance<System.Reflection.PropertyInfo>(__self);
	
		System.Object objConverted = InteropUtils.GetInstance<System.Object>(obj);
	
	    try {
			System.Boolean __returnValue = __selfConverted.Equals(objConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_PropertyInfo_GetHashCode")]
	internal static int /* System.Int32 */ System_Reflection_PropertyInfo_GetHashCode(void* /* System.Reflection.PropertyInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.PropertyInfo __selfConverted = InteropUtils.GetInstance<System.Reflection.PropertyInfo>(__self);
	
	
	    try {
			System.Int32 __returnValue = __selfConverted.GetHashCode();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_PropertyInfo_MemberType_Get")]
	internal static System.Reflection.MemberTypes /* System.Reflection.MemberTypes */ System_Reflection_PropertyInfo_MemberType_Get(void* /* System.Reflection.PropertyInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.PropertyInfo __selfConverted = InteropUtils.GetInstance<System.Reflection.PropertyInfo>(__self);
	
	
	    try {
			System.Reflection.MemberTypes __returnValue = __selfConverted.MemberType;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return default(System.Reflection.MemberTypes);
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_PropertyInfo_PropertyType_Get")]
	internal static void* /* System.Type */ System_Reflection_PropertyInfo_PropertyType_Get(void* /* System.Reflection.PropertyInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.PropertyInfo __selfConverted = InteropUtils.GetInstance<System.Reflection.PropertyInfo>(__self);
	
	
	    try {
			System.Type __returnValue = __selfConverted.PropertyType;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_PropertyInfo_Attributes_Get")]
	internal static System.Reflection.PropertyAttributes /* System.Reflection.PropertyAttributes */ System_Reflection_PropertyInfo_Attributes_Get(void* /* System.Reflection.PropertyInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.PropertyInfo __selfConverted = InteropUtils.GetInstance<System.Reflection.PropertyInfo>(__self);
	
	
	    try {
			System.Reflection.PropertyAttributes __returnValue = __selfConverted.Attributes;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return default(System.Reflection.PropertyAttributes);
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_PropertyInfo_IsSpecialName_Get")]
	internal static byte /* System.Boolean */ System_Reflection_PropertyInfo_IsSpecialName_Get(void* /* System.Reflection.PropertyInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.PropertyInfo __selfConverted = InteropUtils.GetInstance<System.Reflection.PropertyInfo>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.IsSpecialName;
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_PropertyInfo_CanRead_Get")]
	internal static byte /* System.Boolean */ System_Reflection_PropertyInfo_CanRead_Get(void* /* System.Reflection.PropertyInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.PropertyInfo __selfConverted = InteropUtils.GetInstance<System.Reflection.PropertyInfo>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.CanRead;
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_PropertyInfo_CanWrite_Get")]
	internal static byte /* System.Boolean */ System_Reflection_PropertyInfo_CanWrite_Get(void* /* System.Reflection.PropertyInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.PropertyInfo __selfConverted = InteropUtils.GetInstance<System.Reflection.PropertyInfo>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.CanWrite;
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_PropertyInfo_GetMethod_Get")]
	internal static void* /* System.Reflection.MethodInfo */ System_Reflection_PropertyInfo_GetMethod_Get(void* /* System.Reflection.PropertyInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.PropertyInfo __selfConverted = InteropUtils.GetInstance<System.Reflection.PropertyInfo>(__self);
	
	
	    try {
			System.Reflection.MethodInfo __returnValue = __selfConverted.GetMethod;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_PropertyInfo_SetMethod_Get")]
	internal static void* /* System.Reflection.MethodInfo */ System_Reflection_PropertyInfo_SetMethod_Get(void* /* System.Reflection.PropertyInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.PropertyInfo __selfConverted = InteropUtils.GetInstance<System.Reflection.PropertyInfo>(__self);
	
	
	    try {
			System.Reflection.MethodInfo __returnValue = __selfConverted.SetMethod;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_PropertyInfo_TypeOf")]
	internal static void* /* System.Type */ System_Reflection_PropertyInfo_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.Reflection.PropertyInfo);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_PropertyInfo_Destroy")]
	internal static void /* System.Void */ System_Reflection_PropertyInfo_Destroy(void* /* System.Reflection.PropertyInfo */ __self)
	{
	
		InteropUtils.FreeIfAllocated(__self);
	}
	
}


internal unsafe class System_Reflection_PropertyAttributes
{
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_PropertyAttributes_TypeOf")]
	internal static void* /* System.Type */ System_Reflection_PropertyAttributes_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.Reflection.PropertyAttributes);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
}



internal unsafe class System_Reflection_MethodInfo
{
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_MethodInfo_GetGenericArguments")]
	internal static void* /* System.Type[] */ System_Reflection_MethodInfo_GetGenericArguments(void* /* System.Reflection.MethodInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.MethodInfo __selfConverted = InteropUtils.GetInstance<System.Reflection.MethodInfo>(__self);
	
	
	    try {
			System.Type[] __returnValue = __selfConverted.GetGenericArguments();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_MethodInfo_GetGenericMethodDefinition")]
	internal static void* /* System.Reflection.MethodInfo */ System_Reflection_MethodInfo_GetGenericMethodDefinition(void* /* System.Reflection.MethodInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.MethodInfo __selfConverted = InteropUtils.GetInstance<System.Reflection.MethodInfo>(__self);
	
	
	    try {
			System.Reflection.MethodInfo __returnValue = __selfConverted.GetGenericMethodDefinition();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_MethodInfo_MakeGenericMethod")]
	internal static void* /* System.Reflection.MethodInfo */ System_Reflection_MethodInfo_MakeGenericMethod(void* /* System.Reflection.MethodInfo */ __self, void* /* System.Type[] */ typeArguments, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.MethodInfo __selfConverted = InteropUtils.GetInstance<System.Reflection.MethodInfo>(__self);
	
		System.Type[] typeArgumentsConverted = InteropUtils.GetInstance<System.Type[]>(typeArguments);
	
	    try {
			System.Reflection.MethodInfo __returnValue = __selfConverted.MakeGenericMethod(typeArgumentsConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_MethodInfo_GetBaseDefinition")]
	internal static void* /* System.Reflection.MethodInfo */ System_Reflection_MethodInfo_GetBaseDefinition(void* /* System.Reflection.MethodInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.MethodInfo __selfConverted = InteropUtils.GetInstance<System.Reflection.MethodInfo>(__self);
	
	
	    try {
			System.Reflection.MethodInfo __returnValue = __selfConverted.GetBaseDefinition();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_MethodInfo_CreateDelegate")]
	internal static void* /* System.Delegate */ System_Reflection_MethodInfo_CreateDelegate(void* /* System.Reflection.MethodInfo */ __self, void* /* System.Type */ delegateType, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.MethodInfo __selfConverted = InteropUtils.GetInstance<System.Reflection.MethodInfo>(__self);
	
		System.Type delegateTypeConverted = InteropUtils.GetInstance<System.Type>(delegateType);
	
	    try {
			System.Delegate __returnValue = __selfConverted.CreateDelegate(delegateTypeConverted);
			void* __returnValueNative = new System_Delegate(__returnValue).AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_MethodInfo_CreateDelegate_1")]
	internal static void* /* System.Delegate */ System_Reflection_MethodInfo_CreateDelegate_1(void* /* System.Reflection.MethodInfo */ __self, void* /* System.Type */ delegateType, void* /* System.Object */ target, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.MethodInfo __selfConverted = InteropUtils.GetInstance<System.Reflection.MethodInfo>(__self);
	
		System.Type delegateTypeConverted = InteropUtils.GetInstance<System.Type>(delegateType);
		System.Object targetConverted = InteropUtils.GetInstance<System.Object>(target);
	
	    try {
			System.Delegate __returnValue = __selfConverted.CreateDelegate(delegateTypeConverted, targetConverted);
			void* __returnValueNative = new System_Delegate(__returnValue).AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_MethodInfo_Equals")]
	internal static byte /* System.Boolean */ System_Reflection_MethodInfo_Equals(void* /* System.Reflection.MethodInfo */ __self, void* /* System.Object */ obj, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.MethodInfo __selfConverted = InteropUtils.GetInstance<System.Reflection.MethodInfo>(__self);
	
		System.Object objConverted = InteropUtils.GetInstance<System.Object>(obj);
	
	    try {
			System.Boolean __returnValue = __selfConverted.Equals(objConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_MethodInfo_GetHashCode")]
	internal static int /* System.Int32 */ System_Reflection_MethodInfo_GetHashCode(void* /* System.Reflection.MethodInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.MethodInfo __selfConverted = InteropUtils.GetInstance<System.Reflection.MethodInfo>(__self);
	
	
	    try {
			System.Int32 __returnValue = __selfConverted.GetHashCode();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_MethodInfo_MemberType_Get")]
	internal static System.Reflection.MemberTypes /* System.Reflection.MemberTypes */ System_Reflection_MethodInfo_MemberType_Get(void* /* System.Reflection.MethodInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.MethodInfo __selfConverted = InteropUtils.GetInstance<System.Reflection.MethodInfo>(__self);
	
	
	    try {
			System.Reflection.MemberTypes __returnValue = __selfConverted.MemberType;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return default(System.Reflection.MemberTypes);
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_MethodInfo_ReturnParameter_Get")]
	internal static void* /* System.Reflection.ParameterInfo */ System_Reflection_MethodInfo_ReturnParameter_Get(void* /* System.Reflection.MethodInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.MethodInfo __selfConverted = InteropUtils.GetInstance<System.Reflection.MethodInfo>(__self);
	
	
	    try {
			System.Reflection.ParameterInfo __returnValue = __selfConverted.ReturnParameter;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_MethodInfo_ReturnType_Get")]
	internal static void* /* System.Type */ System_Reflection_MethodInfo_ReturnType_Get(void* /* System.Reflection.MethodInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.MethodInfo __selfConverted = InteropUtils.GetInstance<System.Reflection.MethodInfo>(__self);
	
	
	    try {
			System.Type __returnValue = __selfConverted.ReturnType;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_MethodInfo_ReturnTypeCustomAttributes_Get")]
	internal static void* /* System.Reflection.ICustomAttributeProvider */ System_Reflection_MethodInfo_ReturnTypeCustomAttributes_Get(void* /* System.Reflection.MethodInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.MethodInfo __selfConverted = InteropUtils.GetInstance<System.Reflection.MethodInfo>(__self);
	
	
	    try {
			System.Reflection.ICustomAttributeProvider __returnValue = __selfConverted.ReturnTypeCustomAttributes;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_MethodInfo_TypeOf")]
	internal static void* /* System.Type */ System_Reflection_MethodInfo_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.Reflection.MethodInfo);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_MethodInfo_Destroy")]
	internal static void /* System.Void */ System_Reflection_MethodInfo_Destroy(void* /* System.Reflection.MethodInfo */ __self)
	{
	
		InteropUtils.FreeIfAllocated(__self);
	}
	
}





internal unsafe class System_Collections_IDictionary
{
	[UnmanagedCallersOnly(EntryPoint = "System_Collections_IDictionary_Contains")]
	internal static byte /* System.Boolean */ System_Collections_IDictionary_Contains(void* /* System.Collections.IDictionary */ __self, void* /* System.Object */ key, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Collections.IDictionary __selfConverted = InteropUtils.GetInstance<System.Collections.IDictionary>(__self);
	
		System.Object keyConverted = InteropUtils.GetInstance<System.Object>(key);
	
	    try {
			System.Boolean __returnValue = __selfConverted.Contains(keyConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Collections_IDictionary_Add")]
	internal static void /* System.Void */ System_Collections_IDictionary_Add(void* /* System.Collections.IDictionary */ __self, void* /* System.Object */ key, void* /* System.Object */ value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Collections.IDictionary __selfConverted = InteropUtils.GetInstance<System.Collections.IDictionary>(__self);
	
		System.Object keyConverted = InteropUtils.GetInstance<System.Object>(key);
		System.Object valueConverted = InteropUtils.GetInstance<System.Object>(value);
	
	    try {
			__selfConverted.Add(keyConverted, valueConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Collections_IDictionary_Clear")]
	internal static void /* System.Void */ System_Collections_IDictionary_Clear(void* /* System.Collections.IDictionary */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Collections.IDictionary __selfConverted = InteropUtils.GetInstance<System.Collections.IDictionary>(__self);
	
	
	    try {
			__selfConverted.Clear();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Collections_IDictionary_GetEnumerator")]
	internal static void* /* System.Collections.IDictionaryEnumerator */ System_Collections_IDictionary_GetEnumerator(void* /* System.Collections.IDictionary */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Collections.IDictionary __selfConverted = InteropUtils.GetInstance<System.Collections.IDictionary>(__self);
	
	
	    try {
			System.Collections.IDictionaryEnumerator __returnValue = __selfConverted.GetEnumerator();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Collections_IDictionary_Remove")]
	internal static void /* System.Void */ System_Collections_IDictionary_Remove(void* /* System.Collections.IDictionary */ __self, void* /* System.Object */ key, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Collections.IDictionary __selfConverted = InteropUtils.GetInstance<System.Collections.IDictionary>(__self);
	
		System.Object keyConverted = InteropUtils.GetInstance<System.Object>(key);
	
	    try {
			__selfConverted.Remove(keyConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Collections_IDictionary_Item_Get")]
	internal static void* /* System.Object */ System_Collections_IDictionary_Item_Get(void* /* System.Collections.IDictionary */ __self, void* /* System.Object */ key, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Collections.IDictionary __selfConverted = InteropUtils.GetInstance<System.Collections.IDictionary>(__self);
	
		System.Object keyConverted = InteropUtils.GetInstance<System.Object>(key);
	
	    try {
			System.Object __returnValue = __selfConverted[keyConverted];
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Collections_IDictionary_Item_Set")]
	internal static void /* System.Void */ System_Collections_IDictionary_Item_Set(void* /* System.Collections.IDictionary */ __self, void* /* System.Object */ key, void* /* System.Object */ __value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Collections.IDictionary __selfConverted = InteropUtils.GetInstance<System.Collections.IDictionary>(__self);
	
		System.Object keyConverted = InteropUtils.GetInstance<System.Object>(key);
	
	    try {
			__selfConverted[keyConverted]  = InteropUtils.GetInstance<System.Object>(__value);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Collections_IDictionary_Keys_Get")]
	internal static void* /* System.Collections.ICollection */ System_Collections_IDictionary_Keys_Get(void* /* System.Collections.IDictionary */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Collections.IDictionary __selfConverted = InteropUtils.GetInstance<System.Collections.IDictionary>(__self);
	
	
	    try {
			System.Collections.ICollection __returnValue = __selfConverted.Keys;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Collections_IDictionary_Values_Get")]
	internal static void* /* System.Collections.ICollection */ System_Collections_IDictionary_Values_Get(void* /* System.Collections.IDictionary */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Collections.IDictionary __selfConverted = InteropUtils.GetInstance<System.Collections.IDictionary>(__self);
	
	
	    try {
			System.Collections.ICollection __returnValue = __selfConverted.Values;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Collections_IDictionary_IsReadOnly_Get")]
	internal static byte /* System.Boolean */ System_Collections_IDictionary_IsReadOnly_Get(void* /* System.Collections.IDictionary */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Collections.IDictionary __selfConverted = InteropUtils.GetInstance<System.Collections.IDictionary>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.IsReadOnly;
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Collections_IDictionary_IsFixedSize_Get")]
	internal static byte /* System.Boolean */ System_Collections_IDictionary_IsFixedSize_Get(void* /* System.Collections.IDictionary */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Collections.IDictionary __selfConverted = InteropUtils.GetInstance<System.Collections.IDictionary>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.IsFixedSize;
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Collections_IDictionary_TypeOf")]
	internal static void* /* System.Type */ System_Collections_IDictionary_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.Collections.IDictionary);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Collections_IDictionary_Destroy")]
	internal static void /* System.Void */ System_Collections_IDictionary_Destroy(void* /* System.Collections.IDictionary */ __self)
	{
	
		InteropUtils.FreeIfAllocated(__self);
	}
	
}


internal unsafe class System_Collections_IDictionaryEnumerator
{
	[UnmanagedCallersOnly(EntryPoint = "System_Collections_IDictionaryEnumerator_Key_Get")]
	internal static void* /* System.Object */ System_Collections_IDictionaryEnumerator_Key_Get(void* /* System.Collections.IDictionaryEnumerator */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Collections.IDictionaryEnumerator __selfConverted = InteropUtils.GetInstance<System.Collections.IDictionaryEnumerator>(__self);
	
	
	    try {
			System.Object __returnValue = __selfConverted.Key;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Collections_IDictionaryEnumerator_Value_Get")]
	internal static void* /* System.Object */ System_Collections_IDictionaryEnumerator_Value_Get(void* /* System.Collections.IDictionaryEnumerator */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Collections.IDictionaryEnumerator __selfConverted = InteropUtils.GetInstance<System.Collections.IDictionaryEnumerator>(__self);
	
	
	    try {
			System.Object __returnValue = __selfConverted.Value;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Collections_IDictionaryEnumerator_Entry_Get")]
	internal static void* /* System.Collections.DictionaryEntry */ System_Collections_IDictionaryEnumerator_Entry_Get(void* /* System.Collections.IDictionaryEnumerator */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Collections.IDictionaryEnumerator __selfConverted = InteropUtils.GetInstance<System.Collections.IDictionaryEnumerator>(__self);
	
	
	    try {
			System.Collections.DictionaryEntry __returnValue = __selfConverted.Entry;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Collections_IDictionaryEnumerator_TypeOf")]
	internal static void* /* System.Type */ System_Collections_IDictionaryEnumerator_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.Collections.IDictionaryEnumerator);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Collections_IDictionaryEnumerator_Destroy")]
	internal static void /* System.Void */ System_Collections_IDictionaryEnumerator_Destroy(void* /* System.Collections.IDictionaryEnumerator */ __self)
	{
	
		InteropUtils.FreeIfAllocated(__self);
	}
	
}


internal unsafe class System_Collections_DictionaryEntry
{
	[UnmanagedCallersOnly(EntryPoint = "System_Collections_DictionaryEntry_Deconstruct")]
	internal static void /* System.Void */ System_Collections_DictionaryEntry_Deconstruct(void* /* System.Collections.DictionaryEntry */ __self, void** /* System.Object */ key, void** /* System.Object */ value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Collections.DictionaryEntry __selfConverted = InteropUtils.GetInstance<System.Collections.DictionaryEntry>(__self);
	
		System.Object keyConverted;
		System.Object valueConverted;
	
	    try {
			__selfConverted.Deconstruct(out keyConverted, out valueConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			if (key is not null) {
				*key = keyConverted.AllocateGCHandleAndGetAddress();
			}
	
			if (value is not null) {
				*value = valueConverted.AllocateGCHandleAndGetAddress();
			}
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			if (key is not null) {
				*key = null;
			}
	
			if (value is not null) {
				*value = null;
			}
	
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Collections_DictionaryEntry_ToString")]
	internal static void* /* System.String */ System_Collections_DictionaryEntry_ToString(void* /* System.Collections.DictionaryEntry */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Collections.DictionaryEntry __selfConverted = InteropUtils.GetInstance<System.Collections.DictionaryEntry>(__self);
	
	
	    try {
			System.String __returnValue = __selfConverted.ToString();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Collections_DictionaryEntry_Create")]
	internal static void* /* System.Collections.DictionaryEntry */ System_Collections_DictionaryEntry_Create(void* /* System.Object */ key, void* /* System.Object */ value, void** /* System.Exception */ __outException)
	{
		System.Object keyConverted = InteropUtils.GetInstance<System.Object>(key);
		System.Object valueConverted = InteropUtils.GetInstance<System.Object>(value);
	
	    try {
			System.Collections.DictionaryEntry __returnValue = new System.Collections.DictionaryEntry(keyConverted, valueConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Collections_DictionaryEntry_Key_Get")]
	internal static void* /* System.Object */ System_Collections_DictionaryEntry_Key_Get(void* /* System.Collections.DictionaryEntry */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Collections.DictionaryEntry __selfConverted = InteropUtils.GetInstance<System.Collections.DictionaryEntry>(__self);
	
	
	    try {
			System.Object __returnValue = __selfConverted.Key;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Collections_DictionaryEntry_Key_Set")]
	internal static void /* System.Void */ System_Collections_DictionaryEntry_Key_Set(void* /* System.Collections.DictionaryEntry */ __self, void* /* System.Object */ __value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Collections.DictionaryEntry __selfConverted = InteropUtils.GetInstance<System.Collections.DictionaryEntry>(__self);
	
	
	    try {
			__selfConverted.Key = InteropUtils.GetInstance<System.Object>(__value);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Collections_DictionaryEntry_Value_Get")]
	internal static void* /* System.Object */ System_Collections_DictionaryEntry_Value_Get(void* /* System.Collections.DictionaryEntry */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Collections.DictionaryEntry __selfConverted = InteropUtils.GetInstance<System.Collections.DictionaryEntry>(__self);
	
	
	    try {
			System.Object __returnValue = __selfConverted.Value;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Collections_DictionaryEntry_Value_Set")]
	internal static void /* System.Void */ System_Collections_DictionaryEntry_Value_Set(void* /* System.Collections.DictionaryEntry */ __self, void* /* System.Object */ __value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Collections.DictionaryEntry __selfConverted = InteropUtils.GetInstance<System.Collections.DictionaryEntry>(__self);
	
	
	    try {
			__selfConverted.Value = InteropUtils.GetInstance<System.Object>(__value);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Collections_DictionaryEntry_Create_1")]
	internal static void* /* System.Collections.DictionaryEntry */ System_Collections_DictionaryEntry_Create_1(void** /* System.Exception */ __outException)
	{
	
	    try {
			System.Collections.DictionaryEntry __returnValue = new System.Collections.DictionaryEntry();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Collections_DictionaryEntry_TypeOf")]
	internal static void* /* System.Type */ System_Collections_DictionaryEntry_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.Collections.DictionaryEntry);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Collections_DictionaryEntry_Destroy")]
	internal static void /* System.Void */ System_Collections_DictionaryEntry_Destroy(void* /* System.Collections.DictionaryEntry */ __self)
	{
	
		InteropUtils.FreeIfAllocated(__self);
	}
	
}


internal unsafe class System_Threading_Tasks_Task
{
	[UnmanagedCallersOnly(EntryPoint = "System_Threading_Tasks_Task_Start")]
	internal static void /* System.Void */ System_Threading_Tasks_Task_Start(void* /* System.Threading.Tasks.Task */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Threading.Tasks.Task __selfConverted = InteropUtils.GetInstance<System.Threading.Tasks.Task>(__self);
	
	
	    try {
			__selfConverted.Start();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Threading_Tasks_Task_Start_1")]
	internal static void /* System.Void */ System_Threading_Tasks_Task_Start_1(void* /* System.Threading.Tasks.Task */ __self, void* /* System.Threading.Tasks.TaskScheduler */ scheduler, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Threading.Tasks.Task __selfConverted = InteropUtils.GetInstance<System.Threading.Tasks.Task>(__self);
	
		System.Threading.Tasks.TaskScheduler schedulerConverted = InteropUtils.GetInstance<System.Threading.Tasks.TaskScheduler>(scheduler);
	
	    try {
			__selfConverted.Start(schedulerConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Threading_Tasks_Task_RunSynchronously")]
	internal static void /* System.Void */ System_Threading_Tasks_Task_RunSynchronously(void* /* System.Threading.Tasks.Task */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Threading.Tasks.Task __selfConverted = InteropUtils.GetInstance<System.Threading.Tasks.Task>(__self);
	
	
	    try {
			__selfConverted.RunSynchronously();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Threading_Tasks_Task_RunSynchronously_1")]
	internal static void /* System.Void */ System_Threading_Tasks_Task_RunSynchronously_1(void* /* System.Threading.Tasks.Task */ __self, void* /* System.Threading.Tasks.TaskScheduler */ scheduler, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Threading.Tasks.Task __selfConverted = InteropUtils.GetInstance<System.Threading.Tasks.Task>(__self);
	
		System.Threading.Tasks.TaskScheduler schedulerConverted = InteropUtils.GetInstance<System.Threading.Tasks.TaskScheduler>(scheduler);
	
	    try {
			__selfConverted.RunSynchronously(schedulerConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Threading_Tasks_Task_Dispose")]
	internal static void /* System.Void */ System_Threading_Tasks_Task_Dispose(void* /* System.Threading.Tasks.Task */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Threading.Tasks.Task __selfConverted = InteropUtils.GetInstance<System.Threading.Tasks.Task>(__self);
	
	
	    try {
			__selfConverted.Dispose();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Threading_Tasks_Task_GetAwaiter")]
	internal static void* /* System.Runtime.CompilerServices.TaskAwaiter */ System_Threading_Tasks_Task_GetAwaiter(void* /* System.Threading.Tasks.Task */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Threading.Tasks.Task __selfConverted = InteropUtils.GetInstance<System.Threading.Tasks.Task>(__self);
	
	
	    try {
			System.Runtime.CompilerServices.TaskAwaiter __returnValue = __selfConverted.GetAwaiter();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Threading_Tasks_Task_ConfigureAwait")]
	internal static void* /* System.Runtime.CompilerServices.ConfiguredTaskAwaitable */ System_Threading_Tasks_Task_ConfigureAwait(void* /* System.Threading.Tasks.Task */ __self, byte /* System.Boolean */ continueOnCapturedContext, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Threading.Tasks.Task __selfConverted = InteropUtils.GetInstance<System.Threading.Tasks.Task>(__self);
	
		System.Boolean continueOnCapturedContextConverted = continueOnCapturedContext.ToBool();
	
	    try {
			System.Runtime.CompilerServices.ConfiguredTaskAwaitable __returnValue = __selfConverted.ConfigureAwait(continueOnCapturedContextConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Threading_Tasks_Task_ConfigureAwait_1")]
	internal static void* /* System.Runtime.CompilerServices.ConfiguredTaskAwaitable */ System_Threading_Tasks_Task_ConfigureAwait_1(void* /* System.Threading.Tasks.Task */ __self, System.Threading.Tasks.ConfigureAwaitOptions /* System.Threading.Tasks.ConfigureAwaitOptions */ options, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Threading.Tasks.Task __selfConverted = InteropUtils.GetInstance<System.Threading.Tasks.Task>(__self);
	
	
	    try {
			System.Runtime.CompilerServices.ConfiguredTaskAwaitable __returnValue = __selfConverted.ConfigureAwait(options);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Threading_Tasks_Task_Yield")]
	internal static void* /* System.Runtime.CompilerServices.YieldAwaitable */ System_Threading_Tasks_Task_Yield(void** /* System.Exception */ __outException)
	{
	
	    try {
			System.Runtime.CompilerServices.YieldAwaitable __returnValue = System.Threading.Tasks.Task.Yield();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Threading_Tasks_Task_Wait")]
	internal static void /* System.Void */ System_Threading_Tasks_Task_Wait(void* /* System.Threading.Tasks.Task */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Threading.Tasks.Task __selfConverted = InteropUtils.GetInstance<System.Threading.Tasks.Task>(__self);
	
	
	    try {
			__selfConverted.Wait();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Threading_Tasks_Task_Wait_1")]
	internal static byte /* System.Boolean */ System_Threading_Tasks_Task_Wait_1(void* /* System.Threading.Tasks.Task */ __self, void* /* System.TimeSpan */ timeout, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Threading.Tasks.Task __selfConverted = InteropUtils.GetInstance<System.Threading.Tasks.Task>(__self);
	
		System.TimeSpan timeoutConverted = InteropUtils.GetInstance<System.TimeSpan>(timeout);
	
	    try {
			System.Boolean __returnValue = __selfConverted.Wait(timeoutConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Threading_Tasks_Task_Wait_2")]
	internal static byte /* System.Boolean */ System_Threading_Tasks_Task_Wait_2(void* /* System.Threading.Tasks.Task */ __self, void* /* System.TimeSpan */ timeout, void* /* System.Threading.CancellationToken */ cancellationToken, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Threading.Tasks.Task __selfConverted = InteropUtils.GetInstance<System.Threading.Tasks.Task>(__self);
	
		System.TimeSpan timeoutConverted = InteropUtils.GetInstance<System.TimeSpan>(timeout);
		System.Threading.CancellationToken cancellationTokenConverted = InteropUtils.GetInstance<System.Threading.CancellationToken>(cancellationToken);
	
	    try {
			System.Boolean __returnValue = __selfConverted.Wait(timeoutConverted, cancellationTokenConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Threading_Tasks_Task_Wait_3")]
	internal static void /* System.Void */ System_Threading_Tasks_Task_Wait_3(void* /* System.Threading.Tasks.Task */ __self, void* /* System.Threading.CancellationToken */ cancellationToken, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Threading.Tasks.Task __selfConverted = InteropUtils.GetInstance<System.Threading.Tasks.Task>(__self);
	
		System.Threading.CancellationToken cancellationTokenConverted = InteropUtils.GetInstance<System.Threading.CancellationToken>(cancellationToken);
	
	    try {
			__selfConverted.Wait(cancellationTokenConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Threading_Tasks_Task_Wait_4")]
	internal static byte /* System.Boolean */ System_Threading_Tasks_Task_Wait_4(void* /* System.Threading.Tasks.Task */ __self, int /* System.Int32 */ millisecondsTimeout, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Threading.Tasks.Task __selfConverted = InteropUtils.GetInstance<System.Threading.Tasks.Task>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.Wait(millisecondsTimeout);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Threading_Tasks_Task_Wait_5")]
	internal static byte /* System.Boolean */ System_Threading_Tasks_Task_Wait_5(void* /* System.Threading.Tasks.Task */ __self, int /* System.Int32 */ millisecondsTimeout, void* /* System.Threading.CancellationToken */ cancellationToken, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Threading.Tasks.Task __selfConverted = InteropUtils.GetInstance<System.Threading.Tasks.Task>(__self);
	
		System.Threading.CancellationToken cancellationTokenConverted = InteropUtils.GetInstance<System.Threading.CancellationToken>(cancellationToken);
	
	    try {
			System.Boolean __returnValue = __selfConverted.Wait(millisecondsTimeout, cancellationTokenConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Threading_Tasks_Task_WaitAsync")]
	internal static void* /* System.Threading.Tasks.Task */ System_Threading_Tasks_Task_WaitAsync(void* /* System.Threading.Tasks.Task */ __self, void* /* System.Threading.CancellationToken */ cancellationToken, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Threading.Tasks.Task __selfConverted = InteropUtils.GetInstance<System.Threading.Tasks.Task>(__self);
	
		System.Threading.CancellationToken cancellationTokenConverted = InteropUtils.GetInstance<System.Threading.CancellationToken>(cancellationToken);
	
	    try {
			System.Threading.Tasks.Task __returnValue = __selfConverted.WaitAsync(cancellationTokenConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Threading_Tasks_Task_WaitAsync_1")]
	internal static void* /* System.Threading.Tasks.Task */ System_Threading_Tasks_Task_WaitAsync_1(void* /* System.Threading.Tasks.Task */ __self, void* /* System.TimeSpan */ timeout, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Threading.Tasks.Task __selfConverted = InteropUtils.GetInstance<System.Threading.Tasks.Task>(__self);
	
		System.TimeSpan timeoutConverted = InteropUtils.GetInstance<System.TimeSpan>(timeout);
	
	    try {
			System.Threading.Tasks.Task __returnValue = __selfConverted.WaitAsync(timeoutConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Threading_Tasks_Task_WaitAsync_2")]
	internal static void* /* System.Threading.Tasks.Task */ System_Threading_Tasks_Task_WaitAsync_2(void* /* System.Threading.Tasks.Task */ __self, void* /* System.TimeSpan */ timeout, void* /* System.TimeProvider */ timeProvider, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Threading.Tasks.Task __selfConverted = InteropUtils.GetInstance<System.Threading.Tasks.Task>(__self);
	
		System.TimeSpan timeoutConverted = InteropUtils.GetInstance<System.TimeSpan>(timeout);
		System.TimeProvider timeProviderConverted = InteropUtils.GetInstance<System.TimeProvider>(timeProvider);
	
	    try {
			System.Threading.Tasks.Task __returnValue = __selfConverted.WaitAsync(timeoutConverted, timeProviderConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Threading_Tasks_Task_WaitAsync_3")]
	internal static void* /* System.Threading.Tasks.Task */ System_Threading_Tasks_Task_WaitAsync_3(void* /* System.Threading.Tasks.Task */ __self, void* /* System.TimeSpan */ timeout, void* /* System.Threading.CancellationToken */ cancellationToken, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Threading.Tasks.Task __selfConverted = InteropUtils.GetInstance<System.Threading.Tasks.Task>(__self);
	
		System.TimeSpan timeoutConverted = InteropUtils.GetInstance<System.TimeSpan>(timeout);
		System.Threading.CancellationToken cancellationTokenConverted = InteropUtils.GetInstance<System.Threading.CancellationToken>(cancellationToken);
	
	    try {
			System.Threading.Tasks.Task __returnValue = __selfConverted.WaitAsync(timeoutConverted, cancellationTokenConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Threading_Tasks_Task_WaitAsync_4")]
	internal static void* /* System.Threading.Tasks.Task */ System_Threading_Tasks_Task_WaitAsync_4(void* /* System.Threading.Tasks.Task */ __self, void* /* System.TimeSpan */ timeout, void* /* System.TimeProvider */ timeProvider, void* /* System.Threading.CancellationToken */ cancellationToken, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Threading.Tasks.Task __selfConverted = InteropUtils.GetInstance<System.Threading.Tasks.Task>(__self);
	
		System.TimeSpan timeoutConverted = InteropUtils.GetInstance<System.TimeSpan>(timeout);
		System.TimeProvider timeProviderConverted = InteropUtils.GetInstance<System.TimeProvider>(timeProvider);
		System.Threading.CancellationToken cancellationTokenConverted = InteropUtils.GetInstance<System.Threading.CancellationToken>(cancellationToken);
	
	    try {
			System.Threading.Tasks.Task __returnValue = __selfConverted.WaitAsync(timeoutConverted, timeProviderConverted, cancellationTokenConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Threading_Tasks_Task_WaitAll")]
	internal static void /* System.Void */ System_Threading_Tasks_Task_WaitAll(void* /* System.Threading.Tasks.Task[] */ tasks, void** /* System.Exception */ __outException)
	{
		System.Threading.Tasks.Task[] tasksConverted = InteropUtils.GetInstance<System.Threading.Tasks.Task[]>(tasks);
	
	    try {
			System.Threading.Tasks.Task.WaitAll(tasksConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Threading_Tasks_Task_WaitAll_1")]
	internal static byte /* System.Boolean */ System_Threading_Tasks_Task_WaitAll_1(void* /* System.Threading.Tasks.Task[] */ tasks, void* /* System.TimeSpan */ timeout, void** /* System.Exception */ __outException)
	{
		System.Threading.Tasks.Task[] tasksConverted = InteropUtils.GetInstance<System.Threading.Tasks.Task[]>(tasks);
		System.TimeSpan timeoutConverted = InteropUtils.GetInstance<System.TimeSpan>(timeout);
	
	    try {
			System.Boolean __returnValue = System.Threading.Tasks.Task.WaitAll(tasksConverted, timeoutConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Threading_Tasks_Task_WaitAll_2")]
	internal static byte /* System.Boolean */ System_Threading_Tasks_Task_WaitAll_2(void* /* System.Threading.Tasks.Task[] */ tasks, int /* System.Int32 */ millisecondsTimeout, void** /* System.Exception */ __outException)
	{
		System.Threading.Tasks.Task[] tasksConverted = InteropUtils.GetInstance<System.Threading.Tasks.Task[]>(tasks);
	
	    try {
			System.Boolean __returnValue = System.Threading.Tasks.Task.WaitAll(tasksConverted, millisecondsTimeout);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Threading_Tasks_Task_WaitAll_3")]
	internal static void /* System.Void */ System_Threading_Tasks_Task_WaitAll_3(void* /* System.Threading.Tasks.Task[] */ tasks, void* /* System.Threading.CancellationToken */ cancellationToken, void** /* System.Exception */ __outException)
	{
		System.Threading.Tasks.Task[] tasksConverted = InteropUtils.GetInstance<System.Threading.Tasks.Task[]>(tasks);
		System.Threading.CancellationToken cancellationTokenConverted = InteropUtils.GetInstance<System.Threading.CancellationToken>(cancellationToken);
	
	    try {
			System.Threading.Tasks.Task.WaitAll(tasksConverted, cancellationTokenConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Threading_Tasks_Task_WaitAll_4")]
	internal static byte /* System.Boolean */ System_Threading_Tasks_Task_WaitAll_4(void* /* System.Threading.Tasks.Task[] */ tasks, int /* System.Int32 */ millisecondsTimeout, void* /* System.Threading.CancellationToken */ cancellationToken, void** /* System.Exception */ __outException)
	{
		System.Threading.Tasks.Task[] tasksConverted = InteropUtils.GetInstance<System.Threading.Tasks.Task[]>(tasks);
		System.Threading.CancellationToken cancellationTokenConverted = InteropUtils.GetInstance<System.Threading.CancellationToken>(cancellationToken);
	
	    try {
			System.Boolean __returnValue = System.Threading.Tasks.Task.WaitAll(tasksConverted, millisecondsTimeout, cancellationTokenConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Threading_Tasks_Task_WaitAny")]
	internal static int /* System.Int32 */ System_Threading_Tasks_Task_WaitAny(void* /* System.Threading.Tasks.Task[] */ tasks, void** /* System.Exception */ __outException)
	{
		System.Threading.Tasks.Task[] tasksConverted = InteropUtils.GetInstance<System.Threading.Tasks.Task[]>(tasks);
	
	    try {
			System.Int32 __returnValue = System.Threading.Tasks.Task.WaitAny(tasksConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Threading_Tasks_Task_WaitAny_1")]
	internal static int /* System.Int32 */ System_Threading_Tasks_Task_WaitAny_1(void* /* System.Threading.Tasks.Task[] */ tasks, void* /* System.TimeSpan */ timeout, void** /* System.Exception */ __outException)
	{
		System.Threading.Tasks.Task[] tasksConverted = InteropUtils.GetInstance<System.Threading.Tasks.Task[]>(tasks);
		System.TimeSpan timeoutConverted = InteropUtils.GetInstance<System.TimeSpan>(timeout);
	
	    try {
			System.Int32 __returnValue = System.Threading.Tasks.Task.WaitAny(tasksConverted, timeoutConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Threading_Tasks_Task_WaitAny_2")]
	internal static int /* System.Int32 */ System_Threading_Tasks_Task_WaitAny_2(void* /* System.Threading.Tasks.Task[] */ tasks, void* /* System.Threading.CancellationToken */ cancellationToken, void** /* System.Exception */ __outException)
	{
		System.Threading.Tasks.Task[] tasksConverted = InteropUtils.GetInstance<System.Threading.Tasks.Task[]>(tasks);
		System.Threading.CancellationToken cancellationTokenConverted = InteropUtils.GetInstance<System.Threading.CancellationToken>(cancellationToken);
	
	    try {
			System.Int32 __returnValue = System.Threading.Tasks.Task.WaitAny(tasksConverted, cancellationTokenConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Threading_Tasks_Task_WaitAny_3")]
	internal static int /* System.Int32 */ System_Threading_Tasks_Task_WaitAny_3(void* /* System.Threading.Tasks.Task[] */ tasks, int /* System.Int32 */ millisecondsTimeout, void** /* System.Exception */ __outException)
	{
		System.Threading.Tasks.Task[] tasksConverted = InteropUtils.GetInstance<System.Threading.Tasks.Task[]>(tasks);
	
	    try {
			System.Int32 __returnValue = System.Threading.Tasks.Task.WaitAny(tasksConverted, millisecondsTimeout);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Threading_Tasks_Task_WaitAny_4")]
	internal static int /* System.Int32 */ System_Threading_Tasks_Task_WaitAny_4(void* /* System.Threading.Tasks.Task[] */ tasks, int /* System.Int32 */ millisecondsTimeout, void* /* System.Threading.CancellationToken */ cancellationToken, void** /* System.Exception */ __outException)
	{
		System.Threading.Tasks.Task[] tasksConverted = InteropUtils.GetInstance<System.Threading.Tasks.Task[]>(tasks);
		System.Threading.CancellationToken cancellationTokenConverted = InteropUtils.GetInstance<System.Threading.CancellationToken>(cancellationToken);
	
	    try {
			System.Int32 __returnValue = System.Threading.Tasks.Task.WaitAny(tasksConverted, millisecondsTimeout, cancellationTokenConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Threading_Tasks_Task_FromException")]
	internal static void* /* System.Threading.Tasks.Task */ System_Threading_Tasks_Task_FromException(void* /* System.Exception */ exception, void** /* System.Exception */ __outException)
	{
		System.Exception exceptionConverted = InteropUtils.GetInstance<System.Exception>(exception);
	
	    try {
			System.Threading.Tasks.Task __returnValue = System.Threading.Tasks.Task.FromException(exceptionConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Threading_Tasks_Task_FromCanceled")]
	internal static void* /* System.Threading.Tasks.Task */ System_Threading_Tasks_Task_FromCanceled(void* /* System.Threading.CancellationToken */ cancellationToken, void** /* System.Exception */ __outException)
	{
		System.Threading.CancellationToken cancellationTokenConverted = InteropUtils.GetInstance<System.Threading.CancellationToken>(cancellationToken);
	
	    try {
			System.Threading.Tasks.Task __returnValue = System.Threading.Tasks.Task.FromCanceled(cancellationTokenConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Threading_Tasks_Task_Run_1")]
	internal static void* /* System.Threading.Tasks.Task */ System_Threading_Tasks_Task_Run_1(void* /* System.Action */ action, void** /* System.Exception */ __outException)
	{
		System.Action actionConverted = InteropUtils.GetInstance<System_Action>(action)?.Trampoline;
	
	    try {
			System.Threading.Tasks.Task __returnValue = System.Threading.Tasks.Task.Run(actionConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Threading_Tasks_Task_Run_2")]
	internal static void* /* System.Threading.Tasks.Task */ System_Threading_Tasks_Task_Run_2(void* /* System.Action */ action, void* /* System.Threading.CancellationToken */ cancellationToken, void** /* System.Exception */ __outException)
	{
		System.Action actionConverted = InteropUtils.GetInstance<System_Action>(action)?.Trampoline;
		System.Threading.CancellationToken cancellationTokenConverted = InteropUtils.GetInstance<System.Threading.CancellationToken>(cancellationToken);
	
	    try {
			System.Threading.Tasks.Task __returnValue = System.Threading.Tasks.Task.Run(actionConverted, cancellationTokenConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Threading_Tasks_Task_Delay")]
	internal static void* /* System.Threading.Tasks.Task */ System_Threading_Tasks_Task_Delay(void* /* System.TimeSpan */ delay, void** /* System.Exception */ __outException)
	{
		System.TimeSpan delayConverted = InteropUtils.GetInstance<System.TimeSpan>(delay);
	
	    try {
			System.Threading.Tasks.Task __returnValue = System.Threading.Tasks.Task.Delay(delayConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Threading_Tasks_Task_Delay_1")]
	internal static void* /* System.Threading.Tasks.Task */ System_Threading_Tasks_Task_Delay_1(void* /* System.TimeSpan */ delay, void* /* System.TimeProvider */ timeProvider, void** /* System.Exception */ __outException)
	{
		System.TimeSpan delayConverted = InteropUtils.GetInstance<System.TimeSpan>(delay);
		System.TimeProvider timeProviderConverted = InteropUtils.GetInstance<System.TimeProvider>(timeProvider);
	
	    try {
			System.Threading.Tasks.Task __returnValue = System.Threading.Tasks.Task.Delay(delayConverted, timeProviderConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Threading_Tasks_Task_Delay_2")]
	internal static void* /* System.Threading.Tasks.Task */ System_Threading_Tasks_Task_Delay_2(void* /* System.TimeSpan */ delay, void* /* System.Threading.CancellationToken */ cancellationToken, void** /* System.Exception */ __outException)
	{
		System.TimeSpan delayConverted = InteropUtils.GetInstance<System.TimeSpan>(delay);
		System.Threading.CancellationToken cancellationTokenConverted = InteropUtils.GetInstance<System.Threading.CancellationToken>(cancellationToken);
	
	    try {
			System.Threading.Tasks.Task __returnValue = System.Threading.Tasks.Task.Delay(delayConverted, cancellationTokenConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Threading_Tasks_Task_Delay_3")]
	internal static void* /* System.Threading.Tasks.Task */ System_Threading_Tasks_Task_Delay_3(void* /* System.TimeSpan */ delay, void* /* System.TimeProvider */ timeProvider, void* /* System.Threading.CancellationToken */ cancellationToken, void** /* System.Exception */ __outException)
	{
		System.TimeSpan delayConverted = InteropUtils.GetInstance<System.TimeSpan>(delay);
		System.TimeProvider timeProviderConverted = InteropUtils.GetInstance<System.TimeProvider>(timeProvider);
		System.Threading.CancellationToken cancellationTokenConverted = InteropUtils.GetInstance<System.Threading.CancellationToken>(cancellationToken);
	
	    try {
			System.Threading.Tasks.Task __returnValue = System.Threading.Tasks.Task.Delay(delayConverted, timeProviderConverted, cancellationTokenConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Threading_Tasks_Task_Delay_4")]
	internal static void* /* System.Threading.Tasks.Task */ System_Threading_Tasks_Task_Delay_4(int /* System.Int32 */ millisecondsDelay, void** /* System.Exception */ __outException)
	{
	
	    try {
			System.Threading.Tasks.Task __returnValue = System.Threading.Tasks.Task.Delay(millisecondsDelay);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Threading_Tasks_Task_Delay_5")]
	internal static void* /* System.Threading.Tasks.Task */ System_Threading_Tasks_Task_Delay_5(int /* System.Int32 */ millisecondsDelay, void* /* System.Threading.CancellationToken */ cancellationToken, void** /* System.Exception */ __outException)
	{
		System.Threading.CancellationToken cancellationTokenConverted = InteropUtils.GetInstance<System.Threading.CancellationToken>(cancellationToken);
	
	    try {
			System.Threading.Tasks.Task __returnValue = System.Threading.Tasks.Task.Delay(millisecondsDelay, cancellationTokenConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Threading_Tasks_Task_WhenAll")]
	internal static void* /* System.Threading.Tasks.Task */ System_Threading_Tasks_Task_WhenAll(void* /* System.Threading.Tasks.Task[] */ tasks, void** /* System.Exception */ __outException)
	{
		System.Threading.Tasks.Task[] tasksConverted = InteropUtils.GetInstance<System.Threading.Tasks.Task[]>(tasks);
	
	    try {
			System.Threading.Tasks.Task __returnValue = System.Threading.Tasks.Task.WhenAll(tasksConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Threading_Tasks_Task_Create")]
	internal static void* /* System.Threading.Tasks.Task */ System_Threading_Tasks_Task_Create(void* /* System.Action */ action, void** /* System.Exception */ __outException)
	{
		System.Action actionConverted = InteropUtils.GetInstance<System_Action>(action)?.Trampoline;
	
	    try {
			System.Threading.Tasks.Task __returnValue = new System.Threading.Tasks.Task(actionConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Threading_Tasks_Task_Create_1")]
	internal static void* /* System.Threading.Tasks.Task */ System_Threading_Tasks_Task_Create_1(void* /* System.Action */ action, void* /* System.Threading.CancellationToken */ cancellationToken, void** /* System.Exception */ __outException)
	{
		System.Action actionConverted = InteropUtils.GetInstance<System_Action>(action)?.Trampoline;
		System.Threading.CancellationToken cancellationTokenConverted = InteropUtils.GetInstance<System.Threading.CancellationToken>(cancellationToken);
	
	    try {
			System.Threading.Tasks.Task __returnValue = new System.Threading.Tasks.Task(actionConverted, cancellationTokenConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Threading_Tasks_Task_Create_2")]
	internal static void* /* System.Threading.Tasks.Task */ System_Threading_Tasks_Task_Create_2(void* /* System.Action */ action, System.Threading.Tasks.TaskCreationOptions /* System.Threading.Tasks.TaskCreationOptions */ creationOptions, void** /* System.Exception */ __outException)
	{
		System.Action actionConverted = InteropUtils.GetInstance<System_Action>(action)?.Trampoline;
	
	    try {
			System.Threading.Tasks.Task __returnValue = new System.Threading.Tasks.Task(actionConverted, creationOptions);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Threading_Tasks_Task_Create_3")]
	internal static void* /* System.Threading.Tasks.Task */ System_Threading_Tasks_Task_Create_3(void* /* System.Action */ action, void* /* System.Threading.CancellationToken */ cancellationToken, System.Threading.Tasks.TaskCreationOptions /* System.Threading.Tasks.TaskCreationOptions */ creationOptions, void** /* System.Exception */ __outException)
	{
		System.Action actionConverted = InteropUtils.GetInstance<System_Action>(action)?.Trampoline;
		System.Threading.CancellationToken cancellationTokenConverted = InteropUtils.GetInstance<System.Threading.CancellationToken>(cancellationToken);
	
	    try {
			System.Threading.Tasks.Task __returnValue = new System.Threading.Tasks.Task(actionConverted, cancellationTokenConverted, creationOptions);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Threading_Tasks_Task_Id_Get")]
	internal static int /* System.Int32 */ System_Threading_Tasks_Task_Id_Get(void* /* System.Threading.Tasks.Task */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Threading.Tasks.Task __selfConverted = InteropUtils.GetInstance<System.Threading.Tasks.Task>(__self);
	
	
	    try {
			System.Int32 __returnValue = __selfConverted.Id;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Threading_Tasks_Task_Exception_Get")]
	internal static void* /* System.AggregateException */ System_Threading_Tasks_Task_Exception_Get(void* /* System.Threading.Tasks.Task */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Threading.Tasks.Task __selfConverted = InteropUtils.GetInstance<System.Threading.Tasks.Task>(__self);
	
	
	    try {
			System.AggregateException __returnValue = __selfConverted.Exception;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Threading_Tasks_Task_Status_Get")]
	internal static System.Threading.Tasks.TaskStatus /* System.Threading.Tasks.TaskStatus */ System_Threading_Tasks_Task_Status_Get(void* /* System.Threading.Tasks.Task */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Threading.Tasks.Task __selfConverted = InteropUtils.GetInstance<System.Threading.Tasks.Task>(__self);
	
	
	    try {
			System.Threading.Tasks.TaskStatus __returnValue = __selfConverted.Status;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return default(System.Threading.Tasks.TaskStatus);
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Threading_Tasks_Task_IsCanceled_Get")]
	internal static byte /* System.Boolean */ System_Threading_Tasks_Task_IsCanceled_Get(void* /* System.Threading.Tasks.Task */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Threading.Tasks.Task __selfConverted = InteropUtils.GetInstance<System.Threading.Tasks.Task>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.IsCanceled;
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Threading_Tasks_Task_IsCompleted_Get")]
	internal static byte /* System.Boolean */ System_Threading_Tasks_Task_IsCompleted_Get(void* /* System.Threading.Tasks.Task */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Threading.Tasks.Task __selfConverted = InteropUtils.GetInstance<System.Threading.Tasks.Task>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.IsCompleted;
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Threading_Tasks_Task_IsCompletedSuccessfully_Get")]
	internal static byte /* System.Boolean */ System_Threading_Tasks_Task_IsCompletedSuccessfully_Get(void* /* System.Threading.Tasks.Task */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Threading.Tasks.Task __selfConverted = InteropUtils.GetInstance<System.Threading.Tasks.Task>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.IsCompletedSuccessfully;
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Threading_Tasks_Task_CreationOptions_Get")]
	internal static System.Threading.Tasks.TaskCreationOptions /* System.Threading.Tasks.TaskCreationOptions */ System_Threading_Tasks_Task_CreationOptions_Get(void* /* System.Threading.Tasks.Task */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Threading.Tasks.Task __selfConverted = InteropUtils.GetInstance<System.Threading.Tasks.Task>(__self);
	
	
	    try {
			System.Threading.Tasks.TaskCreationOptions __returnValue = __selfConverted.CreationOptions;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return default(System.Threading.Tasks.TaskCreationOptions);
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Threading_Tasks_Task_AsyncState_Get")]
	internal static void* /* System.Object */ System_Threading_Tasks_Task_AsyncState_Get(void* /* System.Threading.Tasks.Task */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Threading.Tasks.Task __selfConverted = InteropUtils.GetInstance<System.Threading.Tasks.Task>(__self);
	
	
	    try {
			System.Object __returnValue = __selfConverted.AsyncState;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Threading_Tasks_Task_Factory_Get")]
	internal static void* /* System.Threading.Tasks.TaskFactory */ System_Threading_Tasks_Task_Factory_Get(void** /* System.Exception */ __outException)
	{
	
	    try {
			System.Threading.Tasks.TaskFactory __returnValue = System.Threading.Tasks.Task.Factory;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Threading_Tasks_Task_CompletedTask_Get")]
	internal static void* /* System.Threading.Tasks.Task */ System_Threading_Tasks_Task_CompletedTask_Get(void** /* System.Exception */ __outException)
	{
	
	    try {
			System.Threading.Tasks.Task __returnValue = System.Threading.Tasks.Task.CompletedTask;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Threading_Tasks_Task_IsFaulted_Get")]
	internal static byte /* System.Boolean */ System_Threading_Tasks_Task_IsFaulted_Get(void* /* System.Threading.Tasks.Task */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Threading.Tasks.Task __selfConverted = InteropUtils.GetInstance<System.Threading.Tasks.Task>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.IsFaulted;
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Threading_Tasks_Task_TypeOf")]
	internal static void* /* System.Type */ System_Threading_Tasks_Task_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.Threading.Tasks.Task);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Threading_Tasks_Task_Destroy")]
	internal static void /* System.Void */ System_Threading_Tasks_Task_Destroy(void* /* System.Threading.Tasks.Task */ __self)
	{
	
		InteropUtils.FreeIfAllocated(__self);
	}
	
}


internal unsafe class System_IAsyncResult
{
	[UnmanagedCallersOnly(EntryPoint = "System_IAsyncResult_IsCompleted_Get")]
	internal static byte /* System.Boolean */ System_IAsyncResult_IsCompleted_Get(void* /* System.IAsyncResult */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.IAsyncResult __selfConverted = InteropUtils.GetInstance<System.IAsyncResult>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.IsCompleted;
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_IAsyncResult_AsyncWaitHandle_Get")]
	internal static void* /* System.Threading.WaitHandle */ System_IAsyncResult_AsyncWaitHandle_Get(void* /* System.IAsyncResult */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.IAsyncResult __selfConverted = InteropUtils.GetInstance<System.IAsyncResult>(__self);
	
	
	    try {
			System.Threading.WaitHandle __returnValue = __selfConverted.AsyncWaitHandle;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_IAsyncResult_AsyncState_Get")]
	internal static void* /* System.Object */ System_IAsyncResult_AsyncState_Get(void* /* System.IAsyncResult */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.IAsyncResult __selfConverted = InteropUtils.GetInstance<System.IAsyncResult>(__self);
	
	
	    try {
			System.Object __returnValue = __selfConverted.AsyncState;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_IAsyncResult_CompletedSynchronously_Get")]
	internal static byte /* System.Boolean */ System_IAsyncResult_CompletedSynchronously_Get(void* /* System.IAsyncResult */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.IAsyncResult __selfConverted = InteropUtils.GetInstance<System.IAsyncResult>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.CompletedSynchronously;
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_IAsyncResult_TypeOf")]
	internal static void* /* System.Type */ System_IAsyncResult_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.IAsyncResult);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_IAsyncResult_Destroy")]
	internal static void /* System.Void */ System_IAsyncResult_Destroy(void* /* System.IAsyncResult */ __self)
	{
	
		InteropUtils.FreeIfAllocated(__self);
	}
	
}


internal unsafe class System_Threading_Tasks_TaskScheduler
{
	[UnmanagedCallersOnly(EntryPoint = "System_Threading_Tasks_TaskScheduler_FromCurrentSynchronizationContext")]
	internal static void* /* System.Threading.Tasks.TaskScheduler */ System_Threading_Tasks_TaskScheduler_FromCurrentSynchronizationContext(void** /* System.Exception */ __outException)
	{
	
	    try {
			System.Threading.Tasks.TaskScheduler __returnValue = System.Threading.Tasks.TaskScheduler.FromCurrentSynchronizationContext();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Threading_Tasks_TaskScheduler_MaximumConcurrencyLevel_Get")]
	internal static int /* System.Int32 */ System_Threading_Tasks_TaskScheduler_MaximumConcurrencyLevel_Get(void* /* System.Threading.Tasks.TaskScheduler */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Threading.Tasks.TaskScheduler __selfConverted = InteropUtils.GetInstance<System.Threading.Tasks.TaskScheduler>(__self);
	
	
	    try {
			System.Int32 __returnValue = __selfConverted.MaximumConcurrencyLevel;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Threading_Tasks_TaskScheduler_Default_Get")]
	internal static void* /* System.Threading.Tasks.TaskScheduler */ System_Threading_Tasks_TaskScheduler_Default_Get(void** /* System.Exception */ __outException)
	{
	
	    try {
			System.Threading.Tasks.TaskScheduler __returnValue = System.Threading.Tasks.TaskScheduler.Default;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Threading_Tasks_TaskScheduler_Current_Get")]
	internal static void* /* System.Threading.Tasks.TaskScheduler */ System_Threading_Tasks_TaskScheduler_Current_Get(void** /* System.Exception */ __outException)
	{
	
	    try {
			System.Threading.Tasks.TaskScheduler __returnValue = System.Threading.Tasks.TaskScheduler.Current;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Threading_Tasks_TaskScheduler_Id_Get")]
	internal static int /* System.Int32 */ System_Threading_Tasks_TaskScheduler_Id_Get(void* /* System.Threading.Tasks.TaskScheduler */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Threading.Tasks.TaskScheduler __selfConverted = InteropUtils.GetInstance<System.Threading.Tasks.TaskScheduler>(__self);
	
	
	    try {
			System.Int32 __returnValue = __selfConverted.Id;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Threading_Tasks_TaskScheduler_TypeOf")]
	internal static void* /* System.Type */ System_Threading_Tasks_TaskScheduler_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.Threading.Tasks.TaskScheduler);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Threading_Tasks_TaskScheduler_Destroy")]
	internal static void /* System.Void */ System_Threading_Tasks_TaskScheduler_Destroy(void* /* System.Threading.Tasks.TaskScheduler */ __self)
	{
	
		InteropUtils.FreeIfAllocated(__self);
	}
	
}


internal unsafe class System_AggregateException
{
	[UnmanagedCallersOnly(EntryPoint = "System_AggregateException_GetObjectData")]
	internal static void /* System.Void */ System_AggregateException_GetObjectData(void* /* System.AggregateException */ __self, void* /* System.Runtime.Serialization.SerializationInfo */ info, void* /* System.Runtime.Serialization.StreamingContext */ context, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.AggregateException __selfConverted = InteropUtils.GetInstance<System.AggregateException>(__self);
	
		System.Runtime.Serialization.SerializationInfo infoConverted = InteropUtils.GetInstance<System.Runtime.Serialization.SerializationInfo>(info);
		System.Runtime.Serialization.StreamingContext contextConverted = InteropUtils.GetInstance<System.Runtime.Serialization.StreamingContext>(context);
	
	    try {
			__selfConverted.GetObjectData(infoConverted, contextConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_AggregateException_GetBaseException")]
	internal static void* /* System.Exception */ System_AggregateException_GetBaseException(void* /* System.AggregateException */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.AggregateException __selfConverted = InteropUtils.GetInstance<System.AggregateException>(__self);
	
	
	    try {
			System.Exception __returnValue = __selfConverted.GetBaseException();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_AggregateException_Flatten")]
	internal static void* /* System.AggregateException */ System_AggregateException_Flatten(void* /* System.AggregateException */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.AggregateException __selfConverted = InteropUtils.GetInstance<System.AggregateException>(__self);
	
	
	    try {
			System.AggregateException __returnValue = __selfConverted.Flatten();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_AggregateException_ToString")]
	internal static void* /* System.String */ System_AggregateException_ToString(void* /* System.AggregateException */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.AggregateException __selfConverted = InteropUtils.GetInstance<System.AggregateException>(__self);
	
	
	    try {
			System.String __returnValue = __selfConverted.ToString();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_AggregateException_Create")]
	internal static void* /* System.AggregateException */ System_AggregateException_Create(void** /* System.Exception */ __outException)
	{
	
	    try {
			System.AggregateException __returnValue = new System.AggregateException();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_AggregateException_Create_1")]
	internal static void* /* System.AggregateException */ System_AggregateException_Create_1(void* /* System.String */ message, void** /* System.Exception */ __outException)
	{
		System.String messageConverted = InteropUtils.GetInstance<System.String>(message);
	
	    try {
			System.AggregateException __returnValue = new System.AggregateException(messageConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_AggregateException_Create_2")]
	internal static void* /* System.AggregateException */ System_AggregateException_Create_2(void* /* System.String */ message, void* /* System.Exception */ innerException, void** /* System.Exception */ __outException)
	{
		System.String messageConverted = InteropUtils.GetInstance<System.String>(message);
		System.Exception innerExceptionConverted = InteropUtils.GetInstance<System.Exception>(innerException);
	
	    try {
			System.AggregateException __returnValue = new System.AggregateException(messageConverted, innerExceptionConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_AggregateException_Create_3")]
	internal static void* /* System.AggregateException */ System_AggregateException_Create_3(void* /* System.Exception[] */ innerExceptions, void** /* System.Exception */ __outException)
	{
		System.Exception[] innerExceptionsConverted = InteropUtils.GetInstance<System.Exception[]>(innerExceptions);
	
	    try {
			System.AggregateException __returnValue = new System.AggregateException(innerExceptionsConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_AggregateException_Create_4")]
	internal static void* /* System.AggregateException */ System_AggregateException_Create_4(void* /* System.String */ message, void* /* System.Exception[] */ innerExceptions, void** /* System.Exception */ __outException)
	{
		System.String messageConverted = InteropUtils.GetInstance<System.String>(message);
		System.Exception[] innerExceptionsConverted = InteropUtils.GetInstance<System.Exception[]>(innerExceptions);
	
	    try {
			System.AggregateException __returnValue = new System.AggregateException(messageConverted, innerExceptionsConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_AggregateException_Message_Get")]
	internal static void* /* System.String */ System_AggregateException_Message_Get(void* /* System.AggregateException */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.AggregateException __selfConverted = InteropUtils.GetInstance<System.AggregateException>(__self);
	
	
	    try {
			System.String __returnValue = __selfConverted.Message;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_AggregateException_TypeOf")]
	internal static void* /* System.Type */ System_AggregateException_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.AggregateException);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_AggregateException_Destroy")]
	internal static void /* System.Void */ System_AggregateException_Destroy(void* /* System.AggregateException */ __self)
	{
	
		InteropUtils.FreeIfAllocated(__self);
	}
	
}




internal unsafe class System_Threading_Tasks_TaskStatus
{
	[UnmanagedCallersOnly(EntryPoint = "System_Threading_Tasks_TaskStatus_TypeOf")]
	internal static void* /* System.Type */ System_Threading_Tasks_TaskStatus_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.Threading.Tasks.TaskStatus);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
}


internal unsafe class System_Threading_Tasks_TaskCreationOptions
{
	[UnmanagedCallersOnly(EntryPoint = "System_Threading_Tasks_TaskCreationOptions_TypeOf")]
	internal static void* /* System.Type */ System_Threading_Tasks_TaskCreationOptions_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.Threading.Tasks.TaskCreationOptions);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
}


internal unsafe class System_Threading_Tasks_TaskFactory
{
	[UnmanagedCallersOnly(EntryPoint = "System_Threading_Tasks_TaskFactory_StartNew")]
	internal static void* /* System.Threading.Tasks.Task */ System_Threading_Tasks_TaskFactory_StartNew(void* /* System.Threading.Tasks.TaskFactory */ __self, void* /* System.Action */ action, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Threading.Tasks.TaskFactory __selfConverted = InteropUtils.GetInstance<System.Threading.Tasks.TaskFactory>(__self);
	
		System.Action actionConverted = InteropUtils.GetInstance<System_Action>(action)?.Trampoline;
	
	    try {
			System.Threading.Tasks.Task __returnValue = __selfConverted.StartNew(actionConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Threading_Tasks_TaskFactory_StartNew_1")]
	internal static void* /* System.Threading.Tasks.Task */ System_Threading_Tasks_TaskFactory_StartNew_1(void* /* System.Threading.Tasks.TaskFactory */ __self, void* /* System.Action */ action, void* /* System.Threading.CancellationToken */ cancellationToken, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Threading.Tasks.TaskFactory __selfConverted = InteropUtils.GetInstance<System.Threading.Tasks.TaskFactory>(__self);
	
		System.Action actionConverted = InteropUtils.GetInstance<System_Action>(action)?.Trampoline;
		System.Threading.CancellationToken cancellationTokenConverted = InteropUtils.GetInstance<System.Threading.CancellationToken>(cancellationToken);
	
	    try {
			System.Threading.Tasks.Task __returnValue = __selfConverted.StartNew(actionConverted, cancellationTokenConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Threading_Tasks_TaskFactory_StartNew_2")]
	internal static void* /* System.Threading.Tasks.Task */ System_Threading_Tasks_TaskFactory_StartNew_2(void* /* System.Threading.Tasks.TaskFactory */ __self, void* /* System.Action */ action, System.Threading.Tasks.TaskCreationOptions /* System.Threading.Tasks.TaskCreationOptions */ creationOptions, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Threading.Tasks.TaskFactory __selfConverted = InteropUtils.GetInstance<System.Threading.Tasks.TaskFactory>(__self);
	
		System.Action actionConverted = InteropUtils.GetInstance<System_Action>(action)?.Trampoline;
	
	    try {
			System.Threading.Tasks.Task __returnValue = __selfConverted.StartNew(actionConverted, creationOptions);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Threading_Tasks_TaskFactory_StartNew_3")]
	internal static void* /* System.Threading.Tasks.Task */ System_Threading_Tasks_TaskFactory_StartNew_3(void* /* System.Threading.Tasks.TaskFactory */ __self, void* /* System.Action */ action, void* /* System.Threading.CancellationToken */ cancellationToken, System.Threading.Tasks.TaskCreationOptions /* System.Threading.Tasks.TaskCreationOptions */ creationOptions, void* /* System.Threading.Tasks.TaskScheduler */ scheduler, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Threading.Tasks.TaskFactory __selfConverted = InteropUtils.GetInstance<System.Threading.Tasks.TaskFactory>(__self);
	
		System.Action actionConverted = InteropUtils.GetInstance<System_Action>(action)?.Trampoline;
		System.Threading.CancellationToken cancellationTokenConverted = InteropUtils.GetInstance<System.Threading.CancellationToken>(cancellationToken);
		System.Threading.Tasks.TaskScheduler schedulerConverted = InteropUtils.GetInstance<System.Threading.Tasks.TaskScheduler>(scheduler);
	
	    try {
			System.Threading.Tasks.Task __returnValue = __selfConverted.StartNew(actionConverted, cancellationTokenConverted, creationOptions, schedulerConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Threading_Tasks_TaskFactory_Create")]
	internal static void* /* System.Threading.Tasks.TaskFactory */ System_Threading_Tasks_TaskFactory_Create(void** /* System.Exception */ __outException)
	{
	
	    try {
			System.Threading.Tasks.TaskFactory __returnValue = new System.Threading.Tasks.TaskFactory();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Threading_Tasks_TaskFactory_Create_1")]
	internal static void* /* System.Threading.Tasks.TaskFactory */ System_Threading_Tasks_TaskFactory_Create_1(void* /* System.Threading.CancellationToken */ cancellationToken, void** /* System.Exception */ __outException)
	{
		System.Threading.CancellationToken cancellationTokenConverted = InteropUtils.GetInstance<System.Threading.CancellationToken>(cancellationToken);
	
	    try {
			System.Threading.Tasks.TaskFactory __returnValue = new System.Threading.Tasks.TaskFactory(cancellationTokenConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Threading_Tasks_TaskFactory_Create_2")]
	internal static void* /* System.Threading.Tasks.TaskFactory */ System_Threading_Tasks_TaskFactory_Create_2(void* /* System.Threading.Tasks.TaskScheduler */ scheduler, void** /* System.Exception */ __outException)
	{
		System.Threading.Tasks.TaskScheduler schedulerConverted = InteropUtils.GetInstance<System.Threading.Tasks.TaskScheduler>(scheduler);
	
	    try {
			System.Threading.Tasks.TaskFactory __returnValue = new System.Threading.Tasks.TaskFactory(schedulerConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Threading_Tasks_TaskFactory_Create_3")]
	internal static void* /* System.Threading.Tasks.TaskFactory */ System_Threading_Tasks_TaskFactory_Create_3(System.Threading.Tasks.TaskCreationOptions /* System.Threading.Tasks.TaskCreationOptions */ creationOptions, System.Threading.Tasks.TaskContinuationOptions /* System.Threading.Tasks.TaskContinuationOptions */ continuationOptions, void** /* System.Exception */ __outException)
	{
	
	    try {
			System.Threading.Tasks.TaskFactory __returnValue = new System.Threading.Tasks.TaskFactory(creationOptions, continuationOptions);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Threading_Tasks_TaskFactory_Create_4")]
	internal static void* /* System.Threading.Tasks.TaskFactory */ System_Threading_Tasks_TaskFactory_Create_4(void* /* System.Threading.CancellationToken */ cancellationToken, System.Threading.Tasks.TaskCreationOptions /* System.Threading.Tasks.TaskCreationOptions */ creationOptions, System.Threading.Tasks.TaskContinuationOptions /* System.Threading.Tasks.TaskContinuationOptions */ continuationOptions, void* /* System.Threading.Tasks.TaskScheduler */ scheduler, void** /* System.Exception */ __outException)
	{
		System.Threading.CancellationToken cancellationTokenConverted = InteropUtils.GetInstance<System.Threading.CancellationToken>(cancellationToken);
		System.Threading.Tasks.TaskScheduler schedulerConverted = InteropUtils.GetInstance<System.Threading.Tasks.TaskScheduler>(scheduler);
	
	    try {
			System.Threading.Tasks.TaskFactory __returnValue = new System.Threading.Tasks.TaskFactory(cancellationTokenConverted, creationOptions, continuationOptions, schedulerConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Threading_Tasks_TaskFactory_CancellationToken_Get")]
	internal static void* /* System.Threading.CancellationToken */ System_Threading_Tasks_TaskFactory_CancellationToken_Get(void* /* System.Threading.Tasks.TaskFactory */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Threading.Tasks.TaskFactory __selfConverted = InteropUtils.GetInstance<System.Threading.Tasks.TaskFactory>(__self);
	
	
	    try {
			System.Threading.CancellationToken __returnValue = __selfConverted.CancellationToken;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Threading_Tasks_TaskFactory_Scheduler_Get")]
	internal static void* /* System.Threading.Tasks.TaskScheduler */ System_Threading_Tasks_TaskFactory_Scheduler_Get(void* /* System.Threading.Tasks.TaskFactory */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Threading.Tasks.TaskFactory __selfConverted = InteropUtils.GetInstance<System.Threading.Tasks.TaskFactory>(__self);
	
	
	    try {
			System.Threading.Tasks.TaskScheduler __returnValue = __selfConverted.Scheduler;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Threading_Tasks_TaskFactory_CreationOptions_Get")]
	internal static System.Threading.Tasks.TaskCreationOptions /* System.Threading.Tasks.TaskCreationOptions */ System_Threading_Tasks_TaskFactory_CreationOptions_Get(void* /* System.Threading.Tasks.TaskFactory */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Threading.Tasks.TaskFactory __selfConverted = InteropUtils.GetInstance<System.Threading.Tasks.TaskFactory>(__self);
	
	
	    try {
			System.Threading.Tasks.TaskCreationOptions __returnValue = __selfConverted.CreationOptions;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return default(System.Threading.Tasks.TaskCreationOptions);
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Threading_Tasks_TaskFactory_ContinuationOptions_Get")]
	internal static System.Threading.Tasks.TaskContinuationOptions /* System.Threading.Tasks.TaskContinuationOptions */ System_Threading_Tasks_TaskFactory_ContinuationOptions_Get(void* /* System.Threading.Tasks.TaskFactory */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Threading.Tasks.TaskFactory __selfConverted = InteropUtils.GetInstance<System.Threading.Tasks.TaskFactory>(__self);
	
	
	    try {
			System.Threading.Tasks.TaskContinuationOptions __returnValue = __selfConverted.ContinuationOptions;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return default(System.Threading.Tasks.TaskContinuationOptions);
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Threading_Tasks_TaskFactory_TypeOf")]
	internal static void* /* System.Type */ System_Threading_Tasks_TaskFactory_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.Threading.Tasks.TaskFactory);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Threading_Tasks_TaskFactory_Destroy")]
	internal static void /* System.Void */ System_Threading_Tasks_TaskFactory_Destroy(void* /* System.Threading.Tasks.TaskFactory */ __self)
	{
	
		InteropUtils.FreeIfAllocated(__self);
	}
	
}


internal unsafe class System_Threading_Tasks_TaskContinuationOptions
{
	[UnmanagedCallersOnly(EntryPoint = "System_Threading_Tasks_TaskContinuationOptions_TypeOf")]
	internal static void* /* System.Type */ System_Threading_Tasks_TaskContinuationOptions_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.Threading.Tasks.TaskContinuationOptions);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
}




internal unsafe class System_Runtime_CompilerServices_TaskAwaiter
{
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_CompilerServices_TaskAwaiter_OnCompleted")]
	internal static void /* System.Void */ System_Runtime_CompilerServices_TaskAwaiter_OnCompleted(void* /* System.Runtime.CompilerServices.TaskAwaiter */ __self, void* /* System.Action */ continuation, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Runtime.CompilerServices.TaskAwaiter __selfConverted = InteropUtils.GetInstance<System.Runtime.CompilerServices.TaskAwaiter>(__self);
	
		System.Action continuationConverted = InteropUtils.GetInstance<System_Action>(continuation)?.Trampoline;
	
	    try {
			__selfConverted.OnCompleted(continuationConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_CompilerServices_TaskAwaiter_UnsafeOnCompleted")]
	internal static void /* System.Void */ System_Runtime_CompilerServices_TaskAwaiter_UnsafeOnCompleted(void* /* System.Runtime.CompilerServices.TaskAwaiter */ __self, void* /* System.Action */ continuation, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Runtime.CompilerServices.TaskAwaiter __selfConverted = InteropUtils.GetInstance<System.Runtime.CompilerServices.TaskAwaiter>(__self);
	
		System.Action continuationConverted = InteropUtils.GetInstance<System_Action>(continuation)?.Trampoline;
	
	    try {
			__selfConverted.UnsafeOnCompleted(continuationConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_CompilerServices_TaskAwaiter_GetResult")]
	internal static void /* System.Void */ System_Runtime_CompilerServices_TaskAwaiter_GetResult(void* /* System.Runtime.CompilerServices.TaskAwaiter */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Runtime.CompilerServices.TaskAwaiter __selfConverted = InteropUtils.GetInstance<System.Runtime.CompilerServices.TaskAwaiter>(__self);
	
	
	    try {
			__selfConverted.GetResult();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_CompilerServices_TaskAwaiter_IsCompleted_Get")]
	internal static byte /* System.Boolean */ System_Runtime_CompilerServices_TaskAwaiter_IsCompleted_Get(void* /* System.Runtime.CompilerServices.TaskAwaiter */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Runtime.CompilerServices.TaskAwaiter __selfConverted = InteropUtils.GetInstance<System.Runtime.CompilerServices.TaskAwaiter>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.IsCompleted;
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_CompilerServices_TaskAwaiter_Create")]
	internal static void* /* System.Runtime.CompilerServices.TaskAwaiter */ System_Runtime_CompilerServices_TaskAwaiter_Create(void** /* System.Exception */ __outException)
	{
	
	    try {
			System.Runtime.CompilerServices.TaskAwaiter __returnValue = new System.Runtime.CompilerServices.TaskAwaiter();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_CompilerServices_TaskAwaiter_TypeOf")]
	internal static void* /* System.Type */ System_Runtime_CompilerServices_TaskAwaiter_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.Runtime.CompilerServices.TaskAwaiter);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_CompilerServices_TaskAwaiter_Destroy")]
	internal static void /* System.Void */ System_Runtime_CompilerServices_TaskAwaiter_Destroy(void* /* System.Runtime.CompilerServices.TaskAwaiter */ __self)
	{
	
		InteropUtils.FreeIfAllocated(__self);
	}
	
}


internal unsafe class System_Runtime_CompilerServices_ICriticalNotifyCompletion
{
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_CompilerServices_ICriticalNotifyCompletion_UnsafeOnCompleted")]
	internal static void /* System.Void */ System_Runtime_CompilerServices_ICriticalNotifyCompletion_UnsafeOnCompleted(void* /* System.Runtime.CompilerServices.ICriticalNotifyCompletion */ __self, void* /* System.Action */ continuation, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Runtime.CompilerServices.ICriticalNotifyCompletion __selfConverted = InteropUtils.GetInstance<System.Runtime.CompilerServices.ICriticalNotifyCompletion>(__self);
	
		System.Action continuationConverted = InteropUtils.GetInstance<System_Action>(continuation)?.Trampoline;
	
	    try {
			__selfConverted.UnsafeOnCompleted(continuationConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_CompilerServices_ICriticalNotifyCompletion_TypeOf")]
	internal static void* /* System.Type */ System_Runtime_CompilerServices_ICriticalNotifyCompletion_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.Runtime.CompilerServices.ICriticalNotifyCompletion);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_CompilerServices_ICriticalNotifyCompletion_Destroy")]
	internal static void /* System.Void */ System_Runtime_CompilerServices_ICriticalNotifyCompletion_Destroy(void* /* System.Runtime.CompilerServices.ICriticalNotifyCompletion */ __self)
	{
	
		InteropUtils.FreeIfAllocated(__self);
	}
	
}


internal unsafe class System_Runtime_CompilerServices_INotifyCompletion
{
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_CompilerServices_INotifyCompletion_OnCompleted")]
	internal static void /* System.Void */ System_Runtime_CompilerServices_INotifyCompletion_OnCompleted(void* /* System.Runtime.CompilerServices.INotifyCompletion */ __self, void* /* System.Action */ continuation, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Runtime.CompilerServices.INotifyCompletion __selfConverted = InteropUtils.GetInstance<System.Runtime.CompilerServices.INotifyCompletion>(__self);
	
		System.Action continuationConverted = InteropUtils.GetInstance<System_Action>(continuation)?.Trampoline;
	
	    try {
			__selfConverted.OnCompleted(continuationConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_CompilerServices_INotifyCompletion_TypeOf")]
	internal static void* /* System.Type */ System_Runtime_CompilerServices_INotifyCompletion_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.Runtime.CompilerServices.INotifyCompletion);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_CompilerServices_INotifyCompletion_Destroy")]
	internal static void /* System.Void */ System_Runtime_CompilerServices_INotifyCompletion_Destroy(void* /* System.Runtime.CompilerServices.INotifyCompletion */ __self)
	{
	
		InteropUtils.FreeIfAllocated(__self);
	}
	
}


internal unsafe class System_Runtime_CompilerServices_ConfiguredTaskAwaitable
{
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_CompilerServices_ConfiguredTaskAwaitable_GetAwaiter")]
	internal static void* /* System.Runtime.CompilerServices.ConfiguredTaskAwaitable.ConfiguredTaskAwaiter */ System_Runtime_CompilerServices_ConfiguredTaskAwaitable_GetAwaiter(void* /* System.Runtime.CompilerServices.ConfiguredTaskAwaitable */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Runtime.CompilerServices.ConfiguredTaskAwaitable __selfConverted = InteropUtils.GetInstance<System.Runtime.CompilerServices.ConfiguredTaskAwaitable>(__self);
	
	
	    try {
			System.Runtime.CompilerServices.ConfiguredTaskAwaitable.ConfiguredTaskAwaiter __returnValue = __selfConverted.GetAwaiter();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_CompilerServices_ConfiguredTaskAwaitable_Create")]
	internal static void* /* System.Runtime.CompilerServices.ConfiguredTaskAwaitable */ System_Runtime_CompilerServices_ConfiguredTaskAwaitable_Create(void** /* System.Exception */ __outException)
	{
	
	    try {
			System.Runtime.CompilerServices.ConfiguredTaskAwaitable __returnValue = new System.Runtime.CompilerServices.ConfiguredTaskAwaitable();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_CompilerServices_ConfiguredTaskAwaitable_TypeOf")]
	internal static void* /* System.Type */ System_Runtime_CompilerServices_ConfiguredTaskAwaitable_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.Runtime.CompilerServices.ConfiguredTaskAwaitable);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_CompilerServices_ConfiguredTaskAwaitable_Destroy")]
	internal static void /* System.Void */ System_Runtime_CompilerServices_ConfiguredTaskAwaitable_Destroy(void* /* System.Runtime.CompilerServices.ConfiguredTaskAwaitable */ __self)
	{
	
		InteropUtils.FreeIfAllocated(__self);
	}
	
}


internal unsafe class System_Runtime_CompilerServices_ConfiguredTaskAwaitable_ConfiguredTaskAwaiter
{
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_CompilerServices_ConfiguredTaskAwaitable_ConfiguredTaskAwaiter_OnCompleted")]
	internal static void /* System.Void */ System_Runtime_CompilerServices_ConfiguredTaskAwaitable_ConfiguredTaskAwaiter_OnCompleted(void* /* System.Runtime.CompilerServices.ConfiguredTaskAwaitable.ConfiguredTaskAwaiter */ __self, void* /* System.Action */ continuation, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Runtime.CompilerServices.ConfiguredTaskAwaitable.ConfiguredTaskAwaiter __selfConverted = InteropUtils.GetInstance<System.Runtime.CompilerServices.ConfiguredTaskAwaitable.ConfiguredTaskAwaiter>(__self);
	
		System.Action continuationConverted = InteropUtils.GetInstance<System_Action>(continuation)?.Trampoline;
	
	    try {
			__selfConverted.OnCompleted(continuationConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_CompilerServices_ConfiguredTaskAwaitable_ConfiguredTaskAwaiter_UnsafeOnCompleted")]
	internal static void /* System.Void */ System_Runtime_CompilerServices_ConfiguredTaskAwaitable_ConfiguredTaskAwaiter_UnsafeOnCompleted(void* /* System.Runtime.CompilerServices.ConfiguredTaskAwaitable.ConfiguredTaskAwaiter */ __self, void* /* System.Action */ continuation, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Runtime.CompilerServices.ConfiguredTaskAwaitable.ConfiguredTaskAwaiter __selfConverted = InteropUtils.GetInstance<System.Runtime.CompilerServices.ConfiguredTaskAwaitable.ConfiguredTaskAwaiter>(__self);
	
		System.Action continuationConverted = InteropUtils.GetInstance<System_Action>(continuation)?.Trampoline;
	
	    try {
			__selfConverted.UnsafeOnCompleted(continuationConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_CompilerServices_ConfiguredTaskAwaitable_ConfiguredTaskAwaiter_GetResult")]
	internal static void /* System.Void */ System_Runtime_CompilerServices_ConfiguredTaskAwaitable_ConfiguredTaskAwaiter_GetResult(void* /* System.Runtime.CompilerServices.ConfiguredTaskAwaitable.ConfiguredTaskAwaiter */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Runtime.CompilerServices.ConfiguredTaskAwaitable.ConfiguredTaskAwaiter __selfConverted = InteropUtils.GetInstance<System.Runtime.CompilerServices.ConfiguredTaskAwaitable.ConfiguredTaskAwaiter>(__self);
	
	
	    try {
			__selfConverted.GetResult();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_CompilerServices_ConfiguredTaskAwaitable_ConfiguredTaskAwaiter_IsCompleted_Get")]
	internal static byte /* System.Boolean */ System_Runtime_CompilerServices_ConfiguredTaskAwaitable_ConfiguredTaskAwaiter_IsCompleted_Get(void* /* System.Runtime.CompilerServices.ConfiguredTaskAwaitable.ConfiguredTaskAwaiter */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Runtime.CompilerServices.ConfiguredTaskAwaitable.ConfiguredTaskAwaiter __selfConverted = InteropUtils.GetInstance<System.Runtime.CompilerServices.ConfiguredTaskAwaitable.ConfiguredTaskAwaiter>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.IsCompleted;
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_CompilerServices_ConfiguredTaskAwaitable_ConfiguredTaskAwaiter_Create")]
	internal static void* /* System.Runtime.CompilerServices.ConfiguredTaskAwaitable.ConfiguredTaskAwaiter */ System_Runtime_CompilerServices_ConfiguredTaskAwaitable_ConfiguredTaskAwaiter_Create(void** /* System.Exception */ __outException)
	{
	
	    try {
			System.Runtime.CompilerServices.ConfiguredTaskAwaitable.ConfiguredTaskAwaiter __returnValue = new System.Runtime.CompilerServices.ConfiguredTaskAwaitable.ConfiguredTaskAwaiter();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_CompilerServices_ConfiguredTaskAwaitable_ConfiguredTaskAwaiter_TypeOf")]
	internal static void* /* System.Type */ System_Runtime_CompilerServices_ConfiguredTaskAwaitable_ConfiguredTaskAwaiter_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.Runtime.CompilerServices.ConfiguredTaskAwaitable.ConfiguredTaskAwaiter);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_CompilerServices_ConfiguredTaskAwaitable_ConfiguredTaskAwaiter_Destroy")]
	internal static void /* System.Void */ System_Runtime_CompilerServices_ConfiguredTaskAwaitable_ConfiguredTaskAwaiter_Destroy(void* /* System.Runtime.CompilerServices.ConfiguredTaskAwaitable.ConfiguredTaskAwaiter */ __self)
	{
	
		InteropUtils.FreeIfAllocated(__self);
	}
	
}


internal unsafe class System_Threading_Tasks_ConfigureAwaitOptions
{
	[UnmanagedCallersOnly(EntryPoint = "System_Threading_Tasks_ConfigureAwaitOptions_TypeOf")]
	internal static void* /* System.Type */ System_Threading_Tasks_ConfigureAwaitOptions_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.Threading.Tasks.ConfigureAwaitOptions);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
}


internal unsafe class System_Runtime_CompilerServices_YieldAwaitable
{
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_CompilerServices_YieldAwaitable_GetAwaiter")]
	internal static void* /* System.Runtime.CompilerServices.YieldAwaitable.YieldAwaiter */ System_Runtime_CompilerServices_YieldAwaitable_GetAwaiter(void* /* System.Runtime.CompilerServices.YieldAwaitable */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Runtime.CompilerServices.YieldAwaitable __selfConverted = InteropUtils.GetInstance<System.Runtime.CompilerServices.YieldAwaitable>(__self);
	
	
	    try {
			System.Runtime.CompilerServices.YieldAwaitable.YieldAwaiter __returnValue = __selfConverted.GetAwaiter();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_CompilerServices_YieldAwaitable_Create")]
	internal static void* /* System.Runtime.CompilerServices.YieldAwaitable */ System_Runtime_CompilerServices_YieldAwaitable_Create(void** /* System.Exception */ __outException)
	{
	
	    try {
			System.Runtime.CompilerServices.YieldAwaitable __returnValue = new System.Runtime.CompilerServices.YieldAwaitable();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_CompilerServices_YieldAwaitable_TypeOf")]
	internal static void* /* System.Type */ System_Runtime_CompilerServices_YieldAwaitable_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.Runtime.CompilerServices.YieldAwaitable);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_CompilerServices_YieldAwaitable_Destroy")]
	internal static void /* System.Void */ System_Runtime_CompilerServices_YieldAwaitable_Destroy(void* /* System.Runtime.CompilerServices.YieldAwaitable */ __self)
	{
	
		InteropUtils.FreeIfAllocated(__self);
	}
	
}


internal unsafe class System_Runtime_CompilerServices_YieldAwaitable_YieldAwaiter
{
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_CompilerServices_YieldAwaitable_YieldAwaiter_OnCompleted")]
	internal static void /* System.Void */ System_Runtime_CompilerServices_YieldAwaitable_YieldAwaiter_OnCompleted(void* /* System.Runtime.CompilerServices.YieldAwaitable.YieldAwaiter */ __self, void* /* System.Action */ continuation, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Runtime.CompilerServices.YieldAwaitable.YieldAwaiter __selfConverted = InteropUtils.GetInstance<System.Runtime.CompilerServices.YieldAwaitable.YieldAwaiter>(__self);
	
		System.Action continuationConverted = InteropUtils.GetInstance<System_Action>(continuation)?.Trampoline;
	
	    try {
			__selfConverted.OnCompleted(continuationConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_CompilerServices_YieldAwaitable_YieldAwaiter_UnsafeOnCompleted")]
	internal static void /* System.Void */ System_Runtime_CompilerServices_YieldAwaitable_YieldAwaiter_UnsafeOnCompleted(void* /* System.Runtime.CompilerServices.YieldAwaitable.YieldAwaiter */ __self, void* /* System.Action */ continuation, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Runtime.CompilerServices.YieldAwaitable.YieldAwaiter __selfConverted = InteropUtils.GetInstance<System.Runtime.CompilerServices.YieldAwaitable.YieldAwaiter>(__self);
	
		System.Action continuationConverted = InteropUtils.GetInstance<System_Action>(continuation)?.Trampoline;
	
	    try {
			__selfConverted.UnsafeOnCompleted(continuationConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_CompilerServices_YieldAwaitable_YieldAwaiter_GetResult")]
	internal static void /* System.Void */ System_Runtime_CompilerServices_YieldAwaitable_YieldAwaiter_GetResult(void* /* System.Runtime.CompilerServices.YieldAwaitable.YieldAwaiter */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Runtime.CompilerServices.YieldAwaitable.YieldAwaiter __selfConverted = InteropUtils.GetInstance<System.Runtime.CompilerServices.YieldAwaitable.YieldAwaiter>(__self);
	
	
	    try {
			__selfConverted.GetResult();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_CompilerServices_YieldAwaitable_YieldAwaiter_IsCompleted_Get")]
	internal static byte /* System.Boolean */ System_Runtime_CompilerServices_YieldAwaitable_YieldAwaiter_IsCompleted_Get(void* /* System.Runtime.CompilerServices.YieldAwaitable.YieldAwaiter */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Runtime.CompilerServices.YieldAwaitable.YieldAwaiter __selfConverted = InteropUtils.GetInstance<System.Runtime.CompilerServices.YieldAwaitable.YieldAwaiter>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.IsCompleted;
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_CompilerServices_YieldAwaitable_YieldAwaiter_Create")]
	internal static void* /* System.Runtime.CompilerServices.YieldAwaitable.YieldAwaiter */ System_Runtime_CompilerServices_YieldAwaitable_YieldAwaiter_Create(void** /* System.Exception */ __outException)
	{
	
	    try {
			System.Runtime.CompilerServices.YieldAwaitable.YieldAwaiter __returnValue = new System.Runtime.CompilerServices.YieldAwaitable.YieldAwaiter();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_CompilerServices_YieldAwaitable_YieldAwaiter_TypeOf")]
	internal static void* /* System.Type */ System_Runtime_CompilerServices_YieldAwaitable_YieldAwaiter_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.Runtime.CompilerServices.YieldAwaitable.YieldAwaiter);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_CompilerServices_YieldAwaitable_YieldAwaiter_Destroy")]
	internal static void /* System.Void */ System_Runtime_CompilerServices_YieldAwaitable_YieldAwaiter_Destroy(void* /* System.Runtime.CompilerServices.YieldAwaitable.YieldAwaiter */ __self)
	{
	
		InteropUtils.FreeIfAllocated(__self);
	}
	
}


internal unsafe class System_TimeProvider
{
	[UnmanagedCallersOnly(EntryPoint = "System_TimeProvider_GetUtcNow")]
	internal static void* /* System.DateTimeOffset */ System_TimeProvider_GetUtcNow(void* /* System.TimeProvider */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.TimeProvider __selfConverted = InteropUtils.GetInstance<System.TimeProvider>(__self);
	
	
	    try {
			System.DateTimeOffset __returnValue = __selfConverted.GetUtcNow();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeProvider_GetLocalNow")]
	internal static void* /* System.DateTimeOffset */ System_TimeProvider_GetLocalNow(void* /* System.TimeProvider */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.TimeProvider __selfConverted = InteropUtils.GetInstance<System.TimeProvider>(__self);
	
	
	    try {
			System.DateTimeOffset __returnValue = __selfConverted.GetLocalNow();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeProvider_GetTimestamp")]
	internal static long /* System.Int64 */ System_TimeProvider_GetTimestamp(void* /* System.TimeProvider */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.TimeProvider __selfConverted = InteropUtils.GetInstance<System.TimeProvider>(__self);
	
	
	    try {
			System.Int64 __returnValue = __selfConverted.GetTimestamp();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeProvider_GetElapsedTime")]
	internal static void* /* System.TimeSpan */ System_TimeProvider_GetElapsedTime(void* /* System.TimeProvider */ __self, long /* System.Int64 */ startingTimestamp, long /* System.Int64 */ endingTimestamp, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.TimeProvider __selfConverted = InteropUtils.GetInstance<System.TimeProvider>(__self);
	
	
	    try {
			System.TimeSpan __returnValue = __selfConverted.GetElapsedTime(startingTimestamp, endingTimestamp);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeProvider_GetElapsedTime_1")]
	internal static void* /* System.TimeSpan */ System_TimeProvider_GetElapsedTime_1(void* /* System.TimeProvider */ __self, long /* System.Int64 */ startingTimestamp, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.TimeProvider __selfConverted = InteropUtils.GetInstance<System.TimeProvider>(__self);
	
	
	    try {
			System.TimeSpan __returnValue = __selfConverted.GetElapsedTime(startingTimestamp);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeProvider_CreateTimer")]
	internal static void* /* System.Threading.ITimer */ System_TimeProvider_CreateTimer(void* /* System.TimeProvider */ __self, void* /* System.Threading.TimerCallback */ callback, void* /* System.Object */ state, void* /* System.TimeSpan */ dueTime, void* /* System.TimeSpan */ period, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.TimeProvider __selfConverted = InteropUtils.GetInstance<System.TimeProvider>(__self);
	
		System.Threading.TimerCallback callbackConverted = InteropUtils.GetInstance<System_Threading_TimerCallback>(callback)?.Trampoline;
		System.Object stateConverted = InteropUtils.GetInstance<System.Object>(state);
		System.TimeSpan dueTimeConverted = InteropUtils.GetInstance<System.TimeSpan>(dueTime);
		System.TimeSpan periodConverted = InteropUtils.GetInstance<System.TimeSpan>(period);
	
	    try {
			System.Threading.ITimer __returnValue = __selfConverted.CreateTimer(callbackConverted, stateConverted, dueTimeConverted, periodConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeProvider_System_Get")]
	internal static void* /* System.TimeProvider */ System_TimeProvider_System_Get(void** /* System.Exception */ __outException)
	{
	
	    try {
			System.TimeProvider __returnValue = System.TimeProvider.System;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeProvider_LocalTimeZone_Get")]
	internal static void* /* System.TimeZoneInfo */ System_TimeProvider_LocalTimeZone_Get(void* /* System.TimeProvider */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.TimeProvider __selfConverted = InteropUtils.GetInstance<System.TimeProvider>(__self);
	
	
	    try {
			System.TimeZoneInfo __returnValue = __selfConverted.LocalTimeZone;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeProvider_TimestampFrequency_Get")]
	internal static long /* System.Int64 */ System_TimeProvider_TimestampFrequency_Get(void* /* System.TimeProvider */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.TimeProvider __selfConverted = InteropUtils.GetInstance<System.TimeProvider>(__self);
	
	
	    try {
			System.Int64 __returnValue = __selfConverted.TimestampFrequency;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeProvider_TypeOf")]
	internal static void* /* System.Type */ System_TimeProvider_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.TimeProvider);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeProvider_Destroy")]
	internal static void /* System.Void */ System_TimeProvider_Destroy(void* /* System.TimeProvider */ __self)
	{
	
		InteropUtils.FreeIfAllocated(__self);
	}
	
}


internal unsafe class System_DateTimeOffset
{
	[UnmanagedCallersOnly(EntryPoint = "System_DateTimeOffset_ToOffset")]
	internal static void* /* System.DateTimeOffset */ System_DateTimeOffset_ToOffset(void* /* System.DateTimeOffset */ __self, void* /* System.TimeSpan */ offset, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.DateTimeOffset __selfConverted = InteropUtils.GetInstance<System.DateTimeOffset>(__self);
	
		System.TimeSpan offsetConverted = InteropUtils.GetInstance<System.TimeSpan>(offset);
	
	    try {
			System.DateTimeOffset __returnValue = __selfConverted.ToOffset(offsetConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateTimeOffset_Add")]
	internal static void* /* System.DateTimeOffset */ System_DateTimeOffset_Add(void* /* System.DateTimeOffset */ __self, void* /* System.TimeSpan */ timeSpan, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.DateTimeOffset __selfConverted = InteropUtils.GetInstance<System.DateTimeOffset>(__self);
	
		System.TimeSpan timeSpanConverted = InteropUtils.GetInstance<System.TimeSpan>(timeSpan);
	
	    try {
			System.DateTimeOffset __returnValue = __selfConverted.Add(timeSpanConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateTimeOffset_AddDays")]
	internal static void* /* System.DateTimeOffset */ System_DateTimeOffset_AddDays(void* /* System.DateTimeOffset */ __self, double /* System.Double */ days, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.DateTimeOffset __selfConverted = InteropUtils.GetInstance<System.DateTimeOffset>(__self);
	
	
	    try {
			System.DateTimeOffset __returnValue = __selfConverted.AddDays(days);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateTimeOffset_AddHours")]
	internal static void* /* System.DateTimeOffset */ System_DateTimeOffset_AddHours(void* /* System.DateTimeOffset */ __self, double /* System.Double */ hours, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.DateTimeOffset __selfConverted = InteropUtils.GetInstance<System.DateTimeOffset>(__self);
	
	
	    try {
			System.DateTimeOffset __returnValue = __selfConverted.AddHours(hours);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateTimeOffset_AddMilliseconds")]
	internal static void* /* System.DateTimeOffset */ System_DateTimeOffset_AddMilliseconds(void* /* System.DateTimeOffset */ __self, double /* System.Double */ milliseconds, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.DateTimeOffset __selfConverted = InteropUtils.GetInstance<System.DateTimeOffset>(__self);
	
	
	    try {
			System.DateTimeOffset __returnValue = __selfConverted.AddMilliseconds(milliseconds);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateTimeOffset_AddMicroseconds")]
	internal static void* /* System.DateTimeOffset */ System_DateTimeOffset_AddMicroseconds(void* /* System.DateTimeOffset */ __self, double /* System.Double */ microseconds, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.DateTimeOffset __selfConverted = InteropUtils.GetInstance<System.DateTimeOffset>(__self);
	
	
	    try {
			System.DateTimeOffset __returnValue = __selfConverted.AddMicroseconds(microseconds);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateTimeOffset_AddMinutes")]
	internal static void* /* System.DateTimeOffset */ System_DateTimeOffset_AddMinutes(void* /* System.DateTimeOffset */ __self, double /* System.Double */ minutes, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.DateTimeOffset __selfConverted = InteropUtils.GetInstance<System.DateTimeOffset>(__self);
	
	
	    try {
			System.DateTimeOffset __returnValue = __selfConverted.AddMinutes(minutes);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateTimeOffset_AddMonths")]
	internal static void* /* System.DateTimeOffset */ System_DateTimeOffset_AddMonths(void* /* System.DateTimeOffset */ __self, int /* System.Int32 */ months, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.DateTimeOffset __selfConverted = InteropUtils.GetInstance<System.DateTimeOffset>(__self);
	
	
	    try {
			System.DateTimeOffset __returnValue = __selfConverted.AddMonths(months);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateTimeOffset_AddSeconds")]
	internal static void* /* System.DateTimeOffset */ System_DateTimeOffset_AddSeconds(void* /* System.DateTimeOffset */ __self, double /* System.Double */ seconds, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.DateTimeOffset __selfConverted = InteropUtils.GetInstance<System.DateTimeOffset>(__self);
	
	
	    try {
			System.DateTimeOffset __returnValue = __selfConverted.AddSeconds(seconds);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateTimeOffset_AddTicks")]
	internal static void* /* System.DateTimeOffset */ System_DateTimeOffset_AddTicks(void* /* System.DateTimeOffset */ __self, long /* System.Int64 */ ticks, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.DateTimeOffset __selfConverted = InteropUtils.GetInstance<System.DateTimeOffset>(__self);
	
	
	    try {
			System.DateTimeOffset __returnValue = __selfConverted.AddTicks(ticks);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateTimeOffset_AddYears")]
	internal static void* /* System.DateTimeOffset */ System_DateTimeOffset_AddYears(void* /* System.DateTimeOffset */ __self, int /* System.Int32 */ years, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.DateTimeOffset __selfConverted = InteropUtils.GetInstance<System.DateTimeOffset>(__self);
	
	
	    try {
			System.DateTimeOffset __returnValue = __selfConverted.AddYears(years);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateTimeOffset_Compare")]
	internal static int /* System.Int32 */ System_DateTimeOffset_Compare(void* /* System.DateTimeOffset */ first, void* /* System.DateTimeOffset */ second, void** /* System.Exception */ __outException)
	{
		System.DateTimeOffset firstConverted = InteropUtils.GetInstance<System.DateTimeOffset>(first);
		System.DateTimeOffset secondConverted = InteropUtils.GetInstance<System.DateTimeOffset>(second);
	
	    try {
			System.Int32 __returnValue = System.DateTimeOffset.Compare(firstConverted, secondConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateTimeOffset_CompareTo")]
	internal static int /* System.Int32 */ System_DateTimeOffset_CompareTo(void* /* System.DateTimeOffset */ __self, void* /* System.DateTimeOffset */ other, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.DateTimeOffset __selfConverted = InteropUtils.GetInstance<System.DateTimeOffset>(__self);
	
		System.DateTimeOffset otherConverted = InteropUtils.GetInstance<System.DateTimeOffset>(other);
	
	    try {
			System.Int32 __returnValue = __selfConverted.CompareTo(otherConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateTimeOffset_Equals")]
	internal static byte /* System.Boolean */ System_DateTimeOffset_Equals(void* /* System.DateTimeOffset */ __self, void* /* System.Object */ obj, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.DateTimeOffset __selfConverted = InteropUtils.GetInstance<System.DateTimeOffset>(__self);
	
		System.Object objConverted = InteropUtils.GetInstance<System.Object>(obj);
	
	    try {
			System.Boolean __returnValue = __selfConverted.Equals(objConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateTimeOffset_Equals_1")]
	internal static byte /* System.Boolean */ System_DateTimeOffset_Equals_1(void* /* System.DateTimeOffset */ __self, void* /* System.DateTimeOffset */ other, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.DateTimeOffset __selfConverted = InteropUtils.GetInstance<System.DateTimeOffset>(__self);
	
		System.DateTimeOffset otherConverted = InteropUtils.GetInstance<System.DateTimeOffset>(other);
	
	    try {
			System.Boolean __returnValue = __selfConverted.Equals(otherConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateTimeOffset_EqualsExact")]
	internal static byte /* System.Boolean */ System_DateTimeOffset_EqualsExact(void* /* System.DateTimeOffset */ __self, void* /* System.DateTimeOffset */ other, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.DateTimeOffset __selfConverted = InteropUtils.GetInstance<System.DateTimeOffset>(__self);
	
		System.DateTimeOffset otherConverted = InteropUtils.GetInstance<System.DateTimeOffset>(other);
	
	    try {
			System.Boolean __returnValue = __selfConverted.EqualsExact(otherConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateTimeOffset_Equals_2")]
	internal static byte /* System.Boolean */ System_DateTimeOffset_Equals_2(void* /* System.DateTimeOffset */ first, void* /* System.DateTimeOffset */ second, void** /* System.Exception */ __outException)
	{
		System.DateTimeOffset firstConverted = InteropUtils.GetInstance<System.DateTimeOffset>(first);
		System.DateTimeOffset secondConverted = InteropUtils.GetInstance<System.DateTimeOffset>(second);
	
	    try {
			System.Boolean __returnValue = System.DateTimeOffset.Equals(firstConverted, secondConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateTimeOffset_FromFileTime")]
	internal static void* /* System.DateTimeOffset */ System_DateTimeOffset_FromFileTime(long /* System.Int64 */ fileTime, void** /* System.Exception */ __outException)
	{
	
	    try {
			System.DateTimeOffset __returnValue = System.DateTimeOffset.FromFileTime(fileTime);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateTimeOffset_FromUnixTimeSeconds")]
	internal static void* /* System.DateTimeOffset */ System_DateTimeOffset_FromUnixTimeSeconds(long /* System.Int64 */ seconds, void** /* System.Exception */ __outException)
	{
	
	    try {
			System.DateTimeOffset __returnValue = System.DateTimeOffset.FromUnixTimeSeconds(seconds);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateTimeOffset_FromUnixTimeMilliseconds")]
	internal static void* /* System.DateTimeOffset */ System_DateTimeOffset_FromUnixTimeMilliseconds(long /* System.Int64 */ milliseconds, void** /* System.Exception */ __outException)
	{
	
	    try {
			System.DateTimeOffset __returnValue = System.DateTimeOffset.FromUnixTimeMilliseconds(milliseconds);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateTimeOffset_GetHashCode")]
	internal static int /* System.Int32 */ System_DateTimeOffset_GetHashCode(void* /* System.DateTimeOffset */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.DateTimeOffset __selfConverted = InteropUtils.GetInstance<System.DateTimeOffset>(__self);
	
	
	    try {
			System.Int32 __returnValue = __selfConverted.GetHashCode();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateTimeOffset_Parse")]
	internal static void* /* System.DateTimeOffset */ System_DateTimeOffset_Parse(void* /* System.String */ input, void** /* System.Exception */ __outException)
	{
		System.String inputConverted = InteropUtils.GetInstance<System.String>(input);
	
	    try {
			System.DateTimeOffset __returnValue = System.DateTimeOffset.Parse(inputConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateTimeOffset_Parse_1")]
	internal static void* /* System.DateTimeOffset */ System_DateTimeOffset_Parse_1(void* /* System.String */ input, void* /* System.IFormatProvider */ formatProvider, void** /* System.Exception */ __outException)
	{
		System.String inputConverted = InteropUtils.GetInstance<System.String>(input);
		System.IFormatProvider formatProviderConverted = InteropUtils.GetInstance<System.IFormatProvider>(formatProvider);
	
	    try {
			System.DateTimeOffset __returnValue = System.DateTimeOffset.Parse(inputConverted, formatProviderConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateTimeOffset_Parse_2")]
	internal static void* /* System.DateTimeOffset */ System_DateTimeOffset_Parse_2(void* /* System.String */ input, void* /* System.IFormatProvider */ formatProvider, System.Globalization.DateTimeStyles /* System.Globalization.DateTimeStyles */ styles, void** /* System.Exception */ __outException)
	{
		System.String inputConverted = InteropUtils.GetInstance<System.String>(input);
		System.IFormatProvider formatProviderConverted = InteropUtils.GetInstance<System.IFormatProvider>(formatProvider);
	
	    try {
			System.DateTimeOffset __returnValue = System.DateTimeOffset.Parse(inputConverted, formatProviderConverted, styles);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateTimeOffset_ParseExact")]
	internal static void* /* System.DateTimeOffset */ System_DateTimeOffset_ParseExact(void* /* System.String */ input, void* /* System.String */ format, void* /* System.IFormatProvider */ formatProvider, void** /* System.Exception */ __outException)
	{
		System.String inputConverted = InteropUtils.GetInstance<System.String>(input);
		System.String formatConverted = InteropUtils.GetInstance<System.String>(format);
		System.IFormatProvider formatProviderConverted = InteropUtils.GetInstance<System.IFormatProvider>(formatProvider);
	
	    try {
			System.DateTimeOffset __returnValue = System.DateTimeOffset.ParseExact(inputConverted, formatConverted, formatProviderConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateTimeOffset_ParseExact_1")]
	internal static void* /* System.DateTimeOffset */ System_DateTimeOffset_ParseExact_1(void* /* System.String */ input, void* /* System.String */ format, void* /* System.IFormatProvider */ formatProvider, System.Globalization.DateTimeStyles /* System.Globalization.DateTimeStyles */ styles, void** /* System.Exception */ __outException)
	{
		System.String inputConverted = InteropUtils.GetInstance<System.String>(input);
		System.String formatConverted = InteropUtils.GetInstance<System.String>(format);
		System.IFormatProvider formatProviderConverted = InteropUtils.GetInstance<System.IFormatProvider>(formatProvider);
	
	    try {
			System.DateTimeOffset __returnValue = System.DateTimeOffset.ParseExact(inputConverted, formatConverted, formatProviderConverted, styles);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateTimeOffset_ParseExact_2")]
	internal static void* /* System.DateTimeOffset */ System_DateTimeOffset_ParseExact_2(void* /* System.String */ input, void* /* System.String[] */ formats, void* /* System.IFormatProvider */ formatProvider, System.Globalization.DateTimeStyles /* System.Globalization.DateTimeStyles */ styles, void** /* System.Exception */ __outException)
	{
		System.String inputConverted = InteropUtils.GetInstance<System.String>(input);
		System.String[] formatsConverted = InteropUtils.GetInstance<System.String[]>(formats);
		System.IFormatProvider formatProviderConverted = InteropUtils.GetInstance<System.IFormatProvider>(formatProvider);
	
	    try {
			System.DateTimeOffset __returnValue = System.DateTimeOffset.ParseExact(inputConverted, formatsConverted, formatProviderConverted, styles);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateTimeOffset_Subtract")]
	internal static void* /* System.TimeSpan */ System_DateTimeOffset_Subtract(void* /* System.DateTimeOffset */ __self, void* /* System.DateTimeOffset */ value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.DateTimeOffset __selfConverted = InteropUtils.GetInstance<System.DateTimeOffset>(__self);
	
		System.DateTimeOffset valueConverted = InteropUtils.GetInstance<System.DateTimeOffset>(value);
	
	    try {
			System.TimeSpan __returnValue = __selfConverted.Subtract(valueConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateTimeOffset_Subtract_1")]
	internal static void* /* System.DateTimeOffset */ System_DateTimeOffset_Subtract_1(void* /* System.DateTimeOffset */ __self, void* /* System.TimeSpan */ value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.DateTimeOffset __selfConverted = InteropUtils.GetInstance<System.DateTimeOffset>(__self);
	
		System.TimeSpan valueConverted = InteropUtils.GetInstance<System.TimeSpan>(value);
	
	    try {
			System.DateTimeOffset __returnValue = __selfConverted.Subtract(valueConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateTimeOffset_ToFileTime")]
	internal static long /* System.Int64 */ System_DateTimeOffset_ToFileTime(void* /* System.DateTimeOffset */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.DateTimeOffset __selfConverted = InteropUtils.GetInstance<System.DateTimeOffset>(__self);
	
	
	    try {
			System.Int64 __returnValue = __selfConverted.ToFileTime();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateTimeOffset_ToUnixTimeSeconds")]
	internal static long /* System.Int64 */ System_DateTimeOffset_ToUnixTimeSeconds(void* /* System.DateTimeOffset */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.DateTimeOffset __selfConverted = InteropUtils.GetInstance<System.DateTimeOffset>(__self);
	
	
	    try {
			System.Int64 __returnValue = __selfConverted.ToUnixTimeSeconds();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateTimeOffset_ToUnixTimeMilliseconds")]
	internal static long /* System.Int64 */ System_DateTimeOffset_ToUnixTimeMilliseconds(void* /* System.DateTimeOffset */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.DateTimeOffset __selfConverted = InteropUtils.GetInstance<System.DateTimeOffset>(__self);
	
	
	    try {
			System.Int64 __returnValue = __selfConverted.ToUnixTimeMilliseconds();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateTimeOffset_ToLocalTime")]
	internal static void* /* System.DateTimeOffset */ System_DateTimeOffset_ToLocalTime(void* /* System.DateTimeOffset */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.DateTimeOffset __selfConverted = InteropUtils.GetInstance<System.DateTimeOffset>(__self);
	
	
	    try {
			System.DateTimeOffset __returnValue = __selfConverted.ToLocalTime();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateTimeOffset_ToString")]
	internal static void* /* System.String */ System_DateTimeOffset_ToString(void* /* System.DateTimeOffset */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.DateTimeOffset __selfConverted = InteropUtils.GetInstance<System.DateTimeOffset>(__self);
	
	
	    try {
			System.String __returnValue = __selfConverted.ToString();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateTimeOffset_ToString_1")]
	internal static void* /* System.String */ System_DateTimeOffset_ToString_1(void* /* System.DateTimeOffset */ __self, void* /* System.String */ format, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.DateTimeOffset __selfConverted = InteropUtils.GetInstance<System.DateTimeOffset>(__self);
	
		System.String formatConverted = InteropUtils.GetInstance<System.String>(format);
	
	    try {
			System.String __returnValue = __selfConverted.ToString(formatConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateTimeOffset_ToString_2")]
	internal static void* /* System.String */ System_DateTimeOffset_ToString_2(void* /* System.DateTimeOffset */ __self, void* /* System.IFormatProvider */ formatProvider, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.DateTimeOffset __selfConverted = InteropUtils.GetInstance<System.DateTimeOffset>(__self);
	
		System.IFormatProvider formatProviderConverted = InteropUtils.GetInstance<System.IFormatProvider>(formatProvider);
	
	    try {
			System.String __returnValue = __selfConverted.ToString(formatProviderConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateTimeOffset_ToString_3")]
	internal static void* /* System.String */ System_DateTimeOffset_ToString_3(void* /* System.DateTimeOffset */ __self, void* /* System.String */ format, void* /* System.IFormatProvider */ formatProvider, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.DateTimeOffset __selfConverted = InteropUtils.GetInstance<System.DateTimeOffset>(__self);
	
		System.String formatConverted = InteropUtils.GetInstance<System.String>(format);
		System.IFormatProvider formatProviderConverted = InteropUtils.GetInstance<System.IFormatProvider>(formatProvider);
	
	    try {
			System.String __returnValue = __selfConverted.ToString(formatConverted, formatProviderConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateTimeOffset_ToUniversalTime")]
	internal static void* /* System.DateTimeOffset */ System_DateTimeOffset_ToUniversalTime(void* /* System.DateTimeOffset */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.DateTimeOffset __selfConverted = InteropUtils.GetInstance<System.DateTimeOffset>(__self);
	
	
	    try {
			System.DateTimeOffset __returnValue = __selfConverted.ToUniversalTime();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateTimeOffset_TryParse")]
	internal static byte /* System.Boolean */ System_DateTimeOffset_TryParse(void* /* System.String */ input, void** /* System.DateTimeOffset */ result, void** /* System.Exception */ __outException)
	{
		System.String inputConverted = InteropUtils.GetInstance<System.String>(input);
		System.DateTimeOffset resultConverted;
	
	    try {
			System.Boolean __returnValue = System.DateTimeOffset.TryParse(inputConverted, out resultConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			if (result is not null) {
				*result = resultConverted.AllocateGCHandleAndGetAddress();
			}
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			if (result is not null) {
				*result = null;
			}
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateTimeOffset_TryParse_1")]
	internal static byte /* System.Boolean */ System_DateTimeOffset_TryParse_1(void* /* System.String */ input, void* /* System.IFormatProvider */ formatProvider, System.Globalization.DateTimeStyles /* System.Globalization.DateTimeStyles */ styles, void** /* System.DateTimeOffset */ result, void** /* System.Exception */ __outException)
	{
		System.String inputConverted = InteropUtils.GetInstance<System.String>(input);
		System.IFormatProvider formatProviderConverted = InteropUtils.GetInstance<System.IFormatProvider>(formatProvider);
		System.DateTimeOffset resultConverted;
	
	    try {
			System.Boolean __returnValue = System.DateTimeOffset.TryParse(inputConverted, formatProviderConverted, styles, out resultConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			if (result is not null) {
				*result = resultConverted.AllocateGCHandleAndGetAddress();
			}
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			if (result is not null) {
				*result = null;
			}
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateTimeOffset_TryParseExact")]
	internal static byte /* System.Boolean */ System_DateTimeOffset_TryParseExact(void* /* System.String */ input, void* /* System.String */ format, void* /* System.IFormatProvider */ formatProvider, System.Globalization.DateTimeStyles /* System.Globalization.DateTimeStyles */ styles, void** /* System.DateTimeOffset */ result, void** /* System.Exception */ __outException)
	{
		System.String inputConverted = InteropUtils.GetInstance<System.String>(input);
		System.String formatConverted = InteropUtils.GetInstance<System.String>(format);
		System.IFormatProvider formatProviderConverted = InteropUtils.GetInstance<System.IFormatProvider>(formatProvider);
		System.DateTimeOffset resultConverted;
	
	    try {
			System.Boolean __returnValue = System.DateTimeOffset.TryParseExact(inputConverted, formatConverted, formatProviderConverted, styles, out resultConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			if (result is not null) {
				*result = resultConverted.AllocateGCHandleAndGetAddress();
			}
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			if (result is not null) {
				*result = null;
			}
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateTimeOffset_TryParseExact_1")]
	internal static byte /* System.Boolean */ System_DateTimeOffset_TryParseExact_1(void* /* System.String */ input, void* /* System.String[] */ formats, void* /* System.IFormatProvider */ formatProvider, System.Globalization.DateTimeStyles /* System.Globalization.DateTimeStyles */ styles, void** /* System.DateTimeOffset */ result, void** /* System.Exception */ __outException)
	{
		System.String inputConverted = InteropUtils.GetInstance<System.String>(input);
		System.String[] formatsConverted = InteropUtils.GetInstance<System.String[]>(formats);
		System.IFormatProvider formatProviderConverted = InteropUtils.GetInstance<System.IFormatProvider>(formatProvider);
		System.DateTimeOffset resultConverted;
	
	    try {
			System.Boolean __returnValue = System.DateTimeOffset.TryParseExact(inputConverted, formatsConverted, formatProviderConverted, styles, out resultConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			if (result is not null) {
				*result = resultConverted.AllocateGCHandleAndGetAddress();
			}
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			if (result is not null) {
				*result = null;
			}
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateTimeOffset_Deconstruct")]
	internal static void /* System.Void */ System_DateTimeOffset_Deconstruct(void* /* System.DateTimeOffset */ __self, void** /* System.DateOnly */ date, void** /* System.TimeOnly */ time, void** /* System.TimeSpan */ offset, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.DateTimeOffset __selfConverted = InteropUtils.GetInstance<System.DateTimeOffset>(__self);
	
		System.DateOnly dateConverted;
		System.TimeOnly timeConverted;
		System.TimeSpan offsetConverted;
	
	    try {
			__selfConverted.Deconstruct(out dateConverted, out timeConverted, out offsetConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			if (date is not null) {
				*date = dateConverted.AllocateGCHandleAndGetAddress();
			}
	
			if (time is not null) {
				*time = timeConverted.AllocateGCHandleAndGetAddress();
			}
	
			if (offset is not null) {
				*offset = offsetConverted.AllocateGCHandleAndGetAddress();
			}
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			if (date is not null) {
				*date = null;
			}
	
			if (time is not null) {
				*time = null;
			}
	
			if (offset is not null) {
				*offset = null;
			}
	
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateTimeOffset_TryParse_2")]
	internal static byte /* System.Boolean */ System_DateTimeOffset_TryParse_2(void* /* System.String */ s, void* /* System.IFormatProvider */ provider, void** /* System.DateTimeOffset */ result, void** /* System.Exception */ __outException)
	{
		System.String sConverted = InteropUtils.GetInstance<System.String>(s);
		System.IFormatProvider providerConverted = InteropUtils.GetInstance<System.IFormatProvider>(provider);
		System.DateTimeOffset resultConverted;
	
	    try {
			System.Boolean __returnValue = System.DateTimeOffset.TryParse(sConverted, providerConverted, out resultConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			if (result is not null) {
				*result = resultConverted.AllocateGCHandleAndGetAddress();
			}
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			if (result is not null) {
				*result = null;
			}
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateTimeOffset_Create")]
	internal static void* /* System.DateTimeOffset */ System_DateTimeOffset_Create(long /* System.Int64 */ ticks, void* /* System.TimeSpan */ offset, void** /* System.Exception */ __outException)
	{
		System.TimeSpan offsetConverted = InteropUtils.GetInstance<System.TimeSpan>(offset);
	
	    try {
			System.DateTimeOffset __returnValue = new System.DateTimeOffset(ticks, offsetConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateTimeOffset_Create_1")]
	internal static void* /* System.DateTimeOffset */ System_DateTimeOffset_Create_1(void* /* System.DateTime */ dateTime, void** /* System.Exception */ __outException)
	{
		System.DateTime dateTimeConverted = InteropUtils.GetInstance<System.DateTime>(dateTime);
	
	    try {
			System.DateTimeOffset __returnValue = new System.DateTimeOffset(dateTimeConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateTimeOffset_Create_2")]
	internal static void* /* System.DateTimeOffset */ System_DateTimeOffset_Create_2(void* /* System.DateTime */ dateTime, void* /* System.TimeSpan */ offset, void** /* System.Exception */ __outException)
	{
		System.DateTime dateTimeConverted = InteropUtils.GetInstance<System.DateTime>(dateTime);
		System.TimeSpan offsetConverted = InteropUtils.GetInstance<System.TimeSpan>(offset);
	
	    try {
			System.DateTimeOffset __returnValue = new System.DateTimeOffset(dateTimeConverted, offsetConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateTimeOffset_Create_3")]
	internal static void* /* System.DateTimeOffset */ System_DateTimeOffset_Create_3(void* /* System.DateOnly */ date, void* /* System.TimeOnly */ time, void* /* System.TimeSpan */ offset, void** /* System.Exception */ __outException)
	{
		System.DateOnly dateConverted = InteropUtils.GetInstance<System.DateOnly>(date);
		System.TimeOnly timeConverted = InteropUtils.GetInstance<System.TimeOnly>(time);
		System.TimeSpan offsetConverted = InteropUtils.GetInstance<System.TimeSpan>(offset);
	
	    try {
			System.DateTimeOffset __returnValue = new System.DateTimeOffset(dateConverted, timeConverted, offsetConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateTimeOffset_Create_4")]
	internal static void* /* System.DateTimeOffset */ System_DateTimeOffset_Create_4(int /* System.Int32 */ year, int /* System.Int32 */ month, int /* System.Int32 */ day, int /* System.Int32 */ hour, int /* System.Int32 */ minute, int /* System.Int32 */ second, void* /* System.TimeSpan */ offset, void** /* System.Exception */ __outException)
	{
		System.TimeSpan offsetConverted = InteropUtils.GetInstance<System.TimeSpan>(offset);
	
	    try {
			System.DateTimeOffset __returnValue = new System.DateTimeOffset(year, month, day, hour, minute, second, offsetConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateTimeOffset_Create_5")]
	internal static void* /* System.DateTimeOffset */ System_DateTimeOffset_Create_5(int /* System.Int32 */ year, int /* System.Int32 */ month, int /* System.Int32 */ day, int /* System.Int32 */ hour, int /* System.Int32 */ minute, int /* System.Int32 */ second, int /* System.Int32 */ millisecond, void* /* System.TimeSpan */ offset, void** /* System.Exception */ __outException)
	{
		System.TimeSpan offsetConverted = InteropUtils.GetInstance<System.TimeSpan>(offset);
	
	    try {
			System.DateTimeOffset __returnValue = new System.DateTimeOffset(year, month, day, hour, minute, second, millisecond, offsetConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateTimeOffset_Create_6")]
	internal static void* /* System.DateTimeOffset */ System_DateTimeOffset_Create_6(int /* System.Int32 */ year, int /* System.Int32 */ month, int /* System.Int32 */ day, int /* System.Int32 */ hour, int /* System.Int32 */ minute, int /* System.Int32 */ second, int /* System.Int32 */ millisecond, void* /* System.Globalization.Calendar */ calendar, void* /* System.TimeSpan */ offset, void** /* System.Exception */ __outException)
	{
		System.Globalization.Calendar calendarConverted = InteropUtils.GetInstance<System.Globalization.Calendar>(calendar);
		System.TimeSpan offsetConverted = InteropUtils.GetInstance<System.TimeSpan>(offset);
	
	    try {
			System.DateTimeOffset __returnValue = new System.DateTimeOffset(year, month, day, hour, minute, second, millisecond, calendarConverted, offsetConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateTimeOffset_Create_7")]
	internal static void* /* System.DateTimeOffset */ System_DateTimeOffset_Create_7(int /* System.Int32 */ year, int /* System.Int32 */ month, int /* System.Int32 */ day, int /* System.Int32 */ hour, int /* System.Int32 */ minute, int /* System.Int32 */ second, int /* System.Int32 */ millisecond, int /* System.Int32 */ microsecond, void* /* System.TimeSpan */ offset, void** /* System.Exception */ __outException)
	{
		System.TimeSpan offsetConverted = InteropUtils.GetInstance<System.TimeSpan>(offset);
	
	    try {
			System.DateTimeOffset __returnValue = new System.DateTimeOffset(year, month, day, hour, minute, second, millisecond, microsecond, offsetConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateTimeOffset_Create_8")]
	internal static void* /* System.DateTimeOffset */ System_DateTimeOffset_Create_8(int /* System.Int32 */ year, int /* System.Int32 */ month, int /* System.Int32 */ day, int /* System.Int32 */ hour, int /* System.Int32 */ minute, int /* System.Int32 */ second, int /* System.Int32 */ millisecond, int /* System.Int32 */ microsecond, void* /* System.Globalization.Calendar */ calendar, void* /* System.TimeSpan */ offset, void** /* System.Exception */ __outException)
	{
		System.Globalization.Calendar calendarConverted = InteropUtils.GetInstance<System.Globalization.Calendar>(calendar);
		System.TimeSpan offsetConverted = InteropUtils.GetInstance<System.TimeSpan>(offset);
	
	    try {
			System.DateTimeOffset __returnValue = new System.DateTimeOffset(year, month, day, hour, minute, second, millisecond, microsecond, calendarConverted, offsetConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateTimeOffset_UtcNow_Get")]
	internal static void* /* System.DateTimeOffset */ System_DateTimeOffset_UtcNow_Get(void** /* System.Exception */ __outException)
	{
	
	    try {
			System.DateTimeOffset __returnValue = System.DateTimeOffset.UtcNow;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateTimeOffset_DateTime_Get")]
	internal static void* /* System.DateTime */ System_DateTimeOffset_DateTime_Get(void* /* System.DateTimeOffset */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.DateTimeOffset __selfConverted = InteropUtils.GetInstance<System.DateTimeOffset>(__self);
	
	
	    try {
			System.DateTime __returnValue = __selfConverted.DateTime;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateTimeOffset_UtcDateTime_Get")]
	internal static void* /* System.DateTime */ System_DateTimeOffset_UtcDateTime_Get(void* /* System.DateTimeOffset */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.DateTimeOffset __selfConverted = InteropUtils.GetInstance<System.DateTimeOffset>(__self);
	
	
	    try {
			System.DateTime __returnValue = __selfConverted.UtcDateTime;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateTimeOffset_LocalDateTime_Get")]
	internal static void* /* System.DateTime */ System_DateTimeOffset_LocalDateTime_Get(void* /* System.DateTimeOffset */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.DateTimeOffset __selfConverted = InteropUtils.GetInstance<System.DateTimeOffset>(__self);
	
	
	    try {
			System.DateTime __returnValue = __selfConverted.LocalDateTime;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateTimeOffset_Date_Get")]
	internal static void* /* System.DateTime */ System_DateTimeOffset_Date_Get(void* /* System.DateTimeOffset */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.DateTimeOffset __selfConverted = InteropUtils.GetInstance<System.DateTimeOffset>(__self);
	
	
	    try {
			System.DateTime __returnValue = __selfConverted.Date;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateTimeOffset_Day_Get")]
	internal static int /* System.Int32 */ System_DateTimeOffset_Day_Get(void* /* System.DateTimeOffset */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.DateTimeOffset __selfConverted = InteropUtils.GetInstance<System.DateTimeOffset>(__self);
	
	
	    try {
			System.Int32 __returnValue = __selfConverted.Day;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateTimeOffset_DayOfWeek_Get")]
	internal static System.DayOfWeek /* System.DayOfWeek */ System_DateTimeOffset_DayOfWeek_Get(void* /* System.DateTimeOffset */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.DateTimeOffset __selfConverted = InteropUtils.GetInstance<System.DateTimeOffset>(__self);
	
	
	    try {
			System.DayOfWeek __returnValue = __selfConverted.DayOfWeek;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return default(System.DayOfWeek);
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateTimeOffset_DayOfYear_Get")]
	internal static int /* System.Int32 */ System_DateTimeOffset_DayOfYear_Get(void* /* System.DateTimeOffset */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.DateTimeOffset __selfConverted = InteropUtils.GetInstance<System.DateTimeOffset>(__self);
	
	
	    try {
			System.Int32 __returnValue = __selfConverted.DayOfYear;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateTimeOffset_Hour_Get")]
	internal static int /* System.Int32 */ System_DateTimeOffset_Hour_Get(void* /* System.DateTimeOffset */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.DateTimeOffset __selfConverted = InteropUtils.GetInstance<System.DateTimeOffset>(__self);
	
	
	    try {
			System.Int32 __returnValue = __selfConverted.Hour;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateTimeOffset_Millisecond_Get")]
	internal static int /* System.Int32 */ System_DateTimeOffset_Millisecond_Get(void* /* System.DateTimeOffset */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.DateTimeOffset __selfConverted = InteropUtils.GetInstance<System.DateTimeOffset>(__self);
	
	
	    try {
			System.Int32 __returnValue = __selfConverted.Millisecond;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateTimeOffset_Microsecond_Get")]
	internal static int /* System.Int32 */ System_DateTimeOffset_Microsecond_Get(void* /* System.DateTimeOffset */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.DateTimeOffset __selfConverted = InteropUtils.GetInstance<System.DateTimeOffset>(__self);
	
	
	    try {
			System.Int32 __returnValue = __selfConverted.Microsecond;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateTimeOffset_Nanosecond_Get")]
	internal static int /* System.Int32 */ System_DateTimeOffset_Nanosecond_Get(void* /* System.DateTimeOffset */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.DateTimeOffset __selfConverted = InteropUtils.GetInstance<System.DateTimeOffset>(__self);
	
	
	    try {
			System.Int32 __returnValue = __selfConverted.Nanosecond;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateTimeOffset_Minute_Get")]
	internal static int /* System.Int32 */ System_DateTimeOffset_Minute_Get(void* /* System.DateTimeOffset */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.DateTimeOffset __selfConverted = InteropUtils.GetInstance<System.DateTimeOffset>(__self);
	
	
	    try {
			System.Int32 __returnValue = __selfConverted.Minute;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateTimeOffset_Month_Get")]
	internal static int /* System.Int32 */ System_DateTimeOffset_Month_Get(void* /* System.DateTimeOffset */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.DateTimeOffset __selfConverted = InteropUtils.GetInstance<System.DateTimeOffset>(__self);
	
	
	    try {
			System.Int32 __returnValue = __selfConverted.Month;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateTimeOffset_Offset_Get")]
	internal static void* /* System.TimeSpan */ System_DateTimeOffset_Offset_Get(void* /* System.DateTimeOffset */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.DateTimeOffset __selfConverted = InteropUtils.GetInstance<System.DateTimeOffset>(__self);
	
	
	    try {
			System.TimeSpan __returnValue = __selfConverted.Offset;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateTimeOffset_TotalOffsetMinutes_Get")]
	internal static int /* System.Int32 */ System_DateTimeOffset_TotalOffsetMinutes_Get(void* /* System.DateTimeOffset */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.DateTimeOffset __selfConverted = InteropUtils.GetInstance<System.DateTimeOffset>(__self);
	
	
	    try {
			System.Int32 __returnValue = __selfConverted.TotalOffsetMinutes;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateTimeOffset_Second_Get")]
	internal static int /* System.Int32 */ System_DateTimeOffset_Second_Get(void* /* System.DateTimeOffset */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.DateTimeOffset __selfConverted = InteropUtils.GetInstance<System.DateTimeOffset>(__self);
	
	
	    try {
			System.Int32 __returnValue = __selfConverted.Second;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateTimeOffset_Ticks_Get")]
	internal static long /* System.Int64 */ System_DateTimeOffset_Ticks_Get(void* /* System.DateTimeOffset */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.DateTimeOffset __selfConverted = InteropUtils.GetInstance<System.DateTimeOffset>(__self);
	
	
	    try {
			System.Int64 __returnValue = __selfConverted.Ticks;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateTimeOffset_UtcTicks_Get")]
	internal static long /* System.Int64 */ System_DateTimeOffset_UtcTicks_Get(void* /* System.DateTimeOffset */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.DateTimeOffset __selfConverted = InteropUtils.GetInstance<System.DateTimeOffset>(__self);
	
	
	    try {
			System.Int64 __returnValue = __selfConverted.UtcTicks;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateTimeOffset_TimeOfDay_Get")]
	internal static void* /* System.TimeSpan */ System_DateTimeOffset_TimeOfDay_Get(void* /* System.DateTimeOffset */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.DateTimeOffset __selfConverted = InteropUtils.GetInstance<System.DateTimeOffset>(__self);
	
	
	    try {
			System.TimeSpan __returnValue = __selfConverted.TimeOfDay;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateTimeOffset_Year_Get")]
	internal static int /* System.Int32 */ System_DateTimeOffset_Year_Get(void* /* System.DateTimeOffset */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.DateTimeOffset __selfConverted = InteropUtils.GetInstance<System.DateTimeOffset>(__self);
	
	
	    try {
			System.Int32 __returnValue = __selfConverted.Year;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateTimeOffset_Now_Get")]
	internal static void* /* System.DateTimeOffset */ System_DateTimeOffset_Now_Get(void** /* System.Exception */ __outException)
	{
	
	    try {
			System.DateTimeOffset __returnValue = System.DateTimeOffset.Now;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateTimeOffset_MinValue_Get")]
	internal static void* /* System.DateTimeOffset */ System_DateTimeOffset_MinValue_Get()
	{
	
		System.DateTimeOffset __returnValue = System.DateTimeOffset.MinValue;
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateTimeOffset_MaxValue_Get")]
	internal static void* /* System.DateTimeOffset */ System_DateTimeOffset_MaxValue_Get()
	{
	
		System.DateTimeOffset __returnValue = System.DateTimeOffset.MaxValue;
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateTimeOffset_UnixEpoch_Get")]
	internal static void* /* System.DateTimeOffset */ System_DateTimeOffset_UnixEpoch_Get()
	{
	
		System.DateTimeOffset __returnValue = System.DateTimeOffset.UnixEpoch;
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateTimeOffset_Create_9")]
	internal static void* /* System.DateTimeOffset */ System_DateTimeOffset_Create_9(void** /* System.Exception */ __outException)
	{
	
	    try {
			System.DateTimeOffset __returnValue = new System.DateTimeOffset();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateTimeOffset_TypeOf")]
	internal static void* /* System.Type */ System_DateTimeOffset_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.DateTimeOffset);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_DateTimeOffset_Destroy")]
	internal static void /* System.Void */ System_DateTimeOffset_Destroy(void* /* System.DateTimeOffset */ __self)
	{
	
		InteropUtils.FreeIfAllocated(__self);
	}
	
}



internal unsafe class System_TimeZoneInfo
{
	[UnmanagedCallersOnly(EntryPoint = "System_TimeZoneInfo_GetAmbiguousTimeOffsets")]
	internal static void* /* System.TimeSpan[] */ System_TimeZoneInfo_GetAmbiguousTimeOffsets(void* /* System.TimeZoneInfo */ __self, void* /* System.DateTimeOffset */ dateTimeOffset, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.TimeZoneInfo __selfConverted = InteropUtils.GetInstance<System.TimeZoneInfo>(__self);
	
		System.DateTimeOffset dateTimeOffsetConverted = InteropUtils.GetInstance<System.DateTimeOffset>(dateTimeOffset);
	
	    try {
			System.TimeSpan[] __returnValue = __selfConverted.GetAmbiguousTimeOffsets(dateTimeOffsetConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeZoneInfo_GetAmbiguousTimeOffsets_1")]
	internal static void* /* System.TimeSpan[] */ System_TimeZoneInfo_GetAmbiguousTimeOffsets_1(void* /* System.TimeZoneInfo */ __self, void* /* System.DateTime */ dateTime, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.TimeZoneInfo __selfConverted = InteropUtils.GetInstance<System.TimeZoneInfo>(__self);
	
		System.DateTime dateTimeConverted = InteropUtils.GetInstance<System.DateTime>(dateTime);
	
	    try {
			System.TimeSpan[] __returnValue = __selfConverted.GetAmbiguousTimeOffsets(dateTimeConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeZoneInfo_GetUtcOffset")]
	internal static void* /* System.TimeSpan */ System_TimeZoneInfo_GetUtcOffset(void* /* System.TimeZoneInfo */ __self, void* /* System.DateTimeOffset */ dateTimeOffset, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.TimeZoneInfo __selfConverted = InteropUtils.GetInstance<System.TimeZoneInfo>(__self);
	
		System.DateTimeOffset dateTimeOffsetConverted = InteropUtils.GetInstance<System.DateTimeOffset>(dateTimeOffset);
	
	    try {
			System.TimeSpan __returnValue = __selfConverted.GetUtcOffset(dateTimeOffsetConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeZoneInfo_GetUtcOffset_1")]
	internal static void* /* System.TimeSpan */ System_TimeZoneInfo_GetUtcOffset_1(void* /* System.TimeZoneInfo */ __self, void* /* System.DateTime */ dateTime, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.TimeZoneInfo __selfConverted = InteropUtils.GetInstance<System.TimeZoneInfo>(__self);
	
		System.DateTime dateTimeConverted = InteropUtils.GetInstance<System.DateTime>(dateTime);
	
	    try {
			System.TimeSpan __returnValue = __selfConverted.GetUtcOffset(dateTimeConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeZoneInfo_IsAmbiguousTime")]
	internal static byte /* System.Boolean */ System_TimeZoneInfo_IsAmbiguousTime(void* /* System.TimeZoneInfo */ __self, void* /* System.DateTimeOffset */ dateTimeOffset, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.TimeZoneInfo __selfConverted = InteropUtils.GetInstance<System.TimeZoneInfo>(__self);
	
		System.DateTimeOffset dateTimeOffsetConverted = InteropUtils.GetInstance<System.DateTimeOffset>(dateTimeOffset);
	
	    try {
			System.Boolean __returnValue = __selfConverted.IsAmbiguousTime(dateTimeOffsetConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeZoneInfo_IsAmbiguousTime_1")]
	internal static byte /* System.Boolean */ System_TimeZoneInfo_IsAmbiguousTime_1(void* /* System.TimeZoneInfo */ __self, void* /* System.DateTime */ dateTime, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.TimeZoneInfo __selfConverted = InteropUtils.GetInstance<System.TimeZoneInfo>(__self);
	
		System.DateTime dateTimeConverted = InteropUtils.GetInstance<System.DateTime>(dateTime);
	
	    try {
			System.Boolean __returnValue = __selfConverted.IsAmbiguousTime(dateTimeConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeZoneInfo_IsDaylightSavingTime")]
	internal static byte /* System.Boolean */ System_TimeZoneInfo_IsDaylightSavingTime(void* /* System.TimeZoneInfo */ __self, void* /* System.DateTimeOffset */ dateTimeOffset, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.TimeZoneInfo __selfConverted = InteropUtils.GetInstance<System.TimeZoneInfo>(__self);
	
		System.DateTimeOffset dateTimeOffsetConverted = InteropUtils.GetInstance<System.DateTimeOffset>(dateTimeOffset);
	
	    try {
			System.Boolean __returnValue = __selfConverted.IsDaylightSavingTime(dateTimeOffsetConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeZoneInfo_IsDaylightSavingTime_1")]
	internal static byte /* System.Boolean */ System_TimeZoneInfo_IsDaylightSavingTime_1(void* /* System.TimeZoneInfo */ __self, void* /* System.DateTime */ dateTime, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.TimeZoneInfo __selfConverted = InteropUtils.GetInstance<System.TimeZoneInfo>(__self);
	
		System.DateTime dateTimeConverted = InteropUtils.GetInstance<System.DateTime>(dateTime);
	
	    try {
			System.Boolean __returnValue = __selfConverted.IsDaylightSavingTime(dateTimeConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeZoneInfo_IsInvalidTime")]
	internal static byte /* System.Boolean */ System_TimeZoneInfo_IsInvalidTime(void* /* System.TimeZoneInfo */ __self, void* /* System.DateTime */ dateTime, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.TimeZoneInfo __selfConverted = InteropUtils.GetInstance<System.TimeZoneInfo>(__self);
	
		System.DateTime dateTimeConverted = InteropUtils.GetInstance<System.DateTime>(dateTime);
	
	    try {
			System.Boolean __returnValue = __selfConverted.IsInvalidTime(dateTimeConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeZoneInfo_ClearCachedData")]
	internal static void /* System.Void */ System_TimeZoneInfo_ClearCachedData(void** /* System.Exception */ __outException)
	{
	
	    try {
			System.TimeZoneInfo.ClearCachedData();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeZoneInfo_ConvertTimeBySystemTimeZoneId")]
	internal static void* /* System.DateTimeOffset */ System_TimeZoneInfo_ConvertTimeBySystemTimeZoneId(void* /* System.DateTimeOffset */ dateTimeOffset, void* /* System.String */ destinationTimeZoneId, void** /* System.Exception */ __outException)
	{
		System.DateTimeOffset dateTimeOffsetConverted = InteropUtils.GetInstance<System.DateTimeOffset>(dateTimeOffset);
		System.String destinationTimeZoneIdConverted = InteropUtils.GetInstance<System.String>(destinationTimeZoneId);
	
	    try {
			System.DateTimeOffset __returnValue = System.TimeZoneInfo.ConvertTimeBySystemTimeZoneId(dateTimeOffsetConverted, destinationTimeZoneIdConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeZoneInfo_ConvertTimeBySystemTimeZoneId_1")]
	internal static void* /* System.DateTime */ System_TimeZoneInfo_ConvertTimeBySystemTimeZoneId_1(void* /* System.DateTime */ dateTime, void* /* System.String */ destinationTimeZoneId, void** /* System.Exception */ __outException)
	{
		System.DateTime dateTimeConverted = InteropUtils.GetInstance<System.DateTime>(dateTime);
		System.String destinationTimeZoneIdConverted = InteropUtils.GetInstance<System.String>(destinationTimeZoneId);
	
	    try {
			System.DateTime __returnValue = System.TimeZoneInfo.ConvertTimeBySystemTimeZoneId(dateTimeConverted, destinationTimeZoneIdConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeZoneInfo_FindSystemTimeZoneById")]
	internal static void* /* System.TimeZoneInfo */ System_TimeZoneInfo_FindSystemTimeZoneById(void* /* System.String */ id, void** /* System.Exception */ __outException)
	{
		System.String idConverted = InteropUtils.GetInstance<System.String>(id);
	
	    try {
			System.TimeZoneInfo __returnValue = System.TimeZoneInfo.FindSystemTimeZoneById(idConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeZoneInfo_TryFindSystemTimeZoneById")]
	internal static byte /* System.Boolean */ System_TimeZoneInfo_TryFindSystemTimeZoneById(void* /* System.String */ id, void** /* System.TimeZoneInfo */ timeZoneInfo, void** /* System.Exception */ __outException)
	{
		System.String idConverted = InteropUtils.GetInstance<System.String>(id);
		System.TimeZoneInfo timeZoneInfoConverted;
	
	    try {
			System.Boolean __returnValue = System.TimeZoneInfo.TryFindSystemTimeZoneById(idConverted, out timeZoneInfoConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			if (timeZoneInfo is not null) {
				*timeZoneInfo = timeZoneInfoConverted.AllocateGCHandleAndGetAddress();
			}
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			if (timeZoneInfo is not null) {
				*timeZoneInfo = null;
			}
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeZoneInfo_ConvertTimeBySystemTimeZoneId_2")]
	internal static void* /* System.DateTime */ System_TimeZoneInfo_ConvertTimeBySystemTimeZoneId_2(void* /* System.DateTime */ dateTime, void* /* System.String */ sourceTimeZoneId, void* /* System.String */ destinationTimeZoneId, void** /* System.Exception */ __outException)
	{
		System.DateTime dateTimeConverted = InteropUtils.GetInstance<System.DateTime>(dateTime);
		System.String sourceTimeZoneIdConverted = InteropUtils.GetInstance<System.String>(sourceTimeZoneId);
		System.String destinationTimeZoneIdConverted = InteropUtils.GetInstance<System.String>(destinationTimeZoneId);
	
	    try {
			System.DateTime __returnValue = System.TimeZoneInfo.ConvertTimeBySystemTimeZoneId(dateTimeConverted, sourceTimeZoneIdConverted, destinationTimeZoneIdConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeZoneInfo_ConvertTime_1")]
	internal static void* /* System.DateTimeOffset */ System_TimeZoneInfo_ConvertTime_1(void* /* System.DateTimeOffset */ dateTimeOffset, void* /* System.TimeZoneInfo */ destinationTimeZone, void** /* System.Exception */ __outException)
	{
		System.DateTimeOffset dateTimeOffsetConverted = InteropUtils.GetInstance<System.DateTimeOffset>(dateTimeOffset);
		System.TimeZoneInfo destinationTimeZoneConverted = InteropUtils.GetInstance<System.TimeZoneInfo>(destinationTimeZone);
	
	    try {
			System.DateTimeOffset __returnValue = System.TimeZoneInfo.ConvertTime(dateTimeOffsetConverted, destinationTimeZoneConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeZoneInfo_ConvertTime_2")]
	internal static void* /* System.DateTime */ System_TimeZoneInfo_ConvertTime_2(void* /* System.DateTime */ dateTime, void* /* System.TimeZoneInfo */ destinationTimeZone, void** /* System.Exception */ __outException)
	{
		System.DateTime dateTimeConverted = InteropUtils.GetInstance<System.DateTime>(dateTime);
		System.TimeZoneInfo destinationTimeZoneConverted = InteropUtils.GetInstance<System.TimeZoneInfo>(destinationTimeZone);
	
	    try {
			System.DateTime __returnValue = System.TimeZoneInfo.ConvertTime(dateTimeConverted, destinationTimeZoneConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeZoneInfo_ConvertTime_3")]
	internal static void* /* System.DateTime */ System_TimeZoneInfo_ConvertTime_3(void* /* System.DateTime */ dateTime, void* /* System.TimeZoneInfo */ sourceTimeZone, void* /* System.TimeZoneInfo */ destinationTimeZone, void** /* System.Exception */ __outException)
	{
		System.DateTime dateTimeConverted = InteropUtils.GetInstance<System.DateTime>(dateTime);
		System.TimeZoneInfo sourceTimeZoneConverted = InteropUtils.GetInstance<System.TimeZoneInfo>(sourceTimeZone);
		System.TimeZoneInfo destinationTimeZoneConverted = InteropUtils.GetInstance<System.TimeZoneInfo>(destinationTimeZone);
	
	    try {
			System.DateTime __returnValue = System.TimeZoneInfo.ConvertTime(dateTimeConverted, sourceTimeZoneConverted, destinationTimeZoneConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeZoneInfo_ConvertTimeFromUtc")]
	internal static void* /* System.DateTime */ System_TimeZoneInfo_ConvertTimeFromUtc(void* /* System.DateTime */ dateTime, void* /* System.TimeZoneInfo */ destinationTimeZone, void** /* System.Exception */ __outException)
	{
		System.DateTime dateTimeConverted = InteropUtils.GetInstance<System.DateTime>(dateTime);
		System.TimeZoneInfo destinationTimeZoneConverted = InteropUtils.GetInstance<System.TimeZoneInfo>(destinationTimeZone);
	
	    try {
			System.DateTime __returnValue = System.TimeZoneInfo.ConvertTimeFromUtc(dateTimeConverted, destinationTimeZoneConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeZoneInfo_ConvertTimeToUtc")]
	internal static void* /* System.DateTime */ System_TimeZoneInfo_ConvertTimeToUtc(void* /* System.DateTime */ dateTime, void** /* System.Exception */ __outException)
	{
		System.DateTime dateTimeConverted = InteropUtils.GetInstance<System.DateTime>(dateTime);
	
	    try {
			System.DateTime __returnValue = System.TimeZoneInfo.ConvertTimeToUtc(dateTimeConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeZoneInfo_ConvertTimeToUtc_1")]
	internal static void* /* System.DateTime */ System_TimeZoneInfo_ConvertTimeToUtc_1(void* /* System.DateTime */ dateTime, void* /* System.TimeZoneInfo */ sourceTimeZone, void** /* System.Exception */ __outException)
	{
		System.DateTime dateTimeConverted = InteropUtils.GetInstance<System.DateTime>(dateTime);
		System.TimeZoneInfo sourceTimeZoneConverted = InteropUtils.GetInstance<System.TimeZoneInfo>(sourceTimeZone);
	
	    try {
			System.DateTime __returnValue = System.TimeZoneInfo.ConvertTimeToUtc(dateTimeConverted, sourceTimeZoneConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeZoneInfo_Equals")]
	internal static byte /* System.Boolean */ System_TimeZoneInfo_Equals(void* /* System.TimeZoneInfo */ __self, void* /* System.TimeZoneInfo */ other, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.TimeZoneInfo __selfConverted = InteropUtils.GetInstance<System.TimeZoneInfo>(__self);
	
		System.TimeZoneInfo otherConverted = InteropUtils.GetInstance<System.TimeZoneInfo>(other);
	
	    try {
			System.Boolean __returnValue = __selfConverted.Equals(otherConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeZoneInfo_Equals_1")]
	internal static byte /* System.Boolean */ System_TimeZoneInfo_Equals_1(void* /* System.TimeZoneInfo */ __self, void* /* System.Object */ obj, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.TimeZoneInfo __selfConverted = InteropUtils.GetInstance<System.TimeZoneInfo>(__self);
	
		System.Object objConverted = InteropUtils.GetInstance<System.Object>(obj);
	
	    try {
			System.Boolean __returnValue = __selfConverted.Equals(objConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeZoneInfo_FromSerializedString")]
	internal static void* /* System.TimeZoneInfo */ System_TimeZoneInfo_FromSerializedString(void* /* System.String */ source, void** /* System.Exception */ __outException)
	{
		System.String sourceConverted = InteropUtils.GetInstance<System.String>(source);
	
	    try {
			System.TimeZoneInfo __returnValue = System.TimeZoneInfo.FromSerializedString(sourceConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeZoneInfo_GetHashCode")]
	internal static int /* System.Int32 */ System_TimeZoneInfo_GetHashCode(void* /* System.TimeZoneInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.TimeZoneInfo __selfConverted = InteropUtils.GetInstance<System.TimeZoneInfo>(__self);
	
	
	    try {
			System.Int32 __returnValue = __selfConverted.GetHashCode();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeZoneInfo_HasSameRules")]
	internal static byte /* System.Boolean */ System_TimeZoneInfo_HasSameRules(void* /* System.TimeZoneInfo */ __self, void* /* System.TimeZoneInfo */ other, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.TimeZoneInfo __selfConverted = InteropUtils.GetInstance<System.TimeZoneInfo>(__self);
	
		System.TimeZoneInfo otherConverted = InteropUtils.GetInstance<System.TimeZoneInfo>(other);
	
	    try {
			System.Boolean __returnValue = __selfConverted.HasSameRules(otherConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeZoneInfo_ToSerializedString")]
	internal static void* /* System.String */ System_TimeZoneInfo_ToSerializedString(void* /* System.TimeZoneInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.TimeZoneInfo __selfConverted = InteropUtils.GetInstance<System.TimeZoneInfo>(__self);
	
	
	    try {
			System.String __returnValue = __selfConverted.ToSerializedString();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeZoneInfo_ToString")]
	internal static void* /* System.String */ System_TimeZoneInfo_ToString(void* /* System.TimeZoneInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.TimeZoneInfo __selfConverted = InteropUtils.GetInstance<System.TimeZoneInfo>(__self);
	
	
	    try {
			System.String __returnValue = __selfConverted.ToString();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeZoneInfo_CreateCustomTimeZone")]
	internal static void* /* System.TimeZoneInfo */ System_TimeZoneInfo_CreateCustomTimeZone(void* /* System.String */ id, void* /* System.TimeSpan */ baseUtcOffset, void* /* System.String */ displayName, void* /* System.String */ standardDisplayName, void** /* System.Exception */ __outException)
	{
		System.String idConverted = InteropUtils.GetInstance<System.String>(id);
		System.TimeSpan baseUtcOffsetConverted = InteropUtils.GetInstance<System.TimeSpan>(baseUtcOffset);
		System.String displayNameConverted = InteropUtils.GetInstance<System.String>(displayName);
		System.String standardDisplayNameConverted = InteropUtils.GetInstance<System.String>(standardDisplayName);
	
	    try {
			System.TimeZoneInfo __returnValue = System.TimeZoneInfo.CreateCustomTimeZone(idConverted, baseUtcOffsetConverted, displayNameConverted, standardDisplayNameConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeZoneInfo_CreateCustomTimeZone_1")]
	internal static void* /* System.TimeZoneInfo */ System_TimeZoneInfo_CreateCustomTimeZone_1(void* /* System.String */ id, void* /* System.TimeSpan */ baseUtcOffset, void* /* System.String */ displayName, void* /* System.String */ standardDisplayName, void* /* System.String */ daylightDisplayName, void* /* System.TimeZoneInfo.AdjustmentRule[] */ adjustmentRules, void** /* System.Exception */ __outException)
	{
		System.String idConverted = InteropUtils.GetInstance<System.String>(id);
		System.TimeSpan baseUtcOffsetConverted = InteropUtils.GetInstance<System.TimeSpan>(baseUtcOffset);
		System.String displayNameConverted = InteropUtils.GetInstance<System.String>(displayName);
		System.String standardDisplayNameConverted = InteropUtils.GetInstance<System.String>(standardDisplayName);
		System.String daylightDisplayNameConverted = InteropUtils.GetInstance<System.String>(daylightDisplayName);
		System.TimeZoneInfo.AdjustmentRule[] adjustmentRulesConverted = InteropUtils.GetInstance<System.TimeZoneInfo.AdjustmentRule[]>(adjustmentRules);
	
	    try {
			System.TimeZoneInfo __returnValue = System.TimeZoneInfo.CreateCustomTimeZone(idConverted, baseUtcOffsetConverted, displayNameConverted, standardDisplayNameConverted, daylightDisplayNameConverted, adjustmentRulesConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeZoneInfo_CreateCustomTimeZone_2")]
	internal static void* /* System.TimeZoneInfo */ System_TimeZoneInfo_CreateCustomTimeZone_2(void* /* System.String */ id, void* /* System.TimeSpan */ baseUtcOffset, void* /* System.String */ displayName, void* /* System.String */ standardDisplayName, void* /* System.String */ daylightDisplayName, void* /* System.TimeZoneInfo.AdjustmentRule[] */ adjustmentRules, byte /* System.Boolean */ disableDaylightSavingTime, void** /* System.Exception */ __outException)
	{
		System.String idConverted = InteropUtils.GetInstance<System.String>(id);
		System.TimeSpan baseUtcOffsetConverted = InteropUtils.GetInstance<System.TimeSpan>(baseUtcOffset);
		System.String displayNameConverted = InteropUtils.GetInstance<System.String>(displayName);
		System.String standardDisplayNameConverted = InteropUtils.GetInstance<System.String>(standardDisplayName);
		System.String daylightDisplayNameConverted = InteropUtils.GetInstance<System.String>(daylightDisplayName);
		System.TimeZoneInfo.AdjustmentRule[] adjustmentRulesConverted = InteropUtils.GetInstance<System.TimeZoneInfo.AdjustmentRule[]>(adjustmentRules);
		System.Boolean disableDaylightSavingTimeConverted = disableDaylightSavingTime.ToBool();
	
	    try {
			System.TimeZoneInfo __returnValue = System.TimeZoneInfo.CreateCustomTimeZone(idConverted, baseUtcOffsetConverted, displayNameConverted, standardDisplayNameConverted, daylightDisplayNameConverted, adjustmentRulesConverted, disableDaylightSavingTimeConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeZoneInfo_TryConvertIanaIdToWindowsId")]
	internal static byte /* System.Boolean */ System_TimeZoneInfo_TryConvertIanaIdToWindowsId(void* /* System.String */ ianaId, void** /* System.String */ windowsId, void** /* System.Exception */ __outException)
	{
		System.String ianaIdConverted = InteropUtils.GetInstance<System.String>(ianaId);
		System.String windowsIdConverted;
	
	    try {
			System.Boolean __returnValue = System.TimeZoneInfo.TryConvertIanaIdToWindowsId(ianaIdConverted, out windowsIdConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			if (windowsId is not null) {
				*windowsId = windowsIdConverted.AllocateGCHandleAndGetAddress();
			}
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			if (windowsId is not null) {
				*windowsId = null;
			}
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeZoneInfo_TryConvertWindowsIdToIanaId")]
	internal static byte /* System.Boolean */ System_TimeZoneInfo_TryConvertWindowsIdToIanaId(void* /* System.String */ windowsId, void** /* System.String */ ianaId, void** /* System.Exception */ __outException)
	{
		System.String windowsIdConverted = InteropUtils.GetInstance<System.String>(windowsId);
		System.String ianaIdConverted;
	
	    try {
			System.Boolean __returnValue = System.TimeZoneInfo.TryConvertWindowsIdToIanaId(windowsIdConverted, out ianaIdConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			if (ianaId is not null) {
				*ianaId = ianaIdConverted.AllocateGCHandleAndGetAddress();
			}
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			if (ianaId is not null) {
				*ianaId = null;
			}
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeZoneInfo_TryConvertWindowsIdToIanaId_1")]
	internal static byte /* System.Boolean */ System_TimeZoneInfo_TryConvertWindowsIdToIanaId_1(void* /* System.String */ windowsId, void* /* System.String */ region, void** /* System.String */ ianaId, void** /* System.Exception */ __outException)
	{
		System.String windowsIdConverted = InteropUtils.GetInstance<System.String>(windowsId);
		System.String regionConverted = InteropUtils.GetInstance<System.String>(region);
		System.String ianaIdConverted;
	
	    try {
			System.Boolean __returnValue = System.TimeZoneInfo.TryConvertWindowsIdToIanaId(windowsIdConverted, regionConverted, out ianaIdConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			if (ianaId is not null) {
				*ianaId = ianaIdConverted.AllocateGCHandleAndGetAddress();
			}
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			if (ianaId is not null) {
				*ianaId = null;
			}
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeZoneInfo_GetAdjustmentRules")]
	internal static void* /* System.TimeZoneInfo.AdjustmentRule[] */ System_TimeZoneInfo_GetAdjustmentRules(void* /* System.TimeZoneInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.TimeZoneInfo __selfConverted = InteropUtils.GetInstance<System.TimeZoneInfo>(__self);
	
	
	    try {
			System.TimeZoneInfo.AdjustmentRule[] __returnValue = __selfConverted.GetAdjustmentRules();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeZoneInfo_Id_Get")]
	internal static void* /* System.String */ System_TimeZoneInfo_Id_Get(void* /* System.TimeZoneInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.TimeZoneInfo __selfConverted = InteropUtils.GetInstance<System.TimeZoneInfo>(__self);
	
	
	    try {
			System.String __returnValue = __selfConverted.Id;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeZoneInfo_HasIanaId_Get")]
	internal static byte /* System.Boolean */ System_TimeZoneInfo_HasIanaId_Get(void* /* System.TimeZoneInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.TimeZoneInfo __selfConverted = InteropUtils.GetInstance<System.TimeZoneInfo>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.HasIanaId;
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeZoneInfo_DisplayName_Get")]
	internal static void* /* System.String */ System_TimeZoneInfo_DisplayName_Get(void* /* System.TimeZoneInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.TimeZoneInfo __selfConverted = InteropUtils.GetInstance<System.TimeZoneInfo>(__self);
	
	
	    try {
			System.String __returnValue = __selfConverted.DisplayName;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeZoneInfo_StandardName_Get")]
	internal static void* /* System.String */ System_TimeZoneInfo_StandardName_Get(void* /* System.TimeZoneInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.TimeZoneInfo __selfConverted = InteropUtils.GetInstance<System.TimeZoneInfo>(__self);
	
	
	    try {
			System.String __returnValue = __selfConverted.StandardName;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeZoneInfo_DaylightName_Get")]
	internal static void* /* System.String */ System_TimeZoneInfo_DaylightName_Get(void* /* System.TimeZoneInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.TimeZoneInfo __selfConverted = InteropUtils.GetInstance<System.TimeZoneInfo>(__self);
	
	
	    try {
			System.String __returnValue = __selfConverted.DaylightName;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeZoneInfo_BaseUtcOffset_Get")]
	internal static void* /* System.TimeSpan */ System_TimeZoneInfo_BaseUtcOffset_Get(void* /* System.TimeZoneInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.TimeZoneInfo __selfConverted = InteropUtils.GetInstance<System.TimeZoneInfo>(__self);
	
	
	    try {
			System.TimeSpan __returnValue = __selfConverted.BaseUtcOffset;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeZoneInfo_SupportsDaylightSavingTime_Get")]
	internal static byte /* System.Boolean */ System_TimeZoneInfo_SupportsDaylightSavingTime_Get(void* /* System.TimeZoneInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.TimeZoneInfo __selfConverted = InteropUtils.GetInstance<System.TimeZoneInfo>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.SupportsDaylightSavingTime;
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeZoneInfo_Local_Get")]
	internal static void* /* System.TimeZoneInfo */ System_TimeZoneInfo_Local_Get(void** /* System.Exception */ __outException)
	{
	
	    try {
			System.TimeZoneInfo __returnValue = System.TimeZoneInfo.Local;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeZoneInfo_Utc_Get")]
	internal static void* /* System.TimeZoneInfo */ System_TimeZoneInfo_Utc_Get(void** /* System.Exception */ __outException)
	{
	
	    try {
			System.TimeZoneInfo __returnValue = System.TimeZoneInfo.Utc;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeZoneInfo_TypeOf")]
	internal static void* /* System.Type */ System_TimeZoneInfo_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.TimeZoneInfo);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeZoneInfo_Destroy")]
	internal static void /* System.Void */ System_TimeZoneInfo_Destroy(void* /* System.TimeZoneInfo */ __self)
	{
	
		InteropUtils.FreeIfAllocated(__self);
	}
	
}





internal unsafe class System_TimeZoneInfo_AdjustmentRule
{
	[UnmanagedCallersOnly(EntryPoint = "System_TimeZoneInfo_AdjustmentRule_Equals")]
	internal static byte /* System.Boolean */ System_TimeZoneInfo_AdjustmentRule_Equals(void* /* System.TimeZoneInfo.AdjustmentRule */ __self, void* /* System.TimeZoneInfo.AdjustmentRule */ other, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.TimeZoneInfo.AdjustmentRule __selfConverted = InteropUtils.GetInstance<System.TimeZoneInfo.AdjustmentRule>(__self);
	
		System.TimeZoneInfo.AdjustmentRule otherConverted = InteropUtils.GetInstance<System.TimeZoneInfo.AdjustmentRule>(other);
	
	    try {
			System.Boolean __returnValue = __selfConverted.Equals(otherConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeZoneInfo_AdjustmentRule_Equals_1")]
	internal static byte /* System.Boolean */ System_TimeZoneInfo_AdjustmentRule_Equals_1(void* /* System.TimeZoneInfo.AdjustmentRule */ __self, void* /* System.Object */ obj, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.TimeZoneInfo.AdjustmentRule __selfConverted = InteropUtils.GetInstance<System.TimeZoneInfo.AdjustmentRule>(__self);
	
		System.Object objConverted = InteropUtils.GetInstance<System.Object>(obj);
	
	    try {
			System.Boolean __returnValue = __selfConverted.Equals(objConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeZoneInfo_AdjustmentRule_GetHashCode")]
	internal static int /* System.Int32 */ System_TimeZoneInfo_AdjustmentRule_GetHashCode(void* /* System.TimeZoneInfo.AdjustmentRule */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.TimeZoneInfo.AdjustmentRule __selfConverted = InteropUtils.GetInstance<System.TimeZoneInfo.AdjustmentRule>(__self);
	
	
	    try {
			System.Int32 __returnValue = __selfConverted.GetHashCode();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeZoneInfo_AdjustmentRule_CreateAdjustmentRule")]
	internal static void* /* System.TimeZoneInfo.AdjustmentRule */ System_TimeZoneInfo_AdjustmentRule_CreateAdjustmentRule(void* /* System.DateTime */ dateStart, void* /* System.DateTime */ dateEnd, void* /* System.TimeSpan */ daylightDelta, void* /* System.TimeZoneInfo.TransitionTime */ daylightTransitionStart, void* /* System.TimeZoneInfo.TransitionTime */ daylightTransitionEnd, void* /* System.TimeSpan */ baseUtcOffsetDelta, void** /* System.Exception */ __outException)
	{
		System.DateTime dateStartConverted = InteropUtils.GetInstance<System.DateTime>(dateStart);
		System.DateTime dateEndConverted = InteropUtils.GetInstance<System.DateTime>(dateEnd);
		System.TimeSpan daylightDeltaConverted = InteropUtils.GetInstance<System.TimeSpan>(daylightDelta);
		System.TimeZoneInfo.TransitionTime daylightTransitionStartConverted = InteropUtils.GetInstance<System.TimeZoneInfo.TransitionTime>(daylightTransitionStart);
		System.TimeZoneInfo.TransitionTime daylightTransitionEndConverted = InteropUtils.GetInstance<System.TimeZoneInfo.TransitionTime>(daylightTransitionEnd);
		System.TimeSpan baseUtcOffsetDeltaConverted = InteropUtils.GetInstance<System.TimeSpan>(baseUtcOffsetDelta);
	
	    try {
			System.TimeZoneInfo.AdjustmentRule __returnValue = System.TimeZoneInfo.AdjustmentRule.CreateAdjustmentRule(dateStartConverted, dateEndConverted, daylightDeltaConverted, daylightTransitionStartConverted, daylightTransitionEndConverted, baseUtcOffsetDeltaConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeZoneInfo_AdjustmentRule_CreateAdjustmentRule_1")]
	internal static void* /* System.TimeZoneInfo.AdjustmentRule */ System_TimeZoneInfo_AdjustmentRule_CreateAdjustmentRule_1(void* /* System.DateTime */ dateStart, void* /* System.DateTime */ dateEnd, void* /* System.TimeSpan */ daylightDelta, void* /* System.TimeZoneInfo.TransitionTime */ daylightTransitionStart, void* /* System.TimeZoneInfo.TransitionTime */ daylightTransitionEnd, void** /* System.Exception */ __outException)
	{
		System.DateTime dateStartConverted = InteropUtils.GetInstance<System.DateTime>(dateStart);
		System.DateTime dateEndConverted = InteropUtils.GetInstance<System.DateTime>(dateEnd);
		System.TimeSpan daylightDeltaConverted = InteropUtils.GetInstance<System.TimeSpan>(daylightDelta);
		System.TimeZoneInfo.TransitionTime daylightTransitionStartConverted = InteropUtils.GetInstance<System.TimeZoneInfo.TransitionTime>(daylightTransitionStart);
		System.TimeZoneInfo.TransitionTime daylightTransitionEndConverted = InteropUtils.GetInstance<System.TimeZoneInfo.TransitionTime>(daylightTransitionEnd);
	
	    try {
			System.TimeZoneInfo.AdjustmentRule __returnValue = System.TimeZoneInfo.AdjustmentRule.CreateAdjustmentRule(dateStartConverted, dateEndConverted, daylightDeltaConverted, daylightTransitionStartConverted, daylightTransitionEndConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeZoneInfo_AdjustmentRule_DateStart_Get")]
	internal static void* /* System.DateTime */ System_TimeZoneInfo_AdjustmentRule_DateStart_Get(void* /* System.TimeZoneInfo.AdjustmentRule */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.TimeZoneInfo.AdjustmentRule __selfConverted = InteropUtils.GetInstance<System.TimeZoneInfo.AdjustmentRule>(__self);
	
	
	    try {
			System.DateTime __returnValue = __selfConverted.DateStart;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeZoneInfo_AdjustmentRule_DateEnd_Get")]
	internal static void* /* System.DateTime */ System_TimeZoneInfo_AdjustmentRule_DateEnd_Get(void* /* System.TimeZoneInfo.AdjustmentRule */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.TimeZoneInfo.AdjustmentRule __selfConverted = InteropUtils.GetInstance<System.TimeZoneInfo.AdjustmentRule>(__self);
	
	
	    try {
			System.DateTime __returnValue = __selfConverted.DateEnd;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeZoneInfo_AdjustmentRule_DaylightDelta_Get")]
	internal static void* /* System.TimeSpan */ System_TimeZoneInfo_AdjustmentRule_DaylightDelta_Get(void* /* System.TimeZoneInfo.AdjustmentRule */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.TimeZoneInfo.AdjustmentRule __selfConverted = InteropUtils.GetInstance<System.TimeZoneInfo.AdjustmentRule>(__self);
	
	
	    try {
			System.TimeSpan __returnValue = __selfConverted.DaylightDelta;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeZoneInfo_AdjustmentRule_DaylightTransitionStart_Get")]
	internal static void* /* System.TimeZoneInfo.TransitionTime */ System_TimeZoneInfo_AdjustmentRule_DaylightTransitionStart_Get(void* /* System.TimeZoneInfo.AdjustmentRule */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.TimeZoneInfo.AdjustmentRule __selfConverted = InteropUtils.GetInstance<System.TimeZoneInfo.AdjustmentRule>(__self);
	
	
	    try {
			System.TimeZoneInfo.TransitionTime __returnValue = __selfConverted.DaylightTransitionStart;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeZoneInfo_AdjustmentRule_DaylightTransitionEnd_Get")]
	internal static void* /* System.TimeZoneInfo.TransitionTime */ System_TimeZoneInfo_AdjustmentRule_DaylightTransitionEnd_Get(void* /* System.TimeZoneInfo.AdjustmentRule */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.TimeZoneInfo.AdjustmentRule __selfConverted = InteropUtils.GetInstance<System.TimeZoneInfo.AdjustmentRule>(__self);
	
	
	    try {
			System.TimeZoneInfo.TransitionTime __returnValue = __selfConverted.DaylightTransitionEnd;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeZoneInfo_AdjustmentRule_BaseUtcOffsetDelta_Get")]
	internal static void* /* System.TimeSpan */ System_TimeZoneInfo_AdjustmentRule_BaseUtcOffsetDelta_Get(void* /* System.TimeZoneInfo.AdjustmentRule */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.TimeZoneInfo.AdjustmentRule __selfConverted = InteropUtils.GetInstance<System.TimeZoneInfo.AdjustmentRule>(__self);
	
	
	    try {
			System.TimeSpan __returnValue = __selfConverted.BaseUtcOffsetDelta;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeZoneInfo_AdjustmentRule_TypeOf")]
	internal static void* /* System.Type */ System_TimeZoneInfo_AdjustmentRule_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.TimeZoneInfo.AdjustmentRule);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeZoneInfo_AdjustmentRule_Destroy")]
	internal static void /* System.Void */ System_TimeZoneInfo_AdjustmentRule_Destroy(void* /* System.TimeZoneInfo.AdjustmentRule */ __self)
	{
	
		InteropUtils.FreeIfAllocated(__self);
	}
	
}


internal unsafe class System_TimeZoneInfo_TransitionTime
{
	[UnmanagedCallersOnly(EntryPoint = "System_TimeZoneInfo_TransitionTime_Equals")]
	internal static byte /* System.Boolean */ System_TimeZoneInfo_TransitionTime_Equals(void* /* System.TimeZoneInfo.TransitionTime */ __self, void* /* System.Object */ obj, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.TimeZoneInfo.TransitionTime __selfConverted = InteropUtils.GetInstance<System.TimeZoneInfo.TransitionTime>(__self);
	
		System.Object objConverted = InteropUtils.GetInstance<System.Object>(obj);
	
	    try {
			System.Boolean __returnValue = __selfConverted.Equals(objConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeZoneInfo_TransitionTime_Equals_1")]
	internal static byte /* System.Boolean */ System_TimeZoneInfo_TransitionTime_Equals_1(void* /* System.TimeZoneInfo.TransitionTime */ __self, void* /* System.TimeZoneInfo.TransitionTime */ other, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.TimeZoneInfo.TransitionTime __selfConverted = InteropUtils.GetInstance<System.TimeZoneInfo.TransitionTime>(__self);
	
		System.TimeZoneInfo.TransitionTime otherConverted = InteropUtils.GetInstance<System.TimeZoneInfo.TransitionTime>(other);
	
	    try {
			System.Boolean __returnValue = __selfConverted.Equals(otherConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeZoneInfo_TransitionTime_GetHashCode")]
	internal static int /* System.Int32 */ System_TimeZoneInfo_TransitionTime_GetHashCode(void* /* System.TimeZoneInfo.TransitionTime */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.TimeZoneInfo.TransitionTime __selfConverted = InteropUtils.GetInstance<System.TimeZoneInfo.TransitionTime>(__self);
	
	
	    try {
			System.Int32 __returnValue = __selfConverted.GetHashCode();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeZoneInfo_TransitionTime_CreateFixedDateRule")]
	internal static void* /* System.TimeZoneInfo.TransitionTime */ System_TimeZoneInfo_TransitionTime_CreateFixedDateRule(void* /* System.DateTime */ timeOfDay, int /* System.Int32 */ month, int /* System.Int32 */ day, void** /* System.Exception */ __outException)
	{
		System.DateTime timeOfDayConverted = InteropUtils.GetInstance<System.DateTime>(timeOfDay);
	
	    try {
			System.TimeZoneInfo.TransitionTime __returnValue = System.TimeZoneInfo.TransitionTime.CreateFixedDateRule(timeOfDayConverted, month, day);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeZoneInfo_TransitionTime_CreateFloatingDateRule")]
	internal static void* /* System.TimeZoneInfo.TransitionTime */ System_TimeZoneInfo_TransitionTime_CreateFloatingDateRule(void* /* System.DateTime */ timeOfDay, int /* System.Int32 */ month, int /* System.Int32 */ week, System.DayOfWeek /* System.DayOfWeek */ dayOfWeek, void** /* System.Exception */ __outException)
	{
		System.DateTime timeOfDayConverted = InteropUtils.GetInstance<System.DateTime>(timeOfDay);
	
	    try {
			System.TimeZoneInfo.TransitionTime __returnValue = System.TimeZoneInfo.TransitionTime.CreateFloatingDateRule(timeOfDayConverted, month, week, dayOfWeek);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeZoneInfo_TransitionTime_TimeOfDay_Get")]
	internal static void* /* System.DateTime */ System_TimeZoneInfo_TransitionTime_TimeOfDay_Get(void* /* System.TimeZoneInfo.TransitionTime */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.TimeZoneInfo.TransitionTime __selfConverted = InteropUtils.GetInstance<System.TimeZoneInfo.TransitionTime>(__self);
	
	
	    try {
			System.DateTime __returnValue = __selfConverted.TimeOfDay;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeZoneInfo_TransitionTime_Month_Get")]
	internal static int /* System.Int32 */ System_TimeZoneInfo_TransitionTime_Month_Get(void* /* System.TimeZoneInfo.TransitionTime */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.TimeZoneInfo.TransitionTime __selfConverted = InteropUtils.GetInstance<System.TimeZoneInfo.TransitionTime>(__self);
	
	
	    try {
			System.Int32 __returnValue = __selfConverted.Month;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeZoneInfo_TransitionTime_Week_Get")]
	internal static int /* System.Int32 */ System_TimeZoneInfo_TransitionTime_Week_Get(void* /* System.TimeZoneInfo.TransitionTime */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.TimeZoneInfo.TransitionTime __selfConverted = InteropUtils.GetInstance<System.TimeZoneInfo.TransitionTime>(__self);
	
	
	    try {
			System.Int32 __returnValue = __selfConverted.Week;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeZoneInfo_TransitionTime_Day_Get")]
	internal static int /* System.Int32 */ System_TimeZoneInfo_TransitionTime_Day_Get(void* /* System.TimeZoneInfo.TransitionTime */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.TimeZoneInfo.TransitionTime __selfConverted = InteropUtils.GetInstance<System.TimeZoneInfo.TransitionTime>(__self);
	
	
	    try {
			System.Int32 __returnValue = __selfConverted.Day;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeZoneInfo_TransitionTime_DayOfWeek_Get")]
	internal static System.DayOfWeek /* System.DayOfWeek */ System_TimeZoneInfo_TransitionTime_DayOfWeek_Get(void* /* System.TimeZoneInfo.TransitionTime */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.TimeZoneInfo.TransitionTime __selfConverted = InteropUtils.GetInstance<System.TimeZoneInfo.TransitionTime>(__self);
	
	
	    try {
			System.DayOfWeek __returnValue = __selfConverted.DayOfWeek;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return default(System.DayOfWeek);
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeZoneInfo_TransitionTime_IsFixedDateRule_Get")]
	internal static byte /* System.Boolean */ System_TimeZoneInfo_TransitionTime_IsFixedDateRule_Get(void* /* System.TimeZoneInfo.TransitionTime */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.TimeZoneInfo.TransitionTime __selfConverted = InteropUtils.GetInstance<System.TimeZoneInfo.TransitionTime>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.IsFixedDateRule;
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeZoneInfo_TransitionTime_Create_1")]
	internal static void* /* System.TimeZoneInfo.TransitionTime */ System_TimeZoneInfo_TransitionTime_Create_1(void** /* System.Exception */ __outException)
	{
	
	    try {
			System.TimeZoneInfo.TransitionTime __returnValue = new System.TimeZoneInfo.TransitionTime();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeZoneInfo_TransitionTime_TypeOf")]
	internal static void* /* System.Type */ System_TimeZoneInfo_TransitionTime_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.TimeZoneInfo.TransitionTime);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_TimeZoneInfo_TransitionTime_Destroy")]
	internal static void /* System.Void */ System_TimeZoneInfo_TransitionTime_Destroy(void* /* System.TimeZoneInfo.TransitionTime */ __self)
	{
	
		InteropUtils.FreeIfAllocated(__self);
	}
	
}



internal unsafe class System_Threading_ITimer
{
	[UnmanagedCallersOnly(EntryPoint = "System_Threading_ITimer_Change")]
	internal static byte /* System.Boolean */ System_Threading_ITimer_Change(void* /* System.Threading.ITimer */ __self, void* /* System.TimeSpan */ dueTime, void* /* System.TimeSpan */ period, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Threading.ITimer __selfConverted = InteropUtils.GetInstance<System.Threading.ITimer>(__self);
	
		System.TimeSpan dueTimeConverted = InteropUtils.GetInstance<System.TimeSpan>(dueTime);
		System.TimeSpan periodConverted = InteropUtils.GetInstance<System.TimeSpan>(period);
	
	    try {
			System.Boolean __returnValue = __selfConverted.Change(dueTimeConverted, periodConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Threading_ITimer_TypeOf")]
	internal static void* /* System.Type */ System_Threading_ITimer_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.Threading.ITimer);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Threading_ITimer_Destroy")]
	internal static void /* System.Void */ System_Threading_ITimer_Destroy(void* /* System.Threading.ITimer */ __self)
	{
	
		InteropUtils.FreeIfAllocated(__self);
	}
	
}


internal unsafe class System_Threading_TimerCallback
{
	internal void* Context { get; }
	internal delegate* unmanaged<void* /* context */, void* /* System.Object */ /* state */, void /* System.Void */ /* return type */> CFunction { get; }
	internal delegate* unmanaged<void*, void> CDestructorFunction { get; }

	private WeakReference<System.Threading.TimerCallback> m_trampoline;
	internal System.Threading.TimerCallback Trampoline
	{
		get {
			System.Threading.TimerCallback? trampoline;

			if (m_trampoline is not null) {
				m_trampoline.TryGetTarget(out trampoline);
			} else {
				trampoline = null;
			}

			if (trampoline is null) {
				trampoline = CreateTrampoline();
				m_trampoline = new(trampoline);
			}

			return trampoline;
		}
	}

	private System_Threading_TimerCallback(void* context, delegate* unmanaged<void* /* context */, void* /* System.Object */ /* state */, void /* System.Void */ /* return type */> cFunction, delegate* unmanaged<void*, void> cDestructorFunction)
	{
		Context = context;
		CFunction = cFunction;
		CDestructorFunction = cDestructorFunction;
	}

	internal System_Threading_TimerCallback(System.Threading.TimerCallback originalDelegate)
	{
		m_trampoline = new(originalDelegate);
	}

	~System_Threading_TimerCallback()
	{
		if (CDestructorFunction is null) {
			return;
		}

		CDestructorFunction(Context);
	}

	private System.Threading.TimerCallback? CreateTrampoline()
	{
		if (CFunction is null) {
			return null;
		}

		System.Type typeOfSelf = typeof(System_Threading_TimerCallback);
		string nameOfInvocationMethod = nameof(__InvokeByCallingCFunction);
		System.Reflection.BindingFlags bindingFlags = System.Reflection.BindingFlags.Instance | BindingFlags.NonPublic;
		System.Reflection.MethodInfo? invocationMethod = typeOfSelf.GetMethod(nameOfInvocationMethod, bindingFlags);

		if (invocationMethod is null) {
			throw new Exception("Failed to retrieve delegate invocation method");
		}

		System.Threading.TimerCallback trampoline = (System.Threading.TimerCallback)System.Delegate.CreateDelegate(typeof(System.Threading.TimerCallback), this, invocationMethod);

		return trampoline;
	}

	private void __InvokeByCallingCFunction(System.Object /* System.Object */ state)
	{
		void* stateConverted = state.AllocateGCHandleAndGetAddress();
	

		CFunction(Context, stateConverted);
	}

	[UnmanagedCallersOnly(EntryPoint = "System_Threading_TimerCallback_Create")]
	public static void* Create(void* context, delegate* unmanaged<void* /* context */, void* /* System.Object */ /* state */, void /* System.Void */ /* return type */> cFunction, delegate* unmanaged<void*, void> cDestructorFunction)
	{
		var self = new System_Threading_TimerCallback(context, cFunction, cDestructorFunction);
		void* selfHandle = self.AllocateGCHandleAndGetAddress();

		return selfHandle;
	}

	[UnmanagedCallersOnly(EntryPoint = "System_Threading_TimerCallback_Invoke")]
	public static void /* System.Void */ Invoke(void* self, void* /* System.Object */ state, void** __outException)
	{
		if (self is null) {
			throw new ArgumentNullException(nameof(self));
		}

		try {
			var selfConverted = InteropUtils.GetInstance<System_Threading_TimerCallback>(self);

			System.Object stateConverted = InteropUtils.GetInstance<System.Object>(state);
		

			selfConverted.Trampoline(stateConverted);
		} catch (Exception __exception) {
			if (__outException is not null) {
				void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();

				*__outException = __exceptionHandleAddress;
			}

		}
	}

	[UnmanagedCallersOnly(EntryPoint = "System_Threading_TimerCallback_Context_Get")]
	public static void* Context_Get(void* self)
	{
		if (self is null) {
			throw new ArgumentNullException(nameof(self));
		}

		var selfConverted = InteropUtils.GetInstance<System_Threading_TimerCallback>(self);

		return selfConverted.Context;
	}

	[UnmanagedCallersOnly(EntryPoint = "System_Threading_TimerCallback_CFunction_Get")]
	public static delegate* unmanaged<void* /* context */, void* /* System.Object */ /* state */, void /* System.Void */ /* return type */> CFunction_Get(void* self)
	{
		if (self is null) {
			throw new ArgumentNullException(nameof(self));
		}

		var selfConverted = InteropUtils.GetInstance<System_Threading_TimerCallback>(self);

		return selfConverted.CFunction;
	}

	[UnmanagedCallersOnly(EntryPoint = "System_Threading_TimerCallback_CDestructorFunction_Get")]
	public static delegate* unmanaged<void*, void> CDestructorFunction_Get(void* self)
	{
		if (self is null) {
			throw new ArgumentNullException(nameof(self));
		}

		var selfConverted = InteropUtils.GetInstance<System_Threading_TimerCallback>(self);

		return selfConverted.CDestructorFunction;
	}

	[UnmanagedCallersOnly(EntryPoint = "System_Threading_TimerCallback_TypeOf")]
	internal static void* /* System.Type */ System_Threading_TimerCallback_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.Threading.TimerCallback);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	

	[UnmanagedCallersOnly(EntryPoint = "System_Threading_TimerCallback_Destroy")]
	internal static void /* System.Void */ System_Threading_TimerCallback_Destroy(void* /* System.Threading.TimerCallback */ __self)
	{
	
		InteropUtils.FreeIfAllocated(__self);
	}
	
}


internal unsafe class System_Runtime_CompilerServices_ValueTaskAwaiter
{
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_CompilerServices_ValueTaskAwaiter_GetResult")]
	internal static void /* System.Void */ System_Runtime_CompilerServices_ValueTaskAwaiter_GetResult(void* /* System.Runtime.CompilerServices.ValueTaskAwaiter */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Runtime.CompilerServices.ValueTaskAwaiter __selfConverted = InteropUtils.GetInstance<System.Runtime.CompilerServices.ValueTaskAwaiter>(__self);
	
	
	    try {
			__selfConverted.GetResult();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_CompilerServices_ValueTaskAwaiter_OnCompleted")]
	internal static void /* System.Void */ System_Runtime_CompilerServices_ValueTaskAwaiter_OnCompleted(void* /* System.Runtime.CompilerServices.ValueTaskAwaiter */ __self, void* /* System.Action */ continuation, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Runtime.CompilerServices.ValueTaskAwaiter __selfConverted = InteropUtils.GetInstance<System.Runtime.CompilerServices.ValueTaskAwaiter>(__self);
	
		System.Action continuationConverted = InteropUtils.GetInstance<System_Action>(continuation)?.Trampoline;
	
	    try {
			__selfConverted.OnCompleted(continuationConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_CompilerServices_ValueTaskAwaiter_UnsafeOnCompleted")]
	internal static void /* System.Void */ System_Runtime_CompilerServices_ValueTaskAwaiter_UnsafeOnCompleted(void* /* System.Runtime.CompilerServices.ValueTaskAwaiter */ __self, void* /* System.Action */ continuation, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Runtime.CompilerServices.ValueTaskAwaiter __selfConverted = InteropUtils.GetInstance<System.Runtime.CompilerServices.ValueTaskAwaiter>(__self);
	
		System.Action continuationConverted = InteropUtils.GetInstance<System_Action>(continuation)?.Trampoline;
	
	    try {
			__selfConverted.UnsafeOnCompleted(continuationConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_CompilerServices_ValueTaskAwaiter_IsCompleted_Get")]
	internal static byte /* System.Boolean */ System_Runtime_CompilerServices_ValueTaskAwaiter_IsCompleted_Get(void* /* System.Runtime.CompilerServices.ValueTaskAwaiter */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Runtime.CompilerServices.ValueTaskAwaiter __selfConverted = InteropUtils.GetInstance<System.Runtime.CompilerServices.ValueTaskAwaiter>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.IsCompleted;
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_CompilerServices_ValueTaskAwaiter_Create")]
	internal static void* /* System.Runtime.CompilerServices.ValueTaskAwaiter */ System_Runtime_CompilerServices_ValueTaskAwaiter_Create(void** /* System.Exception */ __outException)
	{
	
	    try {
			System.Runtime.CompilerServices.ValueTaskAwaiter __returnValue = new System.Runtime.CompilerServices.ValueTaskAwaiter();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_CompilerServices_ValueTaskAwaiter_TypeOf")]
	internal static void* /* System.Type */ System_Runtime_CompilerServices_ValueTaskAwaiter_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.Runtime.CompilerServices.ValueTaskAwaiter);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_CompilerServices_ValueTaskAwaiter_Destroy")]
	internal static void /* System.Void */ System_Runtime_CompilerServices_ValueTaskAwaiter_Destroy(void* /* System.Runtime.CompilerServices.ValueTaskAwaiter */ __self)
	{
	
		InteropUtils.FreeIfAllocated(__self);
	}
	
}


internal unsafe class System_Runtime_CompilerServices_ConfiguredValueTaskAwaitable
{
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_CompilerServices_ConfiguredValueTaskAwaitable_GetAwaiter")]
	internal static void* /* System.Runtime.CompilerServices.ConfiguredValueTaskAwaitable.ConfiguredValueTaskAwaiter */ System_Runtime_CompilerServices_ConfiguredValueTaskAwaitable_GetAwaiter(void* /* System.Runtime.CompilerServices.ConfiguredValueTaskAwaitable */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Runtime.CompilerServices.ConfiguredValueTaskAwaitable __selfConverted = InteropUtils.GetInstance<System.Runtime.CompilerServices.ConfiguredValueTaskAwaitable>(__self);
	
	
	    try {
			System.Runtime.CompilerServices.ConfiguredValueTaskAwaitable.ConfiguredValueTaskAwaiter __returnValue = __selfConverted.GetAwaiter();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_CompilerServices_ConfiguredValueTaskAwaitable_Create")]
	internal static void* /* System.Runtime.CompilerServices.ConfiguredValueTaskAwaitable */ System_Runtime_CompilerServices_ConfiguredValueTaskAwaitable_Create(void** /* System.Exception */ __outException)
	{
	
	    try {
			System.Runtime.CompilerServices.ConfiguredValueTaskAwaitable __returnValue = new System.Runtime.CompilerServices.ConfiguredValueTaskAwaitable();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_CompilerServices_ConfiguredValueTaskAwaitable_TypeOf")]
	internal static void* /* System.Type */ System_Runtime_CompilerServices_ConfiguredValueTaskAwaitable_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.Runtime.CompilerServices.ConfiguredValueTaskAwaitable);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_CompilerServices_ConfiguredValueTaskAwaitable_Destroy")]
	internal static void /* System.Void */ System_Runtime_CompilerServices_ConfiguredValueTaskAwaitable_Destroy(void* /* System.Runtime.CompilerServices.ConfiguredValueTaskAwaitable */ __self)
	{
	
		InteropUtils.FreeIfAllocated(__self);
	}
	
}


internal unsafe class System_Runtime_CompilerServices_ConfiguredValueTaskAwaitable_ConfiguredValueTaskAwaiter
{
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_CompilerServices_ConfiguredValueTaskAwaitable_ConfiguredValueTaskAwaiter_GetResult")]
	internal static void /* System.Void */ System_Runtime_CompilerServices_ConfiguredValueTaskAwaitable_ConfiguredValueTaskAwaiter_GetResult(void* /* System.Runtime.CompilerServices.ConfiguredValueTaskAwaitable.ConfiguredValueTaskAwaiter */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Runtime.CompilerServices.ConfiguredValueTaskAwaitable.ConfiguredValueTaskAwaiter __selfConverted = InteropUtils.GetInstance<System.Runtime.CompilerServices.ConfiguredValueTaskAwaitable.ConfiguredValueTaskAwaiter>(__self);
	
	
	    try {
			__selfConverted.GetResult();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_CompilerServices_ConfiguredValueTaskAwaitable_ConfiguredValueTaskAwaiter_OnCompleted")]
	internal static void /* System.Void */ System_Runtime_CompilerServices_ConfiguredValueTaskAwaitable_ConfiguredValueTaskAwaiter_OnCompleted(void* /* System.Runtime.CompilerServices.ConfiguredValueTaskAwaitable.ConfiguredValueTaskAwaiter */ __self, void* /* System.Action */ continuation, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Runtime.CompilerServices.ConfiguredValueTaskAwaitable.ConfiguredValueTaskAwaiter __selfConverted = InteropUtils.GetInstance<System.Runtime.CompilerServices.ConfiguredValueTaskAwaitable.ConfiguredValueTaskAwaiter>(__self);
	
		System.Action continuationConverted = InteropUtils.GetInstance<System_Action>(continuation)?.Trampoline;
	
	    try {
			__selfConverted.OnCompleted(continuationConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_CompilerServices_ConfiguredValueTaskAwaitable_ConfiguredValueTaskAwaiter_UnsafeOnCompleted")]
	internal static void /* System.Void */ System_Runtime_CompilerServices_ConfiguredValueTaskAwaitable_ConfiguredValueTaskAwaiter_UnsafeOnCompleted(void* /* System.Runtime.CompilerServices.ConfiguredValueTaskAwaitable.ConfiguredValueTaskAwaiter */ __self, void* /* System.Action */ continuation, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Runtime.CompilerServices.ConfiguredValueTaskAwaitable.ConfiguredValueTaskAwaiter __selfConverted = InteropUtils.GetInstance<System.Runtime.CompilerServices.ConfiguredValueTaskAwaitable.ConfiguredValueTaskAwaiter>(__self);
	
		System.Action continuationConverted = InteropUtils.GetInstance<System_Action>(continuation)?.Trampoline;
	
	    try {
			__selfConverted.UnsafeOnCompleted(continuationConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_CompilerServices_ConfiguredValueTaskAwaitable_ConfiguredValueTaskAwaiter_IsCompleted_Get")]
	internal static byte /* System.Boolean */ System_Runtime_CompilerServices_ConfiguredValueTaskAwaitable_ConfiguredValueTaskAwaiter_IsCompleted_Get(void* /* System.Runtime.CompilerServices.ConfiguredValueTaskAwaitable.ConfiguredValueTaskAwaiter */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Runtime.CompilerServices.ConfiguredValueTaskAwaitable.ConfiguredValueTaskAwaiter __selfConverted = InteropUtils.GetInstance<System.Runtime.CompilerServices.ConfiguredValueTaskAwaitable.ConfiguredValueTaskAwaiter>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.IsCompleted;
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_CompilerServices_ConfiguredValueTaskAwaitable_ConfiguredValueTaskAwaiter_Create")]
	internal static void* /* System.Runtime.CompilerServices.ConfiguredValueTaskAwaitable.ConfiguredValueTaskAwaiter */ System_Runtime_CompilerServices_ConfiguredValueTaskAwaitable_ConfiguredValueTaskAwaiter_Create(void** /* System.Exception */ __outException)
	{
	
	    try {
			System.Runtime.CompilerServices.ConfiguredValueTaskAwaitable.ConfiguredValueTaskAwaiter __returnValue = new System.Runtime.CompilerServices.ConfiguredValueTaskAwaitable.ConfiguredValueTaskAwaiter();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_CompilerServices_ConfiguredValueTaskAwaitable_ConfiguredValueTaskAwaiter_TypeOf")]
	internal static void* /* System.Type */ System_Runtime_CompilerServices_ConfiguredValueTaskAwaitable_ConfiguredValueTaskAwaiter_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.Runtime.CompilerServices.ConfiguredValueTaskAwaitable.ConfiguredValueTaskAwaiter);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_CompilerServices_ConfiguredValueTaskAwaitable_ConfiguredValueTaskAwaiter_Destroy")]
	internal static void /* System.Void */ System_Runtime_CompilerServices_ConfiguredValueTaskAwaitable_ConfiguredValueTaskAwaiter_Destroy(void* /* System.Runtime.CompilerServices.ConfiguredValueTaskAwaitable.ConfiguredValueTaskAwaiter */ __self)
	{
	
		InteropUtils.FreeIfAllocated(__self);
	}
	
}


internal unsafe class System_Threading_Tasks_Sources_IValueTaskSource
{
	[UnmanagedCallersOnly(EntryPoint = "System_Threading_Tasks_Sources_IValueTaskSource_GetStatus")]
	internal static System.Threading.Tasks.Sources.ValueTaskSourceStatus /* System.Threading.Tasks.Sources.ValueTaskSourceStatus */ System_Threading_Tasks_Sources_IValueTaskSource_GetStatus(void* /* System.Threading.Tasks.Sources.IValueTaskSource */ __self, short /* System.Int16 */ token, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Threading.Tasks.Sources.IValueTaskSource __selfConverted = InteropUtils.GetInstance<System.Threading.Tasks.Sources.IValueTaskSource>(__self);
	
	
	    try {
			System.Threading.Tasks.Sources.ValueTaskSourceStatus __returnValue = __selfConverted.GetStatus(token);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return default(System.Threading.Tasks.Sources.ValueTaskSourceStatus);
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Threading_Tasks_Sources_IValueTaskSource_GetResult")]
	internal static void /* System.Void */ System_Threading_Tasks_Sources_IValueTaskSource_GetResult(void* /* System.Threading.Tasks.Sources.IValueTaskSource */ __self, short /* System.Int16 */ token, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Threading.Tasks.Sources.IValueTaskSource __selfConverted = InteropUtils.GetInstance<System.Threading.Tasks.Sources.IValueTaskSource>(__self);
	
	
	    try {
			__selfConverted.GetResult(token);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Threading_Tasks_Sources_IValueTaskSource_TypeOf")]
	internal static void* /* System.Type */ System_Threading_Tasks_Sources_IValueTaskSource_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.Threading.Tasks.Sources.IValueTaskSource);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Threading_Tasks_Sources_IValueTaskSource_Destroy")]
	internal static void /* System.Void */ System_Threading_Tasks_Sources_IValueTaskSource_Destroy(void* /* System.Threading.Tasks.Sources.IValueTaskSource */ __self)
	{
	
		InteropUtils.FreeIfAllocated(__self);
	}
	
}


internal unsafe class System_Threading_Tasks_Sources_ValueTaskSourceStatus
{
	[UnmanagedCallersOnly(EntryPoint = "System_Threading_Tasks_Sources_ValueTaskSourceStatus_TypeOf")]
	internal static void* /* System.Type */ System_Threading_Tasks_Sources_ValueTaskSourceStatus_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.Threading.Tasks.Sources.ValueTaskSourceStatus);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
}


internal unsafe class System_Threading_Tasks_Sources_ValueTaskSourceOnCompletedFlags
{
	[UnmanagedCallersOnly(EntryPoint = "System_Threading_Tasks_Sources_ValueTaskSourceOnCompletedFlags_TypeOf")]
	internal static void* /* System.Type */ System_Threading_Tasks_Sources_ValueTaskSourceOnCompletedFlags_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.Threading.Tasks.Sources.ValueTaskSourceOnCompletedFlags);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
}


internal unsafe class System_AsyncCallback
{
	internal void* Context { get; }
	internal delegate* unmanaged<void* /* context */, void* /* System.IAsyncResult */ /* ar */, void /* System.Void */ /* return type */> CFunction { get; }
	internal delegate* unmanaged<void*, void> CDestructorFunction { get; }

	private WeakReference<System.AsyncCallback> m_trampoline;
	internal System.AsyncCallback Trampoline
	{
		get {
			System.AsyncCallback? trampoline;

			if (m_trampoline is not null) {
				m_trampoline.TryGetTarget(out trampoline);
			} else {
				trampoline = null;
			}

			if (trampoline is null) {
				trampoline = CreateTrampoline();
				m_trampoline = new(trampoline);
			}

			return trampoline;
		}
	}

	private System_AsyncCallback(void* context, delegate* unmanaged<void* /* context */, void* /* System.IAsyncResult */ /* ar */, void /* System.Void */ /* return type */> cFunction, delegate* unmanaged<void*, void> cDestructorFunction)
	{
		Context = context;
		CFunction = cFunction;
		CDestructorFunction = cDestructorFunction;
	}

	internal System_AsyncCallback(System.AsyncCallback originalDelegate)
	{
		m_trampoline = new(originalDelegate);
	}

	~System_AsyncCallback()
	{
		if (CDestructorFunction is null) {
			return;
		}

		CDestructorFunction(Context);
	}

	private System.AsyncCallback? CreateTrampoline()
	{
		if (CFunction is null) {
			return null;
		}

		System.Type typeOfSelf = typeof(System_AsyncCallback);
		string nameOfInvocationMethod = nameof(__InvokeByCallingCFunction);
		System.Reflection.BindingFlags bindingFlags = System.Reflection.BindingFlags.Instance | BindingFlags.NonPublic;
		System.Reflection.MethodInfo? invocationMethod = typeOfSelf.GetMethod(nameOfInvocationMethod, bindingFlags);

		if (invocationMethod is null) {
			throw new Exception("Failed to retrieve delegate invocation method");
		}

		System.AsyncCallback trampoline = (System.AsyncCallback)System.Delegate.CreateDelegate(typeof(System.AsyncCallback), this, invocationMethod);

		return trampoline;
	}

	private void __InvokeByCallingCFunction(System.IAsyncResult /* System.IAsyncResult */ ar)
	{
		void* arConverted = ar.AllocateGCHandleAndGetAddress();
	

		CFunction(Context, arConverted);
	}

	[UnmanagedCallersOnly(EntryPoint = "System_AsyncCallback_Create")]
	public static void* Create(void* context, delegate* unmanaged<void* /* context */, void* /* System.IAsyncResult */ /* ar */, void /* System.Void */ /* return type */> cFunction, delegate* unmanaged<void*, void> cDestructorFunction)
	{
		var self = new System_AsyncCallback(context, cFunction, cDestructorFunction);
		void* selfHandle = self.AllocateGCHandleAndGetAddress();

		return selfHandle;
	}

	[UnmanagedCallersOnly(EntryPoint = "System_AsyncCallback_Invoke")]
	public static void /* System.Void */ Invoke(void* self, void* /* System.IAsyncResult */ ar, void** __outException)
	{
		if (self is null) {
			throw new ArgumentNullException(nameof(self));
		}

		try {
			var selfConverted = InteropUtils.GetInstance<System_AsyncCallback>(self);

			System.IAsyncResult arConverted = InteropUtils.GetInstance<System.IAsyncResult>(ar);
		

			selfConverted.Trampoline(arConverted);
		} catch (Exception __exception) {
			if (__outException is not null) {
				void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();

				*__outException = __exceptionHandleAddress;
			}

		}
	}

	[UnmanagedCallersOnly(EntryPoint = "System_AsyncCallback_Context_Get")]
	public static void* Context_Get(void* self)
	{
		if (self is null) {
			throw new ArgumentNullException(nameof(self));
		}

		var selfConverted = InteropUtils.GetInstance<System_AsyncCallback>(self);

		return selfConverted.Context;
	}

	[UnmanagedCallersOnly(EntryPoint = "System_AsyncCallback_CFunction_Get")]
	public static delegate* unmanaged<void* /* context */, void* /* System.IAsyncResult */ /* ar */, void /* System.Void */ /* return type */> CFunction_Get(void* self)
	{
		if (self is null) {
			throw new ArgumentNullException(nameof(self));
		}

		var selfConverted = InteropUtils.GetInstance<System_AsyncCallback>(self);

		return selfConverted.CFunction;
	}

	[UnmanagedCallersOnly(EntryPoint = "System_AsyncCallback_CDestructorFunction_Get")]
	public static delegate* unmanaged<void*, void> CDestructorFunction_Get(void* self)
	{
		if (self is null) {
			throw new ArgumentNullException(nameof(self));
		}

		var selfConverted = InteropUtils.GetInstance<System_AsyncCallback>(self);

		return selfConverted.CDestructorFunction;
	}

	[UnmanagedCallersOnly(EntryPoint = "System_AsyncCallback_TypeOf")]
	internal static void* /* System.Type */ System_AsyncCallback_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.AsyncCallback);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	

	[UnmanagedCallersOnly(EntryPoint = "System_AsyncCallback_Destroy")]
	internal static void /* System.Void */ System_AsyncCallback_Destroy(void* /* System.AsyncCallback */ __self)
	{
	
		InteropUtils.FreeIfAllocated(__self);
	}
	
}


internal unsafe class System_IO_SeekOrigin
{
	[UnmanagedCallersOnly(EntryPoint = "System_IO_SeekOrigin_TypeOf")]
	internal static void* /* System.Type */ System_IO_SeekOrigin_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.IO.SeekOrigin);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
}


internal unsafe class Microsoft_Win32_SafeHandles_SafeFileHandle
{
	[UnmanagedCallersOnly(EntryPoint = "Microsoft_Win32_SafeHandles_SafeFileHandle_Create")]
	internal static void* /* Microsoft.Win32.SafeHandles.SafeFileHandle */ Microsoft_Win32_SafeHandles_SafeFileHandle_Create(nint /* System.IntPtr */ preexistingHandle, byte /* System.Boolean */ ownsHandle, void** /* System.Exception */ __outException)
	{
		System.Boolean ownsHandleConverted = ownsHandle.ToBool();
	
	    try {
			Microsoft.Win32.SafeHandles.SafeFileHandle __returnValue = new Microsoft.Win32.SafeHandles.SafeFileHandle(preexistingHandle, ownsHandleConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "Microsoft_Win32_SafeHandles_SafeFileHandle_Create_1")]
	internal static void* /* Microsoft.Win32.SafeHandles.SafeFileHandle */ Microsoft_Win32_SafeHandles_SafeFileHandle_Create_1(void** /* System.Exception */ __outException)
	{
	
	    try {
			Microsoft.Win32.SafeHandles.SafeFileHandle __returnValue = new Microsoft.Win32.SafeHandles.SafeFileHandle();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "Microsoft_Win32_SafeHandles_SafeFileHandle_IsAsync_Get")]
	internal static byte /* System.Boolean */ Microsoft_Win32_SafeHandles_SafeFileHandle_IsAsync_Get(void* /* Microsoft.Win32.SafeHandles.SafeFileHandle */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		Microsoft.Win32.SafeHandles.SafeFileHandle __selfConverted = InteropUtils.GetInstance<Microsoft.Win32.SafeHandles.SafeFileHandle>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.IsAsync;
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "Microsoft_Win32_SafeHandles_SafeFileHandle_IsInvalid_Get")]
	internal static byte /* System.Boolean */ Microsoft_Win32_SafeHandles_SafeFileHandle_IsInvalid_Get(void* /* Microsoft.Win32.SafeHandles.SafeFileHandle */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		Microsoft.Win32.SafeHandles.SafeFileHandle __selfConverted = InteropUtils.GetInstance<Microsoft.Win32.SafeHandles.SafeFileHandle>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.IsInvalid;
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "Microsoft_Win32_SafeHandles_SafeFileHandle_TypeOf")]
	internal static void* /* System.Type */ Microsoft_Win32_SafeHandles_SafeFileHandle_TypeOf()
	{
	
		System.Type __returnValue = typeof(Microsoft.Win32.SafeHandles.SafeFileHandle);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
	[UnmanagedCallersOnly(EntryPoint = "Microsoft_Win32_SafeHandles_SafeFileHandle_Destroy")]
	internal static void /* System.Void */ Microsoft_Win32_SafeHandles_SafeFileHandle_Destroy(void* /* Microsoft.Win32.SafeHandles.SafeFileHandle */ __self)
	{
	
		InteropUtils.FreeIfAllocated(__self);
	}
	
}


internal unsafe class System_IO_FileAccess
{
	[UnmanagedCallersOnly(EntryPoint = "System_IO_FileAccess_TypeOf")]
	internal static void* /* System.Type */ System_IO_FileAccess_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.IO.FileAccess);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
}


internal unsafe class System_IO_FileMode
{
	[UnmanagedCallersOnly(EntryPoint = "System_IO_FileMode_TypeOf")]
	internal static void* /* System.Type */ System_IO_FileMode_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.IO.FileMode);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
}


internal unsafe class System_IO_FileShare
{
	[UnmanagedCallersOnly(EntryPoint = "System_IO_FileShare_TypeOf")]
	internal static void* /* System.Type */ System_IO_FileShare_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.IO.FileShare);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
}


internal unsafe class System_IO_FileOptions
{
	[UnmanagedCallersOnly(EntryPoint = "System_IO_FileOptions_TypeOf")]
	internal static void* /* System.Type */ System_IO_FileOptions_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.IO.FileOptions);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
}


internal unsafe class System_IO_FileStreamOptions
{
	[UnmanagedCallersOnly(EntryPoint = "System_IO_FileStreamOptions_Create")]
	internal static void* /* System.IO.FileStreamOptions */ System_IO_FileStreamOptions_Create(void** /* System.Exception */ __outException)
	{
	
	    try {
			System.IO.FileStreamOptions __returnValue = new System.IO.FileStreamOptions();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_IO_FileStreamOptions_Mode_Get")]
	internal static System.IO.FileMode /* System.IO.FileMode */ System_IO_FileStreamOptions_Mode_Get(void* /* System.IO.FileStreamOptions */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.IO.FileStreamOptions __selfConverted = InteropUtils.GetInstance<System.IO.FileStreamOptions>(__self);
	
	
	    try {
			System.IO.FileMode __returnValue = __selfConverted.Mode;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return default(System.IO.FileMode);
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_IO_FileStreamOptions_Mode_Set")]
	internal static void /* System.Void */ System_IO_FileStreamOptions_Mode_Set(void* /* System.IO.FileStreamOptions */ __self, System.IO.FileMode /* System.IO.FileMode */ __value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.IO.FileStreamOptions __selfConverted = InteropUtils.GetInstance<System.IO.FileStreamOptions>(__self);
	
	
	    try {
			__selfConverted.Mode = __value;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_IO_FileStreamOptions_Access_Get")]
	internal static System.IO.FileAccess /* System.IO.FileAccess */ System_IO_FileStreamOptions_Access_Get(void* /* System.IO.FileStreamOptions */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.IO.FileStreamOptions __selfConverted = InteropUtils.GetInstance<System.IO.FileStreamOptions>(__self);
	
	
	    try {
			System.IO.FileAccess __returnValue = __selfConverted.Access;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return default(System.IO.FileAccess);
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_IO_FileStreamOptions_Access_Set")]
	internal static void /* System.Void */ System_IO_FileStreamOptions_Access_Set(void* /* System.IO.FileStreamOptions */ __self, System.IO.FileAccess /* System.IO.FileAccess */ __value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.IO.FileStreamOptions __selfConverted = InteropUtils.GetInstance<System.IO.FileStreamOptions>(__self);
	
	
	    try {
			__selfConverted.Access = __value;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_IO_FileStreamOptions_Share_Get")]
	internal static System.IO.FileShare /* System.IO.FileShare */ System_IO_FileStreamOptions_Share_Get(void* /* System.IO.FileStreamOptions */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.IO.FileStreamOptions __selfConverted = InteropUtils.GetInstance<System.IO.FileStreamOptions>(__self);
	
	
	    try {
			System.IO.FileShare __returnValue = __selfConverted.Share;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return default(System.IO.FileShare);
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_IO_FileStreamOptions_Share_Set")]
	internal static void /* System.Void */ System_IO_FileStreamOptions_Share_Set(void* /* System.IO.FileStreamOptions */ __self, System.IO.FileShare /* System.IO.FileShare */ __value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.IO.FileStreamOptions __selfConverted = InteropUtils.GetInstance<System.IO.FileStreamOptions>(__self);
	
	
	    try {
			__selfConverted.Share = __value;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_IO_FileStreamOptions_Options_Get")]
	internal static System.IO.FileOptions /* System.IO.FileOptions */ System_IO_FileStreamOptions_Options_Get(void* /* System.IO.FileStreamOptions */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.IO.FileStreamOptions __selfConverted = InteropUtils.GetInstance<System.IO.FileStreamOptions>(__self);
	
	
	    try {
			System.IO.FileOptions __returnValue = __selfConverted.Options;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return default(System.IO.FileOptions);
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_IO_FileStreamOptions_Options_Set")]
	internal static void /* System.Void */ System_IO_FileStreamOptions_Options_Set(void* /* System.IO.FileStreamOptions */ __self, System.IO.FileOptions /* System.IO.FileOptions */ __value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.IO.FileStreamOptions __selfConverted = InteropUtils.GetInstance<System.IO.FileStreamOptions>(__self);
	
	
	    try {
			__selfConverted.Options = __value;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_IO_FileStreamOptions_PreallocationSize_Get")]
	internal static long /* System.Int64 */ System_IO_FileStreamOptions_PreallocationSize_Get(void* /* System.IO.FileStreamOptions */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.IO.FileStreamOptions __selfConverted = InteropUtils.GetInstance<System.IO.FileStreamOptions>(__self);
	
	
	    try {
			System.Int64 __returnValue = __selfConverted.PreallocationSize;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_IO_FileStreamOptions_PreallocationSize_Set")]
	internal static void /* System.Void */ System_IO_FileStreamOptions_PreallocationSize_Set(void* /* System.IO.FileStreamOptions */ __self, long /* System.Int64 */ __value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.IO.FileStreamOptions __selfConverted = InteropUtils.GetInstance<System.IO.FileStreamOptions>(__self);
	
	
	    try {
			__selfConverted.PreallocationSize = __value;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_IO_FileStreamOptions_BufferSize_Get")]
	internal static int /* System.Int32 */ System_IO_FileStreamOptions_BufferSize_Get(void* /* System.IO.FileStreamOptions */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.IO.FileStreamOptions __selfConverted = InteropUtils.GetInstance<System.IO.FileStreamOptions>(__self);
	
	
	    try {
			System.Int32 __returnValue = __selfConverted.BufferSize;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_IO_FileStreamOptions_BufferSize_Set")]
	internal static void /* System.Void */ System_IO_FileStreamOptions_BufferSize_Set(void* /* System.IO.FileStreamOptions */ __self, int /* System.Int32 */ __value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.IO.FileStreamOptions __selfConverted = InteropUtils.GetInstance<System.IO.FileStreamOptions>(__self);
	
	
	    try {
			__selfConverted.BufferSize = __value;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_IO_FileStreamOptions_TypeOf")]
	internal static void* /* System.Type */ System_IO_FileStreamOptions_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.IO.FileStreamOptions);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_IO_FileStreamOptions_Destroy")]
	internal static void /* System.Void */ System_IO_FileStreamOptions_Destroy(void* /* System.IO.FileStreamOptions */ __self)
	{
	
		InteropUtils.FreeIfAllocated(__self);
	}
	
}


internal unsafe class System_Reflection_ManifestResourceInfo
{
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_ManifestResourceInfo_Create")]
	internal static void* /* System.Reflection.ManifestResourceInfo */ System_Reflection_ManifestResourceInfo_Create(void* /* System.Reflection.Assembly */ containingAssembly, void* /* System.String */ containingFileName, System.Reflection.ResourceLocation /* System.Reflection.ResourceLocation */ resourceLocation, void** /* System.Exception */ __outException)
	{
		System.Reflection.Assembly containingAssemblyConverted = InteropUtils.GetInstance<System.Reflection.Assembly>(containingAssembly);
		System.String containingFileNameConverted = InteropUtils.GetInstance<System.String>(containingFileName);
	
	    try {
			System.Reflection.ManifestResourceInfo __returnValue = new System.Reflection.ManifestResourceInfo(containingAssemblyConverted, containingFileNameConverted, resourceLocation);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_ManifestResourceInfo_ReferencedAssembly_Get")]
	internal static void* /* System.Reflection.Assembly */ System_Reflection_ManifestResourceInfo_ReferencedAssembly_Get(void* /* System.Reflection.ManifestResourceInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.ManifestResourceInfo __selfConverted = InteropUtils.GetInstance<System.Reflection.ManifestResourceInfo>(__self);
	
	
	    try {
			System.Reflection.Assembly __returnValue = __selfConverted.ReferencedAssembly;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_ManifestResourceInfo_FileName_Get")]
	internal static void* /* System.String */ System_Reflection_ManifestResourceInfo_FileName_Get(void* /* System.Reflection.ManifestResourceInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.ManifestResourceInfo __selfConverted = InteropUtils.GetInstance<System.Reflection.ManifestResourceInfo>(__self);
	
	
	    try {
			System.String __returnValue = __selfConverted.FileName;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_ManifestResourceInfo_ResourceLocation_Get")]
	internal static System.Reflection.ResourceLocation /* System.Reflection.ResourceLocation */ System_Reflection_ManifestResourceInfo_ResourceLocation_Get(void* /* System.Reflection.ManifestResourceInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.ManifestResourceInfo __selfConverted = InteropUtils.GetInstance<System.Reflection.ManifestResourceInfo>(__self);
	
	
	    try {
			System.Reflection.ResourceLocation __returnValue = __selfConverted.ResourceLocation;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return default(System.Reflection.ResourceLocation);
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_ManifestResourceInfo_TypeOf")]
	internal static void* /* System.Type */ System_Reflection_ManifestResourceInfo_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.Reflection.ManifestResourceInfo);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_ManifestResourceInfo_Destroy")]
	internal static void /* System.Void */ System_Reflection_ManifestResourceInfo_Destroy(void* /* System.Reflection.ManifestResourceInfo */ __self)
	{
	
		InteropUtils.FreeIfAllocated(__self);
	}
	
}


internal unsafe class System_Reflection_ResourceLocation
{
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_ResourceLocation_TypeOf")]
	internal static void* /* System.Type */ System_Reflection_ResourceLocation_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.Reflection.ResourceLocation);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
}


internal unsafe class System_Reflection_ModuleResolveEventHandler
{
	internal void* Context { get; }
	internal delegate* unmanaged<void* /* context */, void* /* System.Object */ /* sender */, void* /* System.ResolveEventArgs */ /* e */, void* /* System.Reflection.Module */ /* return type */> CFunction { get; }
	internal delegate* unmanaged<void*, void> CDestructorFunction { get; }

	private WeakReference<System.Reflection.ModuleResolveEventHandler> m_trampoline;
	internal System.Reflection.ModuleResolveEventHandler Trampoline
	{
		get {
			System.Reflection.ModuleResolveEventHandler? trampoline;

			if (m_trampoline is not null) {
				m_trampoline.TryGetTarget(out trampoline);
			} else {
				trampoline = null;
			}

			if (trampoline is null) {
				trampoline = CreateTrampoline();
				m_trampoline = new(trampoline);
			}

			return trampoline;
		}
	}

	private System_Reflection_ModuleResolveEventHandler(void* context, delegate* unmanaged<void* /* context */, void* /* System.Object */ /* sender */, void* /* System.ResolveEventArgs */ /* e */, void* /* System.Reflection.Module */ /* return type */> cFunction, delegate* unmanaged<void*, void> cDestructorFunction)
	{
		Context = context;
		CFunction = cFunction;
		CDestructorFunction = cDestructorFunction;
	}

	internal System_Reflection_ModuleResolveEventHandler(System.Reflection.ModuleResolveEventHandler originalDelegate)
	{
		m_trampoline = new(originalDelegate);
	}

	~System_Reflection_ModuleResolveEventHandler()
	{
		if (CDestructorFunction is null) {
			return;
		}

		CDestructorFunction(Context);
	}

	private System.Reflection.ModuleResolveEventHandler? CreateTrampoline()
	{
		if (CFunction is null) {
			return null;
		}

		System.Type typeOfSelf = typeof(System_Reflection_ModuleResolveEventHandler);
		string nameOfInvocationMethod = nameof(__InvokeByCallingCFunction);
		System.Reflection.BindingFlags bindingFlags = System.Reflection.BindingFlags.Instance | BindingFlags.NonPublic;
		System.Reflection.MethodInfo? invocationMethod = typeOfSelf.GetMethod(nameOfInvocationMethod, bindingFlags);

		if (invocationMethod is null) {
			throw new Exception("Failed to retrieve delegate invocation method");
		}

		System.Reflection.ModuleResolveEventHandler trampoline = (System.Reflection.ModuleResolveEventHandler)System.Delegate.CreateDelegate(typeof(System.Reflection.ModuleResolveEventHandler), this, invocationMethod);

		return trampoline;
	}

	private System.Reflection.Module __InvokeByCallingCFunction(System.Object /* System.Object */ sender, System.ResolveEventArgs /* System.ResolveEventArgs */ e)
	{
		void* senderConverted = sender.AllocateGCHandleAndGetAddress();
		void* eConverted = e.AllocateGCHandleAndGetAddress();
	

		var __returnValue = CFunction(Context, senderConverted, eConverted);
		var __returnValueConverted = InteropUtils.GetInstance<System.Reflection.Module>(__returnValue);

		InteropUtils.FreeIfAllocated(__returnValue);

		return __returnValueConverted;
	}

	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_ModuleResolveEventHandler_Create")]
	public static void* Create(void* context, delegate* unmanaged<void* /* context */, void* /* System.Object */ /* sender */, void* /* System.ResolveEventArgs */ /* e */, void* /* System.Reflection.Module */ /* return type */> cFunction, delegate* unmanaged<void*, void> cDestructorFunction)
	{
		var self = new System_Reflection_ModuleResolveEventHandler(context, cFunction, cDestructorFunction);
		void* selfHandle = self.AllocateGCHandleAndGetAddress();

		return selfHandle;
	}

	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_ModuleResolveEventHandler_Invoke")]
	public static void* /* System.Reflection.Module */ Invoke(void* self, void* /* System.Object */ sender, void* /* System.ResolveEventArgs */ e, void** __outException)
	{
		if (self is null) {
			throw new ArgumentNullException(nameof(self));
		}

		try {
			var selfConverted = InteropUtils.GetInstance<System_Reflection_ModuleResolveEventHandler>(self);

			System.Object senderConverted = InteropUtils.GetInstance<System.Object>(sender);
			System.ResolveEventArgs eConverted = InteropUtils.GetInstance<System.ResolveEventArgs>(e);
		

			var __returnValue = selfConverted.Trampoline(senderConverted, eConverted);
			var __returnValueConverted = __returnValue.AllocateGCHandleAndGetAddress();

			return __returnValueConverted;
		} catch (Exception __exception) {
			if (__outException is not null) {
				void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();

				*__outException = __exceptionHandleAddress;
			}

			return null;
		}
	}

	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_ModuleResolveEventHandler_Context_Get")]
	public static void* Context_Get(void* self)
	{
		if (self is null) {
			throw new ArgumentNullException(nameof(self));
		}

		var selfConverted = InteropUtils.GetInstance<System_Reflection_ModuleResolveEventHandler>(self);

		return selfConverted.Context;
	}

	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_ModuleResolveEventHandler_CFunction_Get")]
	public static delegate* unmanaged<void* /* context */, void* /* System.Object */ /* sender */, void* /* System.ResolveEventArgs */ /* e */, void* /* System.Reflection.Module */ /* return type */> CFunction_Get(void* self)
	{
		if (self is null) {
			throw new ArgumentNullException(nameof(self));
		}

		var selfConverted = InteropUtils.GetInstance<System_Reflection_ModuleResolveEventHandler>(self);

		return selfConverted.CFunction;
	}

	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_ModuleResolveEventHandler_CDestructorFunction_Get")]
	public static delegate* unmanaged<void*, void> CDestructorFunction_Get(void* self)
	{
		if (self is null) {
			throw new ArgumentNullException(nameof(self));
		}

		var selfConverted = InteropUtils.GetInstance<System_Reflection_ModuleResolveEventHandler>(self);

		return selfConverted.CDestructorFunction;
	}

	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_ModuleResolveEventHandler_TypeOf")]
	internal static void* /* System.Type */ System_Reflection_ModuleResolveEventHandler_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.Reflection.ModuleResolveEventHandler);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	

	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_ModuleResolveEventHandler_Destroy")]
	internal static void /* System.Void */ System_Reflection_ModuleResolveEventHandler_Destroy(void* /* System.Reflection.ModuleResolveEventHandler */ __self)
	{
	
		InteropUtils.FreeIfAllocated(__self);
	}
	
}


internal unsafe class System_Reflection_Module
{
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_Module_GetPEKind")]
	internal static void /* System.Void */ System_Reflection_Module_GetPEKind(void* /* System.Reflection.Module */ __self, System.Reflection.PortableExecutableKinds* /* System.Reflection.PortableExecutableKinds */ peKind, System.Reflection.ImageFileMachine* /* System.Reflection.ImageFileMachine */ machine, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.Module __selfConverted = InteropUtils.GetInstance<System.Reflection.Module>(__self);
	
		System.Reflection.PortableExecutableKinds peKindConverted;
		System.Reflection.ImageFileMachine machineConverted;
	
	    try {
			__selfConverted.GetPEKind(out peKindConverted, out machineConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			if (peKind is not null) {
				*peKind = peKindConverted;
			}
	
			if (machine is not null) {
				*machine = machineConverted;
			}
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			if (peKind is not null) {
				*peKind = default(System.Reflection.PortableExecutableKinds);
			}
	
			if (machine is not null) {
				*machine = default(System.Reflection.ImageFileMachine);
			}
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_Module_IsResource")]
	internal static byte /* System.Boolean */ System_Reflection_Module_IsResource(void* /* System.Reflection.Module */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.Module __selfConverted = InteropUtils.GetInstance<System.Reflection.Module>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.IsResource();
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_Module_IsDefined")]
	internal static byte /* System.Boolean */ System_Reflection_Module_IsDefined(void* /* System.Reflection.Module */ __self, void* /* System.Type */ attributeType, byte /* System.Boolean */ inherit, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.Module __selfConverted = InteropUtils.GetInstance<System.Reflection.Module>(__self);
	
		System.Type attributeTypeConverted = InteropUtils.GetInstance<System.Type>(attributeType);
		System.Boolean inheritConverted = inherit.ToBool();
	
	    try {
			System.Boolean __returnValue = __selfConverted.IsDefined(attributeTypeConverted, inheritConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_Module_GetCustomAttributes")]
	internal static void* /* System.Object[] */ System_Reflection_Module_GetCustomAttributes(void* /* System.Reflection.Module */ __self, byte /* System.Boolean */ inherit, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.Module __selfConverted = InteropUtils.GetInstance<System.Reflection.Module>(__self);
	
		System.Boolean inheritConverted = inherit.ToBool();
	
	    try {
			System.Object[] __returnValue = __selfConverted.GetCustomAttributes(inheritConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_Module_GetCustomAttributes_1")]
	internal static void* /* System.Object[] */ System_Reflection_Module_GetCustomAttributes_1(void* /* System.Reflection.Module */ __self, void* /* System.Type */ attributeType, byte /* System.Boolean */ inherit, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.Module __selfConverted = InteropUtils.GetInstance<System.Reflection.Module>(__self);
	
		System.Type attributeTypeConverted = InteropUtils.GetInstance<System.Type>(attributeType);
		System.Boolean inheritConverted = inherit.ToBool();
	
	    try {
			System.Object[] __returnValue = __selfConverted.GetCustomAttributes(attributeTypeConverted, inheritConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_Module_GetMethod")]
	internal static void* /* System.Reflection.MethodInfo */ System_Reflection_Module_GetMethod(void* /* System.Reflection.Module */ __self, void* /* System.String */ name, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.Module __selfConverted = InteropUtils.GetInstance<System.Reflection.Module>(__self);
	
		System.String nameConverted = InteropUtils.GetInstance<System.String>(name);
	
	    try {
			System.Reflection.MethodInfo __returnValue = __selfConverted.GetMethod(nameConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_Module_GetMethod_1")]
	internal static void* /* System.Reflection.MethodInfo */ System_Reflection_Module_GetMethod_1(void* /* System.Reflection.Module */ __self, void* /* System.String */ name, void* /* System.Type[] */ types, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.Module __selfConverted = InteropUtils.GetInstance<System.Reflection.Module>(__self);
	
		System.String nameConverted = InteropUtils.GetInstance<System.String>(name);
		System.Type[] typesConverted = InteropUtils.GetInstance<System.Type[]>(types);
	
	    try {
			System.Reflection.MethodInfo __returnValue = __selfConverted.GetMethod(nameConverted, typesConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_Module_GetMethod_2")]
	internal static void* /* System.Reflection.MethodInfo */ System_Reflection_Module_GetMethod_2(void* /* System.Reflection.Module */ __self, void* /* System.String */ name, System.Reflection.BindingFlags /* System.Reflection.BindingFlags */ bindingAttr, void* /* System.Reflection.Binder */ binder, System.Reflection.CallingConventions /* System.Reflection.CallingConventions */ callConvention, void* /* System.Type[] */ types, void* /* System.Reflection.ParameterModifier[] */ modifiers, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.Module __selfConverted = InteropUtils.GetInstance<System.Reflection.Module>(__self);
	
		System.String nameConverted = InteropUtils.GetInstance<System.String>(name);
		System.Reflection.Binder binderConverted = InteropUtils.GetInstance<System.Reflection.Binder>(binder);
		System.Type[] typesConverted = InteropUtils.GetInstance<System.Type[]>(types);
		System.Reflection.ParameterModifier[] modifiersConverted = InteropUtils.GetInstance<System.Reflection.ParameterModifier[]>(modifiers);
	
	    try {
			System.Reflection.MethodInfo __returnValue = __selfConverted.GetMethod(nameConverted, bindingAttr, binderConverted, callConvention, typesConverted, modifiersConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_Module_GetMethods")]
	internal static void* /* System.Reflection.MethodInfo[] */ System_Reflection_Module_GetMethods(void* /* System.Reflection.Module */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.Module __selfConverted = InteropUtils.GetInstance<System.Reflection.Module>(__self);
	
	
	    try {
			System.Reflection.MethodInfo[] __returnValue = __selfConverted.GetMethods();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_Module_GetMethods_1")]
	internal static void* /* System.Reflection.MethodInfo[] */ System_Reflection_Module_GetMethods_1(void* /* System.Reflection.Module */ __self, System.Reflection.BindingFlags /* System.Reflection.BindingFlags */ bindingFlags, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.Module __selfConverted = InteropUtils.GetInstance<System.Reflection.Module>(__self);
	
	
	    try {
			System.Reflection.MethodInfo[] __returnValue = __selfConverted.GetMethods(bindingFlags);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_Module_GetField")]
	internal static void* /* System.Reflection.FieldInfo */ System_Reflection_Module_GetField(void* /* System.Reflection.Module */ __self, void* /* System.String */ name, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.Module __selfConverted = InteropUtils.GetInstance<System.Reflection.Module>(__self);
	
		System.String nameConverted = InteropUtils.GetInstance<System.String>(name);
	
	    try {
			System.Reflection.FieldInfo __returnValue = __selfConverted.GetField(nameConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_Module_GetField_1")]
	internal static void* /* System.Reflection.FieldInfo */ System_Reflection_Module_GetField_1(void* /* System.Reflection.Module */ __self, void* /* System.String */ name, System.Reflection.BindingFlags /* System.Reflection.BindingFlags */ bindingAttr, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.Module __selfConverted = InteropUtils.GetInstance<System.Reflection.Module>(__self);
	
		System.String nameConverted = InteropUtils.GetInstance<System.String>(name);
	
	    try {
			System.Reflection.FieldInfo __returnValue = __selfConverted.GetField(nameConverted, bindingAttr);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_Module_GetFields")]
	internal static void* /* System.Reflection.FieldInfo[] */ System_Reflection_Module_GetFields(void* /* System.Reflection.Module */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.Module __selfConverted = InteropUtils.GetInstance<System.Reflection.Module>(__self);
	
	
	    try {
			System.Reflection.FieldInfo[] __returnValue = __selfConverted.GetFields();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_Module_GetFields_1")]
	internal static void* /* System.Reflection.FieldInfo[] */ System_Reflection_Module_GetFields_1(void* /* System.Reflection.Module */ __self, System.Reflection.BindingFlags /* System.Reflection.BindingFlags */ bindingFlags, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.Module __selfConverted = InteropUtils.GetInstance<System.Reflection.Module>(__self);
	
	
	    try {
			System.Reflection.FieldInfo[] __returnValue = __selfConverted.GetFields(bindingFlags);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_Module_GetTypes")]
	internal static void* /* System.Type[] */ System_Reflection_Module_GetTypes(void* /* System.Reflection.Module */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.Module __selfConverted = InteropUtils.GetInstance<System.Reflection.Module>(__self);
	
	
	    try {
			System.Type[] __returnValue = __selfConverted.GetTypes();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_Module_GetType_1")]
	internal static void* /* System.Type */ System_Reflection_Module_GetType_1(void* /* System.Reflection.Module */ __self, void* /* System.String */ className, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.Module __selfConverted = InteropUtils.GetInstance<System.Reflection.Module>(__self);
	
		System.String classNameConverted = InteropUtils.GetInstance<System.String>(className);
	
	    try {
			System.Type __returnValue = __selfConverted.GetType(classNameConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_Module_GetType_2")]
	internal static void* /* System.Type */ System_Reflection_Module_GetType_2(void* /* System.Reflection.Module */ __self, void* /* System.String */ className, byte /* System.Boolean */ ignoreCase, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.Module __selfConverted = InteropUtils.GetInstance<System.Reflection.Module>(__self);
	
		System.String classNameConverted = InteropUtils.GetInstance<System.String>(className);
		System.Boolean ignoreCaseConverted = ignoreCase.ToBool();
	
	    try {
			System.Type __returnValue = __selfConverted.GetType(classNameConverted, ignoreCaseConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_Module_GetType_3")]
	internal static void* /* System.Type */ System_Reflection_Module_GetType_3(void* /* System.Reflection.Module */ __self, void* /* System.String */ className, byte /* System.Boolean */ throwOnError, byte /* System.Boolean */ ignoreCase, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.Module __selfConverted = InteropUtils.GetInstance<System.Reflection.Module>(__self);
	
		System.String classNameConverted = InteropUtils.GetInstance<System.String>(className);
		System.Boolean throwOnErrorConverted = throwOnError.ToBool();
		System.Boolean ignoreCaseConverted = ignoreCase.ToBool();
	
	    try {
			System.Type __returnValue = __selfConverted.GetType(classNameConverted, throwOnErrorConverted, ignoreCaseConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_Module_FindTypes")]
	internal static void* /* System.Type[] */ System_Reflection_Module_FindTypes(void* /* System.Reflection.Module */ __self, void* /* System.Reflection.TypeFilter */ filter, void* /* System.Object */ filterCriteria, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.Module __selfConverted = InteropUtils.GetInstance<System.Reflection.Module>(__self);
	
		System.Reflection.TypeFilter filterConverted = InteropUtils.GetInstance<System_Reflection_TypeFilter>(filter)?.Trampoline;
		System.Object filterCriteriaConverted = InteropUtils.GetInstance<System.Object>(filterCriteria);
	
	    try {
			System.Type[] __returnValue = __selfConverted.FindTypes(filterConverted, filterCriteriaConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_Module_ResolveField")]
	internal static void* /* System.Reflection.FieldInfo */ System_Reflection_Module_ResolveField(void* /* System.Reflection.Module */ __self, int /* System.Int32 */ metadataToken, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.Module __selfConverted = InteropUtils.GetInstance<System.Reflection.Module>(__self);
	
	
	    try {
			System.Reflection.FieldInfo __returnValue = __selfConverted.ResolveField(metadataToken);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_Module_ResolveField_1")]
	internal static void* /* System.Reflection.FieldInfo */ System_Reflection_Module_ResolveField_1(void* /* System.Reflection.Module */ __self, int /* System.Int32 */ metadataToken, void* /* System.Type[] */ genericTypeArguments, void* /* System.Type[] */ genericMethodArguments, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.Module __selfConverted = InteropUtils.GetInstance<System.Reflection.Module>(__self);
	
		System.Type[] genericTypeArgumentsConverted = InteropUtils.GetInstance<System.Type[]>(genericTypeArguments);
		System.Type[] genericMethodArgumentsConverted = InteropUtils.GetInstance<System.Type[]>(genericMethodArguments);
	
	    try {
			System.Reflection.FieldInfo __returnValue = __selfConverted.ResolveField(metadataToken, genericTypeArgumentsConverted, genericMethodArgumentsConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_Module_ResolveMember")]
	internal static void* /* System.Reflection.MemberInfo */ System_Reflection_Module_ResolveMember(void* /* System.Reflection.Module */ __self, int /* System.Int32 */ metadataToken, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.Module __selfConverted = InteropUtils.GetInstance<System.Reflection.Module>(__self);
	
	
	    try {
			System.Reflection.MemberInfo __returnValue = __selfConverted.ResolveMember(metadataToken);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_Module_ResolveMember_1")]
	internal static void* /* System.Reflection.MemberInfo */ System_Reflection_Module_ResolveMember_1(void* /* System.Reflection.Module */ __self, int /* System.Int32 */ metadataToken, void* /* System.Type[] */ genericTypeArguments, void* /* System.Type[] */ genericMethodArguments, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.Module __selfConverted = InteropUtils.GetInstance<System.Reflection.Module>(__self);
	
		System.Type[] genericTypeArgumentsConverted = InteropUtils.GetInstance<System.Type[]>(genericTypeArguments);
		System.Type[] genericMethodArgumentsConverted = InteropUtils.GetInstance<System.Type[]>(genericMethodArguments);
	
	    try {
			System.Reflection.MemberInfo __returnValue = __selfConverted.ResolveMember(metadataToken, genericTypeArgumentsConverted, genericMethodArgumentsConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_Module_ResolveMethod")]
	internal static void* /* System.Reflection.MethodBase */ System_Reflection_Module_ResolveMethod(void* /* System.Reflection.Module */ __self, int /* System.Int32 */ metadataToken, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.Module __selfConverted = InteropUtils.GetInstance<System.Reflection.Module>(__self);
	
	
	    try {
			System.Reflection.MethodBase __returnValue = __selfConverted.ResolveMethod(metadataToken);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_Module_ResolveMethod_1")]
	internal static void* /* System.Reflection.MethodBase */ System_Reflection_Module_ResolveMethod_1(void* /* System.Reflection.Module */ __self, int /* System.Int32 */ metadataToken, void* /* System.Type[] */ genericTypeArguments, void* /* System.Type[] */ genericMethodArguments, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.Module __selfConverted = InteropUtils.GetInstance<System.Reflection.Module>(__self);
	
		System.Type[] genericTypeArgumentsConverted = InteropUtils.GetInstance<System.Type[]>(genericTypeArguments);
		System.Type[] genericMethodArgumentsConverted = InteropUtils.GetInstance<System.Type[]>(genericMethodArguments);
	
	    try {
			System.Reflection.MethodBase __returnValue = __selfConverted.ResolveMethod(metadataToken, genericTypeArgumentsConverted, genericMethodArgumentsConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_Module_ResolveSignature")]
	internal static void* /* System.Byte[] */ System_Reflection_Module_ResolveSignature(void* /* System.Reflection.Module */ __self, int /* System.Int32 */ metadataToken, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.Module __selfConverted = InteropUtils.GetInstance<System.Reflection.Module>(__self);
	
	
	    try {
			System.Byte[] __returnValue = __selfConverted.ResolveSignature(metadataToken);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_Module_ResolveString")]
	internal static void* /* System.String */ System_Reflection_Module_ResolveString(void* /* System.Reflection.Module */ __self, int /* System.Int32 */ metadataToken, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.Module __selfConverted = InteropUtils.GetInstance<System.Reflection.Module>(__self);
	
	
	    try {
			System.String __returnValue = __selfConverted.ResolveString(metadataToken);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_Module_ResolveType")]
	internal static void* /* System.Type */ System_Reflection_Module_ResolveType(void* /* System.Reflection.Module */ __self, int /* System.Int32 */ metadataToken, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.Module __selfConverted = InteropUtils.GetInstance<System.Reflection.Module>(__self);
	
	
	    try {
			System.Type __returnValue = __selfConverted.ResolveType(metadataToken);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_Module_ResolveType_1")]
	internal static void* /* System.Type */ System_Reflection_Module_ResolveType_1(void* /* System.Reflection.Module */ __self, int /* System.Int32 */ metadataToken, void* /* System.Type[] */ genericTypeArguments, void* /* System.Type[] */ genericMethodArguments, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.Module __selfConverted = InteropUtils.GetInstance<System.Reflection.Module>(__self);
	
		System.Type[] genericTypeArgumentsConverted = InteropUtils.GetInstance<System.Type[]>(genericTypeArguments);
		System.Type[] genericMethodArgumentsConverted = InteropUtils.GetInstance<System.Type[]>(genericMethodArguments);
	
	    try {
			System.Type __returnValue = __selfConverted.ResolveType(metadataToken, genericTypeArgumentsConverted, genericMethodArgumentsConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_Module_GetObjectData")]
	internal static void /* System.Void */ System_Reflection_Module_GetObjectData(void* /* System.Reflection.Module */ __self, void* /* System.Runtime.Serialization.SerializationInfo */ info, void* /* System.Runtime.Serialization.StreamingContext */ context, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.Module __selfConverted = InteropUtils.GetInstance<System.Reflection.Module>(__self);
	
		System.Runtime.Serialization.SerializationInfo infoConverted = InteropUtils.GetInstance<System.Runtime.Serialization.SerializationInfo>(info);
		System.Runtime.Serialization.StreamingContext contextConverted = InteropUtils.GetInstance<System.Runtime.Serialization.StreamingContext>(context);
	
	    try {
			__selfConverted.GetObjectData(infoConverted, contextConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_Module_Equals")]
	internal static byte /* System.Boolean */ System_Reflection_Module_Equals(void* /* System.Reflection.Module */ __self, void* /* System.Object */ o, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.Module __selfConverted = InteropUtils.GetInstance<System.Reflection.Module>(__self);
	
		System.Object oConverted = InteropUtils.GetInstance<System.Object>(o);
	
	    try {
			System.Boolean __returnValue = __selfConverted.Equals(oConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_Module_GetHashCode")]
	internal static int /* System.Int32 */ System_Reflection_Module_GetHashCode(void* /* System.Reflection.Module */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.Module __selfConverted = InteropUtils.GetInstance<System.Reflection.Module>(__self);
	
	
	    try {
			System.Int32 __returnValue = __selfConverted.GetHashCode();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_Module_ToString")]
	internal static void* /* System.String */ System_Reflection_Module_ToString(void* /* System.Reflection.Module */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.Module __selfConverted = InteropUtils.GetInstance<System.Reflection.Module>(__self);
	
	
	    try {
			System.String __returnValue = __selfConverted.ToString();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_Module_Assembly_Get")]
	internal static void* /* System.Reflection.Assembly */ System_Reflection_Module_Assembly_Get(void* /* System.Reflection.Module */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.Module __selfConverted = InteropUtils.GetInstance<System.Reflection.Module>(__self);
	
	
	    try {
			System.Reflection.Assembly __returnValue = __selfConverted.Assembly;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_Module_FullyQualifiedName_Get")]
	internal static void* /* System.String */ System_Reflection_Module_FullyQualifiedName_Get(void* /* System.Reflection.Module */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.Module __selfConverted = InteropUtils.GetInstance<System.Reflection.Module>(__self);
	
	
	    try {
			System.String __returnValue = __selfConverted.FullyQualifiedName;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_Module_Name_Get")]
	internal static void* /* System.String */ System_Reflection_Module_Name_Get(void* /* System.Reflection.Module */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.Module __selfConverted = InteropUtils.GetInstance<System.Reflection.Module>(__self);
	
	
	    try {
			System.String __returnValue = __selfConverted.Name;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_Module_MDStreamVersion_Get")]
	internal static int /* System.Int32 */ System_Reflection_Module_MDStreamVersion_Get(void* /* System.Reflection.Module */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.Module __selfConverted = InteropUtils.GetInstance<System.Reflection.Module>(__self);
	
	
	    try {
			System.Int32 __returnValue = __selfConverted.MDStreamVersion;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_Module_ModuleVersionId_Get")]
	internal static void* /* System.Guid */ System_Reflection_Module_ModuleVersionId_Get(void* /* System.Reflection.Module */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.Module __selfConverted = InteropUtils.GetInstance<System.Reflection.Module>(__self);
	
	
	    try {
			System.Guid __returnValue = __selfConverted.ModuleVersionId;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_Module_ScopeName_Get")]
	internal static void* /* System.String */ System_Reflection_Module_ScopeName_Get(void* /* System.Reflection.Module */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.Module __selfConverted = InteropUtils.GetInstance<System.Reflection.Module>(__self);
	
	
	    try {
			System.String __returnValue = __selfConverted.ScopeName;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_Module_ModuleHandle_Get")]
	internal static void* /* System.ModuleHandle */ System_Reflection_Module_ModuleHandle_Get(void* /* System.Reflection.Module */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.Module __selfConverted = InteropUtils.GetInstance<System.Reflection.Module>(__self);
	
	
	    try {
			System.ModuleHandle __returnValue = __selfConverted.ModuleHandle;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_Module_MetadataToken_Get")]
	internal static int /* System.Int32 */ System_Reflection_Module_MetadataToken_Get(void* /* System.Reflection.Module */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.Module __selfConverted = InteropUtils.GetInstance<System.Reflection.Module>(__self);
	
	
	    try {
			System.Int32 __returnValue = __selfConverted.MetadataToken;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_Module_FilterTypeName_Get")]
	internal static void* /* System.Reflection.TypeFilter */ System_Reflection_Module_FilterTypeName_Get()
	{
	
		System.Reflection.TypeFilter __returnValue = System.Reflection.Module.FilterTypeName;
		void* __returnValueNative = new System_Reflection_TypeFilter(__returnValue).AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_Module_FilterTypeNameIgnoreCase_Get")]
	internal static void* /* System.Reflection.TypeFilter */ System_Reflection_Module_FilterTypeNameIgnoreCase_Get()
	{
	
		System.Reflection.TypeFilter __returnValue = System.Reflection.Module.FilterTypeNameIgnoreCase;
		void* __returnValueNative = new System_Reflection_TypeFilter(__returnValue).AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_Module_TypeOf")]
	internal static void* /* System.Type */ System_Reflection_Module_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.Reflection.Module);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_Module_Destroy")]
	internal static void /* System.Void */ System_Reflection_Module_Destroy(void* /* System.Reflection.Module */ __self)
	{
	
		InteropUtils.FreeIfAllocated(__self);
	}
	
}


internal unsafe class System_Guid
{
	[UnmanagedCallersOnly(EntryPoint = "System_Guid_Parse")]
	internal static void* /* System.Guid */ System_Guid_Parse(void* /* System.String */ input, void** /* System.Exception */ __outException)
	{
		System.String inputConverted = InteropUtils.GetInstance<System.String>(input);
	
	    try {
			System.Guid __returnValue = System.Guid.Parse(inputConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Guid_TryParse")]
	internal static byte /* System.Boolean */ System_Guid_TryParse(void* /* System.String */ input, void** /* System.Guid */ result, void** /* System.Exception */ __outException)
	{
		System.String inputConverted = InteropUtils.GetInstance<System.String>(input);
		System.Guid resultConverted;
	
	    try {
			System.Boolean __returnValue = System.Guid.TryParse(inputConverted, out resultConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			if (result is not null) {
				*result = resultConverted.AllocateGCHandleAndGetAddress();
			}
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			if (result is not null) {
				*result = null;
			}
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Guid_ParseExact")]
	internal static void* /* System.Guid */ System_Guid_ParseExact(void* /* System.String */ input, void* /* System.String */ format, void** /* System.Exception */ __outException)
	{
		System.String inputConverted = InteropUtils.GetInstance<System.String>(input);
		System.String formatConverted = InteropUtils.GetInstance<System.String>(format);
	
	    try {
			System.Guid __returnValue = System.Guid.ParseExact(inputConverted, formatConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Guid_TryParseExact")]
	internal static byte /* System.Boolean */ System_Guid_TryParseExact(void* /* System.String */ input, void* /* System.String */ format, void** /* System.Guid */ result, void** /* System.Exception */ __outException)
	{
		System.String inputConverted = InteropUtils.GetInstance<System.String>(input);
		System.String formatConverted = InteropUtils.GetInstance<System.String>(format);
		System.Guid resultConverted;
	
	    try {
			System.Boolean __returnValue = System.Guid.TryParseExact(inputConverted, formatConverted, out resultConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			if (result is not null) {
				*result = resultConverted.AllocateGCHandleAndGetAddress();
			}
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			if (result is not null) {
				*result = null;
			}
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Guid_ToByteArray")]
	internal static void* /* System.Byte[] */ System_Guid_ToByteArray(void* /* System.Guid */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Guid __selfConverted = InteropUtils.GetInstance<System.Guid>(__self);
	
	
	    try {
			System.Byte[] __returnValue = __selfConverted.ToByteArray();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Guid_ToByteArray_1")]
	internal static void* /* System.Byte[] */ System_Guid_ToByteArray_1(void* /* System.Guid */ __self, byte /* System.Boolean */ bigEndian, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Guid __selfConverted = InteropUtils.GetInstance<System.Guid>(__self);
	
		System.Boolean bigEndianConverted = bigEndian.ToBool();
	
	    try {
			System.Byte[] __returnValue = __selfConverted.ToByteArray(bigEndianConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Guid_GetHashCode")]
	internal static int /* System.Int32 */ System_Guid_GetHashCode(void* /* System.Guid */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Guid __selfConverted = InteropUtils.GetInstance<System.Guid>(__self);
	
	
	    try {
			System.Int32 __returnValue = __selfConverted.GetHashCode();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Guid_Equals")]
	internal static byte /* System.Boolean */ System_Guid_Equals(void* /* System.Guid */ __self, void* /* System.Object */ o, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Guid __selfConverted = InteropUtils.GetInstance<System.Guid>(__self);
	
		System.Object oConverted = InteropUtils.GetInstance<System.Object>(o);
	
	    try {
			System.Boolean __returnValue = __selfConverted.Equals(oConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Guid_Equals_1")]
	internal static byte /* System.Boolean */ System_Guid_Equals_1(void* /* System.Guid */ __self, void* /* System.Guid */ g, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Guid __selfConverted = InteropUtils.GetInstance<System.Guid>(__self);
	
		System.Guid gConverted = InteropUtils.GetInstance<System.Guid>(g);
	
	    try {
			System.Boolean __returnValue = __selfConverted.Equals(gConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Guid_CompareTo")]
	internal static int /* System.Int32 */ System_Guid_CompareTo(void* /* System.Guid */ __self, void* /* System.Object */ value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Guid __selfConverted = InteropUtils.GetInstance<System.Guid>(__self);
	
		System.Object valueConverted = InteropUtils.GetInstance<System.Object>(value);
	
	    try {
			System.Int32 __returnValue = __selfConverted.CompareTo(valueConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Guid_CompareTo_1")]
	internal static int /* System.Int32 */ System_Guid_CompareTo_1(void* /* System.Guid */ __self, void* /* System.Guid */ value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Guid __selfConverted = InteropUtils.GetInstance<System.Guid>(__self);
	
		System.Guid valueConverted = InteropUtils.GetInstance<System.Guid>(value);
	
	    try {
			System.Int32 __returnValue = __selfConverted.CompareTo(valueConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Guid_ToString")]
	internal static void* /* System.String */ System_Guid_ToString(void* /* System.Guid */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Guid __selfConverted = InteropUtils.GetInstance<System.Guid>(__self);
	
	
	    try {
			System.String __returnValue = __selfConverted.ToString();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Guid_ToString_1")]
	internal static void* /* System.String */ System_Guid_ToString_1(void* /* System.Guid */ __self, void* /* System.String */ format, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Guid __selfConverted = InteropUtils.GetInstance<System.Guid>(__self);
	
		System.String formatConverted = InteropUtils.GetInstance<System.String>(format);
	
	    try {
			System.String __returnValue = __selfConverted.ToString(formatConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Guid_ToString_2")]
	internal static void* /* System.String */ System_Guid_ToString_2(void* /* System.Guid */ __self, void* /* System.String */ format, void* /* System.IFormatProvider */ provider, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Guid __selfConverted = InteropUtils.GetInstance<System.Guid>(__self);
	
		System.String formatConverted = InteropUtils.GetInstance<System.String>(format);
		System.IFormatProvider providerConverted = InteropUtils.GetInstance<System.IFormatProvider>(provider);
	
	    try {
			System.String __returnValue = __selfConverted.ToString(formatConverted, providerConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Guid_Parse_1")]
	internal static void* /* System.Guid */ System_Guid_Parse_1(void* /* System.String */ s, void* /* System.IFormatProvider */ provider, void** /* System.Exception */ __outException)
	{
		System.String sConverted = InteropUtils.GetInstance<System.String>(s);
		System.IFormatProvider providerConverted = InteropUtils.GetInstance<System.IFormatProvider>(provider);
	
	    try {
			System.Guid __returnValue = System.Guid.Parse(sConverted, providerConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Guid_TryParse_1")]
	internal static byte /* System.Boolean */ System_Guid_TryParse_1(void* /* System.String */ s, void* /* System.IFormatProvider */ provider, void** /* System.Guid */ result, void** /* System.Exception */ __outException)
	{
		System.String sConverted = InteropUtils.GetInstance<System.String>(s);
		System.IFormatProvider providerConverted = InteropUtils.GetInstance<System.IFormatProvider>(provider);
		System.Guid resultConverted;
	
	    try {
			System.Boolean __returnValue = System.Guid.TryParse(sConverted, providerConverted, out resultConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			if (result is not null) {
				*result = resultConverted.AllocateGCHandleAndGetAddress();
			}
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			if (result is not null) {
				*result = null;
			}
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Guid_NewGuid")]
	internal static void* /* System.Guid */ System_Guid_NewGuid(void** /* System.Exception */ __outException)
	{
	
	    try {
			System.Guid __returnValue = System.Guid.NewGuid();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Guid_Create")]
	internal static void* /* System.Guid */ System_Guid_Create(void* /* System.Byte[] */ b, void** /* System.Exception */ __outException)
	{
		System.Byte[] bConverted = InteropUtils.GetInstance<System.Byte[]>(b);
	
	    try {
			System.Guid __returnValue = new System.Guid(bConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Guid_Create_1")]
	internal static void* /* System.Guid */ System_Guid_Create_1(uint /* System.UInt32 */ a, ushort /* System.UInt16 */ b, ushort /* System.UInt16 */ c, byte /* System.Byte */ d, byte /* System.Byte */ e, byte /* System.Byte */ f, byte /* System.Byte */ g, byte /* System.Byte */ h, byte /* System.Byte */ i, byte /* System.Byte */ j, byte /* System.Byte */ k, void** /* System.Exception */ __outException)
	{
	
	    try {
			System.Guid __returnValue = new System.Guid(a, b, c, d, e, f, g, h, i, j, k);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Guid_Create_2")]
	internal static void* /* System.Guid */ System_Guid_Create_2(int /* System.Int32 */ a, short /* System.Int16 */ b, short /* System.Int16 */ c, void* /* System.Byte[] */ d, void** /* System.Exception */ __outException)
	{
		System.Byte[] dConverted = InteropUtils.GetInstance<System.Byte[]>(d);
	
	    try {
			System.Guid __returnValue = new System.Guid(a, b, c, dConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Guid_Create_3")]
	internal static void* /* System.Guid */ System_Guid_Create_3(int /* System.Int32 */ a, short /* System.Int16 */ b, short /* System.Int16 */ c, byte /* System.Byte */ d, byte /* System.Byte */ e, byte /* System.Byte */ f, byte /* System.Byte */ g, byte /* System.Byte */ h, byte /* System.Byte */ i, byte /* System.Byte */ j, byte /* System.Byte */ k, void** /* System.Exception */ __outException)
	{
	
	    try {
			System.Guid __returnValue = new System.Guid(a, b, c, d, e, f, g, h, i, j, k);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Guid_Create_4")]
	internal static void* /* System.Guid */ System_Guid_Create_4(void* /* System.String */ g, void** /* System.Exception */ __outException)
	{
		System.String gConverted = InteropUtils.GetInstance<System.String>(g);
	
	    try {
			System.Guid __returnValue = new System.Guid(gConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Guid_Empty_Get")]
	internal static void* /* System.Guid */ System_Guid_Empty_Get()
	{
	
		System.Guid __returnValue = System.Guid.Empty;
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Guid_Create_5")]
	internal static void* /* System.Guid */ System_Guid_Create_5(void** /* System.Exception */ __outException)
	{
	
	    try {
			System.Guid __returnValue = new System.Guid();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Guid_TypeOf")]
	internal static void* /* System.Type */ System_Guid_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.Guid);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Guid_Destroy")]
	internal static void /* System.Void */ System_Guid_Destroy(void* /* System.Guid */ __self)
	{
	
		InteropUtils.FreeIfAllocated(__self);
	}
	
}



internal unsafe class System_Reflection_PortableExecutableKinds
{
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_PortableExecutableKinds_TypeOf")]
	internal static void* /* System.Type */ System_Reflection_PortableExecutableKinds_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.Reflection.PortableExecutableKinds);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
}



internal unsafe class System_Reflection_ImageFileMachine
{
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_ImageFileMachine_TypeOf")]
	internal static void* /* System.Type */ System_Reflection_ImageFileMachine_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.Reflection.ImageFileMachine);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
}



internal unsafe class System_Reflection_TypeFilter
{
	internal void* Context { get; }
	internal delegate* unmanaged<void* /* context */, void* /* System.Type */ /* m */, void* /* System.Object */ /* filterCriteria */, byte /* System.Boolean */ /* return type */> CFunction { get; }
	internal delegate* unmanaged<void*, void> CDestructorFunction { get; }

	private WeakReference<System.Reflection.TypeFilter> m_trampoline;
	internal System.Reflection.TypeFilter Trampoline
	{
		get {
			System.Reflection.TypeFilter? trampoline;

			if (m_trampoline is not null) {
				m_trampoline.TryGetTarget(out trampoline);
			} else {
				trampoline = null;
			}

			if (trampoline is null) {
				trampoline = CreateTrampoline();
				m_trampoline = new(trampoline);
			}

			return trampoline;
		}
	}

	private System_Reflection_TypeFilter(void* context, delegate* unmanaged<void* /* context */, void* /* System.Type */ /* m */, void* /* System.Object */ /* filterCriteria */, byte /* System.Boolean */ /* return type */> cFunction, delegate* unmanaged<void*, void> cDestructorFunction)
	{
		Context = context;
		CFunction = cFunction;
		CDestructorFunction = cDestructorFunction;
	}

	internal System_Reflection_TypeFilter(System.Reflection.TypeFilter originalDelegate)
	{
		m_trampoline = new(originalDelegate);
	}

	~System_Reflection_TypeFilter()
	{
		if (CDestructorFunction is null) {
			return;
		}

		CDestructorFunction(Context);
	}

	private System.Reflection.TypeFilter? CreateTrampoline()
	{
		if (CFunction is null) {
			return null;
		}

		System.Type typeOfSelf = typeof(System_Reflection_TypeFilter);
		string nameOfInvocationMethod = nameof(__InvokeByCallingCFunction);
		System.Reflection.BindingFlags bindingFlags = System.Reflection.BindingFlags.Instance | BindingFlags.NonPublic;
		System.Reflection.MethodInfo? invocationMethod = typeOfSelf.GetMethod(nameOfInvocationMethod, bindingFlags);

		if (invocationMethod is null) {
			throw new Exception("Failed to retrieve delegate invocation method");
		}

		System.Reflection.TypeFilter trampoline = (System.Reflection.TypeFilter)System.Delegate.CreateDelegate(typeof(System.Reflection.TypeFilter), this, invocationMethod);

		return trampoline;
	}

	private System.Boolean __InvokeByCallingCFunction(System.Type /* System.Type */ m, System.Object /* System.Object */ filterCriteria)
	{
		void* mConverted = m.AllocateGCHandleAndGetAddress();
		void* filterCriteriaConverted = filterCriteria.AllocateGCHandleAndGetAddress();
	

		var __returnValue = CFunction(Context, mConverted, filterCriteriaConverted);
		var __returnValueConverted = __returnValue.ToBool();

		return __returnValueConverted;
	}

	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_TypeFilter_Create")]
	public static void* Create(void* context, delegate* unmanaged<void* /* context */, void* /* System.Type */ /* m */, void* /* System.Object */ /* filterCriteria */, byte /* System.Boolean */ /* return type */> cFunction, delegate* unmanaged<void*, void> cDestructorFunction)
	{
		var self = new System_Reflection_TypeFilter(context, cFunction, cDestructorFunction);
		void* selfHandle = self.AllocateGCHandleAndGetAddress();

		return selfHandle;
	}

	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_TypeFilter_Invoke")]
	public static byte /* System.Boolean */ Invoke(void* self, void* /* System.Type */ m, void* /* System.Object */ filterCriteria, void** __outException)
	{
		if (self is null) {
			throw new ArgumentNullException(nameof(self));
		}

		try {
			var selfConverted = InteropUtils.GetInstance<System_Reflection_TypeFilter>(self);

			System.Type mConverted = InteropUtils.GetInstance<System.Type>(m);
			System.Object filterCriteriaConverted = InteropUtils.GetInstance<System.Object>(filterCriteria);
		

			var __returnValue = selfConverted.Trampoline(mConverted, filterCriteriaConverted);
			var __returnValueConverted = __returnValue.ToCBool();

			return __returnValueConverted;
		} catch (Exception __exception) {
			if (__outException is not null) {
				void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();

				*__outException = __exceptionHandleAddress;
			}

			return 0;
		}
	}

	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_TypeFilter_Context_Get")]
	public static void* Context_Get(void* self)
	{
		if (self is null) {
			throw new ArgumentNullException(nameof(self));
		}

		var selfConverted = InteropUtils.GetInstance<System_Reflection_TypeFilter>(self);

		return selfConverted.Context;
	}

	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_TypeFilter_CFunction_Get")]
	public static delegate* unmanaged<void* /* context */, void* /* System.Type */ /* m */, void* /* System.Object */ /* filterCriteria */, byte /* System.Boolean */ /* return type */> CFunction_Get(void* self)
	{
		if (self is null) {
			throw new ArgumentNullException(nameof(self));
		}

		var selfConverted = InteropUtils.GetInstance<System_Reflection_TypeFilter>(self);

		return selfConverted.CFunction;
	}

	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_TypeFilter_CDestructorFunction_Get")]
	public static delegate* unmanaged<void*, void> CDestructorFunction_Get(void* self)
	{
		if (self is null) {
			throw new ArgumentNullException(nameof(self));
		}

		var selfConverted = InteropUtils.GetInstance<System_Reflection_TypeFilter>(self);

		return selfConverted.CDestructorFunction;
	}

	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_TypeFilter_TypeOf")]
	internal static void* /* System.Type */ System_Reflection_TypeFilter_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.Reflection.TypeFilter);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	

	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_TypeFilter_Destroy")]
	internal static void /* System.Void */ System_Reflection_TypeFilter_Destroy(void* /* System.Reflection.TypeFilter */ __self)
	{
	
		InteropUtils.FreeIfAllocated(__self);
	}
	
}


internal unsafe class System_ResolveEventArgs
{
	[UnmanagedCallersOnly(EntryPoint = "System_ResolveEventArgs_Create")]
	internal static void* /* System.ResolveEventArgs */ System_ResolveEventArgs_Create(void* /* System.String */ name, void** /* System.Exception */ __outException)
	{
		System.String nameConverted = InteropUtils.GetInstance<System.String>(name);
	
	    try {
			System.ResolveEventArgs __returnValue = new System.ResolveEventArgs(nameConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_ResolveEventArgs_Create_1")]
	internal static void* /* System.ResolveEventArgs */ System_ResolveEventArgs_Create_1(void* /* System.String */ name, void* /* System.Reflection.Assembly */ requestingAssembly, void** /* System.Exception */ __outException)
	{
		System.String nameConverted = InteropUtils.GetInstance<System.String>(name);
		System.Reflection.Assembly requestingAssemblyConverted = InteropUtils.GetInstance<System.Reflection.Assembly>(requestingAssembly);
	
	    try {
			System.ResolveEventArgs __returnValue = new System.ResolveEventArgs(nameConverted, requestingAssemblyConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_ResolveEventArgs_Name_Get")]
	internal static void* /* System.String */ System_ResolveEventArgs_Name_Get(void* /* System.ResolveEventArgs */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.ResolveEventArgs __selfConverted = InteropUtils.GetInstance<System.ResolveEventArgs>(__self);
	
	
	    try {
			System.String __returnValue = __selfConverted.Name;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_ResolveEventArgs_RequestingAssembly_Get")]
	internal static void* /* System.Reflection.Assembly */ System_ResolveEventArgs_RequestingAssembly_Get(void* /* System.ResolveEventArgs */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.ResolveEventArgs __selfConverted = InteropUtils.GetInstance<System.ResolveEventArgs>(__self);
	
	
	    try {
			System.Reflection.Assembly __returnValue = __selfConverted.RequestingAssembly;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_ResolveEventArgs_TypeOf")]
	internal static void* /* System.Type */ System_ResolveEventArgs_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.ResolveEventArgs);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_ResolveEventArgs_Destroy")]
	internal static void /* System.Void */ System_ResolveEventArgs_Destroy(void* /* System.ResolveEventArgs */ __self)
	{
	
		InteropUtils.FreeIfAllocated(__self);
	}
	
}


internal unsafe class System_EventArgs
{
	[UnmanagedCallersOnly(EntryPoint = "System_EventArgs_Create")]
	internal static void* /* System.EventArgs */ System_EventArgs_Create(void** /* System.Exception */ __outException)
	{
	
	    try {
			System.EventArgs __returnValue = new System.EventArgs();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_EventArgs_Empty_Get")]
	internal static void* /* System.EventArgs */ System_EventArgs_Empty_Get()
	{
	
		System.EventArgs __returnValue = System.EventArgs.Empty;
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_EventArgs_TypeOf")]
	internal static void* /* System.Type */ System_EventArgs_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.EventArgs);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_EventArgs_Destroy")]
	internal static void /* System.Void */ System_EventArgs_Destroy(void* /* System.EventArgs */ __self)
	{
	
		InteropUtils.FreeIfAllocated(__self);
	}
	
}








internal unsafe class System_Security_SecurityRuleSet
{
	[UnmanagedCallersOnly(EntryPoint = "System_Security_SecurityRuleSet_TypeOf")]
	internal static void* /* System.Type */ System_Security_SecurityRuleSet_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.Security.SecurityRuleSet);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
}


internal unsafe class System_Text_Rune
{
	[UnmanagedCallersOnly(EntryPoint = "System_Text_Rune_CompareTo")]
	internal static int /* System.Int32 */ System_Text_Rune_CompareTo(void* /* System.Text.Rune */ __self, void* /* System.Text.Rune */ other, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Text.Rune __selfConverted = InteropUtils.GetInstance<System.Text.Rune>(__self);
	
		System.Text.Rune otherConverted = InteropUtils.GetInstance<System.Text.Rune>(other);
	
	    try {
			System.Int32 __returnValue = __selfConverted.CompareTo(otherConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Text_Rune_Equals")]
	internal static byte /* System.Boolean */ System_Text_Rune_Equals(void* /* System.Text.Rune */ __self, void* /* System.Object */ obj, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Text.Rune __selfConverted = InteropUtils.GetInstance<System.Text.Rune>(__self);
	
		System.Object objConverted = InteropUtils.GetInstance<System.Object>(obj);
	
	    try {
			System.Boolean __returnValue = __selfConverted.Equals(objConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Text_Rune_Equals_1")]
	internal static byte /* System.Boolean */ System_Text_Rune_Equals_1(void* /* System.Text.Rune */ __self, void* /* System.Text.Rune */ other, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Text.Rune __selfConverted = InteropUtils.GetInstance<System.Text.Rune>(__self);
	
		System.Text.Rune otherConverted = InteropUtils.GetInstance<System.Text.Rune>(other);
	
	    try {
			System.Boolean __returnValue = __selfConverted.Equals(otherConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Text_Rune_GetHashCode")]
	internal static int /* System.Int32 */ System_Text_Rune_GetHashCode(void* /* System.Text.Rune */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Text.Rune __selfConverted = InteropUtils.GetInstance<System.Text.Rune>(__self);
	
	
	    try {
			System.Int32 __returnValue = __selfConverted.GetHashCode();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Text_Rune_GetRuneAt")]
	internal static void* /* System.Text.Rune */ System_Text_Rune_GetRuneAt(void* /* System.String */ input, int /* System.Int32 */ index, void** /* System.Exception */ __outException)
	{
		System.String inputConverted = InteropUtils.GetInstance<System.String>(input);
	
	    try {
			System.Text.Rune __returnValue = System.Text.Rune.GetRuneAt(inputConverted, index);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Text_Rune_IsValid")]
	internal static byte /* System.Boolean */ System_Text_Rune_IsValid(int /* System.Int32 */ value, void** /* System.Exception */ __outException)
	{
	
	    try {
			System.Boolean __returnValue = System.Text.Rune.IsValid(value);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Text_Rune_IsValid_1")]
	internal static byte /* System.Boolean */ System_Text_Rune_IsValid_1(uint /* System.UInt32 */ value, void** /* System.Exception */ __outException)
	{
	
	    try {
			System.Boolean __returnValue = System.Text.Rune.IsValid(value);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Text_Rune_ToString")]
	internal static void* /* System.String */ System_Text_Rune_ToString(void* /* System.Text.Rune */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Text.Rune __selfConverted = InteropUtils.GetInstance<System.Text.Rune>(__self);
	
	
	    try {
			System.String __returnValue = __selfConverted.ToString();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Text_Rune_TryCreate")]
	internal static byte /* System.Boolean */ System_Text_Rune_TryCreate(char /* System.Char */ ch, void** /* System.Text.Rune */ result, void** /* System.Exception */ __outException)
	{
		System.Text.Rune resultConverted;
	
	    try {
			System.Boolean __returnValue = System.Text.Rune.TryCreate(ch, out resultConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			if (result is not null) {
				*result = resultConverted.AllocateGCHandleAndGetAddress();
			}
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			if (result is not null) {
				*result = null;
			}
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Text_Rune_TryCreate_1")]
	internal static byte /* System.Boolean */ System_Text_Rune_TryCreate_1(char /* System.Char */ highSurrogate, char /* System.Char */ lowSurrogate, void** /* System.Text.Rune */ result, void** /* System.Exception */ __outException)
	{
		System.Text.Rune resultConverted;
	
	    try {
			System.Boolean __returnValue = System.Text.Rune.TryCreate(highSurrogate, lowSurrogate, out resultConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			if (result is not null) {
				*result = resultConverted.AllocateGCHandleAndGetAddress();
			}
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			if (result is not null) {
				*result = null;
			}
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Text_Rune_TryCreate_2")]
	internal static byte /* System.Boolean */ System_Text_Rune_TryCreate_2(int /* System.Int32 */ value, void** /* System.Text.Rune */ result, void** /* System.Exception */ __outException)
	{
		System.Text.Rune resultConverted;
	
	    try {
			System.Boolean __returnValue = System.Text.Rune.TryCreate(value, out resultConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			if (result is not null) {
				*result = resultConverted.AllocateGCHandleAndGetAddress();
			}
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			if (result is not null) {
				*result = null;
			}
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Text_Rune_TryCreate_3")]
	internal static byte /* System.Boolean */ System_Text_Rune_TryCreate_3(uint /* System.UInt32 */ value, void** /* System.Text.Rune */ result, void** /* System.Exception */ __outException)
	{
		System.Text.Rune resultConverted;
	
	    try {
			System.Boolean __returnValue = System.Text.Rune.TryCreate(value, out resultConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			if (result is not null) {
				*result = resultConverted.AllocateGCHandleAndGetAddress();
			}
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			if (result is not null) {
				*result = null;
			}
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Text_Rune_TryGetRuneAt")]
	internal static byte /* System.Boolean */ System_Text_Rune_TryGetRuneAt(void* /* System.String */ input, int /* System.Int32 */ index, void** /* System.Text.Rune */ value, void** /* System.Exception */ __outException)
	{
		System.String inputConverted = InteropUtils.GetInstance<System.String>(input);
		System.Text.Rune valueConverted;
	
	    try {
			System.Boolean __returnValue = System.Text.Rune.TryGetRuneAt(inputConverted, index, out valueConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			if (value is not null) {
				*value = valueConverted.AllocateGCHandleAndGetAddress();
			}
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			if (value is not null) {
				*value = null;
			}
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Text_Rune_GetNumericValue")]
	internal static double /* System.Double */ System_Text_Rune_GetNumericValue(void* /* System.Text.Rune */ value, void** /* System.Exception */ __outException)
	{
		System.Text.Rune valueConverted = InteropUtils.GetInstance<System.Text.Rune>(value);
	
	    try {
			System.Double __returnValue = System.Text.Rune.GetNumericValue(valueConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Text_Rune_GetUnicodeCategory")]
	internal static System.Globalization.UnicodeCategory /* System.Globalization.UnicodeCategory */ System_Text_Rune_GetUnicodeCategory(void* /* System.Text.Rune */ value, void** /* System.Exception */ __outException)
	{
		System.Text.Rune valueConverted = InteropUtils.GetInstance<System.Text.Rune>(value);
	
	    try {
			System.Globalization.UnicodeCategory __returnValue = System.Text.Rune.GetUnicodeCategory(valueConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return default(System.Globalization.UnicodeCategory);
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Text_Rune_IsControl")]
	internal static byte /* System.Boolean */ System_Text_Rune_IsControl(void* /* System.Text.Rune */ value, void** /* System.Exception */ __outException)
	{
		System.Text.Rune valueConverted = InteropUtils.GetInstance<System.Text.Rune>(value);
	
	    try {
			System.Boolean __returnValue = System.Text.Rune.IsControl(valueConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Text_Rune_IsDigit")]
	internal static byte /* System.Boolean */ System_Text_Rune_IsDigit(void* /* System.Text.Rune */ value, void** /* System.Exception */ __outException)
	{
		System.Text.Rune valueConverted = InteropUtils.GetInstance<System.Text.Rune>(value);
	
	    try {
			System.Boolean __returnValue = System.Text.Rune.IsDigit(valueConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Text_Rune_IsLetter")]
	internal static byte /* System.Boolean */ System_Text_Rune_IsLetter(void* /* System.Text.Rune */ value, void** /* System.Exception */ __outException)
	{
		System.Text.Rune valueConverted = InteropUtils.GetInstance<System.Text.Rune>(value);
	
	    try {
			System.Boolean __returnValue = System.Text.Rune.IsLetter(valueConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Text_Rune_IsLetterOrDigit")]
	internal static byte /* System.Boolean */ System_Text_Rune_IsLetterOrDigit(void* /* System.Text.Rune */ value, void** /* System.Exception */ __outException)
	{
		System.Text.Rune valueConverted = InteropUtils.GetInstance<System.Text.Rune>(value);
	
	    try {
			System.Boolean __returnValue = System.Text.Rune.IsLetterOrDigit(valueConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Text_Rune_IsLower")]
	internal static byte /* System.Boolean */ System_Text_Rune_IsLower(void* /* System.Text.Rune */ value, void** /* System.Exception */ __outException)
	{
		System.Text.Rune valueConverted = InteropUtils.GetInstance<System.Text.Rune>(value);
	
	    try {
			System.Boolean __returnValue = System.Text.Rune.IsLower(valueConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Text_Rune_IsNumber")]
	internal static byte /* System.Boolean */ System_Text_Rune_IsNumber(void* /* System.Text.Rune */ value, void** /* System.Exception */ __outException)
	{
		System.Text.Rune valueConverted = InteropUtils.GetInstance<System.Text.Rune>(value);
	
	    try {
			System.Boolean __returnValue = System.Text.Rune.IsNumber(valueConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Text_Rune_IsPunctuation")]
	internal static byte /* System.Boolean */ System_Text_Rune_IsPunctuation(void* /* System.Text.Rune */ value, void** /* System.Exception */ __outException)
	{
		System.Text.Rune valueConverted = InteropUtils.GetInstance<System.Text.Rune>(value);
	
	    try {
			System.Boolean __returnValue = System.Text.Rune.IsPunctuation(valueConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Text_Rune_IsSeparator")]
	internal static byte /* System.Boolean */ System_Text_Rune_IsSeparator(void* /* System.Text.Rune */ value, void** /* System.Exception */ __outException)
	{
		System.Text.Rune valueConverted = InteropUtils.GetInstance<System.Text.Rune>(value);
	
	    try {
			System.Boolean __returnValue = System.Text.Rune.IsSeparator(valueConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Text_Rune_IsSymbol")]
	internal static byte /* System.Boolean */ System_Text_Rune_IsSymbol(void* /* System.Text.Rune */ value, void** /* System.Exception */ __outException)
	{
		System.Text.Rune valueConverted = InteropUtils.GetInstance<System.Text.Rune>(value);
	
	    try {
			System.Boolean __returnValue = System.Text.Rune.IsSymbol(valueConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Text_Rune_IsUpper")]
	internal static byte /* System.Boolean */ System_Text_Rune_IsUpper(void* /* System.Text.Rune */ value, void** /* System.Exception */ __outException)
	{
		System.Text.Rune valueConverted = InteropUtils.GetInstance<System.Text.Rune>(value);
	
	    try {
			System.Boolean __returnValue = System.Text.Rune.IsUpper(valueConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Text_Rune_IsWhiteSpace")]
	internal static byte /* System.Boolean */ System_Text_Rune_IsWhiteSpace(void* /* System.Text.Rune */ value, void** /* System.Exception */ __outException)
	{
		System.Text.Rune valueConverted = InteropUtils.GetInstance<System.Text.Rune>(value);
	
	    try {
			System.Boolean __returnValue = System.Text.Rune.IsWhiteSpace(valueConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Text_Rune_ToLower")]
	internal static void* /* System.Text.Rune */ System_Text_Rune_ToLower(void* /* System.Text.Rune */ value, void* /* System.Globalization.CultureInfo */ culture, void** /* System.Exception */ __outException)
	{
		System.Text.Rune valueConverted = InteropUtils.GetInstance<System.Text.Rune>(value);
		System.Globalization.CultureInfo cultureConverted = InteropUtils.GetInstance<System.Globalization.CultureInfo>(culture);
	
	    try {
			System.Text.Rune __returnValue = System.Text.Rune.ToLower(valueConverted, cultureConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Text_Rune_ToLowerInvariant")]
	internal static void* /* System.Text.Rune */ System_Text_Rune_ToLowerInvariant(void* /* System.Text.Rune */ value, void** /* System.Exception */ __outException)
	{
		System.Text.Rune valueConverted = InteropUtils.GetInstance<System.Text.Rune>(value);
	
	    try {
			System.Text.Rune __returnValue = System.Text.Rune.ToLowerInvariant(valueConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Text_Rune_ToUpper")]
	internal static void* /* System.Text.Rune */ System_Text_Rune_ToUpper(void* /* System.Text.Rune */ value, void* /* System.Globalization.CultureInfo */ culture, void** /* System.Exception */ __outException)
	{
		System.Text.Rune valueConverted = InteropUtils.GetInstance<System.Text.Rune>(value);
		System.Globalization.CultureInfo cultureConverted = InteropUtils.GetInstance<System.Globalization.CultureInfo>(culture);
	
	    try {
			System.Text.Rune __returnValue = System.Text.Rune.ToUpper(valueConverted, cultureConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Text_Rune_ToUpperInvariant")]
	internal static void* /* System.Text.Rune */ System_Text_Rune_ToUpperInvariant(void* /* System.Text.Rune */ value, void** /* System.Exception */ __outException)
	{
		System.Text.Rune valueConverted = InteropUtils.GetInstance<System.Text.Rune>(value);
	
	    try {
			System.Text.Rune __returnValue = System.Text.Rune.ToUpperInvariant(valueConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Text_Rune_Create")]
	internal static void* /* System.Text.Rune */ System_Text_Rune_Create(char /* System.Char */ ch, void** /* System.Exception */ __outException)
	{
	
	    try {
			System.Text.Rune __returnValue = new System.Text.Rune(ch);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Text_Rune_Create_1")]
	internal static void* /* System.Text.Rune */ System_Text_Rune_Create_1(char /* System.Char */ highSurrogate, char /* System.Char */ lowSurrogate, void** /* System.Exception */ __outException)
	{
	
	    try {
			System.Text.Rune __returnValue = new System.Text.Rune(highSurrogate, lowSurrogate);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Text_Rune_Create_2")]
	internal static void* /* System.Text.Rune */ System_Text_Rune_Create_2(int /* System.Int32 */ value, void** /* System.Exception */ __outException)
	{
	
	    try {
			System.Text.Rune __returnValue = new System.Text.Rune(value);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Text_Rune_Create_3")]
	internal static void* /* System.Text.Rune */ System_Text_Rune_Create_3(uint /* System.UInt32 */ value, void** /* System.Exception */ __outException)
	{
	
	    try {
			System.Text.Rune __returnValue = new System.Text.Rune(value);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Text_Rune_IsAscii_Get")]
	internal static byte /* System.Boolean */ System_Text_Rune_IsAscii_Get(void* /* System.Text.Rune */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Text.Rune __selfConverted = InteropUtils.GetInstance<System.Text.Rune>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.IsAscii;
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Text_Rune_IsBmp_Get")]
	internal static byte /* System.Boolean */ System_Text_Rune_IsBmp_Get(void* /* System.Text.Rune */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Text.Rune __selfConverted = InteropUtils.GetInstance<System.Text.Rune>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.IsBmp;
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Text_Rune_Plane_Get")]
	internal static int /* System.Int32 */ System_Text_Rune_Plane_Get(void* /* System.Text.Rune */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Text.Rune __selfConverted = InteropUtils.GetInstance<System.Text.Rune>(__self);
	
	
	    try {
			System.Int32 __returnValue = __selfConverted.Plane;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Text_Rune_ReplacementChar_Get")]
	internal static void* /* System.Text.Rune */ System_Text_Rune_ReplacementChar_Get(void** /* System.Exception */ __outException)
	{
	
	    try {
			System.Text.Rune __returnValue = System.Text.Rune.ReplacementChar;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Text_Rune_Utf16SequenceLength_Get")]
	internal static int /* System.Int32 */ System_Text_Rune_Utf16SequenceLength_Get(void* /* System.Text.Rune */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Text.Rune __selfConverted = InteropUtils.GetInstance<System.Text.Rune>(__self);
	
	
	    try {
			System.Int32 __returnValue = __selfConverted.Utf16SequenceLength;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Text_Rune_Utf8SequenceLength_Get")]
	internal static int /* System.Int32 */ System_Text_Rune_Utf8SequenceLength_Get(void* /* System.Text.Rune */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Text.Rune __selfConverted = InteropUtils.GetInstance<System.Text.Rune>(__self);
	
	
	    try {
			System.Int32 __returnValue = __selfConverted.Utf8SequenceLength;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Text_Rune_Value_Get")]
	internal static int /* System.Int32 */ System_Text_Rune_Value_Get(void* /* System.Text.Rune */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Text.Rune __selfConverted = InteropUtils.GetInstance<System.Text.Rune>(__self);
	
	
	    try {
			System.Int32 __returnValue = __selfConverted.Value;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Text_Rune_Create_4")]
	internal static void* /* System.Text.Rune */ System_Text_Rune_Create_4(void** /* System.Exception */ __outException)
	{
	
	    try {
			System.Text.Rune __returnValue = new System.Text.Rune();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Text_Rune_TypeOf")]
	internal static void* /* System.Type */ System_Text_Rune_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.Text.Rune);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Text_Rune_Destroy")]
	internal static void /* System.Void */ System_Text_Rune_Destroy(void* /* System.Text.Rune */ __self)
	{
	
		InteropUtils.FreeIfAllocated(__self);
	}
	
}


internal unsafe class System_Buffers_OperationStatus
{
	[UnmanagedCallersOnly(EntryPoint = "System_Buffers_OperationStatus_TypeOf")]
	internal static void* /* System.Type */ System_Buffers_OperationStatus_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.Buffers.OperationStatus);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
}



internal unsafe class System_Globalization_CompareOptions
{
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_CompareOptions_TypeOf")]
	internal static void* /* System.Type */ System_Globalization_CompareOptions_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.Globalization.CompareOptions);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
}


internal unsafe class System_Globalization_SortKey
{
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_SortKey_Compare")]
	internal static int /* System.Int32 */ System_Globalization_SortKey_Compare(void* /* System.Globalization.SortKey */ sortkey1, void* /* System.Globalization.SortKey */ sortkey2, void** /* System.Exception */ __outException)
	{
		System.Globalization.SortKey sortkey1Converted = InteropUtils.GetInstance<System.Globalization.SortKey>(sortkey1);
		System.Globalization.SortKey sortkey2Converted = InteropUtils.GetInstance<System.Globalization.SortKey>(sortkey2);
	
	    try {
			System.Int32 __returnValue = System.Globalization.SortKey.Compare(sortkey1Converted, sortkey2Converted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_SortKey_Equals")]
	internal static byte /* System.Boolean */ System_Globalization_SortKey_Equals(void* /* System.Globalization.SortKey */ __self, void* /* System.Object */ value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.SortKey __selfConverted = InteropUtils.GetInstance<System.Globalization.SortKey>(__self);
	
		System.Object valueConverted = InteropUtils.GetInstance<System.Object>(value);
	
	    try {
			System.Boolean __returnValue = __selfConverted.Equals(valueConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_SortKey_GetHashCode")]
	internal static int /* System.Int32 */ System_Globalization_SortKey_GetHashCode(void* /* System.Globalization.SortKey */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.SortKey __selfConverted = InteropUtils.GetInstance<System.Globalization.SortKey>(__self);
	
	
	    try {
			System.Int32 __returnValue = __selfConverted.GetHashCode();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_SortKey_ToString")]
	internal static void* /* System.String */ System_Globalization_SortKey_ToString(void* /* System.Globalization.SortKey */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.SortKey __selfConverted = InteropUtils.GetInstance<System.Globalization.SortKey>(__self);
	
	
	    try {
			System.String __returnValue = __selfConverted.ToString();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_SortKey_OriginalString_Get")]
	internal static void* /* System.String */ System_Globalization_SortKey_OriginalString_Get(void* /* System.Globalization.SortKey */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.SortKey __selfConverted = InteropUtils.GetInstance<System.Globalization.SortKey>(__self);
	
	
	    try {
			System.String __returnValue = __selfConverted.OriginalString;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_SortKey_KeyData_Get")]
	internal static void* /* System.Byte[] */ System_Globalization_SortKey_KeyData_Get(void* /* System.Globalization.SortKey */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.SortKey __selfConverted = InteropUtils.GetInstance<System.Globalization.SortKey>(__self);
	
	
	    try {
			System.Byte[] __returnValue = __selfConverted.KeyData;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_SortKey_TypeOf")]
	internal static void* /* System.Type */ System_Globalization_SortKey_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.Globalization.SortKey);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_SortKey_Destroy")]
	internal static void /* System.Void */ System_Globalization_SortKey_Destroy(void* /* System.Globalization.SortKey */ __self)
	{
	
		InteropUtils.FreeIfAllocated(__self);
	}
	
}


internal unsafe class System_Globalization_SortVersion
{
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_SortVersion_Equals")]
	internal static byte /* System.Boolean */ System_Globalization_SortVersion_Equals(void* /* System.Globalization.SortVersion */ __self, void* /* System.Object */ obj, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.SortVersion __selfConverted = InteropUtils.GetInstance<System.Globalization.SortVersion>(__self);
	
		System.Object objConverted = InteropUtils.GetInstance<System.Object>(obj);
	
	    try {
			System.Boolean __returnValue = __selfConverted.Equals(objConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_SortVersion_Equals_1")]
	internal static byte /* System.Boolean */ System_Globalization_SortVersion_Equals_1(void* /* System.Globalization.SortVersion */ __self, void* /* System.Globalization.SortVersion */ other, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.SortVersion __selfConverted = InteropUtils.GetInstance<System.Globalization.SortVersion>(__self);
	
		System.Globalization.SortVersion otherConverted = InteropUtils.GetInstance<System.Globalization.SortVersion>(other);
	
	    try {
			System.Boolean __returnValue = __selfConverted.Equals(otherConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_SortVersion_GetHashCode")]
	internal static int /* System.Int32 */ System_Globalization_SortVersion_GetHashCode(void* /* System.Globalization.SortVersion */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.SortVersion __selfConverted = InteropUtils.GetInstance<System.Globalization.SortVersion>(__self);
	
	
	    try {
			System.Int32 __returnValue = __selfConverted.GetHashCode();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_SortVersion_Create")]
	internal static void* /* System.Globalization.SortVersion */ System_Globalization_SortVersion_Create(int /* System.Int32 */ fullVersion, void* /* System.Guid */ sortId, void** /* System.Exception */ __outException)
	{
		System.Guid sortIdConverted = InteropUtils.GetInstance<System.Guid>(sortId);
	
	    try {
			System.Globalization.SortVersion __returnValue = new System.Globalization.SortVersion(fullVersion, sortIdConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_SortVersion_FullVersion_Get")]
	internal static int /* System.Int32 */ System_Globalization_SortVersion_FullVersion_Get(void* /* System.Globalization.SortVersion */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.SortVersion __selfConverted = InteropUtils.GetInstance<System.Globalization.SortVersion>(__self);
	
	
	    try {
			System.Int32 __returnValue = __selfConverted.FullVersion;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_SortVersion_SortId_Get")]
	internal static void* /* System.Guid */ System_Globalization_SortVersion_SortId_Get(void* /* System.Globalization.SortVersion */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.SortVersion __selfConverted = InteropUtils.GetInstance<System.Globalization.SortVersion>(__self);
	
	
	    try {
			System.Guid __returnValue = __selfConverted.SortId;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_SortVersion_TypeOf")]
	internal static void* /* System.Type */ System_Globalization_SortVersion_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.Globalization.SortVersion);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_SortVersion_Destroy")]
	internal static void /* System.Void */ System_Globalization_SortVersion_Destroy(void* /* System.Globalization.SortVersion */ __self)
	{
	
		InteropUtils.FreeIfAllocated(__self);
	}
	
}


internal unsafe class System_Globalization_TextInfo
{
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_TextInfo_Clone")]
	internal static void* /* System.Object */ System_Globalization_TextInfo_Clone(void* /* System.Globalization.TextInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.TextInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.TextInfo>(__self);
	
	
	    try {
			System.Object __returnValue = __selfConverted.Clone();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_TextInfo_ReadOnly")]
	internal static void* /* System.Globalization.TextInfo */ System_Globalization_TextInfo_ReadOnly(void* /* System.Globalization.TextInfo */ textInfo, void** /* System.Exception */ __outException)
	{
		System.Globalization.TextInfo textInfoConverted = InteropUtils.GetInstance<System.Globalization.TextInfo>(textInfo);
	
	    try {
			System.Globalization.TextInfo __returnValue = System.Globalization.TextInfo.ReadOnly(textInfoConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_TextInfo_ToLower")]
	internal static char /* System.Char */ System_Globalization_TextInfo_ToLower(void* /* System.Globalization.TextInfo */ __self, char /* System.Char */ c, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.TextInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.TextInfo>(__self);
	
	
	    try {
			System.Char __returnValue = __selfConverted.ToLower(c);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return (char)0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_TextInfo_ToLower_1")]
	internal static void* /* System.String */ System_Globalization_TextInfo_ToLower_1(void* /* System.Globalization.TextInfo */ __self, void* /* System.String */ str, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.TextInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.TextInfo>(__self);
	
		System.String strConverted = InteropUtils.GetInstance<System.String>(str);
	
	    try {
			System.String __returnValue = __selfConverted.ToLower(strConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_TextInfo_ToUpper")]
	internal static char /* System.Char */ System_Globalization_TextInfo_ToUpper(void* /* System.Globalization.TextInfo */ __self, char /* System.Char */ c, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.TextInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.TextInfo>(__self);
	
	
	    try {
			System.Char __returnValue = __selfConverted.ToUpper(c);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return (char)0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_TextInfo_ToUpper_1")]
	internal static void* /* System.String */ System_Globalization_TextInfo_ToUpper_1(void* /* System.Globalization.TextInfo */ __self, void* /* System.String */ str, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.TextInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.TextInfo>(__self);
	
		System.String strConverted = InteropUtils.GetInstance<System.String>(str);
	
	    try {
			System.String __returnValue = __selfConverted.ToUpper(strConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_TextInfo_Equals")]
	internal static byte /* System.Boolean */ System_Globalization_TextInfo_Equals(void* /* System.Globalization.TextInfo */ __self, void* /* System.Object */ obj, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.TextInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.TextInfo>(__self);
	
		System.Object objConverted = InteropUtils.GetInstance<System.Object>(obj);
	
	    try {
			System.Boolean __returnValue = __selfConverted.Equals(objConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_TextInfo_GetHashCode")]
	internal static int /* System.Int32 */ System_Globalization_TextInfo_GetHashCode(void* /* System.Globalization.TextInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.TextInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.TextInfo>(__self);
	
	
	    try {
			System.Int32 __returnValue = __selfConverted.GetHashCode();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_TextInfo_ToString")]
	internal static void* /* System.String */ System_Globalization_TextInfo_ToString(void* /* System.Globalization.TextInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.TextInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.TextInfo>(__self);
	
	
	    try {
			System.String __returnValue = __selfConverted.ToString();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_TextInfo_ToTitleCase")]
	internal static void* /* System.String */ System_Globalization_TextInfo_ToTitleCase(void* /* System.Globalization.TextInfo */ __self, void* /* System.String */ str, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.TextInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.TextInfo>(__self);
	
		System.String strConverted = InteropUtils.GetInstance<System.String>(str);
	
	    try {
			System.String __returnValue = __selfConverted.ToTitleCase(strConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_TextInfo_ANSICodePage_Get")]
	internal static int /* System.Int32 */ System_Globalization_TextInfo_ANSICodePage_Get(void* /* System.Globalization.TextInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.TextInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.TextInfo>(__self);
	
	
	    try {
			System.Int32 __returnValue = __selfConverted.ANSICodePage;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_TextInfo_OEMCodePage_Get")]
	internal static int /* System.Int32 */ System_Globalization_TextInfo_OEMCodePage_Get(void* /* System.Globalization.TextInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.TextInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.TextInfo>(__self);
	
	
	    try {
			System.Int32 __returnValue = __selfConverted.OEMCodePage;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_TextInfo_MacCodePage_Get")]
	internal static int /* System.Int32 */ System_Globalization_TextInfo_MacCodePage_Get(void* /* System.Globalization.TextInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.TextInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.TextInfo>(__self);
	
	
	    try {
			System.Int32 __returnValue = __selfConverted.MacCodePage;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_TextInfo_EBCDICCodePage_Get")]
	internal static int /* System.Int32 */ System_Globalization_TextInfo_EBCDICCodePage_Get(void* /* System.Globalization.TextInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.TextInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.TextInfo>(__self);
	
	
	    try {
			System.Int32 __returnValue = __selfConverted.EBCDICCodePage;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_TextInfo_LCID_Get")]
	internal static int /* System.Int32 */ System_Globalization_TextInfo_LCID_Get(void* /* System.Globalization.TextInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.TextInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.TextInfo>(__self);
	
	
	    try {
			System.Int32 __returnValue = __selfConverted.LCID;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_TextInfo_CultureName_Get")]
	internal static void* /* System.String */ System_Globalization_TextInfo_CultureName_Get(void* /* System.Globalization.TextInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.TextInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.TextInfo>(__self);
	
	
	    try {
			System.String __returnValue = __selfConverted.CultureName;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_TextInfo_IsReadOnly_Get")]
	internal static byte /* System.Boolean */ System_Globalization_TextInfo_IsReadOnly_Get(void* /* System.Globalization.TextInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.TextInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.TextInfo>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.IsReadOnly;
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_TextInfo_ListSeparator_Get")]
	internal static void* /* System.String */ System_Globalization_TextInfo_ListSeparator_Get(void* /* System.Globalization.TextInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.TextInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.TextInfo>(__self);
	
	
	    try {
			System.String __returnValue = __selfConverted.ListSeparator;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_TextInfo_ListSeparator_Set")]
	internal static void /* System.Void */ System_Globalization_TextInfo_ListSeparator_Set(void* /* System.Globalization.TextInfo */ __self, void* /* System.String */ __value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.TextInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.TextInfo>(__self);
	
	
	    try {
			__selfConverted.ListSeparator = InteropUtils.GetInstance<System.String>(__value);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_TextInfo_IsRightToLeft_Get")]
	internal static byte /* System.Boolean */ System_Globalization_TextInfo_IsRightToLeft_Get(void* /* System.Globalization.TextInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.TextInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.TextInfo>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.IsRightToLeft;
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_TextInfo_TypeOf")]
	internal static void* /* System.Type */ System_Globalization_TextInfo_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.Globalization.TextInfo);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_TextInfo_Destroy")]
	internal static void /* System.Void */ System_Globalization_TextInfo_Destroy(void* /* System.Globalization.TextInfo */ __self)
	{
	
		InteropUtils.FreeIfAllocated(__self);
	}
	
}


internal unsafe class System_Globalization_NumberFormatInfo
{
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_NumberFormatInfo_GetInstance")]
	internal static void* /* System.Globalization.NumberFormatInfo */ System_Globalization_NumberFormatInfo_GetInstance(void* /* System.IFormatProvider */ formatProvider, void** /* System.Exception */ __outException)
	{
		System.IFormatProvider formatProviderConverted = InteropUtils.GetInstance<System.IFormatProvider>(formatProvider);
	
	    try {
			System.Globalization.NumberFormatInfo __returnValue = System.Globalization.NumberFormatInfo.GetInstance(formatProviderConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_NumberFormatInfo_Clone")]
	internal static void* /* System.Object */ System_Globalization_NumberFormatInfo_Clone(void* /* System.Globalization.NumberFormatInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.NumberFormatInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.NumberFormatInfo>(__self);
	
	
	    try {
			System.Object __returnValue = __selfConverted.Clone();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_NumberFormatInfo_GetFormat")]
	internal static void* /* System.Object */ System_Globalization_NumberFormatInfo_GetFormat(void* /* System.Globalization.NumberFormatInfo */ __self, void* /* System.Type */ formatType, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.NumberFormatInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.NumberFormatInfo>(__self);
	
		System.Type formatTypeConverted = InteropUtils.GetInstance<System.Type>(formatType);
	
	    try {
			System.Object __returnValue = __selfConverted.GetFormat(formatTypeConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_NumberFormatInfo_ReadOnly")]
	internal static void* /* System.Globalization.NumberFormatInfo */ System_Globalization_NumberFormatInfo_ReadOnly(void* /* System.Globalization.NumberFormatInfo */ nfi, void** /* System.Exception */ __outException)
	{
		System.Globalization.NumberFormatInfo nfiConverted = InteropUtils.GetInstance<System.Globalization.NumberFormatInfo>(nfi);
	
	    try {
			System.Globalization.NumberFormatInfo __returnValue = System.Globalization.NumberFormatInfo.ReadOnly(nfiConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_NumberFormatInfo_Create")]
	internal static void* /* System.Globalization.NumberFormatInfo */ System_Globalization_NumberFormatInfo_Create(void** /* System.Exception */ __outException)
	{
	
	    try {
			System.Globalization.NumberFormatInfo __returnValue = new System.Globalization.NumberFormatInfo();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_NumberFormatInfo_InvariantInfo_Get")]
	internal static void* /* System.Globalization.NumberFormatInfo */ System_Globalization_NumberFormatInfo_InvariantInfo_Get(void** /* System.Exception */ __outException)
	{
	
	    try {
			System.Globalization.NumberFormatInfo __returnValue = System.Globalization.NumberFormatInfo.InvariantInfo;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_NumberFormatInfo_CurrencyDecimalDigits_Get")]
	internal static int /* System.Int32 */ System_Globalization_NumberFormatInfo_CurrencyDecimalDigits_Get(void* /* System.Globalization.NumberFormatInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.NumberFormatInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.NumberFormatInfo>(__self);
	
	
	    try {
			System.Int32 __returnValue = __selfConverted.CurrencyDecimalDigits;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_NumberFormatInfo_CurrencyDecimalDigits_Set")]
	internal static void /* System.Void */ System_Globalization_NumberFormatInfo_CurrencyDecimalDigits_Set(void* /* System.Globalization.NumberFormatInfo */ __self, int /* System.Int32 */ __value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.NumberFormatInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.NumberFormatInfo>(__self);
	
	
	    try {
			__selfConverted.CurrencyDecimalDigits = __value;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_NumberFormatInfo_CurrencyDecimalSeparator_Get")]
	internal static void* /* System.String */ System_Globalization_NumberFormatInfo_CurrencyDecimalSeparator_Get(void* /* System.Globalization.NumberFormatInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.NumberFormatInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.NumberFormatInfo>(__self);
	
	
	    try {
			System.String __returnValue = __selfConverted.CurrencyDecimalSeparator;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_NumberFormatInfo_CurrencyDecimalSeparator_Set")]
	internal static void /* System.Void */ System_Globalization_NumberFormatInfo_CurrencyDecimalSeparator_Set(void* /* System.Globalization.NumberFormatInfo */ __self, void* /* System.String */ __value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.NumberFormatInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.NumberFormatInfo>(__self);
	
	
	    try {
			__selfConverted.CurrencyDecimalSeparator = InteropUtils.GetInstance<System.String>(__value);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_NumberFormatInfo_IsReadOnly_Get")]
	internal static byte /* System.Boolean */ System_Globalization_NumberFormatInfo_IsReadOnly_Get(void* /* System.Globalization.NumberFormatInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.NumberFormatInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.NumberFormatInfo>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.IsReadOnly;
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_NumberFormatInfo_CurrencyGroupSizes_Get")]
	internal static void* /* System.Int32[] */ System_Globalization_NumberFormatInfo_CurrencyGroupSizes_Get(void* /* System.Globalization.NumberFormatInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.NumberFormatInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.NumberFormatInfo>(__self);
	
	
	    try {
			System.Int32[] __returnValue = __selfConverted.CurrencyGroupSizes;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_NumberFormatInfo_CurrencyGroupSizes_Set")]
	internal static void /* System.Void */ System_Globalization_NumberFormatInfo_CurrencyGroupSizes_Set(void* /* System.Globalization.NumberFormatInfo */ __self, void* /* System.Int32[] */ __value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.NumberFormatInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.NumberFormatInfo>(__self);
	
	
	    try {
			__selfConverted.CurrencyGroupSizes = InteropUtils.GetInstance<System.Int32[]>(__value);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_NumberFormatInfo_NumberGroupSizes_Get")]
	internal static void* /* System.Int32[] */ System_Globalization_NumberFormatInfo_NumberGroupSizes_Get(void* /* System.Globalization.NumberFormatInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.NumberFormatInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.NumberFormatInfo>(__self);
	
	
	    try {
			System.Int32[] __returnValue = __selfConverted.NumberGroupSizes;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_NumberFormatInfo_NumberGroupSizes_Set")]
	internal static void /* System.Void */ System_Globalization_NumberFormatInfo_NumberGroupSizes_Set(void* /* System.Globalization.NumberFormatInfo */ __self, void* /* System.Int32[] */ __value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.NumberFormatInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.NumberFormatInfo>(__self);
	
	
	    try {
			__selfConverted.NumberGroupSizes = InteropUtils.GetInstance<System.Int32[]>(__value);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_NumberFormatInfo_PercentGroupSizes_Get")]
	internal static void* /* System.Int32[] */ System_Globalization_NumberFormatInfo_PercentGroupSizes_Get(void* /* System.Globalization.NumberFormatInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.NumberFormatInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.NumberFormatInfo>(__self);
	
	
	    try {
			System.Int32[] __returnValue = __selfConverted.PercentGroupSizes;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_NumberFormatInfo_PercentGroupSizes_Set")]
	internal static void /* System.Void */ System_Globalization_NumberFormatInfo_PercentGroupSizes_Set(void* /* System.Globalization.NumberFormatInfo */ __self, void* /* System.Int32[] */ __value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.NumberFormatInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.NumberFormatInfo>(__self);
	
	
	    try {
			__selfConverted.PercentGroupSizes = InteropUtils.GetInstance<System.Int32[]>(__value);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_NumberFormatInfo_CurrencyGroupSeparator_Get")]
	internal static void* /* System.String */ System_Globalization_NumberFormatInfo_CurrencyGroupSeparator_Get(void* /* System.Globalization.NumberFormatInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.NumberFormatInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.NumberFormatInfo>(__self);
	
	
	    try {
			System.String __returnValue = __selfConverted.CurrencyGroupSeparator;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_NumberFormatInfo_CurrencyGroupSeparator_Set")]
	internal static void /* System.Void */ System_Globalization_NumberFormatInfo_CurrencyGroupSeparator_Set(void* /* System.Globalization.NumberFormatInfo */ __self, void* /* System.String */ __value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.NumberFormatInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.NumberFormatInfo>(__self);
	
	
	    try {
			__selfConverted.CurrencyGroupSeparator = InteropUtils.GetInstance<System.String>(__value);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_NumberFormatInfo_CurrencySymbol_Get")]
	internal static void* /* System.String */ System_Globalization_NumberFormatInfo_CurrencySymbol_Get(void* /* System.Globalization.NumberFormatInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.NumberFormatInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.NumberFormatInfo>(__self);
	
	
	    try {
			System.String __returnValue = __selfConverted.CurrencySymbol;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_NumberFormatInfo_CurrencySymbol_Set")]
	internal static void /* System.Void */ System_Globalization_NumberFormatInfo_CurrencySymbol_Set(void* /* System.Globalization.NumberFormatInfo */ __self, void* /* System.String */ __value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.NumberFormatInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.NumberFormatInfo>(__self);
	
	
	    try {
			__selfConverted.CurrencySymbol = InteropUtils.GetInstance<System.String>(__value);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_NumberFormatInfo_CurrentInfo_Get")]
	internal static void* /* System.Globalization.NumberFormatInfo */ System_Globalization_NumberFormatInfo_CurrentInfo_Get(void** /* System.Exception */ __outException)
	{
	
	    try {
			System.Globalization.NumberFormatInfo __returnValue = System.Globalization.NumberFormatInfo.CurrentInfo;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_NumberFormatInfo_NaNSymbol_Get")]
	internal static void* /* System.String */ System_Globalization_NumberFormatInfo_NaNSymbol_Get(void* /* System.Globalization.NumberFormatInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.NumberFormatInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.NumberFormatInfo>(__self);
	
	
	    try {
			System.String __returnValue = __selfConverted.NaNSymbol;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_NumberFormatInfo_NaNSymbol_Set")]
	internal static void /* System.Void */ System_Globalization_NumberFormatInfo_NaNSymbol_Set(void* /* System.Globalization.NumberFormatInfo */ __self, void* /* System.String */ __value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.NumberFormatInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.NumberFormatInfo>(__self);
	
	
	    try {
			__selfConverted.NaNSymbol = InteropUtils.GetInstance<System.String>(__value);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_NumberFormatInfo_CurrencyNegativePattern_Get")]
	internal static int /* System.Int32 */ System_Globalization_NumberFormatInfo_CurrencyNegativePattern_Get(void* /* System.Globalization.NumberFormatInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.NumberFormatInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.NumberFormatInfo>(__self);
	
	
	    try {
			System.Int32 __returnValue = __selfConverted.CurrencyNegativePattern;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_NumberFormatInfo_CurrencyNegativePattern_Set")]
	internal static void /* System.Void */ System_Globalization_NumberFormatInfo_CurrencyNegativePattern_Set(void* /* System.Globalization.NumberFormatInfo */ __self, int /* System.Int32 */ __value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.NumberFormatInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.NumberFormatInfo>(__self);
	
	
	    try {
			__selfConverted.CurrencyNegativePattern = __value;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_NumberFormatInfo_NumberNegativePattern_Get")]
	internal static int /* System.Int32 */ System_Globalization_NumberFormatInfo_NumberNegativePattern_Get(void* /* System.Globalization.NumberFormatInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.NumberFormatInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.NumberFormatInfo>(__self);
	
	
	    try {
			System.Int32 __returnValue = __selfConverted.NumberNegativePattern;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_NumberFormatInfo_NumberNegativePattern_Set")]
	internal static void /* System.Void */ System_Globalization_NumberFormatInfo_NumberNegativePattern_Set(void* /* System.Globalization.NumberFormatInfo */ __self, int /* System.Int32 */ __value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.NumberFormatInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.NumberFormatInfo>(__self);
	
	
	    try {
			__selfConverted.NumberNegativePattern = __value;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_NumberFormatInfo_PercentPositivePattern_Get")]
	internal static int /* System.Int32 */ System_Globalization_NumberFormatInfo_PercentPositivePattern_Get(void* /* System.Globalization.NumberFormatInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.NumberFormatInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.NumberFormatInfo>(__self);
	
	
	    try {
			System.Int32 __returnValue = __selfConverted.PercentPositivePattern;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_NumberFormatInfo_PercentPositivePattern_Set")]
	internal static void /* System.Void */ System_Globalization_NumberFormatInfo_PercentPositivePattern_Set(void* /* System.Globalization.NumberFormatInfo */ __self, int /* System.Int32 */ __value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.NumberFormatInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.NumberFormatInfo>(__self);
	
	
	    try {
			__selfConverted.PercentPositivePattern = __value;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_NumberFormatInfo_PercentNegativePattern_Get")]
	internal static int /* System.Int32 */ System_Globalization_NumberFormatInfo_PercentNegativePattern_Get(void* /* System.Globalization.NumberFormatInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.NumberFormatInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.NumberFormatInfo>(__self);
	
	
	    try {
			System.Int32 __returnValue = __selfConverted.PercentNegativePattern;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_NumberFormatInfo_PercentNegativePattern_Set")]
	internal static void /* System.Void */ System_Globalization_NumberFormatInfo_PercentNegativePattern_Set(void* /* System.Globalization.NumberFormatInfo */ __self, int /* System.Int32 */ __value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.NumberFormatInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.NumberFormatInfo>(__self);
	
	
	    try {
			__selfConverted.PercentNegativePattern = __value;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_NumberFormatInfo_NegativeInfinitySymbol_Get")]
	internal static void* /* System.String */ System_Globalization_NumberFormatInfo_NegativeInfinitySymbol_Get(void* /* System.Globalization.NumberFormatInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.NumberFormatInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.NumberFormatInfo>(__self);
	
	
	    try {
			System.String __returnValue = __selfConverted.NegativeInfinitySymbol;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_NumberFormatInfo_NegativeInfinitySymbol_Set")]
	internal static void /* System.Void */ System_Globalization_NumberFormatInfo_NegativeInfinitySymbol_Set(void* /* System.Globalization.NumberFormatInfo */ __self, void* /* System.String */ __value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.NumberFormatInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.NumberFormatInfo>(__self);
	
	
	    try {
			__selfConverted.NegativeInfinitySymbol = InteropUtils.GetInstance<System.String>(__value);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_NumberFormatInfo_NegativeSign_Get")]
	internal static void* /* System.String */ System_Globalization_NumberFormatInfo_NegativeSign_Get(void* /* System.Globalization.NumberFormatInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.NumberFormatInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.NumberFormatInfo>(__self);
	
	
	    try {
			System.String __returnValue = __selfConverted.NegativeSign;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_NumberFormatInfo_NegativeSign_Set")]
	internal static void /* System.Void */ System_Globalization_NumberFormatInfo_NegativeSign_Set(void* /* System.Globalization.NumberFormatInfo */ __self, void* /* System.String */ __value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.NumberFormatInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.NumberFormatInfo>(__self);
	
	
	    try {
			__selfConverted.NegativeSign = InteropUtils.GetInstance<System.String>(__value);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_NumberFormatInfo_NumberDecimalDigits_Get")]
	internal static int /* System.Int32 */ System_Globalization_NumberFormatInfo_NumberDecimalDigits_Get(void* /* System.Globalization.NumberFormatInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.NumberFormatInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.NumberFormatInfo>(__self);
	
	
	    try {
			System.Int32 __returnValue = __selfConverted.NumberDecimalDigits;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_NumberFormatInfo_NumberDecimalDigits_Set")]
	internal static void /* System.Void */ System_Globalization_NumberFormatInfo_NumberDecimalDigits_Set(void* /* System.Globalization.NumberFormatInfo */ __self, int /* System.Int32 */ __value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.NumberFormatInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.NumberFormatInfo>(__self);
	
	
	    try {
			__selfConverted.NumberDecimalDigits = __value;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_NumberFormatInfo_NumberDecimalSeparator_Get")]
	internal static void* /* System.String */ System_Globalization_NumberFormatInfo_NumberDecimalSeparator_Get(void* /* System.Globalization.NumberFormatInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.NumberFormatInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.NumberFormatInfo>(__self);
	
	
	    try {
			System.String __returnValue = __selfConverted.NumberDecimalSeparator;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_NumberFormatInfo_NumberDecimalSeparator_Set")]
	internal static void /* System.Void */ System_Globalization_NumberFormatInfo_NumberDecimalSeparator_Set(void* /* System.Globalization.NumberFormatInfo */ __self, void* /* System.String */ __value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.NumberFormatInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.NumberFormatInfo>(__self);
	
	
	    try {
			__selfConverted.NumberDecimalSeparator = InteropUtils.GetInstance<System.String>(__value);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_NumberFormatInfo_NumberGroupSeparator_Get")]
	internal static void* /* System.String */ System_Globalization_NumberFormatInfo_NumberGroupSeparator_Get(void* /* System.Globalization.NumberFormatInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.NumberFormatInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.NumberFormatInfo>(__self);
	
	
	    try {
			System.String __returnValue = __selfConverted.NumberGroupSeparator;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_NumberFormatInfo_NumberGroupSeparator_Set")]
	internal static void /* System.Void */ System_Globalization_NumberFormatInfo_NumberGroupSeparator_Set(void* /* System.Globalization.NumberFormatInfo */ __self, void* /* System.String */ __value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.NumberFormatInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.NumberFormatInfo>(__self);
	
	
	    try {
			__selfConverted.NumberGroupSeparator = InteropUtils.GetInstance<System.String>(__value);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_NumberFormatInfo_CurrencyPositivePattern_Get")]
	internal static int /* System.Int32 */ System_Globalization_NumberFormatInfo_CurrencyPositivePattern_Get(void* /* System.Globalization.NumberFormatInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.NumberFormatInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.NumberFormatInfo>(__self);
	
	
	    try {
			System.Int32 __returnValue = __selfConverted.CurrencyPositivePattern;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_NumberFormatInfo_CurrencyPositivePattern_Set")]
	internal static void /* System.Void */ System_Globalization_NumberFormatInfo_CurrencyPositivePattern_Set(void* /* System.Globalization.NumberFormatInfo */ __self, int /* System.Int32 */ __value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.NumberFormatInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.NumberFormatInfo>(__self);
	
	
	    try {
			__selfConverted.CurrencyPositivePattern = __value;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_NumberFormatInfo_PositiveInfinitySymbol_Get")]
	internal static void* /* System.String */ System_Globalization_NumberFormatInfo_PositiveInfinitySymbol_Get(void* /* System.Globalization.NumberFormatInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.NumberFormatInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.NumberFormatInfo>(__self);
	
	
	    try {
			System.String __returnValue = __selfConverted.PositiveInfinitySymbol;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_NumberFormatInfo_PositiveInfinitySymbol_Set")]
	internal static void /* System.Void */ System_Globalization_NumberFormatInfo_PositiveInfinitySymbol_Set(void* /* System.Globalization.NumberFormatInfo */ __self, void* /* System.String */ __value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.NumberFormatInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.NumberFormatInfo>(__self);
	
	
	    try {
			__selfConverted.PositiveInfinitySymbol = InteropUtils.GetInstance<System.String>(__value);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_NumberFormatInfo_PositiveSign_Get")]
	internal static void* /* System.String */ System_Globalization_NumberFormatInfo_PositiveSign_Get(void* /* System.Globalization.NumberFormatInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.NumberFormatInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.NumberFormatInfo>(__self);
	
	
	    try {
			System.String __returnValue = __selfConverted.PositiveSign;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_NumberFormatInfo_PositiveSign_Set")]
	internal static void /* System.Void */ System_Globalization_NumberFormatInfo_PositiveSign_Set(void* /* System.Globalization.NumberFormatInfo */ __self, void* /* System.String */ __value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.NumberFormatInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.NumberFormatInfo>(__self);
	
	
	    try {
			__selfConverted.PositiveSign = InteropUtils.GetInstance<System.String>(__value);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_NumberFormatInfo_PercentDecimalDigits_Get")]
	internal static int /* System.Int32 */ System_Globalization_NumberFormatInfo_PercentDecimalDigits_Get(void* /* System.Globalization.NumberFormatInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.NumberFormatInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.NumberFormatInfo>(__self);
	
	
	    try {
			System.Int32 __returnValue = __selfConverted.PercentDecimalDigits;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_NumberFormatInfo_PercentDecimalDigits_Set")]
	internal static void /* System.Void */ System_Globalization_NumberFormatInfo_PercentDecimalDigits_Set(void* /* System.Globalization.NumberFormatInfo */ __self, int /* System.Int32 */ __value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.NumberFormatInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.NumberFormatInfo>(__self);
	
	
	    try {
			__selfConverted.PercentDecimalDigits = __value;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_NumberFormatInfo_PercentDecimalSeparator_Get")]
	internal static void* /* System.String */ System_Globalization_NumberFormatInfo_PercentDecimalSeparator_Get(void* /* System.Globalization.NumberFormatInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.NumberFormatInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.NumberFormatInfo>(__self);
	
	
	    try {
			System.String __returnValue = __selfConverted.PercentDecimalSeparator;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_NumberFormatInfo_PercentDecimalSeparator_Set")]
	internal static void /* System.Void */ System_Globalization_NumberFormatInfo_PercentDecimalSeparator_Set(void* /* System.Globalization.NumberFormatInfo */ __self, void* /* System.String */ __value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.NumberFormatInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.NumberFormatInfo>(__self);
	
	
	    try {
			__selfConverted.PercentDecimalSeparator = InteropUtils.GetInstance<System.String>(__value);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_NumberFormatInfo_PercentGroupSeparator_Get")]
	internal static void* /* System.String */ System_Globalization_NumberFormatInfo_PercentGroupSeparator_Get(void* /* System.Globalization.NumberFormatInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.NumberFormatInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.NumberFormatInfo>(__self);
	
	
	    try {
			System.String __returnValue = __selfConverted.PercentGroupSeparator;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_NumberFormatInfo_PercentGroupSeparator_Set")]
	internal static void /* System.Void */ System_Globalization_NumberFormatInfo_PercentGroupSeparator_Set(void* /* System.Globalization.NumberFormatInfo */ __self, void* /* System.String */ __value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.NumberFormatInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.NumberFormatInfo>(__self);
	
	
	    try {
			__selfConverted.PercentGroupSeparator = InteropUtils.GetInstance<System.String>(__value);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_NumberFormatInfo_PercentSymbol_Get")]
	internal static void* /* System.String */ System_Globalization_NumberFormatInfo_PercentSymbol_Get(void* /* System.Globalization.NumberFormatInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.NumberFormatInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.NumberFormatInfo>(__self);
	
	
	    try {
			System.String __returnValue = __selfConverted.PercentSymbol;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_NumberFormatInfo_PercentSymbol_Set")]
	internal static void /* System.Void */ System_Globalization_NumberFormatInfo_PercentSymbol_Set(void* /* System.Globalization.NumberFormatInfo */ __self, void* /* System.String */ __value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.NumberFormatInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.NumberFormatInfo>(__self);
	
	
	    try {
			__selfConverted.PercentSymbol = InteropUtils.GetInstance<System.String>(__value);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_NumberFormatInfo_PerMilleSymbol_Get")]
	internal static void* /* System.String */ System_Globalization_NumberFormatInfo_PerMilleSymbol_Get(void* /* System.Globalization.NumberFormatInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.NumberFormatInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.NumberFormatInfo>(__self);
	
	
	    try {
			System.String __returnValue = __selfConverted.PerMilleSymbol;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_NumberFormatInfo_PerMilleSymbol_Set")]
	internal static void /* System.Void */ System_Globalization_NumberFormatInfo_PerMilleSymbol_Set(void* /* System.Globalization.NumberFormatInfo */ __self, void* /* System.String */ __value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.NumberFormatInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.NumberFormatInfo>(__self);
	
	
	    try {
			__selfConverted.PerMilleSymbol = InteropUtils.GetInstance<System.String>(__value);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_NumberFormatInfo_NativeDigits_Get")]
	internal static void* /* System.String[] */ System_Globalization_NumberFormatInfo_NativeDigits_Get(void* /* System.Globalization.NumberFormatInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.NumberFormatInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.NumberFormatInfo>(__self);
	
	
	    try {
			System.String[] __returnValue = __selfConverted.NativeDigits;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_NumberFormatInfo_NativeDigits_Set")]
	internal static void /* System.Void */ System_Globalization_NumberFormatInfo_NativeDigits_Set(void* /* System.Globalization.NumberFormatInfo */ __self, void* /* System.String[] */ __value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.NumberFormatInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.NumberFormatInfo>(__self);
	
	
	    try {
			__selfConverted.NativeDigits = InteropUtils.GetInstance<System.String[]>(__value);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_NumberFormatInfo_DigitSubstitution_Get")]
	internal static System.Globalization.DigitShapes /* System.Globalization.DigitShapes */ System_Globalization_NumberFormatInfo_DigitSubstitution_Get(void* /* System.Globalization.NumberFormatInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.NumberFormatInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.NumberFormatInfo>(__self);
	
	
	    try {
			System.Globalization.DigitShapes __returnValue = __selfConverted.DigitSubstitution;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return default(System.Globalization.DigitShapes);
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_NumberFormatInfo_DigitSubstitution_Set")]
	internal static void /* System.Void */ System_Globalization_NumberFormatInfo_DigitSubstitution_Set(void* /* System.Globalization.NumberFormatInfo */ __self, System.Globalization.DigitShapes /* System.Globalization.DigitShapes */ __value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.NumberFormatInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.NumberFormatInfo>(__self);
	
	
	    try {
			__selfConverted.DigitSubstitution = __value;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_NumberFormatInfo_TypeOf")]
	internal static void* /* System.Type */ System_Globalization_NumberFormatInfo_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.Globalization.NumberFormatInfo);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_NumberFormatInfo_Destroy")]
	internal static void /* System.Void */ System_Globalization_NumberFormatInfo_Destroy(void* /* System.Globalization.NumberFormatInfo */ __self)
	{
	
		InteropUtils.FreeIfAllocated(__self);
	}
	
}


internal unsafe class System_Globalization_DigitShapes
{
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_DigitShapes_TypeOf")]
	internal static void* /* System.Type */ System_Globalization_DigitShapes_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.Globalization.DigitShapes);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
}


internal unsafe class System_Globalization_DateTimeFormatInfo
{
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_DateTimeFormatInfo_GetInstance")]
	internal static void* /* System.Globalization.DateTimeFormatInfo */ System_Globalization_DateTimeFormatInfo_GetInstance(void* /* System.IFormatProvider */ provider, void** /* System.Exception */ __outException)
	{
		System.IFormatProvider providerConverted = InteropUtils.GetInstance<System.IFormatProvider>(provider);
	
	    try {
			System.Globalization.DateTimeFormatInfo __returnValue = System.Globalization.DateTimeFormatInfo.GetInstance(providerConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_DateTimeFormatInfo_GetFormat")]
	internal static void* /* System.Object */ System_Globalization_DateTimeFormatInfo_GetFormat(void* /* System.Globalization.DateTimeFormatInfo */ __self, void* /* System.Type */ formatType, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.DateTimeFormatInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.DateTimeFormatInfo>(__self);
	
		System.Type formatTypeConverted = InteropUtils.GetInstance<System.Type>(formatType);
	
	    try {
			System.Object __returnValue = __selfConverted.GetFormat(formatTypeConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_DateTimeFormatInfo_Clone")]
	internal static void* /* System.Object */ System_Globalization_DateTimeFormatInfo_Clone(void* /* System.Globalization.DateTimeFormatInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.DateTimeFormatInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.DateTimeFormatInfo>(__self);
	
	
	    try {
			System.Object __returnValue = __selfConverted.Clone();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_DateTimeFormatInfo_GetEra")]
	internal static int /* System.Int32 */ System_Globalization_DateTimeFormatInfo_GetEra(void* /* System.Globalization.DateTimeFormatInfo */ __self, void* /* System.String */ eraName, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.DateTimeFormatInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.DateTimeFormatInfo>(__self);
	
		System.String eraNameConverted = InteropUtils.GetInstance<System.String>(eraName);
	
	    try {
			System.Int32 __returnValue = __selfConverted.GetEra(eraNameConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_DateTimeFormatInfo_GetEraName")]
	internal static void* /* System.String */ System_Globalization_DateTimeFormatInfo_GetEraName(void* /* System.Globalization.DateTimeFormatInfo */ __self, int /* System.Int32 */ era, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.DateTimeFormatInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.DateTimeFormatInfo>(__self);
	
	
	    try {
			System.String __returnValue = __selfConverted.GetEraName(era);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_DateTimeFormatInfo_GetAbbreviatedEraName")]
	internal static void* /* System.String */ System_Globalization_DateTimeFormatInfo_GetAbbreviatedEraName(void* /* System.Globalization.DateTimeFormatInfo */ __self, int /* System.Int32 */ era, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.DateTimeFormatInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.DateTimeFormatInfo>(__self);
	
	
	    try {
			System.String __returnValue = __selfConverted.GetAbbreviatedEraName(era);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_DateTimeFormatInfo_GetAbbreviatedDayName")]
	internal static void* /* System.String */ System_Globalization_DateTimeFormatInfo_GetAbbreviatedDayName(void* /* System.Globalization.DateTimeFormatInfo */ __self, System.DayOfWeek /* System.DayOfWeek */ dayofweek, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.DateTimeFormatInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.DateTimeFormatInfo>(__self);
	
	
	    try {
			System.String __returnValue = __selfConverted.GetAbbreviatedDayName(dayofweek);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_DateTimeFormatInfo_GetShortestDayName")]
	internal static void* /* System.String */ System_Globalization_DateTimeFormatInfo_GetShortestDayName(void* /* System.Globalization.DateTimeFormatInfo */ __self, System.DayOfWeek /* System.DayOfWeek */ dayOfWeek, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.DateTimeFormatInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.DateTimeFormatInfo>(__self);
	
	
	    try {
			System.String __returnValue = __selfConverted.GetShortestDayName(dayOfWeek);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_DateTimeFormatInfo_GetAllDateTimePatterns")]
	internal static void* /* System.String[] */ System_Globalization_DateTimeFormatInfo_GetAllDateTimePatterns(void* /* System.Globalization.DateTimeFormatInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.DateTimeFormatInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.DateTimeFormatInfo>(__self);
	
	
	    try {
			System.String[] __returnValue = __selfConverted.GetAllDateTimePatterns();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_DateTimeFormatInfo_GetAllDateTimePatterns_1")]
	internal static void* /* System.String[] */ System_Globalization_DateTimeFormatInfo_GetAllDateTimePatterns_1(void* /* System.Globalization.DateTimeFormatInfo */ __self, char /* System.Char */ format, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.DateTimeFormatInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.DateTimeFormatInfo>(__self);
	
	
	    try {
			System.String[] __returnValue = __selfConverted.GetAllDateTimePatterns(format);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_DateTimeFormatInfo_GetDayName")]
	internal static void* /* System.String */ System_Globalization_DateTimeFormatInfo_GetDayName(void* /* System.Globalization.DateTimeFormatInfo */ __self, System.DayOfWeek /* System.DayOfWeek */ dayofweek, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.DateTimeFormatInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.DateTimeFormatInfo>(__self);
	
	
	    try {
			System.String __returnValue = __selfConverted.GetDayName(dayofweek);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_DateTimeFormatInfo_GetAbbreviatedMonthName")]
	internal static void* /* System.String */ System_Globalization_DateTimeFormatInfo_GetAbbreviatedMonthName(void* /* System.Globalization.DateTimeFormatInfo */ __self, int /* System.Int32 */ month, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.DateTimeFormatInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.DateTimeFormatInfo>(__self);
	
	
	    try {
			System.String __returnValue = __selfConverted.GetAbbreviatedMonthName(month);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_DateTimeFormatInfo_GetMonthName")]
	internal static void* /* System.String */ System_Globalization_DateTimeFormatInfo_GetMonthName(void* /* System.Globalization.DateTimeFormatInfo */ __self, int /* System.Int32 */ month, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.DateTimeFormatInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.DateTimeFormatInfo>(__self);
	
	
	    try {
			System.String __returnValue = __selfConverted.GetMonthName(month);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_DateTimeFormatInfo_ReadOnly")]
	internal static void* /* System.Globalization.DateTimeFormatInfo */ System_Globalization_DateTimeFormatInfo_ReadOnly(void* /* System.Globalization.DateTimeFormatInfo */ dtfi, void** /* System.Exception */ __outException)
	{
		System.Globalization.DateTimeFormatInfo dtfiConverted = InteropUtils.GetInstance<System.Globalization.DateTimeFormatInfo>(dtfi);
	
	    try {
			System.Globalization.DateTimeFormatInfo __returnValue = System.Globalization.DateTimeFormatInfo.ReadOnly(dtfiConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_DateTimeFormatInfo_SetAllDateTimePatterns")]
	internal static void /* System.Void */ System_Globalization_DateTimeFormatInfo_SetAllDateTimePatterns(void* /* System.Globalization.DateTimeFormatInfo */ __self, void* /* System.String[] */ patterns, char /* System.Char */ format, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.DateTimeFormatInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.DateTimeFormatInfo>(__self);
	
		System.String[] patternsConverted = InteropUtils.GetInstance<System.String[]>(patterns);
	
	    try {
			__selfConverted.SetAllDateTimePatterns(patternsConverted, format);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_DateTimeFormatInfo_Create")]
	internal static void* /* System.Globalization.DateTimeFormatInfo */ System_Globalization_DateTimeFormatInfo_Create(void** /* System.Exception */ __outException)
	{
	
	    try {
			System.Globalization.DateTimeFormatInfo __returnValue = new System.Globalization.DateTimeFormatInfo();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_DateTimeFormatInfo_InvariantInfo_Get")]
	internal static void* /* System.Globalization.DateTimeFormatInfo */ System_Globalization_DateTimeFormatInfo_InvariantInfo_Get(void** /* System.Exception */ __outException)
	{
	
	    try {
			System.Globalization.DateTimeFormatInfo __returnValue = System.Globalization.DateTimeFormatInfo.InvariantInfo;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_DateTimeFormatInfo_CurrentInfo_Get")]
	internal static void* /* System.Globalization.DateTimeFormatInfo */ System_Globalization_DateTimeFormatInfo_CurrentInfo_Get(void** /* System.Exception */ __outException)
	{
	
	    try {
			System.Globalization.DateTimeFormatInfo __returnValue = System.Globalization.DateTimeFormatInfo.CurrentInfo;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_DateTimeFormatInfo_AMDesignator_Get")]
	internal static void* /* System.String */ System_Globalization_DateTimeFormatInfo_AMDesignator_Get(void* /* System.Globalization.DateTimeFormatInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.DateTimeFormatInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.DateTimeFormatInfo>(__self);
	
	
	    try {
			System.String __returnValue = __selfConverted.AMDesignator;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_DateTimeFormatInfo_AMDesignator_Set")]
	internal static void /* System.Void */ System_Globalization_DateTimeFormatInfo_AMDesignator_Set(void* /* System.Globalization.DateTimeFormatInfo */ __self, void* /* System.String */ __value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.DateTimeFormatInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.DateTimeFormatInfo>(__self);
	
	
	    try {
			__selfConverted.AMDesignator = InteropUtils.GetInstance<System.String>(__value);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_DateTimeFormatInfo_Calendar_Get")]
	internal static void* /* System.Globalization.Calendar */ System_Globalization_DateTimeFormatInfo_Calendar_Get(void* /* System.Globalization.DateTimeFormatInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.DateTimeFormatInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.DateTimeFormatInfo>(__self);
	
	
	    try {
			System.Globalization.Calendar __returnValue = __selfConverted.Calendar;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_DateTimeFormatInfo_Calendar_Set")]
	internal static void /* System.Void */ System_Globalization_DateTimeFormatInfo_Calendar_Set(void* /* System.Globalization.DateTimeFormatInfo */ __self, void* /* System.Globalization.Calendar */ __value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.DateTimeFormatInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.DateTimeFormatInfo>(__self);
	
	
	    try {
			__selfConverted.Calendar = InteropUtils.GetInstance<System.Globalization.Calendar>(__value);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_DateTimeFormatInfo_DateSeparator_Get")]
	internal static void* /* System.String */ System_Globalization_DateTimeFormatInfo_DateSeparator_Get(void* /* System.Globalization.DateTimeFormatInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.DateTimeFormatInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.DateTimeFormatInfo>(__self);
	
	
	    try {
			System.String __returnValue = __selfConverted.DateSeparator;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_DateTimeFormatInfo_DateSeparator_Set")]
	internal static void /* System.Void */ System_Globalization_DateTimeFormatInfo_DateSeparator_Set(void* /* System.Globalization.DateTimeFormatInfo */ __self, void* /* System.String */ __value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.DateTimeFormatInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.DateTimeFormatInfo>(__self);
	
	
	    try {
			__selfConverted.DateSeparator = InteropUtils.GetInstance<System.String>(__value);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_DateTimeFormatInfo_FirstDayOfWeek_Get")]
	internal static System.DayOfWeek /* System.DayOfWeek */ System_Globalization_DateTimeFormatInfo_FirstDayOfWeek_Get(void* /* System.Globalization.DateTimeFormatInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.DateTimeFormatInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.DateTimeFormatInfo>(__self);
	
	
	    try {
			System.DayOfWeek __returnValue = __selfConverted.FirstDayOfWeek;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return default(System.DayOfWeek);
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_DateTimeFormatInfo_FirstDayOfWeek_Set")]
	internal static void /* System.Void */ System_Globalization_DateTimeFormatInfo_FirstDayOfWeek_Set(void* /* System.Globalization.DateTimeFormatInfo */ __self, System.DayOfWeek /* System.DayOfWeek */ __value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.DateTimeFormatInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.DateTimeFormatInfo>(__self);
	
	
	    try {
			__selfConverted.FirstDayOfWeek = __value;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_DateTimeFormatInfo_CalendarWeekRule_Get")]
	internal static System.Globalization.CalendarWeekRule /* System.Globalization.CalendarWeekRule */ System_Globalization_DateTimeFormatInfo_CalendarWeekRule_Get(void* /* System.Globalization.DateTimeFormatInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.DateTimeFormatInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.DateTimeFormatInfo>(__self);
	
	
	    try {
			System.Globalization.CalendarWeekRule __returnValue = __selfConverted.CalendarWeekRule;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return default(System.Globalization.CalendarWeekRule);
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_DateTimeFormatInfo_CalendarWeekRule_Set")]
	internal static void /* System.Void */ System_Globalization_DateTimeFormatInfo_CalendarWeekRule_Set(void* /* System.Globalization.DateTimeFormatInfo */ __self, System.Globalization.CalendarWeekRule /* System.Globalization.CalendarWeekRule */ __value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.DateTimeFormatInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.DateTimeFormatInfo>(__self);
	
	
	    try {
			__selfConverted.CalendarWeekRule = __value;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_DateTimeFormatInfo_FullDateTimePattern_Get")]
	internal static void* /* System.String */ System_Globalization_DateTimeFormatInfo_FullDateTimePattern_Get(void* /* System.Globalization.DateTimeFormatInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.DateTimeFormatInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.DateTimeFormatInfo>(__self);
	
	
	    try {
			System.String __returnValue = __selfConverted.FullDateTimePattern;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_DateTimeFormatInfo_FullDateTimePattern_Set")]
	internal static void /* System.Void */ System_Globalization_DateTimeFormatInfo_FullDateTimePattern_Set(void* /* System.Globalization.DateTimeFormatInfo */ __self, void* /* System.String */ __value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.DateTimeFormatInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.DateTimeFormatInfo>(__self);
	
	
	    try {
			__selfConverted.FullDateTimePattern = InteropUtils.GetInstance<System.String>(__value);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_DateTimeFormatInfo_LongDatePattern_Get")]
	internal static void* /* System.String */ System_Globalization_DateTimeFormatInfo_LongDatePattern_Get(void* /* System.Globalization.DateTimeFormatInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.DateTimeFormatInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.DateTimeFormatInfo>(__self);
	
	
	    try {
			System.String __returnValue = __selfConverted.LongDatePattern;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_DateTimeFormatInfo_LongDatePattern_Set")]
	internal static void /* System.Void */ System_Globalization_DateTimeFormatInfo_LongDatePattern_Set(void* /* System.Globalization.DateTimeFormatInfo */ __self, void* /* System.String */ __value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.DateTimeFormatInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.DateTimeFormatInfo>(__self);
	
	
	    try {
			__selfConverted.LongDatePattern = InteropUtils.GetInstance<System.String>(__value);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_DateTimeFormatInfo_LongTimePattern_Get")]
	internal static void* /* System.String */ System_Globalization_DateTimeFormatInfo_LongTimePattern_Get(void* /* System.Globalization.DateTimeFormatInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.DateTimeFormatInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.DateTimeFormatInfo>(__self);
	
	
	    try {
			System.String __returnValue = __selfConverted.LongTimePattern;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_DateTimeFormatInfo_LongTimePattern_Set")]
	internal static void /* System.Void */ System_Globalization_DateTimeFormatInfo_LongTimePattern_Set(void* /* System.Globalization.DateTimeFormatInfo */ __self, void* /* System.String */ __value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.DateTimeFormatInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.DateTimeFormatInfo>(__self);
	
	
	    try {
			__selfConverted.LongTimePattern = InteropUtils.GetInstance<System.String>(__value);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_DateTimeFormatInfo_MonthDayPattern_Get")]
	internal static void* /* System.String */ System_Globalization_DateTimeFormatInfo_MonthDayPattern_Get(void* /* System.Globalization.DateTimeFormatInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.DateTimeFormatInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.DateTimeFormatInfo>(__self);
	
	
	    try {
			System.String __returnValue = __selfConverted.MonthDayPattern;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_DateTimeFormatInfo_MonthDayPattern_Set")]
	internal static void /* System.Void */ System_Globalization_DateTimeFormatInfo_MonthDayPattern_Set(void* /* System.Globalization.DateTimeFormatInfo */ __self, void* /* System.String */ __value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.DateTimeFormatInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.DateTimeFormatInfo>(__self);
	
	
	    try {
			__selfConverted.MonthDayPattern = InteropUtils.GetInstance<System.String>(__value);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_DateTimeFormatInfo_PMDesignator_Get")]
	internal static void* /* System.String */ System_Globalization_DateTimeFormatInfo_PMDesignator_Get(void* /* System.Globalization.DateTimeFormatInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.DateTimeFormatInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.DateTimeFormatInfo>(__self);
	
	
	    try {
			System.String __returnValue = __selfConverted.PMDesignator;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_DateTimeFormatInfo_PMDesignator_Set")]
	internal static void /* System.Void */ System_Globalization_DateTimeFormatInfo_PMDesignator_Set(void* /* System.Globalization.DateTimeFormatInfo */ __self, void* /* System.String */ __value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.DateTimeFormatInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.DateTimeFormatInfo>(__self);
	
	
	    try {
			__selfConverted.PMDesignator = InteropUtils.GetInstance<System.String>(__value);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_DateTimeFormatInfo_RFC1123Pattern_Get")]
	internal static void* /* System.String */ System_Globalization_DateTimeFormatInfo_RFC1123Pattern_Get(void* /* System.Globalization.DateTimeFormatInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.DateTimeFormatInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.DateTimeFormatInfo>(__self);
	
	
	    try {
			System.String __returnValue = __selfConverted.RFC1123Pattern;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_DateTimeFormatInfo_ShortDatePattern_Get")]
	internal static void* /* System.String */ System_Globalization_DateTimeFormatInfo_ShortDatePattern_Get(void* /* System.Globalization.DateTimeFormatInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.DateTimeFormatInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.DateTimeFormatInfo>(__self);
	
	
	    try {
			System.String __returnValue = __selfConverted.ShortDatePattern;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_DateTimeFormatInfo_ShortDatePattern_Set")]
	internal static void /* System.Void */ System_Globalization_DateTimeFormatInfo_ShortDatePattern_Set(void* /* System.Globalization.DateTimeFormatInfo */ __self, void* /* System.String */ __value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.DateTimeFormatInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.DateTimeFormatInfo>(__self);
	
	
	    try {
			__selfConverted.ShortDatePattern = InteropUtils.GetInstance<System.String>(__value);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_DateTimeFormatInfo_ShortTimePattern_Get")]
	internal static void* /* System.String */ System_Globalization_DateTimeFormatInfo_ShortTimePattern_Get(void* /* System.Globalization.DateTimeFormatInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.DateTimeFormatInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.DateTimeFormatInfo>(__self);
	
	
	    try {
			System.String __returnValue = __selfConverted.ShortTimePattern;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_DateTimeFormatInfo_ShortTimePattern_Set")]
	internal static void /* System.Void */ System_Globalization_DateTimeFormatInfo_ShortTimePattern_Set(void* /* System.Globalization.DateTimeFormatInfo */ __self, void* /* System.String */ __value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.DateTimeFormatInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.DateTimeFormatInfo>(__self);
	
	
	    try {
			__selfConverted.ShortTimePattern = InteropUtils.GetInstance<System.String>(__value);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_DateTimeFormatInfo_SortableDateTimePattern_Get")]
	internal static void* /* System.String */ System_Globalization_DateTimeFormatInfo_SortableDateTimePattern_Get(void* /* System.Globalization.DateTimeFormatInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.DateTimeFormatInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.DateTimeFormatInfo>(__self);
	
	
	    try {
			System.String __returnValue = __selfConverted.SortableDateTimePattern;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_DateTimeFormatInfo_TimeSeparator_Get")]
	internal static void* /* System.String */ System_Globalization_DateTimeFormatInfo_TimeSeparator_Get(void* /* System.Globalization.DateTimeFormatInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.DateTimeFormatInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.DateTimeFormatInfo>(__self);
	
	
	    try {
			System.String __returnValue = __selfConverted.TimeSeparator;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_DateTimeFormatInfo_TimeSeparator_Set")]
	internal static void /* System.Void */ System_Globalization_DateTimeFormatInfo_TimeSeparator_Set(void* /* System.Globalization.DateTimeFormatInfo */ __self, void* /* System.String */ __value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.DateTimeFormatInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.DateTimeFormatInfo>(__self);
	
	
	    try {
			__selfConverted.TimeSeparator = InteropUtils.GetInstance<System.String>(__value);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_DateTimeFormatInfo_UniversalSortableDateTimePattern_Get")]
	internal static void* /* System.String */ System_Globalization_DateTimeFormatInfo_UniversalSortableDateTimePattern_Get(void* /* System.Globalization.DateTimeFormatInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.DateTimeFormatInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.DateTimeFormatInfo>(__self);
	
	
	    try {
			System.String __returnValue = __selfConverted.UniversalSortableDateTimePattern;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_DateTimeFormatInfo_YearMonthPattern_Get")]
	internal static void* /* System.String */ System_Globalization_DateTimeFormatInfo_YearMonthPattern_Get(void* /* System.Globalization.DateTimeFormatInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.DateTimeFormatInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.DateTimeFormatInfo>(__self);
	
	
	    try {
			System.String __returnValue = __selfConverted.YearMonthPattern;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_DateTimeFormatInfo_YearMonthPattern_Set")]
	internal static void /* System.Void */ System_Globalization_DateTimeFormatInfo_YearMonthPattern_Set(void* /* System.Globalization.DateTimeFormatInfo */ __self, void* /* System.String */ __value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.DateTimeFormatInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.DateTimeFormatInfo>(__self);
	
	
	    try {
			__selfConverted.YearMonthPattern = InteropUtils.GetInstance<System.String>(__value);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_DateTimeFormatInfo_AbbreviatedDayNames_Get")]
	internal static void* /* System.String[] */ System_Globalization_DateTimeFormatInfo_AbbreviatedDayNames_Get(void* /* System.Globalization.DateTimeFormatInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.DateTimeFormatInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.DateTimeFormatInfo>(__self);
	
	
	    try {
			System.String[] __returnValue = __selfConverted.AbbreviatedDayNames;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_DateTimeFormatInfo_AbbreviatedDayNames_Set")]
	internal static void /* System.Void */ System_Globalization_DateTimeFormatInfo_AbbreviatedDayNames_Set(void* /* System.Globalization.DateTimeFormatInfo */ __self, void* /* System.String[] */ __value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.DateTimeFormatInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.DateTimeFormatInfo>(__self);
	
	
	    try {
			__selfConverted.AbbreviatedDayNames = InteropUtils.GetInstance<System.String[]>(__value);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_DateTimeFormatInfo_ShortestDayNames_Get")]
	internal static void* /* System.String[] */ System_Globalization_DateTimeFormatInfo_ShortestDayNames_Get(void* /* System.Globalization.DateTimeFormatInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.DateTimeFormatInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.DateTimeFormatInfo>(__self);
	
	
	    try {
			System.String[] __returnValue = __selfConverted.ShortestDayNames;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_DateTimeFormatInfo_ShortestDayNames_Set")]
	internal static void /* System.Void */ System_Globalization_DateTimeFormatInfo_ShortestDayNames_Set(void* /* System.Globalization.DateTimeFormatInfo */ __self, void* /* System.String[] */ __value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.DateTimeFormatInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.DateTimeFormatInfo>(__self);
	
	
	    try {
			__selfConverted.ShortestDayNames = InteropUtils.GetInstance<System.String[]>(__value);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_DateTimeFormatInfo_DayNames_Get")]
	internal static void* /* System.String[] */ System_Globalization_DateTimeFormatInfo_DayNames_Get(void* /* System.Globalization.DateTimeFormatInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.DateTimeFormatInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.DateTimeFormatInfo>(__self);
	
	
	    try {
			System.String[] __returnValue = __selfConverted.DayNames;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_DateTimeFormatInfo_DayNames_Set")]
	internal static void /* System.Void */ System_Globalization_DateTimeFormatInfo_DayNames_Set(void* /* System.Globalization.DateTimeFormatInfo */ __self, void* /* System.String[] */ __value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.DateTimeFormatInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.DateTimeFormatInfo>(__self);
	
	
	    try {
			__selfConverted.DayNames = InteropUtils.GetInstance<System.String[]>(__value);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_DateTimeFormatInfo_AbbreviatedMonthNames_Get")]
	internal static void* /* System.String[] */ System_Globalization_DateTimeFormatInfo_AbbreviatedMonthNames_Get(void* /* System.Globalization.DateTimeFormatInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.DateTimeFormatInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.DateTimeFormatInfo>(__self);
	
	
	    try {
			System.String[] __returnValue = __selfConverted.AbbreviatedMonthNames;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_DateTimeFormatInfo_AbbreviatedMonthNames_Set")]
	internal static void /* System.Void */ System_Globalization_DateTimeFormatInfo_AbbreviatedMonthNames_Set(void* /* System.Globalization.DateTimeFormatInfo */ __self, void* /* System.String[] */ __value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.DateTimeFormatInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.DateTimeFormatInfo>(__self);
	
	
	    try {
			__selfConverted.AbbreviatedMonthNames = InteropUtils.GetInstance<System.String[]>(__value);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_DateTimeFormatInfo_MonthNames_Get")]
	internal static void* /* System.String[] */ System_Globalization_DateTimeFormatInfo_MonthNames_Get(void* /* System.Globalization.DateTimeFormatInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.DateTimeFormatInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.DateTimeFormatInfo>(__self);
	
	
	    try {
			System.String[] __returnValue = __selfConverted.MonthNames;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_DateTimeFormatInfo_MonthNames_Set")]
	internal static void /* System.Void */ System_Globalization_DateTimeFormatInfo_MonthNames_Set(void* /* System.Globalization.DateTimeFormatInfo */ __self, void* /* System.String[] */ __value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.DateTimeFormatInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.DateTimeFormatInfo>(__self);
	
	
	    try {
			__selfConverted.MonthNames = InteropUtils.GetInstance<System.String[]>(__value);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_DateTimeFormatInfo_IsReadOnly_Get")]
	internal static byte /* System.Boolean */ System_Globalization_DateTimeFormatInfo_IsReadOnly_Get(void* /* System.Globalization.DateTimeFormatInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.DateTimeFormatInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.DateTimeFormatInfo>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.IsReadOnly;
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_DateTimeFormatInfo_NativeCalendarName_Get")]
	internal static void* /* System.String */ System_Globalization_DateTimeFormatInfo_NativeCalendarName_Get(void* /* System.Globalization.DateTimeFormatInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.DateTimeFormatInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.DateTimeFormatInfo>(__self);
	
	
	    try {
			System.String __returnValue = __selfConverted.NativeCalendarName;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_DateTimeFormatInfo_AbbreviatedMonthGenitiveNames_Get")]
	internal static void* /* System.String[] */ System_Globalization_DateTimeFormatInfo_AbbreviatedMonthGenitiveNames_Get(void* /* System.Globalization.DateTimeFormatInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.DateTimeFormatInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.DateTimeFormatInfo>(__self);
	
	
	    try {
			System.String[] __returnValue = __selfConverted.AbbreviatedMonthGenitiveNames;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_DateTimeFormatInfo_AbbreviatedMonthGenitiveNames_Set")]
	internal static void /* System.Void */ System_Globalization_DateTimeFormatInfo_AbbreviatedMonthGenitiveNames_Set(void* /* System.Globalization.DateTimeFormatInfo */ __self, void* /* System.String[] */ __value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.DateTimeFormatInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.DateTimeFormatInfo>(__self);
	
	
	    try {
			__selfConverted.AbbreviatedMonthGenitiveNames = InteropUtils.GetInstance<System.String[]>(__value);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_DateTimeFormatInfo_MonthGenitiveNames_Get")]
	internal static void* /* System.String[] */ System_Globalization_DateTimeFormatInfo_MonthGenitiveNames_Get(void* /* System.Globalization.DateTimeFormatInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.DateTimeFormatInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.DateTimeFormatInfo>(__self);
	
	
	    try {
			System.String[] __returnValue = __selfConverted.MonthGenitiveNames;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_DateTimeFormatInfo_MonthGenitiveNames_Set")]
	internal static void /* System.Void */ System_Globalization_DateTimeFormatInfo_MonthGenitiveNames_Set(void* /* System.Globalization.DateTimeFormatInfo */ __self, void* /* System.String[] */ __value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Globalization.DateTimeFormatInfo __selfConverted = InteropUtils.GetInstance<System.Globalization.DateTimeFormatInfo>(__self);
	
	
	    try {
			__selfConverted.MonthGenitiveNames = InteropUtils.GetInstance<System.String[]>(__value);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_DateTimeFormatInfo_TypeOf")]
	internal static void* /* System.Type */ System_Globalization_DateTimeFormatInfo_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.Globalization.DateTimeFormatInfo);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Globalization_DateTimeFormatInfo_Destroy")]
	internal static void /* System.Void */ System_Globalization_DateTimeFormatInfo_Destroy(void* /* System.Globalization.DateTimeFormatInfo */ __self)
	{
	
		InteropUtils.FreeIfAllocated(__self);
	}
	
}





internal unsafe class System_CharEnumerator
{
	[UnmanagedCallersOnly(EntryPoint = "System_CharEnumerator_Clone")]
	internal static void* /* System.Object */ System_CharEnumerator_Clone(void* /* System.CharEnumerator */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.CharEnumerator __selfConverted = InteropUtils.GetInstance<System.CharEnumerator>(__self);
	
	
	    try {
			System.Object __returnValue = __selfConverted.Clone();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_CharEnumerator_MoveNext")]
	internal static byte /* System.Boolean */ System_CharEnumerator_MoveNext(void* /* System.CharEnumerator */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.CharEnumerator __selfConverted = InteropUtils.GetInstance<System.CharEnumerator>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.MoveNext();
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_CharEnumerator_Dispose")]
	internal static void /* System.Void */ System_CharEnumerator_Dispose(void* /* System.CharEnumerator */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.CharEnumerator __selfConverted = InteropUtils.GetInstance<System.CharEnumerator>(__self);
	
	
	    try {
			__selfConverted.Dispose();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_CharEnumerator_Reset")]
	internal static void /* System.Void */ System_CharEnumerator_Reset(void* /* System.CharEnumerator */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.CharEnumerator __selfConverted = InteropUtils.GetInstance<System.CharEnumerator>(__self);
	
	
	    try {
			__selfConverted.Reset();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_CharEnumerator_Current_Get")]
	internal static char /* System.Char */ System_CharEnumerator_Current_Get(void* /* System.CharEnumerator */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.CharEnumerator __selfConverted = InteropUtils.GetInstance<System.CharEnumerator>(__self);
	
	
	    try {
			System.Char __returnValue = __selfConverted.Current;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return (char)0;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_CharEnumerator_TypeOf")]
	internal static void* /* System.Type */ System_CharEnumerator_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.CharEnumerator);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_CharEnumerator_Destroy")]
	internal static void /* System.Void */ System_CharEnumerator_Destroy(void* /* System.CharEnumerator */ __self)
	{
	
		InteropUtils.FreeIfAllocated(__self);
	}
	
}


internal unsafe class System_Text_StringRuneEnumerator
{
	[UnmanagedCallersOnly(EntryPoint = "System_Text_StringRuneEnumerator_GetEnumerator")]
	internal static void* /* System.Text.StringRuneEnumerator */ System_Text_StringRuneEnumerator_GetEnumerator(void* /* System.Text.StringRuneEnumerator */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Text.StringRuneEnumerator __selfConverted = InteropUtils.GetInstance<System.Text.StringRuneEnumerator>(__self);
	
	
	    try {
			System.Text.StringRuneEnumerator __returnValue = __selfConverted.GetEnumerator();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Text_StringRuneEnumerator_MoveNext")]
	internal static byte /* System.Boolean */ System_Text_StringRuneEnumerator_MoveNext(void* /* System.Text.StringRuneEnumerator */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Text.StringRuneEnumerator __selfConverted = InteropUtils.GetInstance<System.Text.StringRuneEnumerator>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.MoveNext();
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Text_StringRuneEnumerator_Current_Get")]
	internal static void* /* System.Text.Rune */ System_Text_StringRuneEnumerator_Current_Get(void* /* System.Text.StringRuneEnumerator */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Text.StringRuneEnumerator __selfConverted = InteropUtils.GetInstance<System.Text.StringRuneEnumerator>(__self);
	
	
	    try {
			System.Text.Rune __returnValue = __selfConverted.Current;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
			if (__self is not null) {
				InteropUtils.ReplaceInstance(__self, __selfConverted);
			}
			
			
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Text_StringRuneEnumerator_Create")]
	internal static void* /* System.Text.StringRuneEnumerator */ System_Text_StringRuneEnumerator_Create(void** /* System.Exception */ __outException)
	{
	
	    try {
			System.Text.StringRuneEnumerator __returnValue = new System.Text.StringRuneEnumerator();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Text_StringRuneEnumerator_TypeOf")]
	internal static void* /* System.Type */ System_Text_StringRuneEnumerator_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.Text.StringRuneEnumerator);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Text_StringRuneEnumerator_Destroy")]
	internal static void /* System.Void */ System_Text_StringRuneEnumerator_Destroy(void* /* System.Text.StringRuneEnumerator */ __self)
	{
	
		InteropUtils.FreeIfAllocated(__self);
	}
	
}


internal unsafe class System_Text_NormalizationForm
{
	[UnmanagedCallersOnly(EntryPoint = "System_Text_NormalizationForm_TypeOf")]
	internal static void* /* System.Type */ System_Text_NormalizationForm_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.Text.NormalizationForm);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
}


internal unsafe class System_Text_CompositeFormat
{
	[UnmanagedCallersOnly(EntryPoint = "System_Text_CompositeFormat_Parse")]
	internal static void* /* System.Text.CompositeFormat */ System_Text_CompositeFormat_Parse(void* /* System.String */ format, void** /* System.Exception */ __outException)
	{
		System.String formatConverted = InteropUtils.GetInstance<System.String>(format);
	
	    try {
			System.Text.CompositeFormat __returnValue = System.Text.CompositeFormat.Parse(formatConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Text_CompositeFormat_Format_Get")]
	internal static void* /* System.String */ System_Text_CompositeFormat_Format_Get(void* /* System.Text.CompositeFormat */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Text.CompositeFormat __selfConverted = InteropUtils.GetInstance<System.Text.CompositeFormat>(__self);
	
	
	    try {
			System.String __returnValue = __selfConverted.Format;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Text_CompositeFormat_MinimumArgumentCount_Get")]
	internal static int /* System.Int32 */ System_Text_CompositeFormat_MinimumArgumentCount_Get(void* /* System.Text.CompositeFormat */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Text.CompositeFormat __selfConverted = InteropUtils.GetInstance<System.Text.CompositeFormat>(__self);
	
	
	    try {
			System.Int32 __returnValue = __selfConverted.MinimumArgumentCount;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Text_CompositeFormat_TypeOf")]
	internal static void* /* System.Type */ System_Text_CompositeFormat_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.Text.CompositeFormat);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Text_CompositeFormat_Destroy")]
	internal static void /* System.Void */ System_Text_CompositeFormat_Destroy(void* /* System.Text.CompositeFormat */ __self)
	{
	
		InteropUtils.FreeIfAllocated(__self);
	}
	
}


internal unsafe class System_StringSplitOptions
{
	[UnmanagedCallersOnly(EntryPoint = "System_StringSplitOptions_TypeOf")]
	internal static void* /* System.Type */ System_StringSplitOptions_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.StringSplitOptions);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
}


internal unsafe class System_Text_Encoding
{
	[UnmanagedCallersOnly(EntryPoint = "System_Text_Encoding_Convert")]
	internal static void* /* System.Byte[] */ System_Text_Encoding_Convert(void* /* System.Text.Encoding */ srcEncoding, void* /* System.Text.Encoding */ dstEncoding, void* /* System.Byte[] */ bytes, void** /* System.Exception */ __outException)
	{
		System.Text.Encoding srcEncodingConverted = InteropUtils.GetInstance<System.Text.Encoding>(srcEncoding);
		System.Text.Encoding dstEncodingConverted = InteropUtils.GetInstance<System.Text.Encoding>(dstEncoding);
		System.Byte[] bytesConverted = InteropUtils.GetInstance<System.Byte[]>(bytes);
	
	    try {
			System.Byte[] __returnValue = System.Text.Encoding.Convert(srcEncodingConverted, dstEncodingConverted, bytesConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Text_Encoding_Convert_1")]
	internal static void* /* System.Byte[] */ System_Text_Encoding_Convert_1(void* /* System.Text.Encoding */ srcEncoding, void* /* System.Text.Encoding */ dstEncoding, void* /* System.Byte[] */ bytes, int /* System.Int32 */ index, int /* System.Int32 */ count, void** /* System.Exception */ __outException)
	{
		System.Text.Encoding srcEncodingConverted = InteropUtils.GetInstance<System.Text.Encoding>(srcEncoding);
		System.Text.Encoding dstEncodingConverted = InteropUtils.GetInstance<System.Text.Encoding>(dstEncoding);
		System.Byte[] bytesConverted = InteropUtils.GetInstance<System.Byte[]>(bytes);
	
	    try {
			System.Byte[] __returnValue = System.Text.Encoding.Convert(srcEncodingConverted, dstEncodingConverted, bytesConverted, index, count);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Text_Encoding_RegisterProvider")]
	internal static void /* System.Void */ System_Text_Encoding_RegisterProvider(void* /* System.Text.EncodingProvider */ provider, void** /* System.Exception */ __outException)
	{
		System.Text.EncodingProvider providerConverted = InteropUtils.GetInstance<System.Text.EncodingProvider>(provider);
	
	    try {
			System.Text.Encoding.RegisterProvider(providerConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Text_Encoding_GetEncoding")]
	internal static void* /* System.Text.Encoding */ System_Text_Encoding_GetEncoding(int /* System.Int32 */ codepage, void** /* System.Exception */ __outException)
	{
	
	    try {
			System.Text.Encoding __returnValue = System.Text.Encoding.GetEncoding(codepage);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Text_Encoding_GetEncoding_1")]
	internal static void* /* System.Text.Encoding */ System_Text_Encoding_GetEncoding_1(int /* System.Int32 */ codepage, void* /* System.Text.EncoderFallback */ encoderFallback, void* /* System.Text.DecoderFallback */ decoderFallback, void** /* System.Exception */ __outException)
	{
		System.Text.EncoderFallback encoderFallbackConverted = InteropUtils.GetInstance<System.Text.EncoderFallback>(encoderFallback);
		System.Text.DecoderFallback decoderFallbackConverted = InteropUtils.GetInstance<System.Text.DecoderFallback>(decoderFallback);
	
	    try {
			System.Text.Encoding __returnValue = System.Text.Encoding.GetEncoding(codepage, encoderFallbackConverted, decoderFallbackConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Text_Encoding_GetEncoding_2")]
	internal static void* /* System.Text.Encoding */ System_Text_Encoding_GetEncoding_2(void* /* System.String */ name, void** /* System.Exception */ __outException)
	{
		System.String nameConverted = InteropUtils.GetInstance<System.String>(name);
	
	    try {
			System.Text.Encoding __returnValue = System.Text.Encoding.GetEncoding(nameConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Text_Encoding_GetEncoding_3")]
	internal static void* /* System.Text.Encoding */ System_Text_Encoding_GetEncoding_3(void* /* System.String */ name, void* /* System.Text.EncoderFallback */ encoderFallback, void* /* System.Text.DecoderFallback */ decoderFallback, void** /* System.Exception */ __outException)
	{
		System.String nameConverted = InteropUtils.GetInstance<System.String>(name);
		System.Text.EncoderFallback encoderFallbackConverted = InteropUtils.GetInstance<System.Text.EncoderFallback>(encoderFallback);
		System.Text.DecoderFallback decoderFallbackConverted = InteropUtils.GetInstance<System.Text.DecoderFallback>(decoderFallback);
	
	    try {
			System.Text.Encoding __returnValue = System.Text.Encoding.GetEncoding(nameConverted, encoderFallbackConverted, decoderFallbackConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Text_Encoding_GetEncodings")]
	internal static void* /* System.Text.EncodingInfo[] */ System_Text_Encoding_GetEncodings(void** /* System.Exception */ __outException)
	{
	
	    try {
			System.Text.EncodingInfo[] __returnValue = System.Text.Encoding.GetEncodings();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Text_Encoding_GetPreamble")]
	internal static void* /* System.Byte[] */ System_Text_Encoding_GetPreamble(void* /* System.Text.Encoding */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Text.Encoding __selfConverted = InteropUtils.GetInstance<System.Text.Encoding>(__self);
	
	
	    try {
			System.Byte[] __returnValue = __selfConverted.GetPreamble();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Text_Encoding_Clone")]
	internal static void* /* System.Object */ System_Text_Encoding_Clone(void* /* System.Text.Encoding */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Text.Encoding __selfConverted = InteropUtils.GetInstance<System.Text.Encoding>(__self);
	
	
	    try {
			System.Object __returnValue = __selfConverted.Clone();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Text_Encoding_GetByteCount")]
	internal static int /* System.Int32 */ System_Text_Encoding_GetByteCount(void* /* System.Text.Encoding */ __self, void* /* System.Char[] */ chars, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Text.Encoding __selfConverted = InteropUtils.GetInstance<System.Text.Encoding>(__self);
	
		System.Char[] charsConverted = InteropUtils.GetInstance<System.Char[]>(chars);
	
	    try {
			System.Int32 __returnValue = __selfConverted.GetByteCount(charsConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Text_Encoding_GetByteCount_1")]
	internal static int /* System.Int32 */ System_Text_Encoding_GetByteCount_1(void* /* System.Text.Encoding */ __self, void* /* System.String */ s, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Text.Encoding __selfConverted = InteropUtils.GetInstance<System.Text.Encoding>(__self);
	
		System.String sConverted = InteropUtils.GetInstance<System.String>(s);
	
	    try {
			System.Int32 __returnValue = __selfConverted.GetByteCount(sConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Text_Encoding_GetByteCount_2")]
	internal static int /* System.Int32 */ System_Text_Encoding_GetByteCount_2(void* /* System.Text.Encoding */ __self, void* /* System.Char[] */ chars, int /* System.Int32 */ index, int /* System.Int32 */ count, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Text.Encoding __selfConverted = InteropUtils.GetInstance<System.Text.Encoding>(__self);
	
		System.Char[] charsConverted = InteropUtils.GetInstance<System.Char[]>(chars);
	
	    try {
			System.Int32 __returnValue = __selfConverted.GetByteCount(charsConverted, index, count);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Text_Encoding_GetByteCount_3")]
	internal static int /* System.Int32 */ System_Text_Encoding_GetByteCount_3(void* /* System.Text.Encoding */ __self, void* /* System.String */ s, int /* System.Int32 */ index, int /* System.Int32 */ count, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Text.Encoding __selfConverted = InteropUtils.GetInstance<System.Text.Encoding>(__self);
	
		System.String sConverted = InteropUtils.GetInstance<System.String>(s);
	
	    try {
			System.Int32 __returnValue = __selfConverted.GetByteCount(sConverted, index, count);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Text_Encoding_GetBytes")]
	internal static void* /* System.Byte[] */ System_Text_Encoding_GetBytes(void* /* System.Text.Encoding */ __self, void* /* System.Char[] */ chars, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Text.Encoding __selfConverted = InteropUtils.GetInstance<System.Text.Encoding>(__self);
	
		System.Char[] charsConverted = InteropUtils.GetInstance<System.Char[]>(chars);
	
	    try {
			System.Byte[] __returnValue = __selfConverted.GetBytes(charsConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Text_Encoding_GetBytes_1")]
	internal static void* /* System.Byte[] */ System_Text_Encoding_GetBytes_1(void* /* System.Text.Encoding */ __self, void* /* System.Char[] */ chars, int /* System.Int32 */ index, int /* System.Int32 */ count, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Text.Encoding __selfConverted = InteropUtils.GetInstance<System.Text.Encoding>(__self);
	
		System.Char[] charsConverted = InteropUtils.GetInstance<System.Char[]>(chars);
	
	    try {
			System.Byte[] __returnValue = __selfConverted.GetBytes(charsConverted, index, count);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Text_Encoding_GetBytes_2")]
	internal static int /* System.Int32 */ System_Text_Encoding_GetBytes_2(void* /* System.Text.Encoding */ __self, void* /* System.Char[] */ chars, int /* System.Int32 */ charIndex, int /* System.Int32 */ charCount, void* /* System.Byte[] */ bytes, int /* System.Int32 */ byteIndex, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Text.Encoding __selfConverted = InteropUtils.GetInstance<System.Text.Encoding>(__self);
	
		System.Char[] charsConverted = InteropUtils.GetInstance<System.Char[]>(chars);
		System.Byte[] bytesConverted = InteropUtils.GetInstance<System.Byte[]>(bytes);
	
	    try {
			System.Int32 __returnValue = __selfConverted.GetBytes(charsConverted, charIndex, charCount, bytesConverted, byteIndex);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Text_Encoding_GetBytes_3")]
	internal static void* /* System.Byte[] */ System_Text_Encoding_GetBytes_3(void* /* System.Text.Encoding */ __self, void* /* System.String */ s, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Text.Encoding __selfConverted = InteropUtils.GetInstance<System.Text.Encoding>(__self);
	
		System.String sConverted = InteropUtils.GetInstance<System.String>(s);
	
	    try {
			System.Byte[] __returnValue = __selfConverted.GetBytes(sConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Text_Encoding_GetBytes_4")]
	internal static void* /* System.Byte[] */ System_Text_Encoding_GetBytes_4(void* /* System.Text.Encoding */ __self, void* /* System.String */ s, int /* System.Int32 */ index, int /* System.Int32 */ count, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Text.Encoding __selfConverted = InteropUtils.GetInstance<System.Text.Encoding>(__self);
	
		System.String sConverted = InteropUtils.GetInstance<System.String>(s);
	
	    try {
			System.Byte[] __returnValue = __selfConverted.GetBytes(sConverted, index, count);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Text_Encoding_GetBytes_5")]
	internal static int /* System.Int32 */ System_Text_Encoding_GetBytes_5(void* /* System.Text.Encoding */ __self, void* /* System.String */ s, int /* System.Int32 */ charIndex, int /* System.Int32 */ charCount, void* /* System.Byte[] */ bytes, int /* System.Int32 */ byteIndex, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Text.Encoding __selfConverted = InteropUtils.GetInstance<System.Text.Encoding>(__self);
	
		System.String sConverted = InteropUtils.GetInstance<System.String>(s);
		System.Byte[] bytesConverted = InteropUtils.GetInstance<System.Byte[]>(bytes);
	
	    try {
			System.Int32 __returnValue = __selfConverted.GetBytes(sConverted, charIndex, charCount, bytesConverted, byteIndex);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Text_Encoding_GetCharCount")]
	internal static int /* System.Int32 */ System_Text_Encoding_GetCharCount(void* /* System.Text.Encoding */ __self, void* /* System.Byte[] */ bytes, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Text.Encoding __selfConverted = InteropUtils.GetInstance<System.Text.Encoding>(__self);
	
		System.Byte[] bytesConverted = InteropUtils.GetInstance<System.Byte[]>(bytes);
	
	    try {
			System.Int32 __returnValue = __selfConverted.GetCharCount(bytesConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Text_Encoding_GetCharCount_1")]
	internal static int /* System.Int32 */ System_Text_Encoding_GetCharCount_1(void* /* System.Text.Encoding */ __self, void* /* System.Byte[] */ bytes, int /* System.Int32 */ index, int /* System.Int32 */ count, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Text.Encoding __selfConverted = InteropUtils.GetInstance<System.Text.Encoding>(__self);
	
		System.Byte[] bytesConverted = InteropUtils.GetInstance<System.Byte[]>(bytes);
	
	    try {
			System.Int32 __returnValue = __selfConverted.GetCharCount(bytesConverted, index, count);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Text_Encoding_GetChars")]
	internal static void* /* System.Char[] */ System_Text_Encoding_GetChars(void* /* System.Text.Encoding */ __self, void* /* System.Byte[] */ bytes, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Text.Encoding __selfConverted = InteropUtils.GetInstance<System.Text.Encoding>(__self);
	
		System.Byte[] bytesConverted = InteropUtils.GetInstance<System.Byte[]>(bytes);
	
	    try {
			System.Char[] __returnValue = __selfConverted.GetChars(bytesConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Text_Encoding_GetChars_1")]
	internal static void* /* System.Char[] */ System_Text_Encoding_GetChars_1(void* /* System.Text.Encoding */ __self, void* /* System.Byte[] */ bytes, int /* System.Int32 */ index, int /* System.Int32 */ count, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Text.Encoding __selfConverted = InteropUtils.GetInstance<System.Text.Encoding>(__self);
	
		System.Byte[] bytesConverted = InteropUtils.GetInstance<System.Byte[]>(bytes);
	
	    try {
			System.Char[] __returnValue = __selfConverted.GetChars(bytesConverted, index, count);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Text_Encoding_GetChars_2")]
	internal static int /* System.Int32 */ System_Text_Encoding_GetChars_2(void* /* System.Text.Encoding */ __self, void* /* System.Byte[] */ bytes, int /* System.Int32 */ byteIndex, int /* System.Int32 */ byteCount, void* /* System.Char[] */ chars, int /* System.Int32 */ charIndex, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Text.Encoding __selfConverted = InteropUtils.GetInstance<System.Text.Encoding>(__self);
	
		System.Byte[] bytesConverted = InteropUtils.GetInstance<System.Byte[]>(bytes);
		System.Char[] charsConverted = InteropUtils.GetInstance<System.Char[]>(chars);
	
	    try {
			System.Int32 __returnValue = __selfConverted.GetChars(bytesConverted, byteIndex, byteCount, charsConverted, charIndex);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Text_Encoding_IsAlwaysNormalized")]
	internal static byte /* System.Boolean */ System_Text_Encoding_IsAlwaysNormalized(void* /* System.Text.Encoding */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Text.Encoding __selfConverted = InteropUtils.GetInstance<System.Text.Encoding>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.IsAlwaysNormalized();
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Text_Encoding_IsAlwaysNormalized_1")]
	internal static byte /* System.Boolean */ System_Text_Encoding_IsAlwaysNormalized_1(void* /* System.Text.Encoding */ __self, System.Text.NormalizationForm /* System.Text.NormalizationForm */ form, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Text.Encoding __selfConverted = InteropUtils.GetInstance<System.Text.Encoding>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.IsAlwaysNormalized(form);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Text_Encoding_GetDecoder")]
	internal static void* /* System.Text.Decoder */ System_Text_Encoding_GetDecoder(void* /* System.Text.Encoding */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Text.Encoding __selfConverted = InteropUtils.GetInstance<System.Text.Encoding>(__self);
	
	
	    try {
			System.Text.Decoder __returnValue = __selfConverted.GetDecoder();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Text_Encoding_GetEncoder")]
	internal static void* /* System.Text.Encoder */ System_Text_Encoding_GetEncoder(void* /* System.Text.Encoding */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Text.Encoding __selfConverted = InteropUtils.GetInstance<System.Text.Encoding>(__self);
	
	
	    try {
			System.Text.Encoder __returnValue = __selfConverted.GetEncoder();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Text_Encoding_GetMaxByteCount")]
	internal static int /* System.Int32 */ System_Text_Encoding_GetMaxByteCount(void* /* System.Text.Encoding */ __self, int /* System.Int32 */ charCount, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Text.Encoding __selfConverted = InteropUtils.GetInstance<System.Text.Encoding>(__self);
	
	
	    try {
			System.Int32 __returnValue = __selfConverted.GetMaxByteCount(charCount);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Text_Encoding_GetMaxCharCount")]
	internal static int /* System.Int32 */ System_Text_Encoding_GetMaxCharCount(void* /* System.Text.Encoding */ __self, int /* System.Int32 */ byteCount, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Text.Encoding __selfConverted = InteropUtils.GetInstance<System.Text.Encoding>(__self);
	
	
	    try {
			System.Int32 __returnValue = __selfConverted.GetMaxCharCount(byteCount);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Text_Encoding_GetString")]
	internal static void* /* System.String */ System_Text_Encoding_GetString(void* /* System.Text.Encoding */ __self, void* /* System.Byte[] */ bytes, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Text.Encoding __selfConverted = InteropUtils.GetInstance<System.Text.Encoding>(__self);
	
		System.Byte[] bytesConverted = InteropUtils.GetInstance<System.Byte[]>(bytes);
	
	    try {
			System.String __returnValue = __selfConverted.GetString(bytesConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Text_Encoding_GetString_1")]
	internal static void* /* System.String */ System_Text_Encoding_GetString_1(void* /* System.Text.Encoding */ __self, void* /* System.Byte[] */ bytes, int /* System.Int32 */ index, int /* System.Int32 */ count, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Text.Encoding __selfConverted = InteropUtils.GetInstance<System.Text.Encoding>(__self);
	
		System.Byte[] bytesConverted = InteropUtils.GetInstance<System.Byte[]>(bytes);
	
	    try {
			System.String __returnValue = __selfConverted.GetString(bytesConverted, index, count);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Text_Encoding_Equals")]
	internal static byte /* System.Boolean */ System_Text_Encoding_Equals(void* /* System.Text.Encoding */ __self, void* /* System.Object */ value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Text.Encoding __selfConverted = InteropUtils.GetInstance<System.Text.Encoding>(__self);
	
		System.Object valueConverted = InteropUtils.GetInstance<System.Object>(value);
	
	    try {
			System.Boolean __returnValue = __selfConverted.Equals(valueConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Text_Encoding_GetHashCode")]
	internal static int /* System.Int32 */ System_Text_Encoding_GetHashCode(void* /* System.Text.Encoding */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Text.Encoding __selfConverted = InteropUtils.GetInstance<System.Text.Encoding>(__self);
	
	
	    try {
			System.Int32 __returnValue = __selfConverted.GetHashCode();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Text_Encoding_CreateTranscodingStream")]
	internal static void* /* System.IO.Stream */ System_Text_Encoding_CreateTranscodingStream(void* /* System.IO.Stream */ innerStream, void* /* System.Text.Encoding */ innerStreamEncoding, void* /* System.Text.Encoding */ outerStreamEncoding, byte /* System.Boolean */ leaveOpen, void** /* System.Exception */ __outException)
	{
		System.IO.Stream innerStreamConverted = InteropUtils.GetInstance<System.IO.Stream>(innerStream);
		System.Text.Encoding innerStreamEncodingConverted = InteropUtils.GetInstance<System.Text.Encoding>(innerStreamEncoding);
		System.Text.Encoding outerStreamEncodingConverted = InteropUtils.GetInstance<System.Text.Encoding>(outerStreamEncoding);
		System.Boolean leaveOpenConverted = leaveOpen.ToBool();
	
	    try {
			System.IO.Stream __returnValue = System.Text.Encoding.CreateTranscodingStream(innerStreamConverted, innerStreamEncodingConverted, outerStreamEncodingConverted, leaveOpenConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Text_Encoding_Default_Get")]
	internal static void* /* System.Text.Encoding */ System_Text_Encoding_Default_Get(void** /* System.Exception */ __outException)
	{
	
	    try {
			System.Text.Encoding __returnValue = System.Text.Encoding.Default;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Text_Encoding_BodyName_Get")]
	internal static void* /* System.String */ System_Text_Encoding_BodyName_Get(void* /* System.Text.Encoding */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Text.Encoding __selfConverted = InteropUtils.GetInstance<System.Text.Encoding>(__self);
	
	
	    try {
			System.String __returnValue = __selfConverted.BodyName;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Text_Encoding_EncodingName_Get")]
	internal static void* /* System.String */ System_Text_Encoding_EncodingName_Get(void* /* System.Text.Encoding */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Text.Encoding __selfConverted = InteropUtils.GetInstance<System.Text.Encoding>(__self);
	
	
	    try {
			System.String __returnValue = __selfConverted.EncodingName;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Text_Encoding_HeaderName_Get")]
	internal static void* /* System.String */ System_Text_Encoding_HeaderName_Get(void* /* System.Text.Encoding */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Text.Encoding __selfConverted = InteropUtils.GetInstance<System.Text.Encoding>(__self);
	
	
	    try {
			System.String __returnValue = __selfConverted.HeaderName;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Text_Encoding_WebName_Get")]
	internal static void* /* System.String */ System_Text_Encoding_WebName_Get(void* /* System.Text.Encoding */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Text.Encoding __selfConverted = InteropUtils.GetInstance<System.Text.Encoding>(__self);
	
	
	    try {
			System.String __returnValue = __selfConverted.WebName;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Text_Encoding_WindowsCodePage_Get")]
	internal static int /* System.Int32 */ System_Text_Encoding_WindowsCodePage_Get(void* /* System.Text.Encoding */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Text.Encoding __selfConverted = InteropUtils.GetInstance<System.Text.Encoding>(__self);
	
	
	    try {
			System.Int32 __returnValue = __selfConverted.WindowsCodePage;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Text_Encoding_IsBrowserDisplay_Get")]
	internal static byte /* System.Boolean */ System_Text_Encoding_IsBrowserDisplay_Get(void* /* System.Text.Encoding */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Text.Encoding __selfConverted = InteropUtils.GetInstance<System.Text.Encoding>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.IsBrowserDisplay;
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Text_Encoding_IsBrowserSave_Get")]
	internal static byte /* System.Boolean */ System_Text_Encoding_IsBrowserSave_Get(void* /* System.Text.Encoding */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Text.Encoding __selfConverted = InteropUtils.GetInstance<System.Text.Encoding>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.IsBrowserSave;
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Text_Encoding_IsMailNewsDisplay_Get")]
	internal static byte /* System.Boolean */ System_Text_Encoding_IsMailNewsDisplay_Get(void* /* System.Text.Encoding */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Text.Encoding __selfConverted = InteropUtils.GetInstance<System.Text.Encoding>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.IsMailNewsDisplay;
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Text_Encoding_IsMailNewsSave_Get")]
	internal static byte /* System.Boolean */ System_Text_Encoding_IsMailNewsSave_Get(void* /* System.Text.Encoding */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Text.Encoding __selfConverted = InteropUtils.GetInstance<System.Text.Encoding>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.IsMailNewsSave;
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Text_Encoding_IsSingleByte_Get")]
	internal static byte /* System.Boolean */ System_Text_Encoding_IsSingleByte_Get(void* /* System.Text.Encoding */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Text.Encoding __selfConverted = InteropUtils.GetInstance<System.Text.Encoding>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.IsSingleByte;
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Text_Encoding_EncoderFallback_Get")]
	internal static void* /* System.Text.EncoderFallback */ System_Text_Encoding_EncoderFallback_Get(void* /* System.Text.Encoding */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Text.Encoding __selfConverted = InteropUtils.GetInstance<System.Text.Encoding>(__self);
	
	
	    try {
			System.Text.EncoderFallback __returnValue = __selfConverted.EncoderFallback;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Text_Encoding_EncoderFallback_Set")]
	internal static void /* System.Void */ System_Text_Encoding_EncoderFallback_Set(void* /* System.Text.Encoding */ __self, void* /* System.Text.EncoderFallback */ __value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Text.Encoding __selfConverted = InteropUtils.GetInstance<System.Text.Encoding>(__self);
	
	
	    try {
			__selfConverted.EncoderFallback = InteropUtils.GetInstance<System.Text.EncoderFallback>(__value);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Text_Encoding_DecoderFallback_Get")]
	internal static void* /* System.Text.DecoderFallback */ System_Text_Encoding_DecoderFallback_Get(void* /* System.Text.Encoding */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Text.Encoding __selfConverted = InteropUtils.GetInstance<System.Text.Encoding>(__self);
	
	
	    try {
			System.Text.DecoderFallback __returnValue = __selfConverted.DecoderFallback;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Text_Encoding_DecoderFallback_Set")]
	internal static void /* System.Void */ System_Text_Encoding_DecoderFallback_Set(void* /* System.Text.Encoding */ __self, void* /* System.Text.DecoderFallback */ __value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Text.Encoding __selfConverted = InteropUtils.GetInstance<System.Text.Encoding>(__self);
	
	
	    try {
			__selfConverted.DecoderFallback = InteropUtils.GetInstance<System.Text.DecoderFallback>(__value);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Text_Encoding_IsReadOnly_Get")]
	internal static byte /* System.Boolean */ System_Text_Encoding_IsReadOnly_Get(void* /* System.Text.Encoding */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Text.Encoding __selfConverted = InteropUtils.GetInstance<System.Text.Encoding>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.IsReadOnly;
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Text_Encoding_ASCII_Get")]
	internal static void* /* System.Text.Encoding */ System_Text_Encoding_ASCII_Get(void** /* System.Exception */ __outException)
	{
	
	    try {
			System.Text.Encoding __returnValue = System.Text.Encoding.ASCII;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Text_Encoding_Latin1_Get")]
	internal static void* /* System.Text.Encoding */ System_Text_Encoding_Latin1_Get(void** /* System.Exception */ __outException)
	{
	
	    try {
			System.Text.Encoding __returnValue = System.Text.Encoding.Latin1;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Text_Encoding_CodePage_Get")]
	internal static int /* System.Int32 */ System_Text_Encoding_CodePage_Get(void* /* System.Text.Encoding */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Text.Encoding __selfConverted = InteropUtils.GetInstance<System.Text.Encoding>(__self);
	
	
	    try {
			System.Int32 __returnValue = __selfConverted.CodePage;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Text_Encoding_Unicode_Get")]
	internal static void* /* System.Text.Encoding */ System_Text_Encoding_Unicode_Get(void** /* System.Exception */ __outException)
	{
	
	    try {
			System.Text.Encoding __returnValue = System.Text.Encoding.Unicode;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Text_Encoding_BigEndianUnicode_Get")]
	internal static void* /* System.Text.Encoding */ System_Text_Encoding_BigEndianUnicode_Get(void** /* System.Exception */ __outException)
	{
	
	    try {
			System.Text.Encoding __returnValue = System.Text.Encoding.BigEndianUnicode;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Text_Encoding_UTF7_Get")]
	internal static void* /* System.Text.Encoding */ System_Text_Encoding_UTF7_Get(void** /* System.Exception */ __outException)
	{
	
	    try {
			System.Text.Encoding __returnValue = System.Text.Encoding.UTF7;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Text_Encoding_UTF8_Get")]
	internal static void* /* System.Text.Encoding */ System_Text_Encoding_UTF8_Get(void** /* System.Exception */ __outException)
	{
	
	    try {
			System.Text.Encoding __returnValue = System.Text.Encoding.UTF8;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Text_Encoding_UTF32_Get")]
	internal static void* /* System.Text.Encoding */ System_Text_Encoding_UTF32_Get(void** /* System.Exception */ __outException)
	{
	
	    try {
			System.Text.Encoding __returnValue = System.Text.Encoding.UTF32;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Text_Encoding_TypeOf")]
	internal static void* /* System.Type */ System_Text_Encoding_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.Text.Encoding);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Text_Encoding_Destroy")]
	internal static void /* System.Void */ System_Text_Encoding_Destroy(void* /* System.Text.Encoding */ __self)
	{
	
		InteropUtils.FreeIfAllocated(__self);
	}
	
}


internal unsafe class System_Text_EncodingProvider
{
	[UnmanagedCallersOnly(EntryPoint = "System_Text_EncodingProvider_GetEncoding")]
	internal static void* /* System.Text.Encoding */ System_Text_EncodingProvider_GetEncoding(void* /* System.Text.EncodingProvider */ __self, void* /* System.String */ name, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Text.EncodingProvider __selfConverted = InteropUtils.GetInstance<System.Text.EncodingProvider>(__self);
	
		System.String nameConverted = InteropUtils.GetInstance<System.String>(name);
	
	    try {
			System.Text.Encoding __returnValue = __selfConverted.GetEncoding(nameConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Text_EncodingProvider_GetEncoding_1")]
	internal static void* /* System.Text.Encoding */ System_Text_EncodingProvider_GetEncoding_1(void* /* System.Text.EncodingProvider */ __self, int /* System.Int32 */ codepage, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Text.EncodingProvider __selfConverted = InteropUtils.GetInstance<System.Text.EncodingProvider>(__self);
	
	
	    try {
			System.Text.Encoding __returnValue = __selfConverted.GetEncoding(codepage);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Text_EncodingProvider_GetEncoding_2")]
	internal static void* /* System.Text.Encoding */ System_Text_EncodingProvider_GetEncoding_2(void* /* System.Text.EncodingProvider */ __self, void* /* System.String */ name, void* /* System.Text.EncoderFallback */ encoderFallback, void* /* System.Text.DecoderFallback */ decoderFallback, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Text.EncodingProvider __selfConverted = InteropUtils.GetInstance<System.Text.EncodingProvider>(__self);
	
		System.String nameConverted = InteropUtils.GetInstance<System.String>(name);
		System.Text.EncoderFallback encoderFallbackConverted = InteropUtils.GetInstance<System.Text.EncoderFallback>(encoderFallback);
		System.Text.DecoderFallback decoderFallbackConverted = InteropUtils.GetInstance<System.Text.DecoderFallback>(decoderFallback);
	
	    try {
			System.Text.Encoding __returnValue = __selfConverted.GetEncoding(nameConverted, encoderFallbackConverted, decoderFallbackConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Text_EncodingProvider_GetEncoding_3")]
	internal static void* /* System.Text.Encoding */ System_Text_EncodingProvider_GetEncoding_3(void* /* System.Text.EncodingProvider */ __self, int /* System.Int32 */ codepage, void* /* System.Text.EncoderFallback */ encoderFallback, void* /* System.Text.DecoderFallback */ decoderFallback, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Text.EncodingProvider __selfConverted = InteropUtils.GetInstance<System.Text.EncodingProvider>(__self);
	
		System.Text.EncoderFallback encoderFallbackConverted = InteropUtils.GetInstance<System.Text.EncoderFallback>(encoderFallback);
		System.Text.DecoderFallback decoderFallbackConverted = InteropUtils.GetInstance<System.Text.DecoderFallback>(decoderFallback);
	
	    try {
			System.Text.Encoding __returnValue = __selfConverted.GetEncoding(codepage, encoderFallbackConverted, decoderFallbackConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Text_EncodingProvider_TypeOf")]
	internal static void* /* System.Type */ System_Text_EncodingProvider_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.Text.EncodingProvider);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Text_EncodingProvider_Destroy")]
	internal static void /* System.Void */ System_Text_EncodingProvider_Destroy(void* /* System.Text.EncodingProvider */ __self)
	{
	
		InteropUtils.FreeIfAllocated(__self);
	}
	
}


internal unsafe class System_Text_EncoderFallback
{
	[UnmanagedCallersOnly(EntryPoint = "System_Text_EncoderFallback_CreateFallbackBuffer")]
	internal static void* /* System.Text.EncoderFallbackBuffer */ System_Text_EncoderFallback_CreateFallbackBuffer(void* /* System.Text.EncoderFallback */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Text.EncoderFallback __selfConverted = InteropUtils.GetInstance<System.Text.EncoderFallback>(__self);
	
	
	    try {
			System.Text.EncoderFallbackBuffer __returnValue = __selfConverted.CreateFallbackBuffer();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Text_EncoderFallback_ReplacementFallback_Get")]
	internal static void* /* System.Text.EncoderFallback */ System_Text_EncoderFallback_ReplacementFallback_Get(void** /* System.Exception */ __outException)
	{
	
	    try {
			System.Text.EncoderFallback __returnValue = System.Text.EncoderFallback.ReplacementFallback;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Text_EncoderFallback_ExceptionFallback_Get")]
	internal static void* /* System.Text.EncoderFallback */ System_Text_EncoderFallback_ExceptionFallback_Get(void** /* System.Exception */ __outException)
	{
	
	    try {
			System.Text.EncoderFallback __returnValue = System.Text.EncoderFallback.ExceptionFallback;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Text_EncoderFallback_MaxCharCount_Get")]
	internal static int /* System.Int32 */ System_Text_EncoderFallback_MaxCharCount_Get(void* /* System.Text.EncoderFallback */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Text.EncoderFallback __selfConverted = InteropUtils.GetInstance<System.Text.EncoderFallback>(__self);
	
	
	    try {
			System.Int32 __returnValue = __selfConverted.MaxCharCount;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Text_EncoderFallback_TypeOf")]
	internal static void* /* System.Type */ System_Text_EncoderFallback_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.Text.EncoderFallback);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Text_EncoderFallback_Destroy")]
	internal static void /* System.Void */ System_Text_EncoderFallback_Destroy(void* /* System.Text.EncoderFallback */ __self)
	{
	
		InteropUtils.FreeIfAllocated(__self);
	}
	
}


internal unsafe class System_Text_EncoderFallbackBuffer
{
	[UnmanagedCallersOnly(EntryPoint = "System_Text_EncoderFallbackBuffer_Fallback")]
	internal static byte /* System.Boolean */ System_Text_EncoderFallbackBuffer_Fallback(void* /* System.Text.EncoderFallbackBuffer */ __self, char /* System.Char */ charUnknown, int /* System.Int32 */ index, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Text.EncoderFallbackBuffer __selfConverted = InteropUtils.GetInstance<System.Text.EncoderFallbackBuffer>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.Fallback(charUnknown, index);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Text_EncoderFallbackBuffer_Fallback_1")]
	internal static byte /* System.Boolean */ System_Text_EncoderFallbackBuffer_Fallback_1(void* /* System.Text.EncoderFallbackBuffer */ __self, char /* System.Char */ charUnknownHigh, char /* System.Char */ charUnknownLow, int /* System.Int32 */ index, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Text.EncoderFallbackBuffer __selfConverted = InteropUtils.GetInstance<System.Text.EncoderFallbackBuffer>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.Fallback(charUnknownHigh, charUnknownLow, index);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Text_EncoderFallbackBuffer_GetNextChar")]
	internal static char /* System.Char */ System_Text_EncoderFallbackBuffer_GetNextChar(void* /* System.Text.EncoderFallbackBuffer */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Text.EncoderFallbackBuffer __selfConverted = InteropUtils.GetInstance<System.Text.EncoderFallbackBuffer>(__self);
	
	
	    try {
			System.Char __returnValue = __selfConverted.GetNextChar();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return (char)0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Text_EncoderFallbackBuffer_MovePrevious")]
	internal static byte /* System.Boolean */ System_Text_EncoderFallbackBuffer_MovePrevious(void* /* System.Text.EncoderFallbackBuffer */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Text.EncoderFallbackBuffer __selfConverted = InteropUtils.GetInstance<System.Text.EncoderFallbackBuffer>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.MovePrevious();
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Text_EncoderFallbackBuffer_Reset")]
	internal static void /* System.Void */ System_Text_EncoderFallbackBuffer_Reset(void* /* System.Text.EncoderFallbackBuffer */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Text.EncoderFallbackBuffer __selfConverted = InteropUtils.GetInstance<System.Text.EncoderFallbackBuffer>(__self);
	
	
	    try {
			__selfConverted.Reset();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Text_EncoderFallbackBuffer_Remaining_Get")]
	internal static int /* System.Int32 */ System_Text_EncoderFallbackBuffer_Remaining_Get(void* /* System.Text.EncoderFallbackBuffer */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Text.EncoderFallbackBuffer __selfConverted = InteropUtils.GetInstance<System.Text.EncoderFallbackBuffer>(__self);
	
	
	    try {
			System.Int32 __returnValue = __selfConverted.Remaining;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Text_EncoderFallbackBuffer_TypeOf")]
	internal static void* /* System.Type */ System_Text_EncoderFallbackBuffer_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.Text.EncoderFallbackBuffer);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Text_EncoderFallbackBuffer_Destroy")]
	internal static void /* System.Void */ System_Text_EncoderFallbackBuffer_Destroy(void* /* System.Text.EncoderFallbackBuffer */ __self)
	{
	
		InteropUtils.FreeIfAllocated(__self);
	}
	
}


internal unsafe class System_Text_DecoderFallback
{
	[UnmanagedCallersOnly(EntryPoint = "System_Text_DecoderFallback_CreateFallbackBuffer")]
	internal static void* /* System.Text.DecoderFallbackBuffer */ System_Text_DecoderFallback_CreateFallbackBuffer(void* /* System.Text.DecoderFallback */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Text.DecoderFallback __selfConverted = InteropUtils.GetInstance<System.Text.DecoderFallback>(__self);
	
	
	    try {
			System.Text.DecoderFallbackBuffer __returnValue = __selfConverted.CreateFallbackBuffer();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Text_DecoderFallback_ReplacementFallback_Get")]
	internal static void* /* System.Text.DecoderFallback */ System_Text_DecoderFallback_ReplacementFallback_Get(void** /* System.Exception */ __outException)
	{
	
	    try {
			System.Text.DecoderFallback __returnValue = System.Text.DecoderFallback.ReplacementFallback;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Text_DecoderFallback_ExceptionFallback_Get")]
	internal static void* /* System.Text.DecoderFallback */ System_Text_DecoderFallback_ExceptionFallback_Get(void** /* System.Exception */ __outException)
	{
	
	    try {
			System.Text.DecoderFallback __returnValue = System.Text.DecoderFallback.ExceptionFallback;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Text_DecoderFallback_MaxCharCount_Get")]
	internal static int /* System.Int32 */ System_Text_DecoderFallback_MaxCharCount_Get(void* /* System.Text.DecoderFallback */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Text.DecoderFallback __selfConverted = InteropUtils.GetInstance<System.Text.DecoderFallback>(__self);
	
	
	    try {
			System.Int32 __returnValue = __selfConverted.MaxCharCount;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Text_DecoderFallback_TypeOf")]
	internal static void* /* System.Type */ System_Text_DecoderFallback_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.Text.DecoderFallback);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Text_DecoderFallback_Destroy")]
	internal static void /* System.Void */ System_Text_DecoderFallback_Destroy(void* /* System.Text.DecoderFallback */ __self)
	{
	
		InteropUtils.FreeIfAllocated(__self);
	}
	
}


internal unsafe class System_Text_DecoderFallbackBuffer
{
	[UnmanagedCallersOnly(EntryPoint = "System_Text_DecoderFallbackBuffer_Fallback")]
	internal static byte /* System.Boolean */ System_Text_DecoderFallbackBuffer_Fallback(void* /* System.Text.DecoderFallbackBuffer */ __self, void* /* System.Byte[] */ bytesUnknown, int /* System.Int32 */ index, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Text.DecoderFallbackBuffer __selfConverted = InteropUtils.GetInstance<System.Text.DecoderFallbackBuffer>(__self);
	
		System.Byte[] bytesUnknownConverted = InteropUtils.GetInstance<System.Byte[]>(bytesUnknown);
	
	    try {
			System.Boolean __returnValue = __selfConverted.Fallback(bytesUnknownConverted, index);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Text_DecoderFallbackBuffer_GetNextChar")]
	internal static char /* System.Char */ System_Text_DecoderFallbackBuffer_GetNextChar(void* /* System.Text.DecoderFallbackBuffer */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Text.DecoderFallbackBuffer __selfConverted = InteropUtils.GetInstance<System.Text.DecoderFallbackBuffer>(__self);
	
	
	    try {
			System.Char __returnValue = __selfConverted.GetNextChar();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return (char)0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Text_DecoderFallbackBuffer_MovePrevious")]
	internal static byte /* System.Boolean */ System_Text_DecoderFallbackBuffer_MovePrevious(void* /* System.Text.DecoderFallbackBuffer */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Text.DecoderFallbackBuffer __selfConverted = InteropUtils.GetInstance<System.Text.DecoderFallbackBuffer>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.MovePrevious();
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Text_DecoderFallbackBuffer_Reset")]
	internal static void /* System.Void */ System_Text_DecoderFallbackBuffer_Reset(void* /* System.Text.DecoderFallbackBuffer */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Text.DecoderFallbackBuffer __selfConverted = InteropUtils.GetInstance<System.Text.DecoderFallbackBuffer>(__self);
	
	
	    try {
			__selfConverted.Reset();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Text_DecoderFallbackBuffer_Remaining_Get")]
	internal static int /* System.Int32 */ System_Text_DecoderFallbackBuffer_Remaining_Get(void* /* System.Text.DecoderFallbackBuffer */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Text.DecoderFallbackBuffer __selfConverted = InteropUtils.GetInstance<System.Text.DecoderFallbackBuffer>(__self);
	
	
	    try {
			System.Int32 __returnValue = __selfConverted.Remaining;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Text_DecoderFallbackBuffer_TypeOf")]
	internal static void* /* System.Type */ System_Text_DecoderFallbackBuffer_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.Text.DecoderFallbackBuffer);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Text_DecoderFallbackBuffer_Destroy")]
	internal static void /* System.Void */ System_Text_DecoderFallbackBuffer_Destroy(void* /* System.Text.DecoderFallbackBuffer */ __self)
	{
	
		InteropUtils.FreeIfAllocated(__self);
	}
	
}



internal unsafe class System_Text_EncodingInfo
{
	[UnmanagedCallersOnly(EntryPoint = "System_Text_EncodingInfo_GetEncoding")]
	internal static void* /* System.Text.Encoding */ System_Text_EncodingInfo_GetEncoding(void* /* System.Text.EncodingInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Text.EncodingInfo __selfConverted = InteropUtils.GetInstance<System.Text.EncodingInfo>(__self);
	
	
	    try {
			System.Text.Encoding __returnValue = __selfConverted.GetEncoding();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Text_EncodingInfo_Equals")]
	internal static byte /* System.Boolean */ System_Text_EncodingInfo_Equals(void* /* System.Text.EncodingInfo */ __self, void* /* System.Object */ value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Text.EncodingInfo __selfConverted = InteropUtils.GetInstance<System.Text.EncodingInfo>(__self);
	
		System.Object valueConverted = InteropUtils.GetInstance<System.Object>(value);
	
	    try {
			System.Boolean __returnValue = __selfConverted.Equals(valueConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Text_EncodingInfo_GetHashCode")]
	internal static int /* System.Int32 */ System_Text_EncodingInfo_GetHashCode(void* /* System.Text.EncodingInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Text.EncodingInfo __selfConverted = InteropUtils.GetInstance<System.Text.EncodingInfo>(__self);
	
	
	    try {
			System.Int32 __returnValue = __selfConverted.GetHashCode();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Text_EncodingInfo_Create")]
	internal static void* /* System.Text.EncodingInfo */ System_Text_EncodingInfo_Create(void* /* System.Text.EncodingProvider */ provider, int /* System.Int32 */ codePage, void* /* System.String */ name, void* /* System.String */ displayName, void** /* System.Exception */ __outException)
	{
		System.Text.EncodingProvider providerConverted = InteropUtils.GetInstance<System.Text.EncodingProvider>(provider);
		System.String nameConverted = InteropUtils.GetInstance<System.String>(name);
		System.String displayNameConverted = InteropUtils.GetInstance<System.String>(displayName);
	
	    try {
			System.Text.EncodingInfo __returnValue = new System.Text.EncodingInfo(providerConverted, codePage, nameConverted, displayNameConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Text_EncodingInfo_CodePage_Get")]
	internal static int /* System.Int32 */ System_Text_EncodingInfo_CodePage_Get(void* /* System.Text.EncodingInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Text.EncodingInfo __selfConverted = InteropUtils.GetInstance<System.Text.EncodingInfo>(__self);
	
	
	    try {
			System.Int32 __returnValue = __selfConverted.CodePage;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Text_EncodingInfo_Name_Get")]
	internal static void* /* System.String */ System_Text_EncodingInfo_Name_Get(void* /* System.Text.EncodingInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Text.EncodingInfo __selfConverted = InteropUtils.GetInstance<System.Text.EncodingInfo>(__self);
	
	
	    try {
			System.String __returnValue = __selfConverted.Name;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Text_EncodingInfo_DisplayName_Get")]
	internal static void* /* System.String */ System_Text_EncodingInfo_DisplayName_Get(void* /* System.Text.EncodingInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Text.EncodingInfo __selfConverted = InteropUtils.GetInstance<System.Text.EncodingInfo>(__self);
	
	
	    try {
			System.String __returnValue = __selfConverted.DisplayName;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Text_EncodingInfo_TypeOf")]
	internal static void* /* System.Type */ System_Text_EncodingInfo_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.Text.EncodingInfo);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Text_EncodingInfo_Destroy")]
	internal static void /* System.Void */ System_Text_EncodingInfo_Destroy(void* /* System.Text.EncodingInfo */ __self)
	{
	
		InteropUtils.FreeIfAllocated(__self);
	}
	
}



internal unsafe class System_Text_Decoder
{
	[UnmanagedCallersOnly(EntryPoint = "System_Text_Decoder_Reset")]
	internal static void /* System.Void */ System_Text_Decoder_Reset(void* /* System.Text.Decoder */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Text.Decoder __selfConverted = InteropUtils.GetInstance<System.Text.Decoder>(__self);
	
	
	    try {
			__selfConverted.Reset();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Text_Decoder_GetCharCount")]
	internal static int /* System.Int32 */ System_Text_Decoder_GetCharCount(void* /* System.Text.Decoder */ __self, void* /* System.Byte[] */ bytes, int /* System.Int32 */ index, int /* System.Int32 */ count, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Text.Decoder __selfConverted = InteropUtils.GetInstance<System.Text.Decoder>(__self);
	
		System.Byte[] bytesConverted = InteropUtils.GetInstance<System.Byte[]>(bytes);
	
	    try {
			System.Int32 __returnValue = __selfConverted.GetCharCount(bytesConverted, index, count);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Text_Decoder_GetCharCount_1")]
	internal static int /* System.Int32 */ System_Text_Decoder_GetCharCount_1(void* /* System.Text.Decoder */ __self, void* /* System.Byte[] */ bytes, int /* System.Int32 */ index, int /* System.Int32 */ count, byte /* System.Boolean */ flush, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Text.Decoder __selfConverted = InteropUtils.GetInstance<System.Text.Decoder>(__self);
	
		System.Byte[] bytesConverted = InteropUtils.GetInstance<System.Byte[]>(bytes);
		System.Boolean flushConverted = flush.ToBool();
	
	    try {
			System.Int32 __returnValue = __selfConverted.GetCharCount(bytesConverted, index, count, flushConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Text_Decoder_GetChars")]
	internal static int /* System.Int32 */ System_Text_Decoder_GetChars(void* /* System.Text.Decoder */ __self, void* /* System.Byte[] */ bytes, int /* System.Int32 */ byteIndex, int /* System.Int32 */ byteCount, void* /* System.Char[] */ chars, int /* System.Int32 */ charIndex, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Text.Decoder __selfConverted = InteropUtils.GetInstance<System.Text.Decoder>(__self);
	
		System.Byte[] bytesConverted = InteropUtils.GetInstance<System.Byte[]>(bytes);
		System.Char[] charsConverted = InteropUtils.GetInstance<System.Char[]>(chars);
	
	    try {
			System.Int32 __returnValue = __selfConverted.GetChars(bytesConverted, byteIndex, byteCount, charsConverted, charIndex);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Text_Decoder_GetChars_1")]
	internal static int /* System.Int32 */ System_Text_Decoder_GetChars_1(void* /* System.Text.Decoder */ __self, void* /* System.Byte[] */ bytes, int /* System.Int32 */ byteIndex, int /* System.Int32 */ byteCount, void* /* System.Char[] */ chars, int /* System.Int32 */ charIndex, byte /* System.Boolean */ flush, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Text.Decoder __selfConverted = InteropUtils.GetInstance<System.Text.Decoder>(__self);
	
		System.Byte[] bytesConverted = InteropUtils.GetInstance<System.Byte[]>(bytes);
		System.Char[] charsConverted = InteropUtils.GetInstance<System.Char[]>(chars);
		System.Boolean flushConverted = flush.ToBool();
	
	    try {
			System.Int32 __returnValue = __selfConverted.GetChars(bytesConverted, byteIndex, byteCount, charsConverted, charIndex, flushConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Text_Decoder_Convert")]
	internal static void /* System.Void */ System_Text_Decoder_Convert(void* /* System.Text.Decoder */ __self, void* /* System.Byte[] */ bytes, int /* System.Int32 */ byteIndex, int /* System.Int32 */ byteCount, void* /* System.Char[] */ chars, int /* System.Int32 */ charIndex, int /* System.Int32 */ charCount, byte /* System.Boolean */ flush, int* /* System.Int32 */ bytesUsed, int* /* System.Int32 */ charsUsed, byte* /* System.Boolean */ completed, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Text.Decoder __selfConverted = InteropUtils.GetInstance<System.Text.Decoder>(__self);
	
		System.Byte[] bytesConverted = InteropUtils.GetInstance<System.Byte[]>(bytes);
		System.Char[] charsConverted = InteropUtils.GetInstance<System.Char[]>(chars);
		System.Boolean flushConverted = flush.ToBool();
		System.Int32 bytesUsedConverted;
		System.Int32 charsUsedConverted;
		System.Boolean completedConverted;
	
	    try {
			__selfConverted.Convert(bytesConverted, byteIndex, byteCount, charsConverted, charIndex, charCount, flushConverted, out bytesUsedConverted, out charsUsedConverted, out completedConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			if (bytesUsed is not null) {
				*bytesUsed = bytesUsedConverted;
			}
	
			if (charsUsed is not null) {
				*charsUsed = charsUsedConverted;
			}
	
			if (completed is not null) {
				*completed = completedConverted.ToCBool();
			}
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			if (bytesUsed is not null) {
				*bytesUsed = -1;
			}
	
			if (charsUsed is not null) {
				*charsUsed = -1;
			}
	
			if (completed is not null) {
				*completed = 0;
			}
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Text_Decoder_Fallback_Get")]
	internal static void* /* System.Text.DecoderFallback */ System_Text_Decoder_Fallback_Get(void* /* System.Text.Decoder */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Text.Decoder __selfConverted = InteropUtils.GetInstance<System.Text.Decoder>(__self);
	
	
	    try {
			System.Text.DecoderFallback __returnValue = __selfConverted.Fallback;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Text_Decoder_Fallback_Set")]
	internal static void /* System.Void */ System_Text_Decoder_Fallback_Set(void* /* System.Text.Decoder */ __self, void* /* System.Text.DecoderFallback */ __value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Text.Decoder __selfConverted = InteropUtils.GetInstance<System.Text.Decoder>(__self);
	
	
	    try {
			__selfConverted.Fallback = InteropUtils.GetInstance<System.Text.DecoderFallback>(__value);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Text_Decoder_FallbackBuffer_Get")]
	internal static void* /* System.Text.DecoderFallbackBuffer */ System_Text_Decoder_FallbackBuffer_Get(void* /* System.Text.Decoder */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Text.Decoder __selfConverted = InteropUtils.GetInstance<System.Text.Decoder>(__self);
	
	
	    try {
			System.Text.DecoderFallbackBuffer __returnValue = __selfConverted.FallbackBuffer;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Text_Decoder_TypeOf")]
	internal static void* /* System.Type */ System_Text_Decoder_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.Text.Decoder);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Text_Decoder_Destroy")]
	internal static void /* System.Void */ System_Text_Decoder_Destroy(void* /* System.Text.Decoder */ __self)
	{
	
		InteropUtils.FreeIfAllocated(__self);
	}
	
}


internal unsafe class System_Text_Encoder
{
	[UnmanagedCallersOnly(EntryPoint = "System_Text_Encoder_Reset")]
	internal static void /* System.Void */ System_Text_Encoder_Reset(void* /* System.Text.Encoder */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Text.Encoder __selfConverted = InteropUtils.GetInstance<System.Text.Encoder>(__self);
	
	
	    try {
			__selfConverted.Reset();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Text_Encoder_GetByteCount")]
	internal static int /* System.Int32 */ System_Text_Encoder_GetByteCount(void* /* System.Text.Encoder */ __self, void* /* System.Char[] */ chars, int /* System.Int32 */ index, int /* System.Int32 */ count, byte /* System.Boolean */ flush, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Text.Encoder __selfConverted = InteropUtils.GetInstance<System.Text.Encoder>(__self);
	
		System.Char[] charsConverted = InteropUtils.GetInstance<System.Char[]>(chars);
		System.Boolean flushConverted = flush.ToBool();
	
	    try {
			System.Int32 __returnValue = __selfConverted.GetByteCount(charsConverted, index, count, flushConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Text_Encoder_GetBytes")]
	internal static int /* System.Int32 */ System_Text_Encoder_GetBytes(void* /* System.Text.Encoder */ __self, void* /* System.Char[] */ chars, int /* System.Int32 */ charIndex, int /* System.Int32 */ charCount, void* /* System.Byte[] */ bytes, int /* System.Int32 */ byteIndex, byte /* System.Boolean */ flush, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Text.Encoder __selfConverted = InteropUtils.GetInstance<System.Text.Encoder>(__self);
	
		System.Char[] charsConverted = InteropUtils.GetInstance<System.Char[]>(chars);
		System.Byte[] bytesConverted = InteropUtils.GetInstance<System.Byte[]>(bytes);
		System.Boolean flushConverted = flush.ToBool();
	
	    try {
			System.Int32 __returnValue = __selfConverted.GetBytes(charsConverted, charIndex, charCount, bytesConverted, byteIndex, flushConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Text_Encoder_Convert")]
	internal static void /* System.Void */ System_Text_Encoder_Convert(void* /* System.Text.Encoder */ __self, void* /* System.Char[] */ chars, int /* System.Int32 */ charIndex, int /* System.Int32 */ charCount, void* /* System.Byte[] */ bytes, int /* System.Int32 */ byteIndex, int /* System.Int32 */ byteCount, byte /* System.Boolean */ flush, int* /* System.Int32 */ charsUsed, int* /* System.Int32 */ bytesUsed, byte* /* System.Boolean */ completed, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Text.Encoder __selfConverted = InteropUtils.GetInstance<System.Text.Encoder>(__self);
	
		System.Char[] charsConverted = InteropUtils.GetInstance<System.Char[]>(chars);
		System.Byte[] bytesConverted = InteropUtils.GetInstance<System.Byte[]>(bytes);
		System.Boolean flushConverted = flush.ToBool();
		System.Int32 charsUsedConverted;
		System.Int32 bytesUsedConverted;
		System.Boolean completedConverted;
	
	    try {
			__selfConverted.Convert(charsConverted, charIndex, charCount, bytesConverted, byteIndex, byteCount, flushConverted, out charsUsedConverted, out bytesUsedConverted, out completedConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			if (charsUsed is not null) {
				*charsUsed = charsUsedConverted;
			}
	
			if (bytesUsed is not null) {
				*bytesUsed = bytesUsedConverted;
			}
	
			if (completed is not null) {
				*completed = completedConverted.ToCBool();
			}
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			if (charsUsed is not null) {
				*charsUsed = -1;
			}
	
			if (bytesUsed is not null) {
				*bytesUsed = -1;
			}
	
			if (completed is not null) {
				*completed = 0;
			}
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Text_Encoder_Fallback_Get")]
	internal static void* /* System.Text.EncoderFallback */ System_Text_Encoder_Fallback_Get(void* /* System.Text.Encoder */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Text.Encoder __selfConverted = InteropUtils.GetInstance<System.Text.Encoder>(__self);
	
	
	    try {
			System.Text.EncoderFallback __returnValue = __selfConverted.Fallback;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Text_Encoder_Fallback_Set")]
	internal static void /* System.Void */ System_Text_Encoder_Fallback_Set(void* /* System.Text.Encoder */ __self, void* /* System.Text.EncoderFallback */ __value, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Text.Encoder __selfConverted = InteropUtils.GetInstance<System.Text.Encoder>(__self);
	
	
	    try {
			__selfConverted.Fallback = InteropUtils.GetInstance<System.Text.EncoderFallback>(__value);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Text_Encoder_FallbackBuffer_Get")]
	internal static void* /* System.Text.EncoderFallbackBuffer */ System_Text_Encoder_FallbackBuffer_Get(void* /* System.Text.Encoder */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Text.Encoder __selfConverted = InteropUtils.GetInstance<System.Text.Encoder>(__self);
	
	
	    try {
			System.Text.EncoderFallbackBuffer __returnValue = __selfConverted.FallbackBuffer;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Text_Encoder_TypeOf")]
	internal static void* /* System.Type */ System_Text_Encoder_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.Text.Encoder);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Text_Encoder_Destroy")]
	internal static void /* System.Void */ System_Text_Encoder_Destroy(void* /* System.Text.Encoder */ __self)
	{
	
		InteropUtils.FreeIfAllocated(__self);
	}
	
}

















































internal unsafe class System_Reflection_IReflect
{
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_IReflect_GetMethod")]
	internal static void* /* System.Reflection.MethodInfo */ System_Reflection_IReflect_GetMethod(void* /* System.Reflection.IReflect */ __self, void* /* System.String */ name, System.Reflection.BindingFlags /* System.Reflection.BindingFlags */ bindingAttr, void* /* System.Reflection.Binder */ binder, void* /* System.Type[] */ types, void* /* System.Reflection.ParameterModifier[] */ modifiers, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.IReflect __selfConverted = InteropUtils.GetInstance<System.Reflection.IReflect>(__self);
	
		System.String nameConverted = InteropUtils.GetInstance<System.String>(name);
		System.Reflection.Binder binderConverted = InteropUtils.GetInstance<System.Reflection.Binder>(binder);
		System.Type[] typesConverted = InteropUtils.GetInstance<System.Type[]>(types);
		System.Reflection.ParameterModifier[] modifiersConverted = InteropUtils.GetInstance<System.Reflection.ParameterModifier[]>(modifiers);
	
	    try {
			System.Reflection.MethodInfo __returnValue = __selfConverted.GetMethod(nameConverted, bindingAttr, binderConverted, typesConverted, modifiersConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_IReflect_GetMethod_1")]
	internal static void* /* System.Reflection.MethodInfo */ System_Reflection_IReflect_GetMethod_1(void* /* System.Reflection.IReflect */ __self, void* /* System.String */ name, System.Reflection.BindingFlags /* System.Reflection.BindingFlags */ bindingAttr, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.IReflect __selfConverted = InteropUtils.GetInstance<System.Reflection.IReflect>(__self);
	
		System.String nameConverted = InteropUtils.GetInstance<System.String>(name);
	
	    try {
			System.Reflection.MethodInfo __returnValue = __selfConverted.GetMethod(nameConverted, bindingAttr);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_IReflect_GetMethods")]
	internal static void* /* System.Reflection.MethodInfo[] */ System_Reflection_IReflect_GetMethods(void* /* System.Reflection.IReflect */ __self, System.Reflection.BindingFlags /* System.Reflection.BindingFlags */ bindingAttr, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.IReflect __selfConverted = InteropUtils.GetInstance<System.Reflection.IReflect>(__self);
	
	
	    try {
			System.Reflection.MethodInfo[] __returnValue = __selfConverted.GetMethods(bindingAttr);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_IReflect_GetField")]
	internal static void* /* System.Reflection.FieldInfo */ System_Reflection_IReflect_GetField(void* /* System.Reflection.IReflect */ __self, void* /* System.String */ name, System.Reflection.BindingFlags /* System.Reflection.BindingFlags */ bindingAttr, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.IReflect __selfConverted = InteropUtils.GetInstance<System.Reflection.IReflect>(__self);
	
		System.String nameConverted = InteropUtils.GetInstance<System.String>(name);
	
	    try {
			System.Reflection.FieldInfo __returnValue = __selfConverted.GetField(nameConverted, bindingAttr);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_IReflect_GetFields")]
	internal static void* /* System.Reflection.FieldInfo[] */ System_Reflection_IReflect_GetFields(void* /* System.Reflection.IReflect */ __self, System.Reflection.BindingFlags /* System.Reflection.BindingFlags */ bindingAttr, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.IReflect __selfConverted = InteropUtils.GetInstance<System.Reflection.IReflect>(__self);
	
	
	    try {
			System.Reflection.FieldInfo[] __returnValue = __selfConverted.GetFields(bindingAttr);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_IReflect_GetProperty")]
	internal static void* /* System.Reflection.PropertyInfo */ System_Reflection_IReflect_GetProperty(void* /* System.Reflection.IReflect */ __self, void* /* System.String */ name, System.Reflection.BindingFlags /* System.Reflection.BindingFlags */ bindingAttr, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.IReflect __selfConverted = InteropUtils.GetInstance<System.Reflection.IReflect>(__self);
	
		System.String nameConverted = InteropUtils.GetInstance<System.String>(name);
	
	    try {
			System.Reflection.PropertyInfo __returnValue = __selfConverted.GetProperty(nameConverted, bindingAttr);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_IReflect_GetProperty_1")]
	internal static void* /* System.Reflection.PropertyInfo */ System_Reflection_IReflect_GetProperty_1(void* /* System.Reflection.IReflect */ __self, void* /* System.String */ name, System.Reflection.BindingFlags /* System.Reflection.BindingFlags */ bindingAttr, void* /* System.Reflection.Binder */ binder, void* /* System.Type */ returnType, void* /* System.Type[] */ types, void* /* System.Reflection.ParameterModifier[] */ modifiers, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.IReflect __selfConverted = InteropUtils.GetInstance<System.Reflection.IReflect>(__self);
	
		System.String nameConverted = InteropUtils.GetInstance<System.String>(name);
		System.Reflection.Binder binderConverted = InteropUtils.GetInstance<System.Reflection.Binder>(binder);
		System.Type returnTypeConverted = InteropUtils.GetInstance<System.Type>(returnType);
		System.Type[] typesConverted = InteropUtils.GetInstance<System.Type[]>(types);
		System.Reflection.ParameterModifier[] modifiersConverted = InteropUtils.GetInstance<System.Reflection.ParameterModifier[]>(modifiers);
	
	    try {
			System.Reflection.PropertyInfo __returnValue = __selfConverted.GetProperty(nameConverted, bindingAttr, binderConverted, returnTypeConverted, typesConverted, modifiersConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_IReflect_GetProperties")]
	internal static void* /* System.Reflection.PropertyInfo[] */ System_Reflection_IReflect_GetProperties(void* /* System.Reflection.IReflect */ __self, System.Reflection.BindingFlags /* System.Reflection.BindingFlags */ bindingAttr, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.IReflect __selfConverted = InteropUtils.GetInstance<System.Reflection.IReflect>(__self);
	
	
	    try {
			System.Reflection.PropertyInfo[] __returnValue = __selfConverted.GetProperties(bindingAttr);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_IReflect_GetMember")]
	internal static void* /* System.Reflection.MemberInfo[] */ System_Reflection_IReflect_GetMember(void* /* System.Reflection.IReflect */ __self, void* /* System.String */ name, System.Reflection.BindingFlags /* System.Reflection.BindingFlags */ bindingAttr, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.IReflect __selfConverted = InteropUtils.GetInstance<System.Reflection.IReflect>(__self);
	
		System.String nameConverted = InteropUtils.GetInstance<System.String>(name);
	
	    try {
			System.Reflection.MemberInfo[] __returnValue = __selfConverted.GetMember(nameConverted, bindingAttr);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_IReflect_GetMembers")]
	internal static void* /* System.Reflection.MemberInfo[] */ System_Reflection_IReflect_GetMembers(void* /* System.Reflection.IReflect */ __self, System.Reflection.BindingFlags /* System.Reflection.BindingFlags */ bindingAttr, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.IReflect __selfConverted = InteropUtils.GetInstance<System.Reflection.IReflect>(__self);
	
	
	    try {
			System.Reflection.MemberInfo[] __returnValue = __selfConverted.GetMembers(bindingAttr);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_IReflect_InvokeMember")]
	internal static void* /* System.Object */ System_Reflection_IReflect_InvokeMember(void* /* System.Reflection.IReflect */ __self, void* /* System.String */ name, System.Reflection.BindingFlags /* System.Reflection.BindingFlags */ invokeAttr, void* /* System.Reflection.Binder */ binder, void* /* System.Object */ target, void* /* System.Object[] */ args, void* /* System.Reflection.ParameterModifier[] */ modifiers, void* /* System.Globalization.CultureInfo */ culture, void* /* System.String[] */ namedParameters, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.IReflect __selfConverted = InteropUtils.GetInstance<System.Reflection.IReflect>(__self);
	
		System.String nameConverted = InteropUtils.GetInstance<System.String>(name);
		System.Reflection.Binder binderConverted = InteropUtils.GetInstance<System.Reflection.Binder>(binder);
		System.Object targetConverted = InteropUtils.GetInstance<System.Object>(target);
		System.Object[] argsConverted = InteropUtils.GetInstance<System.Object[]>(args);
		System.Reflection.ParameterModifier[] modifiersConverted = InteropUtils.GetInstance<System.Reflection.ParameterModifier[]>(modifiers);
		System.Globalization.CultureInfo cultureConverted = InteropUtils.GetInstance<System.Globalization.CultureInfo>(culture);
		System.String[] namedParametersConverted = InteropUtils.GetInstance<System.String[]>(namedParameters);
	
	    try {
			System.Object __returnValue = __selfConverted.InvokeMember(nameConverted, invokeAttr, binderConverted, targetConverted, argsConverted, modifiersConverted, cultureConverted, namedParametersConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_IReflect_UnderlyingSystemType_Get")]
	internal static void* /* System.Type */ System_Reflection_IReflect_UnderlyingSystemType_Get(void* /* System.Reflection.IReflect */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.IReflect __selfConverted = InteropUtils.GetInstance<System.Reflection.IReflect>(__self);
	
	
	    try {
			System.Type __returnValue = __selfConverted.UnderlyingSystemType;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_IReflect_TypeOf")]
	internal static void* /* System.Type */ System_Reflection_IReflect_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.Reflection.IReflect);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_IReflect_Destroy")]
	internal static void /* System.Void */ System_Reflection_IReflect_Destroy(void* /* System.Reflection.IReflect */ __self)
	{
	
		InteropUtils.FreeIfAllocated(__self);
	}
	
}




internal unsafe class System_Reflection_GenericParameterAttributes
{
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_GenericParameterAttributes_TypeOf")]
	internal static void* /* System.Type */ System_Reflection_GenericParameterAttributes_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.Reflection.GenericParameterAttributes);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
}


internal unsafe class System_Reflection_TypeAttributes
{
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_TypeAttributes_TypeOf")]
	internal static void* /* System.Type */ System_Reflection_TypeAttributes_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.Reflection.TypeAttributes);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
}


internal unsafe class System_Runtime_InteropServices_StructLayoutAttribute
{
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_InteropServices_StructLayoutAttribute_Create")]
	internal static void* /* System.Runtime.InteropServices.StructLayoutAttribute */ System_Runtime_InteropServices_StructLayoutAttribute_Create(System.Runtime.InteropServices.LayoutKind /* System.Runtime.InteropServices.LayoutKind */ layoutKind, void** /* System.Exception */ __outException)
	{
	
	    try {
			System.Runtime.InteropServices.StructLayoutAttribute __returnValue = new System.Runtime.InteropServices.StructLayoutAttribute(layoutKind);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_InteropServices_StructLayoutAttribute_Create_1")]
	internal static void* /* System.Runtime.InteropServices.StructLayoutAttribute */ System_Runtime_InteropServices_StructLayoutAttribute_Create_1(short /* System.Int16 */ layoutKind, void** /* System.Exception */ __outException)
	{
	
	    try {
			System.Runtime.InteropServices.StructLayoutAttribute __returnValue = new System.Runtime.InteropServices.StructLayoutAttribute(layoutKind);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_InteropServices_StructLayoutAttribute_Value_Get")]
	internal static System.Runtime.InteropServices.LayoutKind /* System.Runtime.InteropServices.LayoutKind */ System_Runtime_InteropServices_StructLayoutAttribute_Value_Get(void* /* System.Runtime.InteropServices.StructLayoutAttribute */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Runtime.InteropServices.StructLayoutAttribute __selfConverted = InteropUtils.GetInstance<System.Runtime.InteropServices.StructLayoutAttribute>(__self);
	
	
	    try {
			System.Runtime.InteropServices.LayoutKind __returnValue = __selfConverted.Value;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return default(System.Runtime.InteropServices.LayoutKind);
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_InteropServices_StructLayoutAttribute_Pack_Get")]
	internal static int /* System.Int32 */ System_Runtime_InteropServices_StructLayoutAttribute_Pack_Get(void* /* System.Runtime.InteropServices.StructLayoutAttribute */ __self)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Runtime.InteropServices.StructLayoutAttribute __selfConverted = InteropUtils.GetInstance<System.Runtime.InteropServices.StructLayoutAttribute>(__self);
	
	
		System.Int32 __returnValue = __selfConverted.Pack;
		return __returnValue;
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_InteropServices_StructLayoutAttribute_Pack_Set")]
	internal static void /* System.Void */ System_Runtime_InteropServices_StructLayoutAttribute_Pack_Set(void* /* System.Runtime.InteropServices.StructLayoutAttribute */ __self, int /* System.Int32 */ __value)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Runtime.InteropServices.StructLayoutAttribute __selfConverted = InteropUtils.GetInstance<System.Runtime.InteropServices.StructLayoutAttribute>(__self);
	
	
		__selfConverted.Pack = __value;
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_InteropServices_StructLayoutAttribute_Size_Get")]
	internal static int /* System.Int32 */ System_Runtime_InteropServices_StructLayoutAttribute_Size_Get(void* /* System.Runtime.InteropServices.StructLayoutAttribute */ __self)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Runtime.InteropServices.StructLayoutAttribute __selfConverted = InteropUtils.GetInstance<System.Runtime.InteropServices.StructLayoutAttribute>(__self);
	
	
		System.Int32 __returnValue = __selfConverted.Size;
		return __returnValue;
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_InteropServices_StructLayoutAttribute_Size_Set")]
	internal static void /* System.Void */ System_Runtime_InteropServices_StructLayoutAttribute_Size_Set(void* /* System.Runtime.InteropServices.StructLayoutAttribute */ __self, int /* System.Int32 */ __value)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Runtime.InteropServices.StructLayoutAttribute __selfConverted = InteropUtils.GetInstance<System.Runtime.InteropServices.StructLayoutAttribute>(__self);
	
	
		__selfConverted.Size = __value;
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_InteropServices_StructLayoutAttribute_CharSet_Get")]
	internal static System.Runtime.InteropServices.CharSet /* System.Runtime.InteropServices.CharSet */ System_Runtime_InteropServices_StructLayoutAttribute_CharSet_Get(void* /* System.Runtime.InteropServices.StructLayoutAttribute */ __self)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Runtime.InteropServices.StructLayoutAttribute __selfConverted = InteropUtils.GetInstance<System.Runtime.InteropServices.StructLayoutAttribute>(__self);
	
	
		System.Runtime.InteropServices.CharSet __returnValue = __selfConverted.CharSet;
		return __returnValue;
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_InteropServices_StructLayoutAttribute_CharSet_Set")]
	internal static void /* System.Void */ System_Runtime_InteropServices_StructLayoutAttribute_CharSet_Set(void* /* System.Runtime.InteropServices.StructLayoutAttribute */ __self, System.Runtime.InteropServices.CharSet /* System.Runtime.InteropServices.CharSet */ __value)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Runtime.InteropServices.StructLayoutAttribute __selfConverted = InteropUtils.GetInstance<System.Runtime.InteropServices.StructLayoutAttribute>(__self);
	
	
		__selfConverted.CharSet = __value;
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_InteropServices_StructLayoutAttribute_TypeOf")]
	internal static void* /* System.Type */ System_Runtime_InteropServices_StructLayoutAttribute_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.Runtime.InteropServices.StructLayoutAttribute);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_InteropServices_StructLayoutAttribute_Destroy")]
	internal static void /* System.Void */ System_Runtime_InteropServices_StructLayoutAttribute_Destroy(void* /* System.Runtime.InteropServices.StructLayoutAttribute */ __self)
	{
	
		InteropUtils.FreeIfAllocated(__self);
	}
	
}


internal unsafe class System_Attribute
{
	[UnmanagedCallersOnly(EntryPoint = "System_Attribute_GetCustomAttributes")]
	internal static void* /* System.Attribute[] */ System_Attribute_GetCustomAttributes(void* /* System.Reflection.MemberInfo */ element, void* /* System.Type */ attributeType, void** /* System.Exception */ __outException)
	{
		System.Reflection.MemberInfo elementConverted = InteropUtils.GetInstance<System.Reflection.MemberInfo>(element);
		System.Type attributeTypeConverted = InteropUtils.GetInstance<System.Type>(attributeType);
	
	    try {
			System.Attribute[] __returnValue = System.Attribute.GetCustomAttributes(elementConverted, attributeTypeConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Attribute_GetCustomAttributes_1")]
	internal static void* /* System.Attribute[] */ System_Attribute_GetCustomAttributes_1(void* /* System.Reflection.MemberInfo */ element, void* /* System.Type */ attributeType, byte /* System.Boolean */ inherit, void** /* System.Exception */ __outException)
	{
		System.Reflection.MemberInfo elementConverted = InteropUtils.GetInstance<System.Reflection.MemberInfo>(element);
		System.Type attributeTypeConverted = InteropUtils.GetInstance<System.Type>(attributeType);
		System.Boolean inheritConverted = inherit.ToBool();
	
	    try {
			System.Attribute[] __returnValue = System.Attribute.GetCustomAttributes(elementConverted, attributeTypeConverted, inheritConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Attribute_GetCustomAttributes_2")]
	internal static void* /* System.Attribute[] */ System_Attribute_GetCustomAttributes_2(void* /* System.Reflection.MemberInfo */ element, void** /* System.Exception */ __outException)
	{
		System.Reflection.MemberInfo elementConverted = InteropUtils.GetInstance<System.Reflection.MemberInfo>(element);
	
	    try {
			System.Attribute[] __returnValue = System.Attribute.GetCustomAttributes(elementConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Attribute_GetCustomAttributes_3")]
	internal static void* /* System.Attribute[] */ System_Attribute_GetCustomAttributes_3(void* /* System.Reflection.MemberInfo */ element, byte /* System.Boolean */ inherit, void** /* System.Exception */ __outException)
	{
		System.Reflection.MemberInfo elementConverted = InteropUtils.GetInstance<System.Reflection.MemberInfo>(element);
		System.Boolean inheritConverted = inherit.ToBool();
	
	    try {
			System.Attribute[] __returnValue = System.Attribute.GetCustomAttributes(elementConverted, inheritConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Attribute_IsDefined")]
	internal static byte /* System.Boolean */ System_Attribute_IsDefined(void* /* System.Reflection.MemberInfo */ element, void* /* System.Type */ attributeType, void** /* System.Exception */ __outException)
	{
		System.Reflection.MemberInfo elementConverted = InteropUtils.GetInstance<System.Reflection.MemberInfo>(element);
		System.Type attributeTypeConverted = InteropUtils.GetInstance<System.Type>(attributeType);
	
	    try {
			System.Boolean __returnValue = System.Attribute.IsDefined(elementConverted, attributeTypeConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Attribute_IsDefined_1")]
	internal static byte /* System.Boolean */ System_Attribute_IsDefined_1(void* /* System.Reflection.MemberInfo */ element, void* /* System.Type */ attributeType, byte /* System.Boolean */ inherit, void** /* System.Exception */ __outException)
	{
		System.Reflection.MemberInfo elementConverted = InteropUtils.GetInstance<System.Reflection.MemberInfo>(element);
		System.Type attributeTypeConverted = InteropUtils.GetInstance<System.Type>(attributeType);
		System.Boolean inheritConverted = inherit.ToBool();
	
	    try {
			System.Boolean __returnValue = System.Attribute.IsDefined(elementConverted, attributeTypeConverted, inheritConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Attribute_GetCustomAttribute_1")]
	internal static void* /* System.Attribute */ System_Attribute_GetCustomAttribute_1(void* /* System.Reflection.MemberInfo */ element, void* /* System.Type */ attributeType, void** /* System.Exception */ __outException)
	{
		System.Reflection.MemberInfo elementConverted = InteropUtils.GetInstance<System.Reflection.MemberInfo>(element);
		System.Type attributeTypeConverted = InteropUtils.GetInstance<System.Type>(attributeType);
	
	    try {
			System.Attribute __returnValue = System.Attribute.GetCustomAttribute(elementConverted, attributeTypeConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Attribute_GetCustomAttribute_2")]
	internal static void* /* System.Attribute */ System_Attribute_GetCustomAttribute_2(void* /* System.Reflection.MemberInfo */ element, void* /* System.Type */ attributeType, byte /* System.Boolean */ inherit, void** /* System.Exception */ __outException)
	{
		System.Reflection.MemberInfo elementConverted = InteropUtils.GetInstance<System.Reflection.MemberInfo>(element);
		System.Type attributeTypeConverted = InteropUtils.GetInstance<System.Type>(attributeType);
		System.Boolean inheritConverted = inherit.ToBool();
	
	    try {
			System.Attribute __returnValue = System.Attribute.GetCustomAttribute(elementConverted, attributeTypeConverted, inheritConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Attribute_GetCustomAttributes_4")]
	internal static void* /* System.Attribute[] */ System_Attribute_GetCustomAttributes_4(void* /* System.Reflection.ParameterInfo */ element, void** /* System.Exception */ __outException)
	{
		System.Reflection.ParameterInfo elementConverted = InteropUtils.GetInstance<System.Reflection.ParameterInfo>(element);
	
	    try {
			System.Attribute[] __returnValue = System.Attribute.GetCustomAttributes(elementConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Attribute_GetCustomAttributes_5")]
	internal static void* /* System.Attribute[] */ System_Attribute_GetCustomAttributes_5(void* /* System.Reflection.ParameterInfo */ element, void* /* System.Type */ attributeType, void** /* System.Exception */ __outException)
	{
		System.Reflection.ParameterInfo elementConverted = InteropUtils.GetInstance<System.Reflection.ParameterInfo>(element);
		System.Type attributeTypeConverted = InteropUtils.GetInstance<System.Type>(attributeType);
	
	    try {
			System.Attribute[] __returnValue = System.Attribute.GetCustomAttributes(elementConverted, attributeTypeConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Attribute_GetCustomAttributes_6")]
	internal static void* /* System.Attribute[] */ System_Attribute_GetCustomAttributes_6(void* /* System.Reflection.ParameterInfo */ element, void* /* System.Type */ attributeType, byte /* System.Boolean */ inherit, void** /* System.Exception */ __outException)
	{
		System.Reflection.ParameterInfo elementConverted = InteropUtils.GetInstance<System.Reflection.ParameterInfo>(element);
		System.Type attributeTypeConverted = InteropUtils.GetInstance<System.Type>(attributeType);
		System.Boolean inheritConverted = inherit.ToBool();
	
	    try {
			System.Attribute[] __returnValue = System.Attribute.GetCustomAttributes(elementConverted, attributeTypeConverted, inheritConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Attribute_GetCustomAttributes_7")]
	internal static void* /* System.Attribute[] */ System_Attribute_GetCustomAttributes_7(void* /* System.Reflection.ParameterInfo */ element, byte /* System.Boolean */ inherit, void** /* System.Exception */ __outException)
	{
		System.Reflection.ParameterInfo elementConverted = InteropUtils.GetInstance<System.Reflection.ParameterInfo>(element);
		System.Boolean inheritConverted = inherit.ToBool();
	
	    try {
			System.Attribute[] __returnValue = System.Attribute.GetCustomAttributes(elementConverted, inheritConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Attribute_IsDefined_2")]
	internal static byte /* System.Boolean */ System_Attribute_IsDefined_2(void* /* System.Reflection.ParameterInfo */ element, void* /* System.Type */ attributeType, void** /* System.Exception */ __outException)
	{
		System.Reflection.ParameterInfo elementConverted = InteropUtils.GetInstance<System.Reflection.ParameterInfo>(element);
		System.Type attributeTypeConverted = InteropUtils.GetInstance<System.Type>(attributeType);
	
	    try {
			System.Boolean __returnValue = System.Attribute.IsDefined(elementConverted, attributeTypeConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Attribute_IsDefined_3")]
	internal static byte /* System.Boolean */ System_Attribute_IsDefined_3(void* /* System.Reflection.ParameterInfo */ element, void* /* System.Type */ attributeType, byte /* System.Boolean */ inherit, void** /* System.Exception */ __outException)
	{
		System.Reflection.ParameterInfo elementConverted = InteropUtils.GetInstance<System.Reflection.ParameterInfo>(element);
		System.Type attributeTypeConverted = InteropUtils.GetInstance<System.Type>(attributeType);
		System.Boolean inheritConverted = inherit.ToBool();
	
	    try {
			System.Boolean __returnValue = System.Attribute.IsDefined(elementConverted, attributeTypeConverted, inheritConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Attribute_GetCustomAttribute_3")]
	internal static void* /* System.Attribute */ System_Attribute_GetCustomAttribute_3(void* /* System.Reflection.ParameterInfo */ element, void* /* System.Type */ attributeType, void** /* System.Exception */ __outException)
	{
		System.Reflection.ParameterInfo elementConverted = InteropUtils.GetInstance<System.Reflection.ParameterInfo>(element);
		System.Type attributeTypeConverted = InteropUtils.GetInstance<System.Type>(attributeType);
	
	    try {
			System.Attribute __returnValue = System.Attribute.GetCustomAttribute(elementConverted, attributeTypeConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Attribute_GetCustomAttribute_4")]
	internal static void* /* System.Attribute */ System_Attribute_GetCustomAttribute_4(void* /* System.Reflection.ParameterInfo */ element, void* /* System.Type */ attributeType, byte /* System.Boolean */ inherit, void** /* System.Exception */ __outException)
	{
		System.Reflection.ParameterInfo elementConverted = InteropUtils.GetInstance<System.Reflection.ParameterInfo>(element);
		System.Type attributeTypeConverted = InteropUtils.GetInstance<System.Type>(attributeType);
		System.Boolean inheritConverted = inherit.ToBool();
	
	    try {
			System.Attribute __returnValue = System.Attribute.GetCustomAttribute(elementConverted, attributeTypeConverted, inheritConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Attribute_GetCustomAttributes_8")]
	internal static void* /* System.Attribute[] */ System_Attribute_GetCustomAttributes_8(void* /* System.Reflection.Module */ element, void* /* System.Type */ attributeType, void** /* System.Exception */ __outException)
	{
		System.Reflection.Module elementConverted = InteropUtils.GetInstance<System.Reflection.Module>(element);
		System.Type attributeTypeConverted = InteropUtils.GetInstance<System.Type>(attributeType);
	
	    try {
			System.Attribute[] __returnValue = System.Attribute.GetCustomAttributes(elementConverted, attributeTypeConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Attribute_GetCustomAttributes_9")]
	internal static void* /* System.Attribute[] */ System_Attribute_GetCustomAttributes_9(void* /* System.Reflection.Module */ element, void** /* System.Exception */ __outException)
	{
		System.Reflection.Module elementConverted = InteropUtils.GetInstance<System.Reflection.Module>(element);
	
	    try {
			System.Attribute[] __returnValue = System.Attribute.GetCustomAttributes(elementConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Attribute_GetCustomAttributes_10")]
	internal static void* /* System.Attribute[] */ System_Attribute_GetCustomAttributes_10(void* /* System.Reflection.Module */ element, byte /* System.Boolean */ inherit, void** /* System.Exception */ __outException)
	{
		System.Reflection.Module elementConverted = InteropUtils.GetInstance<System.Reflection.Module>(element);
		System.Boolean inheritConverted = inherit.ToBool();
	
	    try {
			System.Attribute[] __returnValue = System.Attribute.GetCustomAttributes(elementConverted, inheritConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Attribute_GetCustomAttributes_11")]
	internal static void* /* System.Attribute[] */ System_Attribute_GetCustomAttributes_11(void* /* System.Reflection.Module */ element, void* /* System.Type */ attributeType, byte /* System.Boolean */ inherit, void** /* System.Exception */ __outException)
	{
		System.Reflection.Module elementConverted = InteropUtils.GetInstance<System.Reflection.Module>(element);
		System.Type attributeTypeConverted = InteropUtils.GetInstance<System.Type>(attributeType);
		System.Boolean inheritConverted = inherit.ToBool();
	
	    try {
			System.Attribute[] __returnValue = System.Attribute.GetCustomAttributes(elementConverted, attributeTypeConverted, inheritConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Attribute_IsDefined_4")]
	internal static byte /* System.Boolean */ System_Attribute_IsDefined_4(void* /* System.Reflection.Module */ element, void* /* System.Type */ attributeType, void** /* System.Exception */ __outException)
	{
		System.Reflection.Module elementConverted = InteropUtils.GetInstance<System.Reflection.Module>(element);
		System.Type attributeTypeConverted = InteropUtils.GetInstance<System.Type>(attributeType);
	
	    try {
			System.Boolean __returnValue = System.Attribute.IsDefined(elementConverted, attributeTypeConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Attribute_IsDefined_5")]
	internal static byte /* System.Boolean */ System_Attribute_IsDefined_5(void* /* System.Reflection.Module */ element, void* /* System.Type */ attributeType, byte /* System.Boolean */ inherit, void** /* System.Exception */ __outException)
	{
		System.Reflection.Module elementConverted = InteropUtils.GetInstance<System.Reflection.Module>(element);
		System.Type attributeTypeConverted = InteropUtils.GetInstance<System.Type>(attributeType);
		System.Boolean inheritConverted = inherit.ToBool();
	
	    try {
			System.Boolean __returnValue = System.Attribute.IsDefined(elementConverted, attributeTypeConverted, inheritConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Attribute_GetCustomAttribute_5")]
	internal static void* /* System.Attribute */ System_Attribute_GetCustomAttribute_5(void* /* System.Reflection.Module */ element, void* /* System.Type */ attributeType, void** /* System.Exception */ __outException)
	{
		System.Reflection.Module elementConverted = InteropUtils.GetInstance<System.Reflection.Module>(element);
		System.Type attributeTypeConverted = InteropUtils.GetInstance<System.Type>(attributeType);
	
	    try {
			System.Attribute __returnValue = System.Attribute.GetCustomAttribute(elementConverted, attributeTypeConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Attribute_GetCustomAttribute_6")]
	internal static void* /* System.Attribute */ System_Attribute_GetCustomAttribute_6(void* /* System.Reflection.Module */ element, void* /* System.Type */ attributeType, byte /* System.Boolean */ inherit, void** /* System.Exception */ __outException)
	{
		System.Reflection.Module elementConverted = InteropUtils.GetInstance<System.Reflection.Module>(element);
		System.Type attributeTypeConverted = InteropUtils.GetInstance<System.Type>(attributeType);
		System.Boolean inheritConverted = inherit.ToBool();
	
	    try {
			System.Attribute __returnValue = System.Attribute.GetCustomAttribute(elementConverted, attributeTypeConverted, inheritConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Attribute_GetCustomAttributes_12")]
	internal static void* /* System.Attribute[] */ System_Attribute_GetCustomAttributes_12(void* /* System.Reflection.Assembly */ element, void* /* System.Type */ attributeType, void** /* System.Exception */ __outException)
	{
		System.Reflection.Assembly elementConverted = InteropUtils.GetInstance<System.Reflection.Assembly>(element);
		System.Type attributeTypeConverted = InteropUtils.GetInstance<System.Type>(attributeType);
	
	    try {
			System.Attribute[] __returnValue = System.Attribute.GetCustomAttributes(elementConverted, attributeTypeConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Attribute_GetCustomAttributes_13")]
	internal static void* /* System.Attribute[] */ System_Attribute_GetCustomAttributes_13(void* /* System.Reflection.Assembly */ element, void* /* System.Type */ attributeType, byte /* System.Boolean */ inherit, void** /* System.Exception */ __outException)
	{
		System.Reflection.Assembly elementConverted = InteropUtils.GetInstance<System.Reflection.Assembly>(element);
		System.Type attributeTypeConverted = InteropUtils.GetInstance<System.Type>(attributeType);
		System.Boolean inheritConverted = inherit.ToBool();
	
	    try {
			System.Attribute[] __returnValue = System.Attribute.GetCustomAttributes(elementConverted, attributeTypeConverted, inheritConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Attribute_GetCustomAttributes_14")]
	internal static void* /* System.Attribute[] */ System_Attribute_GetCustomAttributes_14(void* /* System.Reflection.Assembly */ element, void** /* System.Exception */ __outException)
	{
		System.Reflection.Assembly elementConverted = InteropUtils.GetInstance<System.Reflection.Assembly>(element);
	
	    try {
			System.Attribute[] __returnValue = System.Attribute.GetCustomAttributes(elementConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Attribute_GetCustomAttributes_15")]
	internal static void* /* System.Attribute[] */ System_Attribute_GetCustomAttributes_15(void* /* System.Reflection.Assembly */ element, byte /* System.Boolean */ inherit, void** /* System.Exception */ __outException)
	{
		System.Reflection.Assembly elementConverted = InteropUtils.GetInstance<System.Reflection.Assembly>(element);
		System.Boolean inheritConverted = inherit.ToBool();
	
	    try {
			System.Attribute[] __returnValue = System.Attribute.GetCustomAttributes(elementConverted, inheritConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Attribute_IsDefined_6")]
	internal static byte /* System.Boolean */ System_Attribute_IsDefined_6(void* /* System.Reflection.Assembly */ element, void* /* System.Type */ attributeType, void** /* System.Exception */ __outException)
	{
		System.Reflection.Assembly elementConverted = InteropUtils.GetInstance<System.Reflection.Assembly>(element);
		System.Type attributeTypeConverted = InteropUtils.GetInstance<System.Type>(attributeType);
	
	    try {
			System.Boolean __returnValue = System.Attribute.IsDefined(elementConverted, attributeTypeConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Attribute_IsDefined_7")]
	internal static byte /* System.Boolean */ System_Attribute_IsDefined_7(void* /* System.Reflection.Assembly */ element, void* /* System.Type */ attributeType, byte /* System.Boolean */ inherit, void** /* System.Exception */ __outException)
	{
		System.Reflection.Assembly elementConverted = InteropUtils.GetInstance<System.Reflection.Assembly>(element);
		System.Type attributeTypeConverted = InteropUtils.GetInstance<System.Type>(attributeType);
		System.Boolean inheritConverted = inherit.ToBool();
	
	    try {
			System.Boolean __returnValue = System.Attribute.IsDefined(elementConverted, attributeTypeConverted, inheritConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Attribute_GetCustomAttribute_7")]
	internal static void* /* System.Attribute */ System_Attribute_GetCustomAttribute_7(void* /* System.Reflection.Assembly */ element, void* /* System.Type */ attributeType, void** /* System.Exception */ __outException)
	{
		System.Reflection.Assembly elementConverted = InteropUtils.GetInstance<System.Reflection.Assembly>(element);
		System.Type attributeTypeConverted = InteropUtils.GetInstance<System.Type>(attributeType);
	
	    try {
			System.Attribute __returnValue = System.Attribute.GetCustomAttribute(elementConverted, attributeTypeConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Attribute_GetCustomAttribute_8")]
	internal static void* /* System.Attribute */ System_Attribute_GetCustomAttribute_8(void* /* System.Reflection.Assembly */ element, void* /* System.Type */ attributeType, byte /* System.Boolean */ inherit, void** /* System.Exception */ __outException)
	{
		System.Reflection.Assembly elementConverted = InteropUtils.GetInstance<System.Reflection.Assembly>(element);
		System.Type attributeTypeConverted = InteropUtils.GetInstance<System.Type>(attributeType);
		System.Boolean inheritConverted = inherit.ToBool();
	
	    try {
			System.Attribute __returnValue = System.Attribute.GetCustomAttribute(elementConverted, attributeTypeConverted, inheritConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Attribute_Equals")]
	internal static byte /* System.Boolean */ System_Attribute_Equals(void* /* System.Attribute */ __self, void* /* System.Object */ obj, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Attribute __selfConverted = InteropUtils.GetInstance<System.Attribute>(__self);
	
		System.Object objConverted = InteropUtils.GetInstance<System.Object>(obj);
	
	    try {
			System.Boolean __returnValue = __selfConverted.Equals(objConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Attribute_GetHashCode")]
	internal static int /* System.Int32 */ System_Attribute_GetHashCode(void* /* System.Attribute */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Attribute __selfConverted = InteropUtils.GetInstance<System.Attribute>(__self);
	
	
	    try {
			System.Int32 __returnValue = __selfConverted.GetHashCode();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Attribute_Match")]
	internal static byte /* System.Boolean */ System_Attribute_Match(void* /* System.Attribute */ __self, void* /* System.Object */ obj, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Attribute __selfConverted = InteropUtils.GetInstance<System.Attribute>(__self);
	
		System.Object objConverted = InteropUtils.GetInstance<System.Object>(obj);
	
	    try {
			System.Boolean __returnValue = __selfConverted.Match(objConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Attribute_IsDefaultAttribute")]
	internal static byte /* System.Boolean */ System_Attribute_IsDefaultAttribute(void* /* System.Attribute */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Attribute __selfConverted = InteropUtils.GetInstance<System.Attribute>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.IsDefaultAttribute();
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Attribute_TypeId_Get")]
	internal static void* /* System.Object */ System_Attribute_TypeId_Get(void* /* System.Attribute */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Attribute __selfConverted = InteropUtils.GetInstance<System.Attribute>(__self);
	
	
	    try {
			System.Object __returnValue = __selfConverted.TypeId;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Attribute_TypeOf")]
	internal static void* /* System.Type */ System_Attribute_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.Attribute);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Attribute_Destroy")]
	internal static void /* System.Void */ System_Attribute_Destroy(void* /* System.Attribute */ __self)
	{
	
		InteropUtils.FreeIfAllocated(__self);
	}
	
}




internal unsafe class System_Runtime_InteropServices_LayoutKind
{
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_InteropServices_LayoutKind_TypeOf")]
	internal static void* /* System.Type */ System_Runtime_InteropServices_LayoutKind_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.Runtime.InteropServices.LayoutKind);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
}


internal unsafe class System_Runtime_InteropServices_CharSet
{
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_InteropServices_CharSet_TypeOf")]
	internal static void* /* System.Type */ System_Runtime_InteropServices_CharSet_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.Runtime.InteropServices.CharSet);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
}


internal unsafe class System_Reflection_ConstructorInfo
{
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_ConstructorInfo_Invoke")]
	internal static void* /* System.Object */ System_Reflection_ConstructorInfo_Invoke(void* /* System.Reflection.ConstructorInfo */ __self, void* /* System.Object[] */ parameters, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.ConstructorInfo __selfConverted = InteropUtils.GetInstance<System.Reflection.ConstructorInfo>(__self);
	
		System.Object[] parametersConverted = InteropUtils.GetInstance<System.Object[]>(parameters);
	
	    try {
			System.Object __returnValue = __selfConverted.Invoke(parametersConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_ConstructorInfo_Invoke_1")]
	internal static void* /* System.Object */ System_Reflection_ConstructorInfo_Invoke_1(void* /* System.Reflection.ConstructorInfo */ __self, System.Reflection.BindingFlags /* System.Reflection.BindingFlags */ invokeAttr, void* /* System.Reflection.Binder */ binder, void* /* System.Object[] */ parameters, void* /* System.Globalization.CultureInfo */ culture, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.ConstructorInfo __selfConverted = InteropUtils.GetInstance<System.Reflection.ConstructorInfo>(__self);
	
		System.Reflection.Binder binderConverted = InteropUtils.GetInstance<System.Reflection.Binder>(binder);
		System.Object[] parametersConverted = InteropUtils.GetInstance<System.Object[]>(parameters);
		System.Globalization.CultureInfo cultureConverted = InteropUtils.GetInstance<System.Globalization.CultureInfo>(culture);
	
	    try {
			System.Object __returnValue = __selfConverted.Invoke(invokeAttr, binderConverted, parametersConverted, cultureConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_ConstructorInfo_Equals")]
	internal static byte /* System.Boolean */ System_Reflection_ConstructorInfo_Equals(void* /* System.Reflection.ConstructorInfo */ __self, void* /* System.Object */ obj, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.ConstructorInfo __selfConverted = InteropUtils.GetInstance<System.Reflection.ConstructorInfo>(__self);
	
		System.Object objConverted = InteropUtils.GetInstance<System.Object>(obj);
	
	    try {
			System.Boolean __returnValue = __selfConverted.Equals(objConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_ConstructorInfo_GetHashCode")]
	internal static int /* System.Int32 */ System_Reflection_ConstructorInfo_GetHashCode(void* /* System.Reflection.ConstructorInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.ConstructorInfo __selfConverted = InteropUtils.GetInstance<System.Reflection.ConstructorInfo>(__self);
	
	
	    try {
			System.Int32 __returnValue = __selfConverted.GetHashCode();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_ConstructorInfo_MemberType_Get")]
	internal static System.Reflection.MemberTypes /* System.Reflection.MemberTypes */ System_Reflection_ConstructorInfo_MemberType_Get(void* /* System.Reflection.ConstructorInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.ConstructorInfo __selfConverted = InteropUtils.GetInstance<System.Reflection.ConstructorInfo>(__self);
	
	
	    try {
			System.Reflection.MemberTypes __returnValue = __selfConverted.MemberType;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return default(System.Reflection.MemberTypes);
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_ConstructorInfo_ConstructorName_Get")]
	internal static void* /* System.String */ System_Reflection_ConstructorInfo_ConstructorName_Get()
	{
	
		System.String __returnValue = System.Reflection.ConstructorInfo.ConstructorName;
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_ConstructorInfo_TypeConstructorName_Get")]
	internal static void* /* System.String */ System_Reflection_ConstructorInfo_TypeConstructorName_Get()
	{
	
		System.String __returnValue = System.Reflection.ConstructorInfo.TypeConstructorName;
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_ConstructorInfo_TypeOf")]
	internal static void* /* System.Type */ System_Reflection_ConstructorInfo_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.Reflection.ConstructorInfo);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_ConstructorInfo_Destroy")]
	internal static void /* System.Void */ System_Reflection_ConstructorInfo_Destroy(void* /* System.Reflection.ConstructorInfo */ __self)
	{
	
		InteropUtils.FreeIfAllocated(__self);
	}
	
}




internal unsafe class System_Reflection_EventInfo
{
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_EventInfo_GetOtherMethods")]
	internal static void* /* System.Reflection.MethodInfo[] */ System_Reflection_EventInfo_GetOtherMethods(void* /* System.Reflection.EventInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.EventInfo __selfConverted = InteropUtils.GetInstance<System.Reflection.EventInfo>(__self);
	
	
	    try {
			System.Reflection.MethodInfo[] __returnValue = __selfConverted.GetOtherMethods();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_EventInfo_GetOtherMethods_1")]
	internal static void* /* System.Reflection.MethodInfo[] */ System_Reflection_EventInfo_GetOtherMethods_1(void* /* System.Reflection.EventInfo */ __self, byte /* System.Boolean */ nonPublic, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.EventInfo __selfConverted = InteropUtils.GetInstance<System.Reflection.EventInfo>(__self);
	
		System.Boolean nonPublicConverted = nonPublic.ToBool();
	
	    try {
			System.Reflection.MethodInfo[] __returnValue = __selfConverted.GetOtherMethods(nonPublicConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_EventInfo_GetAddMethod")]
	internal static void* /* System.Reflection.MethodInfo */ System_Reflection_EventInfo_GetAddMethod(void* /* System.Reflection.EventInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.EventInfo __selfConverted = InteropUtils.GetInstance<System.Reflection.EventInfo>(__self);
	
	
	    try {
			System.Reflection.MethodInfo __returnValue = __selfConverted.GetAddMethod();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_EventInfo_GetRemoveMethod")]
	internal static void* /* System.Reflection.MethodInfo */ System_Reflection_EventInfo_GetRemoveMethod(void* /* System.Reflection.EventInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.EventInfo __selfConverted = InteropUtils.GetInstance<System.Reflection.EventInfo>(__self);
	
	
	    try {
			System.Reflection.MethodInfo __returnValue = __selfConverted.GetRemoveMethod();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_EventInfo_GetRaiseMethod")]
	internal static void* /* System.Reflection.MethodInfo */ System_Reflection_EventInfo_GetRaiseMethod(void* /* System.Reflection.EventInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.EventInfo __selfConverted = InteropUtils.GetInstance<System.Reflection.EventInfo>(__self);
	
	
	    try {
			System.Reflection.MethodInfo __returnValue = __selfConverted.GetRaiseMethod();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_EventInfo_GetAddMethod_1")]
	internal static void* /* System.Reflection.MethodInfo */ System_Reflection_EventInfo_GetAddMethod_1(void* /* System.Reflection.EventInfo */ __self, byte /* System.Boolean */ nonPublic, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.EventInfo __selfConverted = InteropUtils.GetInstance<System.Reflection.EventInfo>(__self);
	
		System.Boolean nonPublicConverted = nonPublic.ToBool();
	
	    try {
			System.Reflection.MethodInfo __returnValue = __selfConverted.GetAddMethod(nonPublicConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_EventInfo_GetRemoveMethod_1")]
	internal static void* /* System.Reflection.MethodInfo */ System_Reflection_EventInfo_GetRemoveMethod_1(void* /* System.Reflection.EventInfo */ __self, byte /* System.Boolean */ nonPublic, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.EventInfo __selfConverted = InteropUtils.GetInstance<System.Reflection.EventInfo>(__self);
	
		System.Boolean nonPublicConverted = nonPublic.ToBool();
	
	    try {
			System.Reflection.MethodInfo __returnValue = __selfConverted.GetRemoveMethod(nonPublicConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_EventInfo_GetRaiseMethod_1")]
	internal static void* /* System.Reflection.MethodInfo */ System_Reflection_EventInfo_GetRaiseMethod_1(void* /* System.Reflection.EventInfo */ __self, byte /* System.Boolean */ nonPublic, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.EventInfo __selfConverted = InteropUtils.GetInstance<System.Reflection.EventInfo>(__self);
	
		System.Boolean nonPublicConverted = nonPublic.ToBool();
	
	    try {
			System.Reflection.MethodInfo __returnValue = __selfConverted.GetRaiseMethod(nonPublicConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_EventInfo_AddEventHandler")]
	internal static void /* System.Void */ System_Reflection_EventInfo_AddEventHandler(void* /* System.Reflection.EventInfo */ __self, void* /* System.Object */ target, void* /* System.Delegate */ handler, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.EventInfo __selfConverted = InteropUtils.GetInstance<System.Reflection.EventInfo>(__self);
	
		System.Object targetConverted = InteropUtils.GetInstance<System.Object>(target);
		System.Delegate handlerConverted = InteropUtils.GetInstance<System_Delegate>(handler)?.Trampoline;
	
	    try {
			__selfConverted.AddEventHandler(targetConverted, handlerConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_EventInfo_RemoveEventHandler")]
	internal static void /* System.Void */ System_Reflection_EventInfo_RemoveEventHandler(void* /* System.Reflection.EventInfo */ __self, void* /* System.Object */ target, void* /* System.Delegate */ handler, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.EventInfo __selfConverted = InteropUtils.GetInstance<System.Reflection.EventInfo>(__self);
	
		System.Object targetConverted = InteropUtils.GetInstance<System.Object>(target);
		System.Delegate handlerConverted = InteropUtils.GetInstance<System_Delegate>(handler)?.Trampoline;
	
	    try {
			__selfConverted.RemoveEventHandler(targetConverted, handlerConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_EventInfo_Equals")]
	internal static byte /* System.Boolean */ System_Reflection_EventInfo_Equals(void* /* System.Reflection.EventInfo */ __self, void* /* System.Object */ obj, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.EventInfo __selfConverted = InteropUtils.GetInstance<System.Reflection.EventInfo>(__self);
	
		System.Object objConverted = InteropUtils.GetInstance<System.Object>(obj);
	
	    try {
			System.Boolean __returnValue = __selfConverted.Equals(objConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_EventInfo_GetHashCode")]
	internal static int /* System.Int32 */ System_Reflection_EventInfo_GetHashCode(void* /* System.Reflection.EventInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.EventInfo __selfConverted = InteropUtils.GetInstance<System.Reflection.EventInfo>(__self);
	
	
	    try {
			System.Int32 __returnValue = __selfConverted.GetHashCode();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_EventInfo_MemberType_Get")]
	internal static System.Reflection.MemberTypes /* System.Reflection.MemberTypes */ System_Reflection_EventInfo_MemberType_Get(void* /* System.Reflection.EventInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.EventInfo __selfConverted = InteropUtils.GetInstance<System.Reflection.EventInfo>(__self);
	
	
	    try {
			System.Reflection.MemberTypes __returnValue = __selfConverted.MemberType;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return default(System.Reflection.MemberTypes);
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_EventInfo_Attributes_Get")]
	internal static System.Reflection.EventAttributes /* System.Reflection.EventAttributes */ System_Reflection_EventInfo_Attributes_Get(void* /* System.Reflection.EventInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.EventInfo __selfConverted = InteropUtils.GetInstance<System.Reflection.EventInfo>(__self);
	
	
	    try {
			System.Reflection.EventAttributes __returnValue = __selfConverted.Attributes;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return default(System.Reflection.EventAttributes);
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_EventInfo_IsSpecialName_Get")]
	internal static byte /* System.Boolean */ System_Reflection_EventInfo_IsSpecialName_Get(void* /* System.Reflection.EventInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.EventInfo __selfConverted = InteropUtils.GetInstance<System.Reflection.EventInfo>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.IsSpecialName;
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_EventInfo_AddMethod_Get")]
	internal static void* /* System.Reflection.MethodInfo */ System_Reflection_EventInfo_AddMethod_Get(void* /* System.Reflection.EventInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.EventInfo __selfConverted = InteropUtils.GetInstance<System.Reflection.EventInfo>(__self);
	
	
	    try {
			System.Reflection.MethodInfo __returnValue = __selfConverted.AddMethod;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_EventInfo_RemoveMethod_Get")]
	internal static void* /* System.Reflection.MethodInfo */ System_Reflection_EventInfo_RemoveMethod_Get(void* /* System.Reflection.EventInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.EventInfo __selfConverted = InteropUtils.GetInstance<System.Reflection.EventInfo>(__self);
	
	
	    try {
			System.Reflection.MethodInfo __returnValue = __selfConverted.RemoveMethod;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_EventInfo_RaiseMethod_Get")]
	internal static void* /* System.Reflection.MethodInfo */ System_Reflection_EventInfo_RaiseMethod_Get(void* /* System.Reflection.EventInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.EventInfo __selfConverted = InteropUtils.GetInstance<System.Reflection.EventInfo>(__self);
	
	
	    try {
			System.Reflection.MethodInfo __returnValue = __selfConverted.RaiseMethod;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_EventInfo_IsMulticast_Get")]
	internal static byte /* System.Boolean */ System_Reflection_EventInfo_IsMulticast_Get(void* /* System.Reflection.EventInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.EventInfo __selfConverted = InteropUtils.GetInstance<System.Reflection.EventInfo>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.IsMulticast;
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_EventInfo_EventHandlerType_Get")]
	internal static void* /* System.Type */ System_Reflection_EventInfo_EventHandlerType_Get(void* /* System.Reflection.EventInfo */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.EventInfo __selfConverted = InteropUtils.GetInstance<System.Reflection.EventInfo>(__self);
	
	
	    try {
			System.Type __returnValue = __selfConverted.EventHandlerType;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_EventInfo_TypeOf")]
	internal static void* /* System.Type */ System_Reflection_EventInfo_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.Reflection.EventInfo);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_EventInfo_Destroy")]
	internal static void /* System.Void */ System_Reflection_EventInfo_Destroy(void* /* System.Reflection.EventInfo */ __self)
	{
	
		InteropUtils.FreeIfAllocated(__self);
	}
	
}


internal unsafe class System_Reflection_EventAttributes
{
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_EventAttributes_TypeOf")]
	internal static void* /* System.Type */ System_Reflection_EventAttributes_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.Reflection.EventAttributes);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
}




internal unsafe class System_Reflection_InterfaceMapping
{
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_InterfaceMapping_TargetType_Get")]
	internal static void* /* System.Type */ System_Reflection_InterfaceMapping_TargetType_Get(void* /* System.Reflection.InterfaceMapping */ __self)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.InterfaceMapping __selfConverted = InteropUtils.GetInstance<System.Reflection.InterfaceMapping>(__self);
	
	
		System.Type __returnValue = __selfConverted.TargetType;
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		if (__self is not null) {
			InteropUtils.ReplaceInstance(__self, __selfConverted);
		}
		
		
		return __returnValueNative;
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_InterfaceMapping_TargetType_Set")]
	internal static void /* System.Void */ System_Reflection_InterfaceMapping_TargetType_Set(void* /* System.Reflection.InterfaceMapping */ __self, void* /* System.Type */ __value)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.InterfaceMapping __selfConverted = InteropUtils.GetInstance<System.Reflection.InterfaceMapping>(__self);
	
	
		__selfConverted.TargetType = InteropUtils.GetInstance<System.Type>(__value);
		if (__self is not null) {
			InteropUtils.ReplaceInstance(__self, __selfConverted);
		}
		
		
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_InterfaceMapping_InterfaceType_Get")]
	internal static void* /* System.Type */ System_Reflection_InterfaceMapping_InterfaceType_Get(void* /* System.Reflection.InterfaceMapping */ __self)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.InterfaceMapping __selfConverted = InteropUtils.GetInstance<System.Reflection.InterfaceMapping>(__self);
	
	
		System.Type __returnValue = __selfConverted.InterfaceType;
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		if (__self is not null) {
			InteropUtils.ReplaceInstance(__self, __selfConverted);
		}
		
		
		return __returnValueNative;
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_InterfaceMapping_InterfaceType_Set")]
	internal static void /* System.Void */ System_Reflection_InterfaceMapping_InterfaceType_Set(void* /* System.Reflection.InterfaceMapping */ __self, void* /* System.Type */ __value)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.InterfaceMapping __selfConverted = InteropUtils.GetInstance<System.Reflection.InterfaceMapping>(__self);
	
	
		__selfConverted.InterfaceType = InteropUtils.GetInstance<System.Type>(__value);
		if (__self is not null) {
			InteropUtils.ReplaceInstance(__self, __selfConverted);
		}
		
		
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_InterfaceMapping_TargetMethods_Get")]
	internal static void* /* System.Reflection.MethodInfo[] */ System_Reflection_InterfaceMapping_TargetMethods_Get(void* /* System.Reflection.InterfaceMapping */ __self)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.InterfaceMapping __selfConverted = InteropUtils.GetInstance<System.Reflection.InterfaceMapping>(__self);
	
	
		System.Reflection.MethodInfo[] __returnValue = __selfConverted.TargetMethods;
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		if (__self is not null) {
			InteropUtils.ReplaceInstance(__self, __selfConverted);
		}
		
		
		return __returnValueNative;
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_InterfaceMapping_TargetMethods_Set")]
	internal static void /* System.Void */ System_Reflection_InterfaceMapping_TargetMethods_Set(void* /* System.Reflection.InterfaceMapping */ __self, void* /* System.Reflection.MethodInfo[] */ __value)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.InterfaceMapping __selfConverted = InteropUtils.GetInstance<System.Reflection.InterfaceMapping>(__self);
	
	
		__selfConverted.TargetMethods = InteropUtils.GetInstance<System.Reflection.MethodInfo[]>(__value);
		if (__self is not null) {
			InteropUtils.ReplaceInstance(__self, __selfConverted);
		}
		
		
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_InterfaceMapping_InterfaceMethods_Get")]
	internal static void* /* System.Reflection.MethodInfo[] */ System_Reflection_InterfaceMapping_InterfaceMethods_Get(void* /* System.Reflection.InterfaceMapping */ __self)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.InterfaceMapping __selfConverted = InteropUtils.GetInstance<System.Reflection.InterfaceMapping>(__self);
	
	
		System.Reflection.MethodInfo[] __returnValue = __selfConverted.InterfaceMethods;
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		if (__self is not null) {
			InteropUtils.ReplaceInstance(__self, __selfConverted);
		}
		
		
		return __returnValueNative;
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_InterfaceMapping_InterfaceMethods_Set")]
	internal static void /* System.Void */ System_Reflection_InterfaceMapping_InterfaceMethods_Set(void* /* System.Reflection.InterfaceMapping */ __self, void* /* System.Reflection.MethodInfo[] */ __value)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Reflection.InterfaceMapping __selfConverted = InteropUtils.GetInstance<System.Reflection.InterfaceMapping>(__self);
	
	
		__selfConverted.InterfaceMethods = InteropUtils.GetInstance<System.Reflection.MethodInfo[]>(__value);
		if (__self is not null) {
			InteropUtils.ReplaceInstance(__self, __selfConverted);
		}
		
		
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_InterfaceMapping_Create")]
	internal static void* /* System.Reflection.InterfaceMapping */ System_Reflection_InterfaceMapping_Create(void** /* System.Exception */ __outException)
	{
	
	    try {
			System.Reflection.InterfaceMapping __returnValue = new System.Reflection.InterfaceMapping();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_InterfaceMapping_TypeOf")]
	internal static void* /* System.Type */ System_Reflection_InterfaceMapping_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.Reflection.InterfaceMapping);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_InterfaceMapping_Destroy")]
	internal static void /* System.Void */ System_Reflection_InterfaceMapping_Destroy(void* /* System.Reflection.InterfaceMapping */ __self)
	{
	
		InteropUtils.FreeIfAllocated(__self);
	}
	
}


internal unsafe class System_Reflection_MemberFilter
{
	internal void* Context { get; }
	internal delegate* unmanaged<void* /* context */, void* /* System.Reflection.MemberInfo */ /* m */, void* /* System.Object */ /* filterCriteria */, byte /* System.Boolean */ /* return type */> CFunction { get; }
	internal delegate* unmanaged<void*, void> CDestructorFunction { get; }

	private WeakReference<System.Reflection.MemberFilter> m_trampoline;
	internal System.Reflection.MemberFilter Trampoline
	{
		get {
			System.Reflection.MemberFilter? trampoline;

			if (m_trampoline is not null) {
				m_trampoline.TryGetTarget(out trampoline);
			} else {
				trampoline = null;
			}

			if (trampoline is null) {
				trampoline = CreateTrampoline();
				m_trampoline = new(trampoline);
			}

			return trampoline;
		}
	}

	private System_Reflection_MemberFilter(void* context, delegate* unmanaged<void* /* context */, void* /* System.Reflection.MemberInfo */ /* m */, void* /* System.Object */ /* filterCriteria */, byte /* System.Boolean */ /* return type */> cFunction, delegate* unmanaged<void*, void> cDestructorFunction)
	{
		Context = context;
		CFunction = cFunction;
		CDestructorFunction = cDestructorFunction;
	}

	internal System_Reflection_MemberFilter(System.Reflection.MemberFilter originalDelegate)
	{
		m_trampoline = new(originalDelegate);
	}

	~System_Reflection_MemberFilter()
	{
		if (CDestructorFunction is null) {
			return;
		}

		CDestructorFunction(Context);
	}

	private System.Reflection.MemberFilter? CreateTrampoline()
	{
		if (CFunction is null) {
			return null;
		}

		System.Type typeOfSelf = typeof(System_Reflection_MemberFilter);
		string nameOfInvocationMethod = nameof(__InvokeByCallingCFunction);
		System.Reflection.BindingFlags bindingFlags = System.Reflection.BindingFlags.Instance | BindingFlags.NonPublic;
		System.Reflection.MethodInfo? invocationMethod = typeOfSelf.GetMethod(nameOfInvocationMethod, bindingFlags);

		if (invocationMethod is null) {
			throw new Exception("Failed to retrieve delegate invocation method");
		}

		System.Reflection.MemberFilter trampoline = (System.Reflection.MemberFilter)System.Delegate.CreateDelegate(typeof(System.Reflection.MemberFilter), this, invocationMethod);

		return trampoline;
	}

	private System.Boolean __InvokeByCallingCFunction(System.Reflection.MemberInfo /* System.Reflection.MemberInfo */ m, System.Object /* System.Object */ filterCriteria)
	{
		void* mConverted = m.AllocateGCHandleAndGetAddress();
		void* filterCriteriaConverted = filterCriteria.AllocateGCHandleAndGetAddress();
	

		var __returnValue = CFunction(Context, mConverted, filterCriteriaConverted);
		var __returnValueConverted = __returnValue.ToBool();

		return __returnValueConverted;
	}

	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_MemberFilter_Create")]
	public static void* Create(void* context, delegate* unmanaged<void* /* context */, void* /* System.Reflection.MemberInfo */ /* m */, void* /* System.Object */ /* filterCriteria */, byte /* System.Boolean */ /* return type */> cFunction, delegate* unmanaged<void*, void> cDestructorFunction)
	{
		var self = new System_Reflection_MemberFilter(context, cFunction, cDestructorFunction);
		void* selfHandle = self.AllocateGCHandleAndGetAddress();

		return selfHandle;
	}

	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_MemberFilter_Invoke")]
	public static byte /* System.Boolean */ Invoke(void* self, void* /* System.Reflection.MemberInfo */ m, void* /* System.Object */ filterCriteria, void** __outException)
	{
		if (self is null) {
			throw new ArgumentNullException(nameof(self));
		}

		try {
			var selfConverted = InteropUtils.GetInstance<System_Reflection_MemberFilter>(self);

			System.Reflection.MemberInfo mConverted = InteropUtils.GetInstance<System.Reflection.MemberInfo>(m);
			System.Object filterCriteriaConverted = InteropUtils.GetInstance<System.Object>(filterCriteria);
		

			var __returnValue = selfConverted.Trampoline(mConverted, filterCriteriaConverted);
			var __returnValueConverted = __returnValue.ToCBool();

			return __returnValueConverted;
		} catch (Exception __exception) {
			if (__outException is not null) {
				void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();

				*__outException = __exceptionHandleAddress;
			}

			return 0;
		}
	}

	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_MemberFilter_Context_Get")]
	public static void* Context_Get(void* self)
	{
		if (self is null) {
			throw new ArgumentNullException(nameof(self));
		}

		var selfConverted = InteropUtils.GetInstance<System_Reflection_MemberFilter>(self);

		return selfConverted.Context;
	}

	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_MemberFilter_CFunction_Get")]
	public static delegate* unmanaged<void* /* context */, void* /* System.Reflection.MemberInfo */ /* m */, void* /* System.Object */ /* filterCriteria */, byte /* System.Boolean */ /* return type */> CFunction_Get(void* self)
	{
		if (self is null) {
			throw new ArgumentNullException(nameof(self));
		}

		var selfConverted = InteropUtils.GetInstance<System_Reflection_MemberFilter>(self);

		return selfConverted.CFunction;
	}

	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_MemberFilter_CDestructorFunction_Get")]
	public static delegate* unmanaged<void*, void> CDestructorFunction_Get(void* self)
	{
		if (self is null) {
			throw new ArgumentNullException(nameof(self));
		}

		var selfConverted = InteropUtils.GetInstance<System_Reflection_MemberFilter>(self);

		return selfConverted.CDestructorFunction;
	}

	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_MemberFilter_TypeOf")]
	internal static void* /* System.Type */ System_Reflection_MemberFilter_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.Reflection.MemberFilter);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	

	[UnmanagedCallersOnly(EntryPoint = "System_Reflection_MemberFilter_Destroy")]
	internal static void /* System.Void */ System_Reflection_MemberFilter_Destroy(void* /* System.Reflection.MemberFilter */ __self)
	{
	
		InteropUtils.FreeIfAllocated(__self);
	}
	
}


internal unsafe class System_Runtime_InteropServices_Marshal
{
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_InteropServices_Marshal_OffsetOf")]
	internal static nint /* System.IntPtr */ System_Runtime_InteropServices_Marshal_OffsetOf(void* /* System.Type */ t, void* /* System.String */ fieldName, void** /* System.Exception */ __outException)
	{
		System.Type tConverted = InteropUtils.GetInstance<System.Type>(t);
		System.String fieldNameConverted = InteropUtils.GetInstance<System.String>(fieldName);
	
	    try {
			System.IntPtr __returnValue = System.Runtime.InteropServices.Marshal.OffsetOf(tConverted, fieldNameConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return nint.Zero;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_InteropServices_Marshal_ReadByte")]
	internal static byte /* System.Byte */ System_Runtime_InteropServices_Marshal_ReadByte(void* /* System.Object */ ptr, int /* System.Int32 */ ofs, void** /* System.Exception */ __outException)
	{
		System.Object ptrConverted = InteropUtils.GetInstance<System.Object>(ptr);
	
	    try {
			System.Byte __returnValue = System.Runtime.InteropServices.Marshal.ReadByte(ptrConverted, ofs);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_InteropServices_Marshal_ReadInt16")]
	internal static short /* System.Int16 */ System_Runtime_InteropServices_Marshal_ReadInt16(void* /* System.Object */ ptr, int /* System.Int32 */ ofs, void** /* System.Exception */ __outException)
	{
		System.Object ptrConverted = InteropUtils.GetInstance<System.Object>(ptr);
	
	    try {
			System.Int16 __returnValue = System.Runtime.InteropServices.Marshal.ReadInt16(ptrConverted, ofs);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_InteropServices_Marshal_ReadInt32")]
	internal static int /* System.Int32 */ System_Runtime_InteropServices_Marshal_ReadInt32(void* /* System.Object */ ptr, int /* System.Int32 */ ofs, void** /* System.Exception */ __outException)
	{
		System.Object ptrConverted = InteropUtils.GetInstance<System.Object>(ptr);
	
	    try {
			System.Int32 __returnValue = System.Runtime.InteropServices.Marshal.ReadInt32(ptrConverted, ofs);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_InteropServices_Marshal_ReadInt64")]
	internal static long /* System.Int64 */ System_Runtime_InteropServices_Marshal_ReadInt64(void** /* System.Object */ ptr, int /* System.Int32 */ ofs, void** /* System.Exception */ __outException)
	{
		System.Object ptrConverted;
	
		if (ptr is not null) {
			ptrConverted = InteropUtils.GetInstance<System.Object>((*ptr));
		} else {
			ptrConverted = default(System.Object);
		}
	
	
	    try {
			System.Int64 __returnValue = System.Runtime.InteropServices.Marshal.ReadInt64(ptrConverted, ofs);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			if (ptr is not null) {
				*ptr = ptrConverted.AllocateGCHandleAndGetAddress();
			}
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_InteropServices_Marshal_WriteByte")]
	internal static void /* System.Void */ System_Runtime_InteropServices_Marshal_WriteByte(void* /* System.Object */ ptr, int /* System.Int32 */ ofs, byte /* System.Byte */ val, void** /* System.Exception */ __outException)
	{
		System.Object ptrConverted = InteropUtils.GetInstance<System.Object>(ptr);
	
	    try {
			System.Runtime.InteropServices.Marshal.WriteByte(ptrConverted, ofs, val);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_InteropServices_Marshal_WriteInt32")]
	internal static void /* System.Void */ System_Runtime_InteropServices_Marshal_WriteInt32(void* /* System.Object */ ptr, int /* System.Int32 */ ofs, int /* System.Int32 */ val, void** /* System.Exception */ __outException)
	{
		System.Object ptrConverted = InteropUtils.GetInstance<System.Object>(ptr);
	
	    try {
			System.Runtime.InteropServices.Marshal.WriteInt32(ptrConverted, ofs, val);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_InteropServices_Marshal_WriteInt64")]
	internal static void /* System.Void */ System_Runtime_InteropServices_Marshal_WriteInt64(void* /* System.Object */ ptr, int /* System.Int32 */ ofs, long /* System.Int64 */ val, void** /* System.Exception */ __outException)
	{
		System.Object ptrConverted = InteropUtils.GetInstance<System.Object>(ptr);
	
	    try {
			System.Runtime.InteropServices.Marshal.WriteInt64(ptrConverted, ofs, val);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_InteropServices_Marshal_GetLastPInvokeError")]
	internal static int /* System.Int32 */ System_Runtime_InteropServices_Marshal_GetLastPInvokeError(void** /* System.Exception */ __outException)
	{
	
	    try {
			System.Int32 __returnValue = System.Runtime.InteropServices.Marshal.GetLastPInvokeError();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_InteropServices_Marshal_SetLastPInvokeError")]
	internal static void /* System.Void */ System_Runtime_InteropServices_Marshal_SetLastPInvokeError(int /* System.Int32 */ error, void** /* System.Exception */ __outException)
	{
	
	    try {
			System.Runtime.InteropServices.Marshal.SetLastPInvokeError(error);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_InteropServices_Marshal_GetExceptionPointers")]
	internal static nint /* System.IntPtr */ System_Runtime_InteropServices_Marshal_GetExceptionPointers(void** /* System.Exception */ __outException)
	{
	
	    try {
			System.IntPtr __returnValue = System.Runtime.InteropServices.Marshal.GetExceptionPointers();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return nint.Zero;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_InteropServices_Marshal_GetExceptionCode")]
	internal static int /* System.Int32 */ System_Runtime_InteropServices_Marshal_GetExceptionCode(void** /* System.Exception */ __outException)
	{
	
	    try {
			System.Int32 __returnValue = System.Runtime.InteropServices.Marshal.GetExceptionCode();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_InteropServices_Marshal_StructureToPtr")]
	internal static void /* System.Void */ System_Runtime_InteropServices_Marshal_StructureToPtr(void* /* System.Object */ structure, nint /* System.IntPtr */ ptr, byte /* System.Boolean */ fDeleteOld, void** /* System.Exception */ __outException)
	{
		System.Object structureConverted = InteropUtils.GetInstance<System.Object>(structure);
		System.Boolean fDeleteOldConverted = fDeleteOld.ToBool();
	
	    try {
			System.Runtime.InteropServices.Marshal.StructureToPtr(structureConverted, ptr, fDeleteOldConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_InteropServices_Marshal_DestroyStructure")]
	internal static void /* System.Void */ System_Runtime_InteropServices_Marshal_DestroyStructure(nint /* System.IntPtr */ ptr, void* /* System.Type */ structuretype, void** /* System.Exception */ __outException)
	{
		System.Type structuretypeConverted = InteropUtils.GetInstance<System.Type>(structuretype);
	
	    try {
			System.Runtime.InteropServices.Marshal.DestroyStructure(ptr, structuretypeConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_InteropServices_Marshal_AllocHGlobal")]
	internal static nint /* System.IntPtr */ System_Runtime_InteropServices_Marshal_AllocHGlobal(int /* System.Int32 */ cb, void** /* System.Exception */ __outException)
	{
	
	    try {
			System.IntPtr __returnValue = System.Runtime.InteropServices.Marshal.AllocHGlobal(cb);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return nint.Zero;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_InteropServices_Marshal_PtrToStringAnsi")]
	internal static void* /* System.String */ System_Runtime_InteropServices_Marshal_PtrToStringAnsi(nint /* System.IntPtr */ ptr, void** /* System.Exception */ __outException)
	{
	
	    try {
			System.String __returnValue = System.Runtime.InteropServices.Marshal.PtrToStringAnsi(ptr);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_InteropServices_Marshal_PtrToStringAnsi_1")]
	internal static void* /* System.String */ System_Runtime_InteropServices_Marshal_PtrToStringAnsi_1(nint /* System.IntPtr */ ptr, int /* System.Int32 */ len, void** /* System.Exception */ __outException)
	{
	
	    try {
			System.String __returnValue = System.Runtime.InteropServices.Marshal.PtrToStringAnsi(ptr, len);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_InteropServices_Marshal_PtrToStringUni")]
	internal static void* /* System.String */ System_Runtime_InteropServices_Marshal_PtrToStringUni(nint /* System.IntPtr */ ptr, void** /* System.Exception */ __outException)
	{
	
	    try {
			System.String __returnValue = System.Runtime.InteropServices.Marshal.PtrToStringUni(ptr);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_InteropServices_Marshal_PtrToStringUni_1")]
	internal static void* /* System.String */ System_Runtime_InteropServices_Marshal_PtrToStringUni_1(nint /* System.IntPtr */ ptr, int /* System.Int32 */ len, void** /* System.Exception */ __outException)
	{
	
	    try {
			System.String __returnValue = System.Runtime.InteropServices.Marshal.PtrToStringUni(ptr, len);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_InteropServices_Marshal_PtrToStringUTF8")]
	internal static void* /* System.String */ System_Runtime_InteropServices_Marshal_PtrToStringUTF8(nint /* System.IntPtr */ ptr, void** /* System.Exception */ __outException)
	{
	
	    try {
			System.String __returnValue = System.Runtime.InteropServices.Marshal.PtrToStringUTF8(ptr);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_InteropServices_Marshal_PtrToStringUTF8_1")]
	internal static void* /* System.String */ System_Runtime_InteropServices_Marshal_PtrToStringUTF8_1(nint /* System.IntPtr */ ptr, int /* System.Int32 */ byteLen, void** /* System.Exception */ __outException)
	{
	
	    try {
			System.String __returnValue = System.Runtime.InteropServices.Marshal.PtrToStringUTF8(ptr, byteLen);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_InteropServices_Marshal_SizeOf")]
	internal static int /* System.Int32 */ System_Runtime_InteropServices_Marshal_SizeOf(void* /* System.Object */ structure, void** /* System.Exception */ __outException)
	{
		System.Object structureConverted = InteropUtils.GetInstance<System.Object>(structure);
	
	    try {
			System.Int32 __returnValue = System.Runtime.InteropServices.Marshal.SizeOf(structureConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_InteropServices_Marshal_SizeOf_1")]
	internal static int /* System.Int32 */ System_Runtime_InteropServices_Marshal_SizeOf_1(void* /* System.Type */ t, void** /* System.Exception */ __outException)
	{
		System.Type tConverted = InteropUtils.GetInstance<System.Type>(t);
	
	    try {
			System.Int32 __returnValue = System.Runtime.InteropServices.Marshal.SizeOf(tConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_InteropServices_Marshal_SizeOf_A1")]
	internal static int /* System.Int32 */ System_Runtime_InteropServices_Marshal_SizeOf_A1(void* /* System.Type */ T, void** /* System.Exception */ __outException)
	{
		System.Type TConverted = InteropUtils.GetInstance<System.Type>(T);
	
	    try {
			System.Type __targetTypeForGenericCall = typeof(System.Runtime.InteropServices.Marshal);
			System.String __memberNameForGenericCall = nameof(System.Runtime.InteropServices.Marshal.SizeOf);
			System.Object? __methodTargetForGenericCall = null;
	
			System.Object[]? __parametersForGenericCall = null;
			System.Type[] __parameterTypesForGenericCall = System.Type.EmptyTypes;
	
			System.Type[] __genericParameterTypesForGenericCall = new System.Type[] { TConverted };
	
			System.Reflection.MethodInfo __methodForGenericCall = __targetTypeForGenericCall.GetMethod(__memberNameForGenericCall, 1, __parameterTypesForGenericCall) ?? throw new Exception("Method SizeOf not found");
			System.Reflection.MethodInfo __genericMethodForGenericCall = __methodForGenericCall.MakeGenericMethod(__genericParameterTypesForGenericCall);
	
			System.Int32 __returnValue = (System.Int32)__genericMethodForGenericCall.Invoke(__methodTargetForGenericCall, __parametersForGenericCall);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_InteropServices_Marshal_QueryInterface")]
	internal static int /* System.Int32 */ System_Runtime_InteropServices_Marshal_QueryInterface(nint /* System.IntPtr */ pUnk, void** /* System.Guid */ iid, nint* /* System.IntPtr */ ppv, void** /* System.Exception */ __outException)
	{
		System.Guid iidConverted;
	
		if (iid is not null) {
			iidConverted = InteropUtils.GetInstance<System.Guid>((*iid));
		} else {
			iidConverted = default(System.Guid);
		}
	
		System.IntPtr ppvConverted;
	
	    try {
			System.Int32 __returnValue = System.Runtime.InteropServices.Marshal.QueryInterface(pUnk, iidConverted, out ppvConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			if (iid is not null) {
				*iid = iidConverted.AllocateGCHandleAndGetAddress();
			}
	
			if (ppv is not null) {
				*ppv = ppvConverted;
			}
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			if (ppv is not null) {
				*ppv = nint.Zero;
			}
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_InteropServices_Marshal_AddRef")]
	internal static int /* System.Int32 */ System_Runtime_InteropServices_Marshal_AddRef(nint /* System.IntPtr */ pUnk, void** /* System.Exception */ __outException)
	{
	
	    try {
			System.Int32 __returnValue = System.Runtime.InteropServices.Marshal.AddRef(pUnk);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_InteropServices_Marshal_Release")]
	internal static int /* System.Int32 */ System_Runtime_InteropServices_Marshal_Release(nint /* System.IntPtr */ pUnk, void** /* System.Exception */ __outException)
	{
	
	    try {
			System.Int32 __returnValue = System.Runtime.InteropServices.Marshal.Release(pUnk);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_InteropServices_Marshal_UnsafeAddrOfPinnedArrayElement")]
	internal static nint /* System.IntPtr */ System_Runtime_InteropServices_Marshal_UnsafeAddrOfPinnedArrayElement(void* /* System.Array */ arr, int /* System.Int32 */ index, void** /* System.Exception */ __outException)
	{
		System.Array arrConverted = InteropUtils.GetInstance<System.Array>(arr);
	
	    try {
			System.IntPtr __returnValue = System.Runtime.InteropServices.Marshal.UnsafeAddrOfPinnedArrayElement(arrConverted, index);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return nint.Zero;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_InteropServices_Marshal_UnsafeAddrOfPinnedArrayElement_A1")]
	internal static nint /* System.IntPtr */ System_Runtime_InteropServices_Marshal_UnsafeAddrOfPinnedArrayElement_A1(void* /* System.Type */ T, void* /* T[] */ arr, int /* System.Int32 */ index, void** /* System.Exception */ __outException)
	{
		System.Type TConverted = InteropUtils.GetInstance<System.Type>(T);
		System.Array arrConverted = InteropUtils.GetInstance<System.Array>(arr);
	
	    try {
			System.Type __targetTypeForGenericCall = typeof(System.Runtime.InteropServices.Marshal);
			System.String __memberNameForGenericCall = nameof(System.Runtime.InteropServices.Marshal.UnsafeAddrOfPinnedArrayElement);
			System.Object? __methodTargetForGenericCall = null;
	
			System.Object[] __parametersForGenericCall = new System.Object[] { arrConverted, index };
			System.Type[] __parameterTypesForGenericCall = new System.Type[] { System.Type.MakeGenericMethodParameter(0).MakeArrayType(), typeof(System.Int32) };
	
			System.Type[] __genericParameterTypesForGenericCall = new System.Type[] { TConverted };
	
			System.Reflection.MethodInfo __methodForGenericCall = __targetTypeForGenericCall.GetMethod(__memberNameForGenericCall, 1, __parameterTypesForGenericCall) ?? throw new Exception("Method UnsafeAddrOfPinnedArrayElement not found");
			System.Reflection.MethodInfo __genericMethodForGenericCall = __methodForGenericCall.MakeGenericMethod(__genericParameterTypesForGenericCall);
	
			System.IntPtr __returnValue = (System.IntPtr)__genericMethodForGenericCall.Invoke(__methodTargetForGenericCall, __parametersForGenericCall);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return nint.Zero;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_InteropServices_Marshal_OffsetOf_A1")]
	internal static nint /* System.IntPtr */ System_Runtime_InteropServices_Marshal_OffsetOf_A1(void* /* System.Type */ T, void* /* System.String */ fieldName, void** /* System.Exception */ __outException)
	{
		System.Type TConverted = InteropUtils.GetInstance<System.Type>(T);
		System.String fieldNameConverted = InteropUtils.GetInstance<System.String>(fieldName);
	
	    try {
			System.Type __targetTypeForGenericCall = typeof(System.Runtime.InteropServices.Marshal);
			System.String __memberNameForGenericCall = nameof(System.Runtime.InteropServices.Marshal.OffsetOf);
			System.Object? __methodTargetForGenericCall = null;
	
			System.Object[] __parametersForGenericCall = new System.Object[] { fieldNameConverted };
			System.Type[] __parameterTypesForGenericCall = new System.Type[] { typeof(System.String) };
	
			System.Type[] __genericParameterTypesForGenericCall = new System.Type[] { TConverted };
	
			System.Reflection.MethodInfo __methodForGenericCall = __targetTypeForGenericCall.GetMethod(__memberNameForGenericCall, 1, __parameterTypesForGenericCall) ?? throw new Exception("Method OffsetOf not found");
			System.Reflection.MethodInfo __genericMethodForGenericCall = __methodForGenericCall.MakeGenericMethod(__genericParameterTypesForGenericCall);
	
			System.IntPtr __returnValue = (System.IntPtr)__genericMethodForGenericCall.Invoke(__methodTargetForGenericCall, __parametersForGenericCall);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return nint.Zero;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_InteropServices_Marshal_Copy")]
	internal static void /* System.Void */ System_Runtime_InteropServices_Marshal_Copy(void* /* System.Int32[] */ source, int /* System.Int32 */ startIndex, nint /* System.IntPtr */ destination, int /* System.Int32 */ length, void** /* System.Exception */ __outException)
	{
		System.Int32[] sourceConverted = InteropUtils.GetInstance<System.Int32[]>(source);
	
	    try {
			System.Runtime.InteropServices.Marshal.Copy(sourceConverted, startIndex, destination, length);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_InteropServices_Marshal_Copy_1")]
	internal static void /* System.Void */ System_Runtime_InteropServices_Marshal_Copy_1(void* /* System.Char[] */ source, int /* System.Int32 */ startIndex, nint /* System.IntPtr */ destination, int /* System.Int32 */ length, void** /* System.Exception */ __outException)
	{
		System.Char[] sourceConverted = InteropUtils.GetInstance<System.Char[]>(source);
	
	    try {
			System.Runtime.InteropServices.Marshal.Copy(sourceConverted, startIndex, destination, length);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_InteropServices_Marshal_Copy_2")]
	internal static void /* System.Void */ System_Runtime_InteropServices_Marshal_Copy_2(void* /* System.Int16[] */ source, int /* System.Int32 */ startIndex, nint /* System.IntPtr */ destination, int /* System.Int32 */ length, void** /* System.Exception */ __outException)
	{
		System.Int16[] sourceConverted = InteropUtils.GetInstance<System.Int16[]>(source);
	
	    try {
			System.Runtime.InteropServices.Marshal.Copy(sourceConverted, startIndex, destination, length);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_InteropServices_Marshal_Copy_3")]
	internal static void /* System.Void */ System_Runtime_InteropServices_Marshal_Copy_3(void* /* System.Int64[] */ source, int /* System.Int32 */ startIndex, nint /* System.IntPtr */ destination, int /* System.Int32 */ length, void** /* System.Exception */ __outException)
	{
		System.Int64[] sourceConverted = InteropUtils.GetInstance<System.Int64[]>(source);
	
	    try {
			System.Runtime.InteropServices.Marshal.Copy(sourceConverted, startIndex, destination, length);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_InteropServices_Marshal_Copy_4")]
	internal static void /* System.Void */ System_Runtime_InteropServices_Marshal_Copy_4(void* /* System.Single[] */ source, int /* System.Int32 */ startIndex, nint /* System.IntPtr */ destination, int /* System.Int32 */ length, void** /* System.Exception */ __outException)
	{
		System.Single[] sourceConverted = InteropUtils.GetInstance<System.Single[]>(source);
	
	    try {
			System.Runtime.InteropServices.Marshal.Copy(sourceConverted, startIndex, destination, length);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_InteropServices_Marshal_Copy_5")]
	internal static void /* System.Void */ System_Runtime_InteropServices_Marshal_Copy_5(void* /* System.Double[] */ source, int /* System.Int32 */ startIndex, nint /* System.IntPtr */ destination, int /* System.Int32 */ length, void** /* System.Exception */ __outException)
	{
		System.Double[] sourceConverted = InteropUtils.GetInstance<System.Double[]>(source);
	
	    try {
			System.Runtime.InteropServices.Marshal.Copy(sourceConverted, startIndex, destination, length);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_InteropServices_Marshal_Copy_6")]
	internal static void /* System.Void */ System_Runtime_InteropServices_Marshal_Copy_6(void* /* System.Byte[] */ source, int /* System.Int32 */ startIndex, nint /* System.IntPtr */ destination, int /* System.Int32 */ length, void** /* System.Exception */ __outException)
	{
		System.Byte[] sourceConverted = InteropUtils.GetInstance<System.Byte[]>(source);
	
	    try {
			System.Runtime.InteropServices.Marshal.Copy(sourceConverted, startIndex, destination, length);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_InteropServices_Marshal_Copy_7")]
	internal static void /* System.Void */ System_Runtime_InteropServices_Marshal_Copy_7(void* /* System.IntPtr[] */ source, int /* System.Int32 */ startIndex, nint /* System.IntPtr */ destination, int /* System.Int32 */ length, void** /* System.Exception */ __outException)
	{
		System.IntPtr[] sourceConverted = InteropUtils.GetInstance<System.IntPtr[]>(source);
	
	    try {
			System.Runtime.InteropServices.Marshal.Copy(sourceConverted, startIndex, destination, length);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_InteropServices_Marshal_Copy_8")]
	internal static void /* System.Void */ System_Runtime_InteropServices_Marshal_Copy_8(nint /* System.IntPtr */ source, void* /* System.Int32[] */ destination, int /* System.Int32 */ startIndex, int /* System.Int32 */ length, void** /* System.Exception */ __outException)
	{
		System.Int32[] destinationConverted = InteropUtils.GetInstance<System.Int32[]>(destination);
	
	    try {
			System.Runtime.InteropServices.Marshal.Copy(source, destinationConverted, startIndex, length);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_InteropServices_Marshal_Copy_9")]
	internal static void /* System.Void */ System_Runtime_InteropServices_Marshal_Copy_9(nint /* System.IntPtr */ source, void* /* System.Char[] */ destination, int /* System.Int32 */ startIndex, int /* System.Int32 */ length, void** /* System.Exception */ __outException)
	{
		System.Char[] destinationConverted = InteropUtils.GetInstance<System.Char[]>(destination);
	
	    try {
			System.Runtime.InteropServices.Marshal.Copy(source, destinationConverted, startIndex, length);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_InteropServices_Marshal_Copy_10")]
	internal static void /* System.Void */ System_Runtime_InteropServices_Marshal_Copy_10(nint /* System.IntPtr */ source, void* /* System.Int16[] */ destination, int /* System.Int32 */ startIndex, int /* System.Int32 */ length, void** /* System.Exception */ __outException)
	{
		System.Int16[] destinationConverted = InteropUtils.GetInstance<System.Int16[]>(destination);
	
	    try {
			System.Runtime.InteropServices.Marshal.Copy(source, destinationConverted, startIndex, length);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_InteropServices_Marshal_Copy_11")]
	internal static void /* System.Void */ System_Runtime_InteropServices_Marshal_Copy_11(nint /* System.IntPtr */ source, void* /* System.Int64[] */ destination, int /* System.Int32 */ startIndex, int /* System.Int32 */ length, void** /* System.Exception */ __outException)
	{
		System.Int64[] destinationConverted = InteropUtils.GetInstance<System.Int64[]>(destination);
	
	    try {
			System.Runtime.InteropServices.Marshal.Copy(source, destinationConverted, startIndex, length);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_InteropServices_Marshal_Copy_12")]
	internal static void /* System.Void */ System_Runtime_InteropServices_Marshal_Copy_12(nint /* System.IntPtr */ source, void* /* System.Single[] */ destination, int /* System.Int32 */ startIndex, int /* System.Int32 */ length, void** /* System.Exception */ __outException)
	{
		System.Single[] destinationConverted = InteropUtils.GetInstance<System.Single[]>(destination);
	
	    try {
			System.Runtime.InteropServices.Marshal.Copy(source, destinationConverted, startIndex, length);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_InteropServices_Marshal_Copy_13")]
	internal static void /* System.Void */ System_Runtime_InteropServices_Marshal_Copy_13(nint /* System.IntPtr */ source, void* /* System.Double[] */ destination, int /* System.Int32 */ startIndex, int /* System.Int32 */ length, void** /* System.Exception */ __outException)
	{
		System.Double[] destinationConverted = InteropUtils.GetInstance<System.Double[]>(destination);
	
	    try {
			System.Runtime.InteropServices.Marshal.Copy(source, destinationConverted, startIndex, length);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_InteropServices_Marshal_Copy_14")]
	internal static void /* System.Void */ System_Runtime_InteropServices_Marshal_Copy_14(nint /* System.IntPtr */ source, void* /* System.Byte[] */ destination, int /* System.Int32 */ startIndex, int /* System.Int32 */ length, void** /* System.Exception */ __outException)
	{
		System.Byte[] destinationConverted = InteropUtils.GetInstance<System.Byte[]>(destination);
	
	    try {
			System.Runtime.InteropServices.Marshal.Copy(source, destinationConverted, startIndex, length);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_InteropServices_Marshal_Copy_15")]
	internal static void /* System.Void */ System_Runtime_InteropServices_Marshal_Copy_15(nint /* System.IntPtr */ source, void* /* System.IntPtr[] */ destination, int /* System.Int32 */ startIndex, int /* System.Int32 */ length, void** /* System.Exception */ __outException)
	{
		System.IntPtr[] destinationConverted = InteropUtils.GetInstance<System.IntPtr[]>(destination);
	
	    try {
			System.Runtime.InteropServices.Marshal.Copy(source, destinationConverted, startIndex, length);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_InteropServices_Marshal_ReadByte_1")]
	internal static byte /* System.Byte */ System_Runtime_InteropServices_Marshal_ReadByte_1(nint /* System.IntPtr */ ptr, int /* System.Int32 */ ofs, void** /* System.Exception */ __outException)
	{
	
	    try {
			System.Byte __returnValue = System.Runtime.InteropServices.Marshal.ReadByte(ptr, ofs);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_InteropServices_Marshal_ReadByte_2")]
	internal static byte /* System.Byte */ System_Runtime_InteropServices_Marshal_ReadByte_2(nint /* System.IntPtr */ ptr, void** /* System.Exception */ __outException)
	{
	
	    try {
			System.Byte __returnValue = System.Runtime.InteropServices.Marshal.ReadByte(ptr);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_InteropServices_Marshal_ReadInt16_1")]
	internal static short /* System.Int16 */ System_Runtime_InteropServices_Marshal_ReadInt16_1(nint /* System.IntPtr */ ptr, int /* System.Int32 */ ofs, void** /* System.Exception */ __outException)
	{
	
	    try {
			System.Int16 __returnValue = System.Runtime.InteropServices.Marshal.ReadInt16(ptr, ofs);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_InteropServices_Marshal_ReadInt16_2")]
	internal static short /* System.Int16 */ System_Runtime_InteropServices_Marshal_ReadInt16_2(nint /* System.IntPtr */ ptr, void** /* System.Exception */ __outException)
	{
	
	    try {
			System.Int16 __returnValue = System.Runtime.InteropServices.Marshal.ReadInt16(ptr);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_InteropServices_Marshal_ReadInt32_1")]
	internal static int /* System.Int32 */ System_Runtime_InteropServices_Marshal_ReadInt32_1(nint /* System.IntPtr */ ptr, int /* System.Int32 */ ofs, void** /* System.Exception */ __outException)
	{
	
	    try {
			System.Int32 __returnValue = System.Runtime.InteropServices.Marshal.ReadInt32(ptr, ofs);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_InteropServices_Marshal_ReadInt32_2")]
	internal static int /* System.Int32 */ System_Runtime_InteropServices_Marshal_ReadInt32_2(nint /* System.IntPtr */ ptr, void** /* System.Exception */ __outException)
	{
	
	    try {
			System.Int32 __returnValue = System.Runtime.InteropServices.Marshal.ReadInt32(ptr);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_InteropServices_Marshal_ReadIntPtr")]
	internal static nint /* System.IntPtr */ System_Runtime_InteropServices_Marshal_ReadIntPtr(void* /* System.Object */ ptr, int /* System.Int32 */ ofs, void** /* System.Exception */ __outException)
	{
		System.Object ptrConverted = InteropUtils.GetInstance<System.Object>(ptr);
	
	    try {
			System.IntPtr __returnValue = System.Runtime.InteropServices.Marshal.ReadIntPtr(ptrConverted, ofs);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return nint.Zero;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_InteropServices_Marshal_ReadIntPtr_1")]
	internal static nint /* System.IntPtr */ System_Runtime_InteropServices_Marshal_ReadIntPtr_1(nint /* System.IntPtr */ ptr, int /* System.Int32 */ ofs, void** /* System.Exception */ __outException)
	{
	
	    try {
			System.IntPtr __returnValue = System.Runtime.InteropServices.Marshal.ReadIntPtr(ptr, ofs);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return nint.Zero;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_InteropServices_Marshal_ReadIntPtr_2")]
	internal static nint /* System.IntPtr */ System_Runtime_InteropServices_Marshal_ReadIntPtr_2(nint /* System.IntPtr */ ptr, void** /* System.Exception */ __outException)
	{
	
	    try {
			System.IntPtr __returnValue = System.Runtime.InteropServices.Marshal.ReadIntPtr(ptr);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return nint.Zero;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_InteropServices_Marshal_ReadInt64_1")]
	internal static long /* System.Int64 */ System_Runtime_InteropServices_Marshal_ReadInt64_1(nint /* System.IntPtr */ ptr, int /* System.Int32 */ ofs, void** /* System.Exception */ __outException)
	{
	
	    try {
			System.Int64 __returnValue = System.Runtime.InteropServices.Marshal.ReadInt64(ptr, ofs);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_InteropServices_Marshal_ReadInt64_2")]
	internal static long /* System.Int64 */ System_Runtime_InteropServices_Marshal_ReadInt64_2(nint /* System.IntPtr */ ptr, void** /* System.Exception */ __outException)
	{
	
	    try {
			System.Int64 __returnValue = System.Runtime.InteropServices.Marshal.ReadInt64(ptr);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_InteropServices_Marshal_WriteByte_1")]
	internal static void /* System.Void */ System_Runtime_InteropServices_Marshal_WriteByte_1(nint /* System.IntPtr */ ptr, int /* System.Int32 */ ofs, byte /* System.Byte */ val, void** /* System.Exception */ __outException)
	{
	
	    try {
			System.Runtime.InteropServices.Marshal.WriteByte(ptr, ofs, val);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_InteropServices_Marshal_WriteByte_2")]
	internal static void /* System.Void */ System_Runtime_InteropServices_Marshal_WriteByte_2(nint /* System.IntPtr */ ptr, byte /* System.Byte */ val, void** /* System.Exception */ __outException)
	{
	
	    try {
			System.Runtime.InteropServices.Marshal.WriteByte(ptr, val);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_InteropServices_Marshal_WriteInt32_1")]
	internal static void /* System.Void */ System_Runtime_InteropServices_Marshal_WriteInt32_1(nint /* System.IntPtr */ ptr, int /* System.Int32 */ ofs, int /* System.Int32 */ val, void** /* System.Exception */ __outException)
	{
	
	    try {
			System.Runtime.InteropServices.Marshal.WriteInt32(ptr, ofs, val);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_InteropServices_Marshal_WriteInt32_2")]
	internal static void /* System.Void */ System_Runtime_InteropServices_Marshal_WriteInt32_2(nint /* System.IntPtr */ ptr, int /* System.Int32 */ val, void** /* System.Exception */ __outException)
	{
	
	    try {
			System.Runtime.InteropServices.Marshal.WriteInt32(ptr, val);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_InteropServices_Marshal_WriteIntPtr")]
	internal static void /* System.Void */ System_Runtime_InteropServices_Marshal_WriteIntPtr(nint /* System.IntPtr */ ptr, int /* System.Int32 */ ofs, nint /* System.IntPtr */ val, void** /* System.Exception */ __outException)
	{
	
	    try {
			System.Runtime.InteropServices.Marshal.WriteIntPtr(ptr, ofs, val);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_InteropServices_Marshal_WriteIntPtr_1")]
	internal static void /* System.Void */ System_Runtime_InteropServices_Marshal_WriteIntPtr_1(void* /* System.Object */ ptr, int /* System.Int32 */ ofs, nint /* System.IntPtr */ val, void** /* System.Exception */ __outException)
	{
		System.Object ptrConverted = InteropUtils.GetInstance<System.Object>(ptr);
	
	    try {
			System.Runtime.InteropServices.Marshal.WriteIntPtr(ptrConverted, ofs, val);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_InteropServices_Marshal_WriteIntPtr_2")]
	internal static void /* System.Void */ System_Runtime_InteropServices_Marshal_WriteIntPtr_2(nint /* System.IntPtr */ ptr, nint /* System.IntPtr */ val, void** /* System.Exception */ __outException)
	{
	
	    try {
			System.Runtime.InteropServices.Marshal.WriteIntPtr(ptr, val);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_InteropServices_Marshal_WriteInt64_1")]
	internal static void /* System.Void */ System_Runtime_InteropServices_Marshal_WriteInt64_1(nint /* System.IntPtr */ ptr, int /* System.Int32 */ ofs, long /* System.Int64 */ val, void** /* System.Exception */ __outException)
	{
	
	    try {
			System.Runtime.InteropServices.Marshal.WriteInt64(ptr, ofs, val);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_InteropServices_Marshal_WriteInt64_2")]
	internal static void /* System.Void */ System_Runtime_InteropServices_Marshal_WriteInt64_2(nint /* System.IntPtr */ ptr, long /* System.Int64 */ val, void** /* System.Exception */ __outException)
	{
	
	    try {
			System.Runtime.InteropServices.Marshal.WriteInt64(ptr, val);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_InteropServices_Marshal_Prelink")]
	internal static void /* System.Void */ System_Runtime_InteropServices_Marshal_Prelink(void* /* System.Reflection.MethodInfo */ m, void** /* System.Exception */ __outException)
	{
		System.Reflection.MethodInfo mConverted = InteropUtils.GetInstance<System.Reflection.MethodInfo>(m);
	
	    try {
			System.Runtime.InteropServices.Marshal.Prelink(mConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_InteropServices_Marshal_PrelinkAll")]
	internal static void /* System.Void */ System_Runtime_InteropServices_Marshal_PrelinkAll(void* /* System.Type */ c, void** /* System.Exception */ __outException)
	{
		System.Type cConverted = InteropUtils.GetInstance<System.Type>(c);
	
	    try {
			System.Runtime.InteropServices.Marshal.PrelinkAll(cConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_InteropServices_Marshal_PtrToStructure")]
	internal static void* /* System.Object */ System_Runtime_InteropServices_Marshal_PtrToStructure(nint /* System.IntPtr */ ptr, void* /* System.Type */ structureType, void** /* System.Exception */ __outException)
	{
		System.Type structureTypeConverted = InteropUtils.GetInstance<System.Type>(structureType);
	
	    try {
			System.Object __returnValue = System.Runtime.InteropServices.Marshal.PtrToStructure(ptr, structureTypeConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_InteropServices_Marshal_PtrToStructure_1")]
	internal static void /* System.Void */ System_Runtime_InteropServices_Marshal_PtrToStructure_1(nint /* System.IntPtr */ ptr, void* /* System.Object */ structure, void** /* System.Exception */ __outException)
	{
		System.Object structureConverted = InteropUtils.GetInstance<System.Object>(structure);
	
	    try {
			System.Runtime.InteropServices.Marshal.PtrToStructure(ptr, structureConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_InteropServices_Marshal_DestroyStructure_A1")]
	internal static void /* System.Void */ System_Runtime_InteropServices_Marshal_DestroyStructure_A1(void* /* System.Type */ T, nint /* System.IntPtr */ ptr, void** /* System.Exception */ __outException)
	{
		System.Type TConverted = InteropUtils.GetInstance<System.Type>(T);
	
	    try {
			System.Type __targetTypeForGenericCall = typeof(System.Runtime.InteropServices.Marshal);
			System.String __memberNameForGenericCall = nameof(System.Runtime.InteropServices.Marshal.DestroyStructure);
			System.Object? __methodTargetForGenericCall = null;
	
			System.Object[] __parametersForGenericCall = new System.Object[] { ptr };
			System.Type[] __parameterTypesForGenericCall = new System.Type[] { typeof(System.IntPtr) };
	
			System.Type[] __genericParameterTypesForGenericCall = new System.Type[] { TConverted };
	
			System.Reflection.MethodInfo __methodForGenericCall = __targetTypeForGenericCall.GetMethod(__memberNameForGenericCall, 1, __parameterTypesForGenericCall) ?? throw new Exception("Method DestroyStructure not found");
			System.Reflection.MethodInfo __genericMethodForGenericCall = __methodForGenericCall.MakeGenericMethod(__genericParameterTypesForGenericCall);
	
			__genericMethodForGenericCall.Invoke(__methodTargetForGenericCall, __parametersForGenericCall);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_InteropServices_Marshal_GetHINSTANCE")]
	internal static nint /* System.IntPtr */ System_Runtime_InteropServices_Marshal_GetHINSTANCE(void* /* System.Reflection.Module */ m, void** /* System.Exception */ __outException)
	{
		System.Reflection.Module mConverted = InteropUtils.GetInstance<System.Reflection.Module>(m);
	
	    try {
			System.IntPtr __returnValue = System.Runtime.InteropServices.Marshal.GetHINSTANCE(mConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return nint.Zero;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_InteropServices_Marshal_GetExceptionForHR")]
	internal static void* /* System.Exception */ System_Runtime_InteropServices_Marshal_GetExceptionForHR(int /* System.Int32 */ errorCode, void** /* System.Exception */ __outException)
	{
	
	    try {
			System.Exception __returnValue = System.Runtime.InteropServices.Marshal.GetExceptionForHR(errorCode);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_InteropServices_Marshal_GetExceptionForHR_1")]
	internal static void* /* System.Exception */ System_Runtime_InteropServices_Marshal_GetExceptionForHR_1(int /* System.Int32 */ errorCode, nint /* System.IntPtr */ errorInfo, void** /* System.Exception */ __outException)
	{
	
	    try {
			System.Exception __returnValue = System.Runtime.InteropServices.Marshal.GetExceptionForHR(errorCode, errorInfo);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_InteropServices_Marshal_ThrowExceptionForHR")]
	internal static void /* System.Void */ System_Runtime_InteropServices_Marshal_ThrowExceptionForHR(int /* System.Int32 */ errorCode, void** /* System.Exception */ __outException)
	{
	
	    try {
			System.Runtime.InteropServices.Marshal.ThrowExceptionForHR(errorCode);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_InteropServices_Marshal_ThrowExceptionForHR_1")]
	internal static void /* System.Void */ System_Runtime_InteropServices_Marshal_ThrowExceptionForHR_1(int /* System.Int32 */ errorCode, nint /* System.IntPtr */ errorInfo, void** /* System.Exception */ __outException)
	{
	
	    try {
			System.Runtime.InteropServices.Marshal.ThrowExceptionForHR(errorCode, errorInfo);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_InteropServices_Marshal_SecureStringToBSTR")]
	internal static nint /* System.IntPtr */ System_Runtime_InteropServices_Marshal_SecureStringToBSTR(void* /* System.Security.SecureString */ s, void** /* System.Exception */ __outException)
	{
		System.Security.SecureString sConverted = InteropUtils.GetInstance<System.Security.SecureString>(s);
	
	    try {
			System.IntPtr __returnValue = System.Runtime.InteropServices.Marshal.SecureStringToBSTR(sConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return nint.Zero;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_InteropServices_Marshal_SecureStringToCoTaskMemAnsi")]
	internal static nint /* System.IntPtr */ System_Runtime_InteropServices_Marshal_SecureStringToCoTaskMemAnsi(void* /* System.Security.SecureString */ s, void** /* System.Exception */ __outException)
	{
		System.Security.SecureString sConverted = InteropUtils.GetInstance<System.Security.SecureString>(s);
	
	    try {
			System.IntPtr __returnValue = System.Runtime.InteropServices.Marshal.SecureStringToCoTaskMemAnsi(sConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return nint.Zero;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_InteropServices_Marshal_SecureStringToCoTaskMemUnicode")]
	internal static nint /* System.IntPtr */ System_Runtime_InteropServices_Marshal_SecureStringToCoTaskMemUnicode(void* /* System.Security.SecureString */ s, void** /* System.Exception */ __outException)
	{
		System.Security.SecureString sConverted = InteropUtils.GetInstance<System.Security.SecureString>(s);
	
	    try {
			System.IntPtr __returnValue = System.Runtime.InteropServices.Marshal.SecureStringToCoTaskMemUnicode(sConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return nint.Zero;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_InteropServices_Marshal_SecureStringToGlobalAllocAnsi")]
	internal static nint /* System.IntPtr */ System_Runtime_InteropServices_Marshal_SecureStringToGlobalAllocAnsi(void* /* System.Security.SecureString */ s, void** /* System.Exception */ __outException)
	{
		System.Security.SecureString sConverted = InteropUtils.GetInstance<System.Security.SecureString>(s);
	
	    try {
			System.IntPtr __returnValue = System.Runtime.InteropServices.Marshal.SecureStringToGlobalAllocAnsi(sConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return nint.Zero;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_InteropServices_Marshal_SecureStringToGlobalAllocUnicode")]
	internal static nint /* System.IntPtr */ System_Runtime_InteropServices_Marshal_SecureStringToGlobalAllocUnicode(void* /* System.Security.SecureString */ s, void** /* System.Exception */ __outException)
	{
		System.Security.SecureString sConverted = InteropUtils.GetInstance<System.Security.SecureString>(s);
	
	    try {
			System.IntPtr __returnValue = System.Runtime.InteropServices.Marshal.SecureStringToGlobalAllocUnicode(sConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return nint.Zero;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_InteropServices_Marshal_StringToHGlobalAnsi")]
	internal static nint /* System.IntPtr */ System_Runtime_InteropServices_Marshal_StringToHGlobalAnsi(void* /* System.String */ s, void** /* System.Exception */ __outException)
	{
		System.String sConverted = InteropUtils.GetInstance<System.String>(s);
	
	    try {
			System.IntPtr __returnValue = System.Runtime.InteropServices.Marshal.StringToHGlobalAnsi(sConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return nint.Zero;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_InteropServices_Marshal_StringToHGlobalUni")]
	internal static nint /* System.IntPtr */ System_Runtime_InteropServices_Marshal_StringToHGlobalUni(void* /* System.String */ s, void** /* System.Exception */ __outException)
	{
		System.String sConverted = InteropUtils.GetInstance<System.String>(s);
	
	    try {
			System.IntPtr __returnValue = System.Runtime.InteropServices.Marshal.StringToHGlobalUni(sConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return nint.Zero;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_InteropServices_Marshal_StringToCoTaskMemUni")]
	internal static nint /* System.IntPtr */ System_Runtime_InteropServices_Marshal_StringToCoTaskMemUni(void* /* System.String */ s, void** /* System.Exception */ __outException)
	{
		System.String sConverted = InteropUtils.GetInstance<System.String>(s);
	
	    try {
			System.IntPtr __returnValue = System.Runtime.InteropServices.Marshal.StringToCoTaskMemUni(sConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return nint.Zero;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_InteropServices_Marshal_StringToCoTaskMemUTF8")]
	internal static nint /* System.IntPtr */ System_Runtime_InteropServices_Marshal_StringToCoTaskMemUTF8(void* /* System.String */ s, void** /* System.Exception */ __outException)
	{
		System.String sConverted = InteropUtils.GetInstance<System.String>(s);
	
	    try {
			System.IntPtr __returnValue = System.Runtime.InteropServices.Marshal.StringToCoTaskMemUTF8(sConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return nint.Zero;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_InteropServices_Marshal_StringToCoTaskMemAnsi")]
	internal static nint /* System.IntPtr */ System_Runtime_InteropServices_Marshal_StringToCoTaskMemAnsi(void* /* System.String */ s, void** /* System.Exception */ __outException)
	{
		System.String sConverted = InteropUtils.GetInstance<System.String>(s);
	
	    try {
			System.IntPtr __returnValue = System.Runtime.InteropServices.Marshal.StringToCoTaskMemAnsi(sConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return nint.Zero;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_InteropServices_Marshal_GenerateGuidForType")]
	internal static void* /* System.Guid */ System_Runtime_InteropServices_Marshal_GenerateGuidForType(void* /* System.Type */ type, void** /* System.Exception */ __outException)
	{
		System.Type typeConverted = InteropUtils.GetInstance<System.Type>(type);
	
	    try {
			System.Guid __returnValue = System.Runtime.InteropServices.Marshal.GenerateGuidForType(typeConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_InteropServices_Marshal_GenerateProgIdForType")]
	internal static void* /* System.String */ System_Runtime_InteropServices_Marshal_GenerateProgIdForType(void* /* System.Type */ type, void** /* System.Exception */ __outException)
	{
		System.Type typeConverted = InteropUtils.GetInstance<System.Type>(type);
	
	    try {
			System.String __returnValue = System.Runtime.InteropServices.Marshal.GenerateProgIdForType(typeConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_InteropServices_Marshal_GetDelegateForFunctionPointer")]
	internal static void* /* System.Delegate */ System_Runtime_InteropServices_Marshal_GetDelegateForFunctionPointer(nint /* System.IntPtr */ ptr, void* /* System.Type */ t, void** /* System.Exception */ __outException)
	{
		System.Type tConverted = InteropUtils.GetInstance<System.Type>(t);
	
	    try {
			System.Delegate __returnValue = System.Runtime.InteropServices.Marshal.GetDelegateForFunctionPointer(ptr, tConverted);
			void* __returnValueNative = new System_Delegate(__returnValue).AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_InteropServices_Marshal_GetFunctionPointerForDelegate")]
	internal static nint /* System.IntPtr */ System_Runtime_InteropServices_Marshal_GetFunctionPointerForDelegate(void* /* System.Delegate */ d, void** /* System.Exception */ __outException)
	{
		System.Delegate dConverted = InteropUtils.GetInstance<System_Delegate>(d)?.Trampoline;
	
	    try {
			System.IntPtr __returnValue = System.Runtime.InteropServices.Marshal.GetFunctionPointerForDelegate(dConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return nint.Zero;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_InteropServices_Marshal_GetHRForLastWin32Error")]
	internal static int /* System.Int32 */ System_Runtime_InteropServices_Marshal_GetHRForLastWin32Error(void** /* System.Exception */ __outException)
	{
	
	    try {
			System.Int32 __returnValue = System.Runtime.InteropServices.Marshal.GetHRForLastWin32Error();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_InteropServices_Marshal_ZeroFreeBSTR")]
	internal static void /* System.Void */ System_Runtime_InteropServices_Marshal_ZeroFreeBSTR(nint /* System.IntPtr */ s, void** /* System.Exception */ __outException)
	{
	
	    try {
			System.Runtime.InteropServices.Marshal.ZeroFreeBSTR(s);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_InteropServices_Marshal_ZeroFreeCoTaskMemAnsi")]
	internal static void /* System.Void */ System_Runtime_InteropServices_Marshal_ZeroFreeCoTaskMemAnsi(nint /* System.IntPtr */ s, void** /* System.Exception */ __outException)
	{
	
	    try {
			System.Runtime.InteropServices.Marshal.ZeroFreeCoTaskMemAnsi(s);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_InteropServices_Marshal_ZeroFreeCoTaskMemUnicode")]
	internal static void /* System.Void */ System_Runtime_InteropServices_Marshal_ZeroFreeCoTaskMemUnicode(nint /* System.IntPtr */ s, void** /* System.Exception */ __outException)
	{
	
	    try {
			System.Runtime.InteropServices.Marshal.ZeroFreeCoTaskMemUnicode(s);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_InteropServices_Marshal_ZeroFreeCoTaskMemUTF8")]
	internal static void /* System.Void */ System_Runtime_InteropServices_Marshal_ZeroFreeCoTaskMemUTF8(nint /* System.IntPtr */ s, void** /* System.Exception */ __outException)
	{
	
	    try {
			System.Runtime.InteropServices.Marshal.ZeroFreeCoTaskMemUTF8(s);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_InteropServices_Marshal_ZeroFreeGlobalAllocAnsi")]
	internal static void /* System.Void */ System_Runtime_InteropServices_Marshal_ZeroFreeGlobalAllocAnsi(nint /* System.IntPtr */ s, void** /* System.Exception */ __outException)
	{
	
	    try {
			System.Runtime.InteropServices.Marshal.ZeroFreeGlobalAllocAnsi(s);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_InteropServices_Marshal_ZeroFreeGlobalAllocUnicode")]
	internal static void /* System.Void */ System_Runtime_InteropServices_Marshal_ZeroFreeGlobalAllocUnicode(nint /* System.IntPtr */ s, void** /* System.Exception */ __outException)
	{
	
	    try {
			System.Runtime.InteropServices.Marshal.ZeroFreeGlobalAllocUnicode(s);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_InteropServices_Marshal_StringToBSTR")]
	internal static nint /* System.IntPtr */ System_Runtime_InteropServices_Marshal_StringToBSTR(void* /* System.String */ s, void** /* System.Exception */ __outException)
	{
		System.String sConverted = InteropUtils.GetInstance<System.String>(s);
	
	    try {
			System.IntPtr __returnValue = System.Runtime.InteropServices.Marshal.StringToBSTR(sConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return nint.Zero;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_InteropServices_Marshal_PtrToStringBSTR")]
	internal static void* /* System.String */ System_Runtime_InteropServices_Marshal_PtrToStringBSTR(nint /* System.IntPtr */ ptr, void** /* System.Exception */ __outException)
	{
	
	    try {
			System.String __returnValue = System.Runtime.InteropServices.Marshal.PtrToStringBSTR(ptr);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_InteropServices_Marshal_GetTypeFromCLSID")]
	internal static void* /* System.Type */ System_Runtime_InteropServices_Marshal_GetTypeFromCLSID(void* /* System.Guid */ clsid, void** /* System.Exception */ __outException)
	{
		System.Guid clsidConverted = InteropUtils.GetInstance<System.Guid>(clsid);
	
	    try {
			System.Type __returnValue = System.Runtime.InteropServices.Marshal.GetTypeFromCLSID(clsidConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_InteropServices_Marshal_InitHandle")]
	internal static void /* System.Void */ System_Runtime_InteropServices_Marshal_InitHandle(void* /* System.Runtime.InteropServices.SafeHandle */ safeHandle, nint /* System.IntPtr */ handle, void** /* System.Exception */ __outException)
	{
		System.Runtime.InteropServices.SafeHandle safeHandleConverted = InteropUtils.GetInstance<System.Runtime.InteropServices.SafeHandle>(safeHandle);
	
	    try {
			System.Runtime.InteropServices.Marshal.InitHandle(safeHandleConverted, handle);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_InteropServices_Marshal_GetLastWin32Error")]
	internal static int /* System.Int32 */ System_Runtime_InteropServices_Marshal_GetLastWin32Error(void** /* System.Exception */ __outException)
	{
	
	    try {
			System.Int32 __returnValue = System.Runtime.InteropServices.Marshal.GetLastWin32Error();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_InteropServices_Marshal_GetLastPInvokeErrorMessage")]
	internal static void* /* System.String */ System_Runtime_InteropServices_Marshal_GetLastPInvokeErrorMessage(void** /* System.Exception */ __outException)
	{
	
	    try {
			System.String __returnValue = System.Runtime.InteropServices.Marshal.GetLastPInvokeErrorMessage();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_InteropServices_Marshal_GetHRForException")]
	internal static int /* System.Int32 */ System_Runtime_InteropServices_Marshal_GetHRForException(void* /* System.Exception */ e, void** /* System.Exception */ __outException)
	{
		System.Exception eConverted = InteropUtils.GetInstance<System.Exception>(e);
	
	    try {
			System.Int32 __returnValue = System.Runtime.InteropServices.Marshal.GetHRForException(eConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_InteropServices_Marshal_AreComObjectsAvailableForCleanup")]
	internal static byte /* System.Boolean */ System_Runtime_InteropServices_Marshal_AreComObjectsAvailableForCleanup(void** /* System.Exception */ __outException)
	{
	
	    try {
			System.Boolean __returnValue = System.Runtime.InteropServices.Marshal.AreComObjectsAvailableForCleanup();
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_InteropServices_Marshal_CreateAggregatedObject")]
	internal static nint /* System.IntPtr */ System_Runtime_InteropServices_Marshal_CreateAggregatedObject(nint /* System.IntPtr */ pOuter, void* /* System.Object */ o, void** /* System.Exception */ __outException)
	{
		System.Object oConverted = InteropUtils.GetInstance<System.Object>(o);
	
	    try {
			System.IntPtr __returnValue = System.Runtime.InteropServices.Marshal.CreateAggregatedObject(pOuter, oConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return nint.Zero;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_InteropServices_Marshal_BindToMoniker")]
	internal static void* /* System.Object */ System_Runtime_InteropServices_Marshal_BindToMoniker(void* /* System.String */ monikerName, void** /* System.Exception */ __outException)
	{
		System.String monikerNameConverted = InteropUtils.GetInstance<System.String>(monikerName);
	
	    try {
			System.Object __returnValue = System.Runtime.InteropServices.Marshal.BindToMoniker(monikerNameConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_InteropServices_Marshal_CleanupUnusedObjectsInCurrentContext")]
	internal static void /* System.Void */ System_Runtime_InteropServices_Marshal_CleanupUnusedObjectsInCurrentContext(void** /* System.Exception */ __outException)
	{
	
	    try {
			System.Runtime.InteropServices.Marshal.CleanupUnusedObjectsInCurrentContext();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_InteropServices_Marshal_CreateWrapperOfType")]
	internal static void* /* System.Object */ System_Runtime_InteropServices_Marshal_CreateWrapperOfType(void* /* System.Object */ o, void* /* System.Type */ t, void** /* System.Exception */ __outException)
	{
		System.Object oConverted = InteropUtils.GetInstance<System.Object>(o);
		System.Type tConverted = InteropUtils.GetInstance<System.Type>(t);
	
	    try {
			System.Object __returnValue = System.Runtime.InteropServices.Marshal.CreateWrapperOfType(oConverted, tConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_InteropServices_Marshal_ChangeWrapperHandleStrength")]
	internal static void /* System.Void */ System_Runtime_InteropServices_Marshal_ChangeWrapperHandleStrength(void* /* System.Object */ otp, byte /* System.Boolean */ fIsWeak, void** /* System.Exception */ __outException)
	{
		System.Object otpConverted = InteropUtils.GetInstance<System.Object>(otp);
		System.Boolean fIsWeakConverted = fIsWeak.ToBool();
	
	    try {
			System.Runtime.InteropServices.Marshal.ChangeWrapperHandleStrength(otpConverted, fIsWeakConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_InteropServices_Marshal_FinalReleaseComObject")]
	internal static int /* System.Int32 */ System_Runtime_InteropServices_Marshal_FinalReleaseComObject(void* /* System.Object */ o, void** /* System.Exception */ __outException)
	{
		System.Object oConverted = InteropUtils.GetInstance<System.Object>(o);
	
	    try {
			System.Int32 __returnValue = System.Runtime.InteropServices.Marshal.FinalReleaseComObject(oConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_InteropServices_Marshal_GetComInterfaceForObject")]
	internal static nint /* System.IntPtr */ System_Runtime_InteropServices_Marshal_GetComInterfaceForObject(void* /* System.Object */ o, void* /* System.Type */ T, void** /* System.Exception */ __outException)
	{
		System.Object oConverted = InteropUtils.GetInstance<System.Object>(o);
		System.Type TConverted = InteropUtils.GetInstance<System.Type>(T);
	
	    try {
			System.IntPtr __returnValue = System.Runtime.InteropServices.Marshal.GetComInterfaceForObject(oConverted, TConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return nint.Zero;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_InteropServices_Marshal_GetComInterfaceForObject_1")]
	internal static nint /* System.IntPtr */ System_Runtime_InteropServices_Marshal_GetComInterfaceForObject_1(void* /* System.Object */ o, void* /* System.Type */ T, System.Runtime.InteropServices.CustomQueryInterfaceMode /* System.Runtime.InteropServices.CustomQueryInterfaceMode */ mode, void** /* System.Exception */ __outException)
	{
		System.Object oConverted = InteropUtils.GetInstance<System.Object>(o);
		System.Type TConverted = InteropUtils.GetInstance<System.Type>(T);
	
	    try {
			System.IntPtr __returnValue = System.Runtime.InteropServices.Marshal.GetComInterfaceForObject(oConverted, TConverted, mode);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return nint.Zero;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_InteropServices_Marshal_GetComObjectData")]
	internal static void* /* System.Object */ System_Runtime_InteropServices_Marshal_GetComObjectData(void* /* System.Object */ obj, void* /* System.Object */ key, void** /* System.Exception */ __outException)
	{
		System.Object objConverted = InteropUtils.GetInstance<System.Object>(obj);
		System.Object keyConverted = InteropUtils.GetInstance<System.Object>(key);
	
	    try {
			System.Object __returnValue = System.Runtime.InteropServices.Marshal.GetComObjectData(objConverted, keyConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_InteropServices_Marshal_GetIDispatchForObject")]
	internal static nint /* System.IntPtr */ System_Runtime_InteropServices_Marshal_GetIDispatchForObject(void* /* System.Object */ o, void** /* System.Exception */ __outException)
	{
		System.Object oConverted = InteropUtils.GetInstance<System.Object>(o);
	
	    try {
			System.IntPtr __returnValue = System.Runtime.InteropServices.Marshal.GetIDispatchForObject(oConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return nint.Zero;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_InteropServices_Marshal_GetIUnknownForObject")]
	internal static nint /* System.IntPtr */ System_Runtime_InteropServices_Marshal_GetIUnknownForObject(void* /* System.Object */ o, void** /* System.Exception */ __outException)
	{
		System.Object oConverted = InteropUtils.GetInstance<System.Object>(o);
	
	    try {
			System.IntPtr __returnValue = System.Runtime.InteropServices.Marshal.GetIUnknownForObject(oConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return nint.Zero;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_InteropServices_Marshal_GetNativeVariantForObject")]
	internal static void /* System.Void */ System_Runtime_InteropServices_Marshal_GetNativeVariantForObject(void* /* System.Object */ obj, nint /* System.IntPtr */ pDstNativeVariant, void** /* System.Exception */ __outException)
	{
		System.Object objConverted = InteropUtils.GetInstance<System.Object>(obj);
	
	    try {
			System.Runtime.InteropServices.Marshal.GetNativeVariantForObject(objConverted, pDstNativeVariant);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_InteropServices_Marshal_GetTypedObjectForIUnknown")]
	internal static void* /* System.Object */ System_Runtime_InteropServices_Marshal_GetTypedObjectForIUnknown(nint /* System.IntPtr */ pUnk, void* /* System.Type */ t, void** /* System.Exception */ __outException)
	{
		System.Type tConverted = InteropUtils.GetInstance<System.Type>(t);
	
	    try {
			System.Object __returnValue = System.Runtime.InteropServices.Marshal.GetTypedObjectForIUnknown(pUnk, tConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_InteropServices_Marshal_GetObjectForIUnknown")]
	internal static void* /* System.Object */ System_Runtime_InteropServices_Marshal_GetObjectForIUnknown(nint /* System.IntPtr */ pUnk, void** /* System.Exception */ __outException)
	{
	
	    try {
			System.Object __returnValue = System.Runtime.InteropServices.Marshal.GetObjectForIUnknown(pUnk);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_InteropServices_Marshal_GetObjectForNativeVariant")]
	internal static void* /* System.Object */ System_Runtime_InteropServices_Marshal_GetObjectForNativeVariant(nint /* System.IntPtr */ pSrcNativeVariant, void** /* System.Exception */ __outException)
	{
	
	    try {
			System.Object __returnValue = System.Runtime.InteropServices.Marshal.GetObjectForNativeVariant(pSrcNativeVariant);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_InteropServices_Marshal_GetObjectsForNativeVariants")]
	internal static void* /* System.Object[] */ System_Runtime_InteropServices_Marshal_GetObjectsForNativeVariants(nint /* System.IntPtr */ aSrcNativeVariant, int /* System.Int32 */ cVars, void** /* System.Exception */ __outException)
	{
	
	    try {
			System.Object[] __returnValue = System.Runtime.InteropServices.Marshal.GetObjectsForNativeVariants(aSrcNativeVariant, cVars);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_InteropServices_Marshal_GetObjectsForNativeVariants_A1")]
	internal static void* /* System.Array */ System_Runtime_InteropServices_Marshal_GetObjectsForNativeVariants_A1(void* /* System.Type */ T, nint /* System.IntPtr */ aSrcNativeVariant, int /* System.Int32 */ cVars, void** /* System.Exception */ __outException)
	{
		System.Type TConverted = InteropUtils.GetInstance<System.Type>(T);
	
	    try {
			System.Type __targetTypeForGenericCall = typeof(System.Runtime.InteropServices.Marshal);
			System.String __memberNameForGenericCall = nameof(System.Runtime.InteropServices.Marshal.GetObjectsForNativeVariants);
			System.Object? __methodTargetForGenericCall = null;
	
			System.Object[] __parametersForGenericCall = new System.Object[] { aSrcNativeVariant, cVars };
			System.Type[] __parameterTypesForGenericCall = new System.Type[] { typeof(System.IntPtr), typeof(System.Int32) };
	
			System.Type[] __genericParameterTypesForGenericCall = new System.Type[] { TConverted };
	
			System.Reflection.MethodInfo __methodForGenericCall = __targetTypeForGenericCall.GetMethod(__memberNameForGenericCall, 1, __parameterTypesForGenericCall) ?? throw new Exception("Method GetObjectsForNativeVariants not found");
			System.Reflection.MethodInfo __genericMethodForGenericCall = __methodForGenericCall.MakeGenericMethod(__genericParameterTypesForGenericCall);
	
			System.Array __returnValue = (System.Array)__genericMethodForGenericCall.Invoke(__methodTargetForGenericCall, __parametersForGenericCall);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_InteropServices_Marshal_GetStartComSlot")]
	internal static int /* System.Int32 */ System_Runtime_InteropServices_Marshal_GetStartComSlot(void* /* System.Type */ t, void** /* System.Exception */ __outException)
	{
		System.Type tConverted = InteropUtils.GetInstance<System.Type>(t);
	
	    try {
			System.Int32 __returnValue = System.Runtime.InteropServices.Marshal.GetStartComSlot(tConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_InteropServices_Marshal_GetEndComSlot")]
	internal static int /* System.Int32 */ System_Runtime_InteropServices_Marshal_GetEndComSlot(void* /* System.Type */ t, void** /* System.Exception */ __outException)
	{
		System.Type tConverted = InteropUtils.GetInstance<System.Type>(t);
	
	    try {
			System.Int32 __returnValue = System.Runtime.InteropServices.Marshal.GetEndComSlot(tConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_InteropServices_Marshal_GetUniqueObjectForIUnknown")]
	internal static void* /* System.Object */ System_Runtime_InteropServices_Marshal_GetUniqueObjectForIUnknown(nint /* System.IntPtr */ unknown, void** /* System.Exception */ __outException)
	{
	
	    try {
			System.Object __returnValue = System.Runtime.InteropServices.Marshal.GetUniqueObjectForIUnknown(unknown);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_InteropServices_Marshal_IsComObject")]
	internal static byte /* System.Boolean */ System_Runtime_InteropServices_Marshal_IsComObject(void* /* System.Object */ o, void** /* System.Exception */ __outException)
	{
		System.Object oConverted = InteropUtils.GetInstance<System.Object>(o);
	
	    try {
			System.Boolean __returnValue = System.Runtime.InteropServices.Marshal.IsComObject(oConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_InteropServices_Marshal_IsTypeVisibleFromCom")]
	internal static byte /* System.Boolean */ System_Runtime_InteropServices_Marshal_IsTypeVisibleFromCom(void* /* System.Type */ t, void** /* System.Exception */ __outException)
	{
		System.Type tConverted = InteropUtils.GetInstance<System.Type>(t);
	
	    try {
			System.Boolean __returnValue = System.Runtime.InteropServices.Marshal.IsTypeVisibleFromCom(tConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_InteropServices_Marshal_ReleaseComObject")]
	internal static int /* System.Int32 */ System_Runtime_InteropServices_Marshal_ReleaseComObject(void* /* System.Object */ o, void** /* System.Exception */ __outException)
	{
		System.Object oConverted = InteropUtils.GetInstance<System.Object>(o);
	
	    try {
			System.Int32 __returnValue = System.Runtime.InteropServices.Marshal.ReleaseComObject(oConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_InteropServices_Marshal_SetComObjectData")]
	internal static byte /* System.Boolean */ System_Runtime_InteropServices_Marshal_SetComObjectData(void* /* System.Object */ obj, void* /* System.Object */ key, void* /* System.Object */ data, void** /* System.Exception */ __outException)
	{
		System.Object objConverted = InteropUtils.GetInstance<System.Object>(obj);
		System.Object keyConverted = InteropUtils.GetInstance<System.Object>(key);
		System.Object dataConverted = InteropUtils.GetInstance<System.Object>(data);
	
	    try {
			System.Boolean __returnValue = System.Runtime.InteropServices.Marshal.SetComObjectData(objConverted, keyConverted, dataConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_InteropServices_Marshal_PtrToStringAuto")]
	internal static void* /* System.String */ System_Runtime_InteropServices_Marshal_PtrToStringAuto(nint /* System.IntPtr */ ptr, int /* System.Int32 */ len, void** /* System.Exception */ __outException)
	{
	
	    try {
			System.String __returnValue = System.Runtime.InteropServices.Marshal.PtrToStringAuto(ptr, len);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_InteropServices_Marshal_PtrToStringAuto_1")]
	internal static void* /* System.String */ System_Runtime_InteropServices_Marshal_PtrToStringAuto_1(nint /* System.IntPtr */ ptr, void** /* System.Exception */ __outException)
	{
	
	    try {
			System.String __returnValue = System.Runtime.InteropServices.Marshal.PtrToStringAuto(ptr);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_InteropServices_Marshal_StringToHGlobalAuto")]
	internal static nint /* System.IntPtr */ System_Runtime_InteropServices_Marshal_StringToHGlobalAuto(void* /* System.String */ s, void** /* System.Exception */ __outException)
	{
		System.String sConverted = InteropUtils.GetInstance<System.String>(s);
	
	    try {
			System.IntPtr __returnValue = System.Runtime.InteropServices.Marshal.StringToHGlobalAuto(sConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return nint.Zero;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_InteropServices_Marshal_StringToCoTaskMemAuto")]
	internal static nint /* System.IntPtr */ System_Runtime_InteropServices_Marshal_StringToCoTaskMemAuto(void* /* System.String */ s, void** /* System.Exception */ __outException)
	{
		System.String sConverted = InteropUtils.GetInstance<System.String>(s);
	
	    try {
			System.IntPtr __returnValue = System.Runtime.InteropServices.Marshal.StringToCoTaskMemAuto(sConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return nint.Zero;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_InteropServices_Marshal_AllocHGlobal_1")]
	internal static nint /* System.IntPtr */ System_Runtime_InteropServices_Marshal_AllocHGlobal_1(nint /* System.IntPtr */ cb, void** /* System.Exception */ __outException)
	{
	
	    try {
			System.IntPtr __returnValue = System.Runtime.InteropServices.Marshal.AllocHGlobal(cb);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return nint.Zero;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_InteropServices_Marshal_FreeHGlobal")]
	internal static void /* System.Void */ System_Runtime_InteropServices_Marshal_FreeHGlobal(nint /* System.IntPtr */ hglobal, void** /* System.Exception */ __outException)
	{
	
	    try {
			System.Runtime.InteropServices.Marshal.FreeHGlobal(hglobal);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_InteropServices_Marshal_ReAllocHGlobal")]
	internal static nint /* System.IntPtr */ System_Runtime_InteropServices_Marshal_ReAllocHGlobal(nint /* System.IntPtr */ pv, nint /* System.IntPtr */ cb, void** /* System.Exception */ __outException)
	{
	
	    try {
			System.IntPtr __returnValue = System.Runtime.InteropServices.Marshal.ReAllocHGlobal(pv, cb);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return nint.Zero;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_InteropServices_Marshal_AllocCoTaskMem")]
	internal static nint /* System.IntPtr */ System_Runtime_InteropServices_Marshal_AllocCoTaskMem(int /* System.Int32 */ cb, void** /* System.Exception */ __outException)
	{
	
	    try {
			System.IntPtr __returnValue = System.Runtime.InteropServices.Marshal.AllocCoTaskMem(cb);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return nint.Zero;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_InteropServices_Marshal_FreeCoTaskMem")]
	internal static void /* System.Void */ System_Runtime_InteropServices_Marshal_FreeCoTaskMem(nint /* System.IntPtr */ ptr, void** /* System.Exception */ __outException)
	{
	
	    try {
			System.Runtime.InteropServices.Marshal.FreeCoTaskMem(ptr);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_InteropServices_Marshal_ReAllocCoTaskMem")]
	internal static nint /* System.IntPtr */ System_Runtime_InteropServices_Marshal_ReAllocCoTaskMem(nint /* System.IntPtr */ pv, int /* System.Int32 */ cb, void** /* System.Exception */ __outException)
	{
	
	    try {
			System.IntPtr __returnValue = System.Runtime.InteropServices.Marshal.ReAllocCoTaskMem(pv, cb);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return nint.Zero;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_InteropServices_Marshal_FreeBSTR")]
	internal static void /* System.Void */ System_Runtime_InteropServices_Marshal_FreeBSTR(nint /* System.IntPtr */ ptr, void** /* System.Exception */ __outException)
	{
	
	    try {
			System.Runtime.InteropServices.Marshal.FreeBSTR(ptr);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_InteropServices_Marshal_GetLastSystemError")]
	internal static int /* System.Int32 */ System_Runtime_InteropServices_Marshal_GetLastSystemError(void** /* System.Exception */ __outException)
	{
	
	    try {
			System.Int32 __returnValue = System.Runtime.InteropServices.Marshal.GetLastSystemError();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_InteropServices_Marshal_SetLastSystemError")]
	internal static void /* System.Void */ System_Runtime_InteropServices_Marshal_SetLastSystemError(int /* System.Int32 */ error, void** /* System.Exception */ __outException)
	{
	
	    try {
			System.Runtime.InteropServices.Marshal.SetLastSystemError(error);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_InteropServices_Marshal_GetPInvokeErrorMessage")]
	internal static void* /* System.String */ System_Runtime_InteropServices_Marshal_GetPInvokeErrorMessage(int /* System.Int32 */ error, void** /* System.Exception */ __outException)
	{
	
	    try {
			System.String __returnValue = System.Runtime.InteropServices.Marshal.GetPInvokeErrorMessage(error);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_InteropServices_Marshal_SystemDefaultCharSize_Get")]
	internal static int /* System.Int32 */ System_Runtime_InteropServices_Marshal_SystemDefaultCharSize_Get()
	{
	
		System.Int32 __returnValue = System.Runtime.InteropServices.Marshal.SystemDefaultCharSize;
		return __returnValue;
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_InteropServices_Marshal_SystemMaxDBCSCharSize_Get")]
	internal static int /* System.Int32 */ System_Runtime_InteropServices_Marshal_SystemMaxDBCSCharSize_Get()
	{
	
		System.Int32 __returnValue = System.Runtime.InteropServices.Marshal.SystemMaxDBCSCharSize;
		return __returnValue;
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_InteropServices_Marshal_TypeOf")]
	internal static void* /* System.Type */ System_Runtime_InteropServices_Marshal_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.Runtime.InteropServices.Marshal);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_InteropServices_Marshal_Destroy_1")]
	internal static void /* System.Void */ System_Runtime_InteropServices_Marshal_Destroy_1(void* /* System.Runtime.InteropServices.Marshal */ __self)
	{
	
		InteropUtils.FreeIfAllocated(__self);
	}
	
}







internal unsafe class System_Security_SecureString
{
	[UnmanagedCallersOnly(EntryPoint = "System_Security_SecureString_AppendChar")]
	internal static void /* System.Void */ System_Security_SecureString_AppendChar(void* /* System.Security.SecureString */ __self, char /* System.Char */ c, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Security.SecureString __selfConverted = InteropUtils.GetInstance<System.Security.SecureString>(__self);
	
	
	    try {
			__selfConverted.AppendChar(c);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Security_SecureString_Clear")]
	internal static void /* System.Void */ System_Security_SecureString_Clear(void* /* System.Security.SecureString */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Security.SecureString __selfConverted = InteropUtils.GetInstance<System.Security.SecureString>(__self);
	
	
	    try {
			__selfConverted.Clear();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Security_SecureString_Copy")]
	internal static void* /* System.Security.SecureString */ System_Security_SecureString_Copy(void* /* System.Security.SecureString */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Security.SecureString __selfConverted = InteropUtils.GetInstance<System.Security.SecureString>(__self);
	
	
	    try {
			System.Security.SecureString __returnValue = __selfConverted.Copy();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Security_SecureString_Dispose")]
	internal static void /* System.Void */ System_Security_SecureString_Dispose(void* /* System.Security.SecureString */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Security.SecureString __selfConverted = InteropUtils.GetInstance<System.Security.SecureString>(__self);
	
	
	    try {
			__selfConverted.Dispose();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Security_SecureString_InsertAt")]
	internal static void /* System.Void */ System_Security_SecureString_InsertAt(void* /* System.Security.SecureString */ __self, int /* System.Int32 */ index, char /* System.Char */ c, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Security.SecureString __selfConverted = InteropUtils.GetInstance<System.Security.SecureString>(__self);
	
	
	    try {
			__selfConverted.InsertAt(index, c);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Security_SecureString_IsReadOnly")]
	internal static byte /* System.Boolean */ System_Security_SecureString_IsReadOnly(void* /* System.Security.SecureString */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Security.SecureString __selfConverted = InteropUtils.GetInstance<System.Security.SecureString>(__self);
	
	
	    try {
			System.Boolean __returnValue = __selfConverted.IsReadOnly();
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Security_SecureString_MakeReadOnly")]
	internal static void /* System.Void */ System_Security_SecureString_MakeReadOnly(void* /* System.Security.SecureString */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Security.SecureString __selfConverted = InteropUtils.GetInstance<System.Security.SecureString>(__self);
	
	
	    try {
			__selfConverted.MakeReadOnly();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Security_SecureString_RemoveAt")]
	internal static void /* System.Void */ System_Security_SecureString_RemoveAt(void* /* System.Security.SecureString */ __self, int /* System.Int32 */ index, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Security.SecureString __selfConverted = InteropUtils.GetInstance<System.Security.SecureString>(__self);
	
	
	    try {
			__selfConverted.RemoveAt(index);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Security_SecureString_SetAt")]
	internal static void /* System.Void */ System_Security_SecureString_SetAt(void* /* System.Security.SecureString */ __self, int /* System.Int32 */ index, char /* System.Char */ c, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Security.SecureString __selfConverted = InteropUtils.GetInstance<System.Security.SecureString>(__self);
	
	
	    try {
			__selfConverted.SetAt(index, c);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Security_SecureString_Create")]
	internal static void* /* System.Security.SecureString */ System_Security_SecureString_Create(void** /* System.Exception */ __outException)
	{
	
	    try {
			System.Security.SecureString __returnValue = new System.Security.SecureString();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Security_SecureString_Length_Get")]
	internal static int /* System.Int32 */ System_Security_SecureString_Length_Get(void* /* System.Security.SecureString */ __self, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		System.Security.SecureString __selfConverted = InteropUtils.GetInstance<System.Security.SecureString>(__self);
	
	
	    try {
			System.Int32 __returnValue = __selfConverted.Length;
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_Security_SecureString_TypeOf")]
	internal static void* /* System.Type */ System_Security_SecureString_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.Security.SecureString);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_Security_SecureString_Destroy")]
	internal static void /* System.Void */ System_Security_SecureString_Destroy(void* /* System.Security.SecureString */ __self)
	{
	
		InteropUtils.FreeIfAllocated(__self);
	}
	
}


internal unsafe class System_Runtime_InteropServices_CustomQueryInterfaceMode
{
	[UnmanagedCallersOnly(EntryPoint = "System_Runtime_InteropServices_CustomQueryInterfaceMode_TypeOf")]
	internal static void* /* System.Type */ System_Runtime_InteropServices_CustomQueryInterfaceMode_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.Runtime.InteropServices.CustomQueryInterfaceMode);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
}



internal unsafe class System_NullReferenceException
{
	[UnmanagedCallersOnly(EntryPoint = "System_NullReferenceException_Create")]
	internal static void* /* System.NullReferenceException */ System_NullReferenceException_Create(void** /* System.Exception */ __outException)
	{
	
	    try {
			System.NullReferenceException __returnValue = new System.NullReferenceException();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_NullReferenceException_Create_1")]
	internal static void* /* System.NullReferenceException */ System_NullReferenceException_Create_1(void* /* System.String */ message, void** /* System.Exception */ __outException)
	{
		System.String messageConverted = InteropUtils.GetInstance<System.String>(message);
	
	    try {
			System.NullReferenceException __returnValue = new System.NullReferenceException(messageConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_NullReferenceException_Create_2")]
	internal static void* /* System.NullReferenceException */ System_NullReferenceException_Create_2(void* /* System.String */ message, void* /* System.Exception */ innerException, void** /* System.Exception */ __outException)
	{
		System.String messageConverted = InteropUtils.GetInstance<System.String>(message);
		System.Exception innerExceptionConverted = InteropUtils.GetInstance<System.Exception>(innerException);
	
	    try {
			System.NullReferenceException __returnValue = new System.NullReferenceException(messageConverted, innerExceptionConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_NullReferenceException_TypeOf")]
	internal static void* /* System.Type */ System_NullReferenceException_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.NullReferenceException);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_NullReferenceException_Destroy")]
	internal static void /* System.Void */ System_NullReferenceException_Destroy(void* /* System.NullReferenceException */ __self)
	{
	
		InteropUtils.FreeIfAllocated(__self);
	}
	
}


internal unsafe class System_SystemException
{
	[UnmanagedCallersOnly(EntryPoint = "System_SystemException_Create")]
	internal static void* /* System.SystemException */ System_SystemException_Create(void** /* System.Exception */ __outException)
	{
	
	    try {
			System.SystemException __returnValue = new System.SystemException();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_SystemException_Create_1")]
	internal static void* /* System.SystemException */ System_SystemException_Create_1(void* /* System.String */ message, void** /* System.Exception */ __outException)
	{
		System.String messageConverted = InteropUtils.GetInstance<System.String>(message);
	
	    try {
			System.SystemException __returnValue = new System.SystemException(messageConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_SystemException_Create_2")]
	internal static void* /* System.SystemException */ System_SystemException_Create_2(void* /* System.String */ message, void* /* System.Exception */ innerException, void** /* System.Exception */ __outException)
	{
		System.String messageConverted = InteropUtils.GetInstance<System.String>(message);
		System.Exception innerExceptionConverted = InteropUtils.GetInstance<System.Exception>(innerException);
	
	    try {
			System.SystemException __returnValue = new System.SystemException(messageConverted, innerExceptionConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_SystemException_TypeOf")]
	internal static void* /* System.Type */ System_SystemException_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.SystemException);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_SystemException_Destroy")]
	internal static void /* System.Void */ System_SystemException_Destroy(void* /* System.SystemException */ __self)
	{
	
		InteropUtils.FreeIfAllocated(__self);
	}
	
}


internal unsafe class System_PlatformNotSupportedException
{
	[UnmanagedCallersOnly(EntryPoint = "System_PlatformNotSupportedException_Create")]
	internal static void* /* System.PlatformNotSupportedException */ System_PlatformNotSupportedException_Create(void** /* System.Exception */ __outException)
	{
	
	    try {
			System.PlatformNotSupportedException __returnValue = new System.PlatformNotSupportedException();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_PlatformNotSupportedException_Create_1")]
	internal static void* /* System.PlatformNotSupportedException */ System_PlatformNotSupportedException_Create_1(void* /* System.String */ message, void** /* System.Exception */ __outException)
	{
		System.String messageConverted = InteropUtils.GetInstance<System.String>(message);
	
	    try {
			System.PlatformNotSupportedException __returnValue = new System.PlatformNotSupportedException(messageConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_PlatformNotSupportedException_Create_2")]
	internal static void* /* System.PlatformNotSupportedException */ System_PlatformNotSupportedException_Create_2(void* /* System.String */ message, void* /* System.Exception */ inner, void** /* System.Exception */ __outException)
	{
		System.String messageConverted = InteropUtils.GetInstance<System.String>(message);
		System.Exception innerConverted = InteropUtils.GetInstance<System.Exception>(inner);
	
	    try {
			System.PlatformNotSupportedException __returnValue = new System.PlatformNotSupportedException(messageConverted, innerConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_PlatformNotSupportedException_TypeOf")]
	internal static void* /* System.Type */ System_PlatformNotSupportedException_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.PlatformNotSupportedException);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_PlatformNotSupportedException_Destroy")]
	internal static void /* System.Void */ System_PlatformNotSupportedException_Destroy(void* /* System.PlatformNotSupportedException */ __self)
	{
	
		InteropUtils.FreeIfAllocated(__self);
	}
	
}


internal unsafe class System_NotSupportedException
{
	[UnmanagedCallersOnly(EntryPoint = "System_NotSupportedException_Create")]
	internal static void* /* System.NotSupportedException */ System_NotSupportedException_Create(void** /* System.Exception */ __outException)
	{
	
	    try {
			System.NotSupportedException __returnValue = new System.NotSupportedException();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_NotSupportedException_Create_1")]
	internal static void* /* System.NotSupportedException */ System_NotSupportedException_Create_1(void* /* System.String */ message, void** /* System.Exception */ __outException)
	{
		System.String messageConverted = InteropUtils.GetInstance<System.String>(message);
	
	    try {
			System.NotSupportedException __returnValue = new System.NotSupportedException(messageConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_NotSupportedException_Create_2")]
	internal static void* /* System.NotSupportedException */ System_NotSupportedException_Create_2(void* /* System.String */ message, void* /* System.Exception */ innerException, void** /* System.Exception */ __outException)
	{
		System.String messageConverted = InteropUtils.GetInstance<System.String>(message);
		System.Exception innerExceptionConverted = InteropUtils.GetInstance<System.Exception>(innerException);
	
	    try {
			System.NotSupportedException __returnValue = new System.NotSupportedException(messageConverted, innerExceptionConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_NotSupportedException_TypeOf")]
	internal static void* /* System.Type */ System_NotSupportedException_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.NotSupportedException);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_NotSupportedException_Destroy")]
	internal static void /* System.Void */ System_NotSupportedException_Destroy(void* /* System.NotSupportedException */ __self)
	{
	
		InteropUtils.FreeIfAllocated(__self);
	}
	
}


internal unsafe class System_UIntPtr
{
	[UnmanagedCallersOnly(EntryPoint = "System_UIntPtr_TypeOf")]
	internal static void* /* System.Type */ System_UIntPtr_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.UIntPtr);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
}



internal unsafe class System_AppContext
{
	[UnmanagedCallersOnly(EntryPoint = "System_AppContext_GetData")]
	internal static void* /* System.Object */ System_AppContext_GetData(void* /* System.String */ name, void** /* System.Exception */ __outException)
	{
		System.String nameConverted = InteropUtils.GetInstance<System.String>(name);
	
	    try {
			System.Object __returnValue = System.AppContext.GetData(nameConverted);
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_AppContext_SetData")]
	internal static void /* System.Void */ System_AppContext_SetData(void* /* System.String */ name, void* /* System.Object */ data, void** /* System.Exception */ __outException)
	{
		System.String nameConverted = InteropUtils.GetInstance<System.String>(name);
		System.Object dataConverted = InteropUtils.GetInstance<System.Object>(data);
	
	    try {
			System.AppContext.SetData(nameConverted, dataConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_AppContext_TryGetSwitch")]
	internal static byte /* System.Boolean */ System_AppContext_TryGetSwitch(void* /* System.String */ switchName, byte* /* System.Boolean */ isEnabled, void** /* System.Exception */ __outException)
	{
		System.String switchNameConverted = InteropUtils.GetInstance<System.String>(switchName);
		System.Boolean isEnabledConverted;
	
	    try {
			System.Boolean __returnValue = System.AppContext.TryGetSwitch(switchNameConverted, out isEnabledConverted);
			byte __returnValueNative = __returnValue.ToCBool();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			if (isEnabled is not null) {
				*isEnabled = isEnabledConverted.ToCBool();
			}
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			if (isEnabled is not null) {
				*isEnabled = 0;
			}
	
			return 0;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_AppContext_SetSwitch")]
	internal static void /* System.Void */ System_AppContext_SetSwitch(void* /* System.String */ switchName, byte /* System.Boolean */ isEnabled, void** /* System.Exception */ __outException)
	{
		System.String switchNameConverted = InteropUtils.GetInstance<System.String>(switchName);
		System.Boolean isEnabledConverted = isEnabled.ToBool();
	
	    try {
			System.AppContext.SetSwitch(switchNameConverted, isEnabledConverted);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_AppContext_BaseDirectory_Get")]
	internal static void* /* System.String */ System_AppContext_BaseDirectory_Get(void** /* System.Exception */ __outException)
	{
	
	    try {
			System.String __returnValue = System.AppContext.BaseDirectory;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_AppContext_TargetFrameworkName_Get")]
	internal static void* /* System.String */ System_AppContext_TargetFrameworkName_Get(void** /* System.Exception */ __outException)
	{
	
	    try {
			System.String __returnValue = System.AppContext.TargetFrameworkName;
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	
	[UnmanagedCallersOnly(EntryPoint = "System_AppContext_TypeOf")]
	internal static void* /* System.Type */ System_AppContext_TypeOf()
	{
	
		System.Type __returnValue = typeof(System.AppContext);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
	[UnmanagedCallersOnly(EntryPoint = "System_AppContext_Destroy")]
	internal static void /* System.Void */ System_AppContext_Destroy(void* /* System.AppContext */ __self)
	{
	
		InteropUtils.FreeIfAllocated(__self);
	}
	
}


internal unsafe class MyLib_Hello
{
	[UnmanagedCallersOnly(EntryPoint = "MyLib_Hello_Sum")]
	internal static int /* System.Int32 */ MyLib_Hello_Sum(void* /* MyLib.Hello */ __self, int /* System.Int32 */ a, int /* System.Int32 */ b, void** /* System.Exception */ __outException)
	{
		if (__self is null) {
			throw new ArgumentNullException(nameof(__self));
		}
	
		MyLib.Hello __selfConverted = InteropUtils.GetInstance<MyLib.Hello>(__self);
	
	
	    try {
			System.Int32 __returnValue = __selfConverted.Sum(a, b);
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValue;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return -1;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "MyLib_Hello_Create")]
	internal static void* /* MyLib.Hello */ MyLib_Hello_Create(void** /* System.Exception */ __outException)
	{
	
	    try {
			MyLib.Hello __returnValue = new MyLib.Hello();
			void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
	
	        if (__outException is not null) {
	            *__outException = null;
	        }
	
			return __returnValueNative;
	    } catch (Exception __exception) {
	        if (__outException is not null) {
	            void* __exceptionHandleAddress = __exception.AllocateGCHandleAndGetAddress();
	                
	            *__outException = __exceptionHandleAddress;
	        }
	
			return null;
		} finally {
		}
	}
	
	[UnmanagedCallersOnly(EntryPoint = "MyLib_Hello_TypeOf")]
	internal static void* /* System.Type */ MyLib_Hello_TypeOf()
	{
	
		System.Type __returnValue = typeof(MyLib.Hello);
		void* __returnValueNative = __returnValue.AllocateGCHandleAndGetAddress();
		return __returnValueNative;
	}
	
	[UnmanagedCallersOnly(EntryPoint = "MyLib_Hello_Destroy")]
	internal static void /* System.Void */ MyLib_Hello_Destroy(void* /* MyLib.Hello */ __self)
	{
	
		InteropUtils.FreeIfAllocated(__self);
	}
	
}



// </APIs>
